@@ -1,17 +1,9 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 Development script of the ChemEnv utility to get the explicit permutations for coordination environments identified
 with the explicit permutations algorithms (typically with coordination numbers <= 6)
 """
 
-__author__ = "David Waroquiers"
-__copyright__ = "Copyright 2012, The Materials Project"
-__version__ = "2.0"
-__maintainer__ = "David Waroquiers"
-__email__ = "david.waroquiers@gmail.com"
-__date__ = "Feb 20, 2016"
+from __future__ import annotations
 
 import itertools
 import json
@@ -28,13 +20,19 @@ from pymatgen.analysis.chemenv.coordination_environments.coordination_geometry_f
     LocalGeometryFinder,
 )
 
+__author__ = "David Waroquiers"
+__copyright__ = "Copyright 2012, The Materials Project"
+__version__ = "2.0"
+__maintainer__ = "David Waroquiers"
+__email__ = "david.waroquiers@gmail.com"
+__date__ = "Feb 20, 2016"
+
 
 class Algo:
     pass
 
 
 if __name__ == "__main__":
-
     # Choose the geometry
     allcg = AllCoordinationGeometries()
     while True:
@@ -63,12 +61,11 @@ if __name__ == "__main__":
     lgf.perfect_geometry = AbstractGeometry.from_cg(cg=cg)
 
     points_perfect = lgf.perfect_geometry.points_wocs_ctwocc()
-    res = lgf.coordination_geometry_symmetry_measures_standard(
+    csms, perms, algos, local2perfect_maps, perfect2local_maps = lgf.coordination_geometry_symmetry_measures_standard(
         coordination_geometry=cg, algo=algo, points_perfect=points_perfect
     )
-    (csms, perms, algos, local2perfect_maps, perfect2local_maps) = res
 
-    csms_with_recorded_permutation = []
+    csms_with_recorded_permutation: list[float] = []
     explicit_permutations = []
     for icsm, csm in enumerate(csms):
         found = False
