@@ -1,11 +1,10 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 Development script of the ChemEnv utility to get the optimized explicit permutations for coordination environments
 identified with the separation plane algorithms (typically with coordination numbers >= 6)
 """
 
+from __future__ import annotations
+
 import itertools
 import json
 import os
@@ -17,9 +16,7 @@ from random import shuffle
 import numpy as np
 import tabulate
 
-from pymatgen.analysis.chemenv.coordination_environments.coordination_geometries import (
-    AllCoordinationGeometries,
-)
+from pymatgen.analysis.chemenv.coordination_environments.coordination_geometries import AllCoordinationGeometries
 from pymatgen.analysis.chemenv.coordination_environments.coordination_geometry_finder import (
     AbstractGeometry,
     LocalGeometryFinder,
@@ -46,8 +43,15 @@ def prt2(string, printing_volume):
 
 
 # Iterator function for the random permutations
-def random_permutations_iterator(initial_permutation, npermutations):
-    for _ in range(npermutations):
+def random_permutations_iterator(initial_permutation, n_permutations):
+    """
+    It takes a list and returns an iterator that yields random permutations of that list
+
+    Args:
+        initial_permutation: the initial permutation of the data
+        n_permutations: the number of permutations to generate
+    """
+    for _ in range(n_permutations):
         shuffle(initial_permutation)
         yield initial_permutation
 
@@ -82,33 +86,33 @@ if __name__ == "__main__":
         "which case all possible permutations are used",
         dest="permutations_setup",
     )
-    (options, args) = option_parser.parse_args()
+    options, args = option_parser.parse_args()
 
     # Get the printing volume and permutations setup options
     printing_volume = options.printing_volume
     permutations_setup = options.permutations_setup
-    nperm_factor = None
+    n_perm_factor = None
     if permutations_setup == "all":
         permutations_setup_type = "all"
-        npermutations = None
+        n_permutations = None
     elif permutations_setup[0] == "x":
         permutations_setup_type = "x"
-        npermutations = None
+        n_permutations = None
         try:
-            nperm_factor = int(permutations_setup[1:])
+            n_perm_factor = int(permutations_setup[1:])
         except Exception:
             raise ValueError("Wrong command line option for permutations_setup")
     elif permutations_setup[0] == "y":
         permutations_setup_type = "y"
-        npermutations = None
+        n_permutations = None
         try:
-            nperm_factor = int(permutations_setup[1:])
+            n_perm_factor = int(permutations_setup[1:])
         except Exception:
             raise ValueError("Wrong command line option for permutations_setup")
     else:
         permutations_setup_type = "n"
         try:
-            npermutations = int(permutations_setup)
+            n_permutations = int(permutations_setup)
         except Exception:
             raise ValueError("Wrong command line option for permutations_setup")
 
@@ -125,17 +129,17 @@ if __name__ == "__main__":
             if cg.algorithms[0].algorithm_type != "EXPLICIT_PERMUTATIONS":
                 sep_plane_cgs.append(symbol)
                 continue
-    ncols = 5
-    nlines = int(np.ceil(float(len(sep_plane_cgs)) / ncols))
+    n_cols = 5
+    n_lines = int(np.ceil(float(len(sep_plane_cgs)) / n_cols))
     sep_plane_cgs_grid = []
-    for _ in range(nlines):
-        sep_plane_cgs_grid.append([""] * ncols)
-    for iline in range(nlines):
-        for icol in range(ncols):
-            ii = iline * ncols + icol
+    for _ in range(n_lines):
+        sep_plane_cgs_grid.append([""] * n_cols)
+    for line_idx in range(n_lines):
+        for col_idx in range(n_cols):
+            ii = line_idx * n_cols + col_idx
             if ii >= len(sep_plane_cgs):
                 break
-            sep_plane_cgs_grid[iline][icol] = sep_plane_cgs[ii]
+            sep_plane_cgs_grid[line_idx][col_idx] = sep_plane_cgs[ii]
 
     while True:
         # Printing all symbols
@@ -145,7 +149,7 @@ if __name__ == "__main__":
 
         # Define the coordination geometry
         cg_symbol = input(
-            "Enter symbol of the geometry for which you want to get the optimized permutations " 'or "q" to quit : '
+            'Enter symbol of the geometry for which you want to get the optimized permutations or "q" to quit : '
         )
         if cg_symbol == "q":
             break
@@ -155,7 +159,7 @@ if __name__ == "__main__":
 
         cg = all_cg[cg_symbol]
 
-        print(f'Getting explicit permutations for geometry "{cg.name}" (symbol : "{cg_symbol}")\n')
+        print(f"Getting explicit permutations for geometry {cg.name!r} (symbol : {cg_symbol!r})\n")
 
         # Setup of the local geometry finder
         lgf = LocalGeometryFinder()
@@ -169,8 +173,8 @@ if __name__ == "__main__":
         points_perfect = lgf.perfect_geometry.points_wcs_ctwcc()
 
         # 1. Check the algorithms defined for this coordination geometry and get the explicit permutations
-        original_nexplicit_perms = []
-        original_nexplicit_optimized_perms = []
+        original_n_explicit_perms = []
+        original_n_explicit_optimized_perms = []
         for ialgo, algo in enumerate(cg.algorithms):
             algo._permutations = algo.explicit_permutations
             algo.minimum_number_of_points = 4
@@ -186,8 +190,8 @@ if __name__ == "__main__":
                 f"side_0 is [{', '.join(map(str, algo.point_groups[0]))}] and "
                 f"side_1 is [{', '.join(map(str, algo.point_groups[1]))}]."
             )
-            original_nexplicit_perms.append(len(algo.explicit_permutations))
-            original_nexplicit_optimized_perms.append(eop)
+            original_n_explicit_perms.append(len(algo.explicit_permutations))
+            original_n_explicit_optimized_perms.append(eop)
             print(
                 f"  For this algorithm, there are {eop} optimized permutations and "
                 f"{len(algo.explicit_permutations):d} explicit permutations"
@@ -229,10 +233,10 @@ if __name__ == "__main__":
                     points_perfect=points_perfect,
                 )
 
-                mycsms = [c["symmetry_measure"] for c in csms]
+                my_csms = [c["symmetry_measure"] for c in csms]
                 prt1(string="Continuous symmetry measures", printing_volume=printing_volume)
-                prt1(string=mycsms, printing_volume=printing_volume)
-                csms_with_recorded_permutation = []
+                prt1(string=my_csms, printing_volume=printing_volume)
+                csms_with_recorded_permutation = []  # type: ignore
                 explicit_permutations = []
                 for icsm, csm in enumerate(csms):
                     found = False
@@ -272,8 +276,8 @@ if __name__ == "__main__":
 
         while True:
             test = input(
-                f'Get the explicit optimized permutations for geometry "{cg.name}" (symbol : '
-                f'"{cg_symbol}") ? ("y" to confirm, "q" to quit)\n'
+                f"Get the explicit optimized permutations for geometry {cg.name!r} (symbol : "
+                f'{cg_symbol!r}) ? ("y" to confirm, "q" to quit)\n'
             )
             if test not in ["y", "q"]:
                 print("Wrong key, try again")
@@ -281,14 +285,14 @@ if __name__ == "__main__":
             if test == "y":
                 break
             elif test == "q":
-                exit()
+                raise SystemExit(0)
         # 2. Optimization of the permutations
-        print(f'Getting explicit optimized permutations for geometry "{cg.name}" (symbol : "{cg_symbol}")\n')
-        perms_used_algos = [dict() for algo in cg.algorithms]
+        print(f"Getting explicit optimized permutations for geometry {cg.name!r} (symbol : {cg_symbol!r})\n")
+        perms_used_algos: list[dict] = [{} for _ in cg.algorithms]
 
         # Loop on algorithms
         for ialgo, algo in enumerate(cg.algorithms):
-            perms_used = {}
+            perms_used: dict[tuple, int] = {}
             print(
                 f"In ialgo {ialgo:d} (plane_points : "
                 f"[{', '.join(map(str, algo.plane_points))}], "
@@ -305,26 +309,26 @@ if __name__ == "__main__":
 
             # Setup of the permutations to be used for this algorithm
 
-            myindices = list(range(cg.coordination_number))
+            indices = list(range(cg.coordination_number))
             if permutations_setup_type == "all":
-                perms_iterator = itertools.permutations(myindices)
-                npermutations = factorial(cg.coordination_number)
+                perms_iterator = itertools.permutations(indices)
+                n_permutations = factorial(cg.coordination_number)
             elif permutations_setup_type == "n":
-                if npermutations >= factorial(cg.coordination_number):
-                    perms_iterator = itertools.permutations(myindices)
-                    npermutations = factorial(cg.coordination_number)
+                if n_permutations and n_permutations >= factorial(cg.coordination_number):
+                    perms_iterator = itertools.permutations(indices)
+                    n_permutations = factorial(cg.coordination_number)
                 else:
                     perms_iterator = random_permutations_iterator(
-                        initial_permutation=myindices, npermutations=npermutations
+                        initial_permutation=indices, n_permutations=n_permutations
                     )
-            elif permutations_setup_type in ["x", "y"]:
-                npermutations = nperm_factor * len(algo.explicit_permutations)
-                if permutations_setup_type == "y" and npermutations >= factorial(cg.coordination_number):
-                    perms_iterator = itertools.permutations(myindices)
-                    npermutations = factorial(cg.coordination_number)
+            elif permutations_setup_type in ["x", "y"] and n_perm_factor:
+                n_permutations = n_perm_factor * len(algo.explicit_permutations)
+                if permutations_setup_type == "y" and n_permutations >= factorial(cg.coordination_number):
+                    perms_iterator = itertools.permutations(indices)
+                    n_permutations = factorial(cg.coordination_number)
                 else:
                     perms_iterator = random_permutations_iterator(
-                        initial_permutation=myindices, npermutations=npermutations
+                        initial_permutation=indices, n_permutations=n_permutations
                     )
             else:
                 raise ValueError("Permutation setup not allowed ...")
@@ -332,13 +336,12 @@ if __name__ == "__main__":
             # Loop on permutations
             iperm = 1
             t0 = time.process_time()
-            timeleft = "Unknown"
+            time_left: float | str = "Unknown"
             for indices_perm in perms_iterator:
-
                 prt1(
-                    string=f"Perm # {iperm:d}/{npermutations:d} : "
+                    string=f"Perm # {iperm:d}/{n_permutations:d} : "
                     f"{'-'.join(map(str, indices_perm))} "
-                    f"(est. rem. time : {timeleft} sec)",
+                    f"(est. rem. time : {time_left} sec)",
                     printing_volume=printing_volume,
                 )
                 # Setup of the local and perfect geometries
@@ -349,7 +352,7 @@ if __name__ == "__main__":
                 points_perfect = lgf.perfect_geometry.points_wcs_ctwcc()
 
                 # Loop on the facets
-                separation_permutations = list()
+                separation_permutations = []
                 for iplane, plane_point_indices in enumerate(all_planes_point_indices):
                     prt2(
                         string=f"In plane {iplane:d} ({'-'.join(str(pp) for pp in plane_point_indices)})",
@@ -373,19 +376,19 @@ if __name__ == "__main__":
                         points_perfect=points_perfect,
                     )
 
-                    mycsms = [c["symmetry_measure"] for c in csms]
-                    imin = np.argmin(mycsms)
-                    mincsm = min(mycsms)
+                    my_csms = [c["symmetry_measure"] for c in csms]
+                    imin = np.argmin(my_csms)
+                    mincsm = min(my_csms)
                     if not mincsm < 1.0:
-                        print("Following is not close enough to 0.0 ...")
-                        input(mycsms)
+                        print("Following is not close enough to 0 ...")
+                        input(my_csms)
                     mincsm_indices = []
-                    for icsm, csm in enumerate(mycsms):
+                    for icsm, csm in enumerate(my_csms):
                         if np.isclose(mincsm, csm, rtol=0.0):
                             mincsm_indices.append(icsm)
                     this_plane_sep_perm = tuple(sep_perms[imin])
                     prt2(
-                        string=f"  permutation {'-'.join(map(str, this_plane_sep_perm))} gives csm={mycsms[imin]:.6f}",
+                        string=f"  permutation {'-'.join(map(str, this_plane_sep_perm))} gives csm={my_csms[imin]:.6f}",
                         printing_volume=printing_volume,
                     )
 
@@ -396,23 +399,23 @@ if __name__ == "__main__":
                     else:
                         perms_used[some_perm] = 1
                 tcurrent = time.process_time()
-                timeleft = (npermutations - iperm) * (tcurrent - t0) / iperm
-                timeleft = f"{timeleft:.1f}"
+                time_left = (n_permutations - iperm) * (tcurrent - t0) / iperm  # type: ignore
+                time_left = f"{time_left:.1f}"
                 iperm += 1
             print(
                 f"Optimized permutations {len(perms_used):d}/{len(algo.permutations):d}"
-                f"(old : {original_nexplicit_optimized_perms[ialgo]}/{original_nexplicit_perms[ialgo]}) : "
+                f"(old : {original_n_explicit_optimized_perms[ialgo]}/{original_n_explicit_perms[ialgo]}) : "
             )
             for perm, number in perms_used.items():
                 print(f" - permutation {'-'.join(map(str, perm))} : {number:d}")
             print(
-                f"For ialgo {ialgo} (plane_points : [{', '.join(map(str, algo.plane_points))}], "
+                f"For {ialgo=} (plane_points : [{', '.join(map(str, algo.plane_points))}], "
                 f"side_0 : [{', '.join(map(str, algo.point_groups[0]))}] and "
                 f"side_1 : [{', '.join(map(str, algo.point_groups[1]))}]),\n"
                 f"Optimized perturbations {len(perms_used)}/{len(algo.permutations)} (old : "
-                f"{original_nexplicit_optimized_perms[ialgo]}/{original_nexplicit_perms[ialgo]}) are :"
+                f"{original_n_explicit_optimized_perms[ialgo]}/{original_n_explicit_perms[ialgo]}) are :"
             )
-            # print('Optimized permutations ({:d}/{:d}) : '.format(len(perms_used), len(algo.permutations)))
+            # print(f"Optimized permutations ({len(perms_used):d}/{len(algo.permutations):d}) : ")
             explicit_optimized_permutations = [list(perm) for perm in perms_used]
             explicit_optimized_permutations.sort()
             print(explicit_optimized_permutations)
@@ -422,12 +425,12 @@ if __name__ == "__main__":
                 algo.explicit_optimized_permutations = np.array(explicit_optimized_permutations)
 
         test = input(
-            f'Save coordination geometry "{cg.name}" (symbol "{cg_symbol}") and new explicit and optimized '
+            f"Save coordination geometry {cg.name!r} (symbol {cg_symbol!r}) and new explicit and optimized "
             'permutations ? ("y" to confirm)'
         )
         if test == "y":
-            newgeom_dir = "new_geometry_files"
-            if not os.path.exists(newgeom_dir):
-                os.makedirs(newgeom_dir)
-            with open(f"{newgeom_dir}/{cg_symbol}.json", "w") as f:
-                json.dump(cg.as_dict(), f)
+            new_geom_dir = "new_geometry_files"
+            if not os.path.exists(new_geom_dir):
+                os.makedirs(new_geom_dir)
+            with open(f"{new_geom_dir}/{cg_symbol}.json", "w") as file:
+                json.dump(cg.as_dict(), file)
