@@ -1,10 +1,11 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 Development script to get the multiplicity of the separation facets for some model coordination environments
 """
 
+from __future__ import annotations
+
+from pymatgen.analysis.chemenv.coordination_environments.coordination_geometries import AllCoordinationGeometries
+
 __author__ = "David Waroquiers"
 __copyright__ = "Copyright 2012, The Materials Project"
 __version__ = "2.0"
@@ -12,12 +13,7 @@ __maintainer__ = "David Waroquiers"
 __email__ = "david.waroquiers@gmail.com"
 __date__ = "Feb 20, 2016"
 
-from pymatgen.analysis.chemenv.coordination_environments.coordination_geometries import (
-    AllCoordinationGeometries,
-)
-
 if __name__ == "__main__":
-
     allcg = AllCoordinationGeometries()
 
     cg_symbol = "I:12"
@@ -33,10 +29,8 @@ if __name__ == "__main__":
             equiv_plane = list(edge)
             equiv_plane.extend(opposite_edge)
             equiv_plane.sort()
-            equiv_plane = tuple(equiv_plane)
-            all_plane_points.append(equiv_plane)
-        all_plane_points = list(set(all_plane_points))
-        all_plane_points = [list(equiv_plane) for equiv_plane in all_plane_points]
+            all_plane_points.append(tuple(equiv_plane))
+        all_plane_points = [tuple(equiv_plane) for equiv_plane in set(all_plane_points)]
 
     print(f"All plane points ({len(all_plane_points):d}) for {cg_symbol} : ")
     print(all_plane_points)
