@@ -7,6 +7,8 @@ and update the enum values declared in LibxcFunc.
 The script must be executed inside pymatgen/dev_scripts.
 """
 
+from __future__ import annotations
+
 import json
 import os
 import sys
@@ -19,15 +21,14 @@ def parse_libxc_docs(path):
     """
 
     def parse_section(section):
-        d = {}
-        for l in section:
-            key, value = l.split(":")
-            key = key.strip()
-            d[key] = value.strip()
+        dct = {}
+        for line in section:
+            key, value = line.split(":")
+            dct[key.strip()] = value.strip()
 
-        return int(d["Number"]), d
+        return int(dct["Number"]), dct
 
-    d = {}
+    dct = {}
     with open(path) as fh:
         section = []
         for line in fh:
@@ -35,12 +36,12 @@ def parse_libxc_docs(path):
                 section.append(line)
             else:
                 num, entry = parse_section(section)
-                assert num not in d
-                d[num] = entry
+                assert num not in dct
+                dct[num] = entry
                 section = []
         assert not section
 
-    return d
+    return dct
 
 
 def write_libxc_docs_json(xcfuncs, jpath):
@@ -63,7 +64,7 @@ def write_libxc_docs_json(xcfuncs, jpath):
             if desc is not None:
                 xcfuncs[num][opt] = desc
 
-    with open(jpath, "wt") as fh:
+    with open(jpath, "w") as fh:
         json.dump(xcfuncs, fh)
 
     return xcfuncs
@@ -83,16 +84,16 @@ def main():
         print("Usage: regen_libxcfunc.py path_to_libxc_docs.txt")
         return 1
 
-    xcfuncs = parse_libxc_docs(path)
+    xc_funcs = parse_libxc_docs(path)
 
     # Generate new json file in pycore
     pycore = os.path.abspath("../pymatgen/core/")
     jpath = os.path.join(pycore, "libxc_docs.json")
-    write_libxc_docs_json(xcfuncs, jpath)
+    write_libxc_docs_json(xc_funcs, jpath)
 
     # Build new enum list.
     enum_list = []
-    for num, d in xcfuncs.items():
+    for num, d in xc_funcs.items():
         # Remove XC_ from codename
         codename = d["Codename"][3:]
         enum_list.append(f"    {codename} = {num}")
@@ -111,7 +112,7 @@ def main():
     del lines[start + 1 : stop]
 
     # [2] write new py module
-    with open(xcfuncpy_path, "wt") as fh:
+    with open(xcfuncpy_path, "w") as fh:
         fh.writelines(lines)
 
     print("Files have been regenerated")
@@ -121,4 +122,4 @@ def main():
 
 
 if __name__ == "__main__":
-    sys.exit(main())
+    raise SystemExit(main())
