@@ -5,12 +5,14 @@ Developer script to convert yaml periodic table to json format.
 Created on Nov 15, 2011
 """
 
+from __future__ import annotations
+
 import json
 import re
 from itertools import product
 
-import ruamel.yaml as yaml
 from monty.serialization import dumpfn, loadfn
+from ruamel import yaml
 
 from pymatgen.core import Element
 from pymatgen.core.periodic_table import get_el_sp
@@ -31,19 +33,18 @@ def test_json():
 def parse_oxi_state():
     with open("periodic_table.yaml") as f:
         data = yaml.load(f)
-    f = open("oxidation_states.txt")
-    oxidata = f.read()
-    f.close()
-    oxidata = re.sub("[\n\r]", "", oxidata)
+    with open("oxidation_states.txt") as f:
+        oxi_data = f.read()
+    oxi_data = re.sub("[\n\r]", "", oxi_data)
     patt = re.compile("<tr>(.*?)</tr>", re.MULTILINE)
 
-    for m in patt.finditer(oxidata):
+    for m in patt.finditer(oxi_data):
         line = m.group(1)
         line = re.sub("</td>", "", line)
         line = re.sub("(<td>)+", "<td>", line)
         line = re.sub("</*a[^>]*>", "", line)
         el = None
-        oxistates = []
+        oxi_states = []
         common_oxi = []
         for tok in re.split("<td>", line.strip()):
             m2 = re.match(r"<b>([A-Z][a-z]*)</b>", tok)
@@ -52,7 +53,7 @@ def parse_oxi_state():
             else:
                 m3 = re.match(r"(<b>)*([\+\-]\d)(</b>)*", tok)
                 if m3:
-                    oxistates.append(int(m3.group(2)))
+                    oxi_states.append(int(m3.group(2)))
                     if m3.group(1):
                         common_oxi.append(int(m3.group(2)))
         if el in data:
@@ -60,7 +61,7 @@ def parse_oxi_state():
             del data[el]["Min oxidation state"]
             del data[el]["Oxidation_states"]
             del data[el]["Common_oxidation_states"]
-            data[el]["Oxidation states"] = oxistates
+            data[el]["Oxidation states"] = oxi_states
             data[el]["Common oxidation states"] = common_oxi
         else:
             print(el)
@@ -71,13 +72,12 @@ def parse_oxi_state():
 def parse_ionic_radii():
     with open("periodic_table.yaml") as f:
         data = yaml.load(f)
-    f = open("ionic_radii.csv")
-    radiidata = f.read()
-    f.close()
-    radiidata = radiidata.split("\r")
-    header = radiidata[0].split(",")
-    for i in range(1, len(radiidata)):
-        line = radiidata[i]
+    with open("ionic_radii.csv") as f:
+        radii_data = f.read()
+    radii_data = radii_data.split("\r")
+    header = radii_data[0].split(",")
+    for idx in range(1, len(radii_data)):
+        line = radii_data[idx]
         toks = line.strip().split(",")
         suffix = ""
         name = toks[1]
@@ -104,9 +104,8 @@ def parse_ionic_radii():
 def parse_radii():
     with open("periodic_table.yaml") as f:
         data = yaml.load(f)
-    f = open("radii.csv")
-    radiidata = f.read()
-    f.close()
+    with open("radii.csv") as f:
+        radiidata = f.read()
     radiidata = radiidata.split("\r")
 
     for i in range(1, len(radiidata)):
@@ -144,7 +143,7 @@ def update_ionic_radii():
     with open("periodic_table.yaml") as f:
         data = yaml.load(f)
 
-    for el, d in data.items():
+    for d in data.values():
         if "Ionic_radii" in d:
             d["Ionic radii"] = {k: v / 100 for k, v in d["Ionic_radii"].items()}
             del d["Ionic_radii"]
@@ -172,30 +171,26 @@ def parse_shannon_radii():
     sheet = wb["Sheet1"]
     i = 2
     radii = collections.defaultdict(dict)
-    while sheet["E%d" % i].value:
-        if sheet["A%d" % i].value:
-            el = sheet["A%d" % i].value
-        if sheet["B%d" % i].value:
-            charge = int(sheet["B%d" % i].value)
-            radii[el][charge] = dict()
-        if sheet["C%d" % i].value:
-            cn = sheet["C%d" % i].value
+    while sheet[f"E{i}"].value:
+        if sheet[f"A{i}"].value:
+            el = sheet[f"A{i}"].value
+        if sheet[f"B{i}"].value:
+            charge = int(sheet[f"B{i}"].value)
+            radii[el][charge] = {}
+        if sheet[f"C{i}"].value:
+            cn = sheet[f"C{i}"].value
             if cn not in radii[el][charge]:
-                radii[el][charge][cn] = dict()
+                radii[el][charge][cn] = {}
 
-        if sheet["D%d" % i].value is not None:
-            spin = sheet["D%d" % i].value
-        else:
-            spin = ""
-        # print("%s - %d - %s" % (el, charge, cn))
+        spin = sheet[f"D{i}"].value if sheet[f"D{i}"].value is not None else ""
 
         radii[el][charge][cn][spin] = {
-            "crystal_radius": float(sheet["E%d" % i].value),
-            "ionic_radius": float(sheet["F%d" % i].value),
+            "crystal_radius": float(sheet[f"E{i}"].value),
+            "ionic_radius": float(sheet[f"F{i}"].value),
         }
         i += 1
 
-    for el in radii.keys():
+    for el in radii:
         if el in data:
             data[el]["Shannon radii"] = dict(radii[el])
 
@@ -275,11 +270,11 @@ def add_electron_affinities():
         data.append(row)
     data.pop(0)
     ea = {int(r[0]): float(re.sub(r"[\s\(\)]", "", r[3].strip("()[]"))) for r in data}
-    assert set(ea.keys()).issuperset(range(1, 93))  # Ensure that we have data for up to U.
+    assert set(ea).issuperset(range(1, 93))  # Ensure that we have data for up to U.
     print(ea)
     pt = loadfn("../pymatgen/core/periodic_table.json")
     for k, v in pt.items():
-        v["Electron affinity"] = ea.get(Element(k).Z, None)
+        v["Electron affinity"] = ea.get(Element(k).Z)
     dumpfn(pt, "../pymatgen/core/periodic_table.json")
 
 
@@ -302,14 +297,11 @@ def add_ionization_energies():
         if row:
             Z = int(row[0])
             val = re.sub(r"\s", "", row[8].strip("()[]"))
-            if val == "":
-                val = None
-            else:
-                val = float(val)
+            val = None if val == "" else float(val)
             data[Z].append(val)
     print(data)
     print(data[51])
-    assert set(data.keys()).issuperset(range(1, 93))  # Ensure that we have data for up to U.
+    assert set(data).issuperset(range(1, 93))  # Ensure that we have data for up to U.
     pt = loadfn("../pymatgen/core/periodic_table.json")
     for k, v in pt.items():
         del v["Ionization energy"]
