@@ -1,9 +1,7 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
+from __future__ import annotations
 
 import json
 import os
-import unittest
 import warnings
 
 import pytest
@@ -32,22 +30,21 @@ class TransformedStructureTest(PymatgenTest):
     def test_append_transformation(self):
         t = SubstitutionTransformation({"Fe": "Mn"})
         self.trans.append_transformation(t)
-        assert "NaMnPO4" == self.trans.final_structure.composition.reduced_formula
+        assert self.trans.final_structure.composition.reduced_formula == "NaMnPO4"
         assert len(self.trans.structures) == 3
         coords = []
         coords.append([0, 0, 0])
         coords.append([0.75, 0.5, 0.75])
         lattice = [
-            [3.8401979337, 0.00, 0.00],
-            [1.9200989668, 3.3257101909, 0.00],
-            [0.00, -2.2171384943, 3.1355090603],
+            [3.8401979337, 0, 0],
+            [1.9200989668, 3.3257101909, 0],
+            [0, -2.2171384943, 3.1355090603],
         ]
         struct = Structure(lattice, ["Si4+", "Si4+"], coords)
         ts = TransformedStructure(struct, [])
         ts.append_transformation(SupercellTransformation.from_scaling_factors(2, 1, 1))
         alt = ts.append_transformation(
-            PartialRemoveSpecieTransformation("Si4+", 0.5, algo=PartialRemoveSpecieTransformation.ALGO_COMPLETE),
-            5,
+            PartialRemoveSpecieTransformation("Si4+", 0.5, algo=PartialRemoveSpecieTransformation.ALGO_COMPLETE), 5
         )
         assert len(alt) == 2
 
@@ -58,19 +55,20 @@ class TransformedStructureTest(PymatgenTest):
     def test_get_vasp_input(self):
         SETTINGS["PMG_VASP_PSP_DIR"] = PymatgenTest.TEST_FILES_DIR
         potcar = self.trans.get_vasp_input(MPRelaxSet)["POTCAR"]
-        assert "Na_pv\nFe_pv\nP\nO" == "\n".join([p.symbol for p in potcar])
+        assert "\n".join(p.symbol for p in potcar) == "Na_pv\nFe_pv\nP\nO"
         assert len(self.trans.structures) == 2
 
     def test_final_structure(self):
-        assert "NaFePO4" == self.trans.final_structure.composition.reduced_formula
+        assert self.trans.final_structure.composition.reduced_formula == "NaFePO4"
 
     def test_from_dict(self):
-        d = json.load(open(os.path.join(PymatgenTest.TEST_FILES_DIR, "transformations.json")))
-        d["other_parameters"] = {"tags": ["test"]}
-        ts = TransformedStructure.from_dict(d)
+        with open(os.path.join(PymatgenTest.TEST_FILES_DIR, "transformations.json")) as file:
+            dct = json.load(file)
+        dct["other_parameters"] = {"tags": ["test"]}
+        ts = TransformedStructure.from_dict(dct)
         ts.other_parameters["author"] = "Will"
         ts.append_transformation(SubstitutionTransformation({"Fe": "Mn"}))
-        assert "MnPO4" == ts.final_structure.composition.reduced_formula
+        assert ts.final_structure.composition.reduced_formula == "MnPO4"
         assert ts.other_parameters == {"author": "Will", "tags": ["test"]}
 
     def test_undo_and_redo_last_change(self):
@@ -79,18 +77,18 @@ class TransformedStructureTest(PymatgenTest):
             SubstitutionTransformation({"Fe": "Mn"}),
         ]
         ts = TransformedStructure(self.structure, trans)
-        assert "NaMnPO4" == ts.final_structure.composition.reduced_formula
+        assert ts.final_structure.composition.reduced_formula == "NaMnPO4"
         ts.undo_last_change()
-        assert "NaFePO4" == ts.final_structure.composition.reduced_formula
+        assert ts.final_structure.composition.reduced_formula == "NaFePO4"
         ts.undo_last_change()
-        assert "LiFePO4" == ts.final_structure.composition.reduced_formula
-        with pytest.raises(IndexError):
+        assert ts.final_structure.composition.reduced_formula == "LiFePO4"
+        with pytest.raises(IndexError, match="No more changes to undo"):
             ts.undo_last_change()
         ts.redo_next_change()
-        assert "NaFePO4" == ts.final_structure.composition.reduced_formula
+        assert ts.final_structure.composition.reduced_formula == "NaFePO4"
         ts.redo_next_change()
-        assert "NaMnPO4" == ts.final_structure.composition.reduced_formula
-        with pytest.raises(IndexError):
+        assert ts.final_structure.composition.reduced_formula == "NaMnPO4"
+        with pytest.raises(IndexError, match="No more changes to redo"):
             ts.redo_next_change()
         # Make sure that this works with filters.
         f3 = ContainsSpecieFilter(["O2-"], strict_compare=True, AND=False)
@@ -120,7 +118,3 @@ class TransformedStructureTest(PymatgenTest):
         snl = TransformedStructure.from_snl(snl).to_snl([("notwill", "notwill@test.com")])
         assert snl.history == [h]
         assert snl.authors == [("notwill", "notwill@test.com")]
-
-
-if __name__ == "__main__":
-    unittest.main()
