@@ -2,6 +2,8 @@
 Connected components.
 """
 
+from __future__ import annotations
+
 import itertools
 import logging
 
@@ -39,7 +41,7 @@ def draw_network(env_graph, pos, ax, sg=None, periodicity_vectors=None):
         ax.annotate(str(n), pos[n], ha="center", va="center", xycoords="data")
     seen = {}
     e = None
-    for (u, v, d) in env_graph.edges(data=True):
+    for u, v, d in env_graph.edges(data=True):
         n1 = env_graph.node[u]["patch"]
         n2 = env_graph.node[v]["patch"]
         rad = 0.1
@@ -76,7 +78,7 @@ def draw_network(env_graph, pos, ax, sg=None, periodicity_vectors=None):
                     patchA=n1,
                     patchB=n2,
                     arrowstyle="-|>",
-                    connectionstyle=f"arc3,rad={rad}",
+                    connectionstyle=f"arc3,{rad=}",
                     mutation_scale=15.0,
                     lw=2,
                     alpha=alpha,
@@ -90,7 +92,7 @@ def draw_network(env_graph, pos, ax, sg=None, periodicity_vectors=None):
                     patchA=n1,
                     patchB=n2,
                     arrowstyle="-|>",
-                    connectionstyle=f"arc3,rad={rad}",
+                    connectionstyle=f"arc3,{rad=}",
                     mutation_scale=10.0,
                     lw=2,
                     alpha=alpha,
@@ -104,7 +106,7 @@ def draw_network(env_graph, pos, ax, sg=None, periodicity_vectors=None):
                 patchA=n1,
                 patchB=n2,
                 arrowstyle="-|>",
-                connectionstyle=f"arc3,rad={rad}",
+                connectionstyle=f"arc3,{rad=}",
                 mutation_scale=10.0,
                 lw=2,
                 alpha=alpha,
@@ -145,7 +147,7 @@ def make_supergraph(graph, multiplicity, periodicity_vectors):
         edges = graph.edges(data=True, keys=True)
         connecting_edges = []
         other_edges = []
-        for (n1, n2, key, data) in edges:
+        for n1, n2, key, data in edges:
             print(n1, n2, key, data)
             if np.all(np.array(data["delta"]) == np.array(periodicity_vectors[0])):
                 connecting_edges.append((n1, n2, key, data))
@@ -208,7 +210,7 @@ class ConnectedComponent(MSONable):
         environments_data=None,
         links_data=None,
         graph=None,
-    ):
+    ) -> None:
         """
         Constructor for the ConnectedComponent object.
 
@@ -222,7 +224,7 @@ class ConnectedComponent(MSONable):
         Returns:
             ConnectedComponent: Instance of this class
         """
-        self._periodicity_vectors = None
+        self._periodicity_vectors: list[list] | None = None
         self._primitive_reduced_connected_subgraph = None
         self._projected = False
         if graph is None:
@@ -238,17 +240,14 @@ class ConnectedComponent(MSONable):
             for edge in links:
                 env_node1 = edge[0]
                 env_node2 = edge[1]
-                if len(edge) == 2:
-                    key = None
-                else:
-                    key = edge[2]
+                key = None if len(edge) == 2 else edge[2]
                 if (not self._connected_subgraph.has_node(env_node1)) or (
                     not self._connected_subgraph.has_node(env_node2)
                 ):
                     raise ChemenvError(
                         self.__class__,
                         "__init__",
-                        "Trying to add edge with some unexisting node ...",
+                        "Trying to add edge with some unexistent node ...",
                     )
                 if links_data is not None:
                     if (env_node1, env_node2, key) in links_data:
@@ -332,10 +331,10 @@ class ConnectedComponent(MSONable):
         # One possible quotient graph of this periodic net :
         #          __           __
         # (0,1,0) /  \         /  \ (0,1,0)
-        #         `<--A--->---B--<´
+        #         `<--A--->---B--<`
         #            / (0,0,0) \
         #            \         /
-        #             `--->---´
+        #             `--->---`
         #              (1,0,0)
         #
         # The "number" coordination sequence starting from any environment is : 4-8-12-16-...
@@ -352,7 +351,7 @@ class ConnectedComponent(MSONable):
             elif coordination == "env:number":
                 cseq[0] = {source_node.coordination_environment: 1}
             else:
-                raise ValueError(f'Coordination type "{coordination}" is not valid for coordination_sequence.')
+                raise ValueError(f"Coordination type {coordination!r} is not valid for coordination_sequence.")
         while path_len < path_size:
             new_ends = []
             for current_node_end, current_delta_end in current_ends:
@@ -375,7 +374,7 @@ class ConnectedComponent(MSONable):
                 myenvs = [myend.coordination_environment for myend, _ in current_ends]
                 cseq[path_len] = {myenv: myenvs.count(myenv) for myenv in set(myenvs)}
             else:
-                raise ValueError(f'Coordination type "{coordination}" is not valid for coordination_sequence.')
+                raise ValueError(f"Coordination type {coordination!r} is not valid for coordination_sequence.")
         return cseq
 
     def __len__(self):
@@ -393,7 +392,7 @@ class ConnectedComponent(MSONable):
         elif algorithm == "cycle_basis":
             self.compute_periodicity_cycle_basis()
         else:
-            raise ValueError(f'Algorithm "{algorithm}" is not allowed to compute periodicity')
+            raise ValueError(f"Algorithm {algorithm!r} is not allowed to compute periodicity")
         self._order_periodicity_vectors()
 
     def compute_periodicity_all_simple_paths_algorithm(self):
@@ -420,7 +419,7 @@ class ConnectedComponent(MSONable):
             paths = []
             # TODO: its probably possible to do just a dfs or bfs traversal instead of taking all simple paths!
             test_node_neighbors = my_simple_graph.neighbors(test_node)
-            breaknodeloop = False
+            break_node_loop = False
             for test_node_neighbor in test_node_neighbors:
                 # Special case for two nodes
                 if len(self._connected_subgraph[test_node][test_node_neighbor]) > 1:
@@ -442,7 +441,7 @@ class ConnectedComponent(MSONable):
                     test_node_neighbor,
                     cutoff=len(self._connected_subgraph),
                 ):
-                    path_indices = [nodepath.isite for nodepath in path]
+                    path_indices = [node_path.isite for node_path in path]
                     if path_indices == [test_node.isite, test_node_neighbor.isite]:
                         continue
                     path_indices.append(test_node.isite)
@@ -455,7 +454,7 @@ class ConnectedComponent(MSONable):
                     # TODO: there are some paths that appears twice for cycles, and there are some paths that should
                     # probably not be considered
                     this_path_deltas = [np.zeros(3, int)]
-                    for (node1, node2) in [(node1, path[inode1 + 1]) for inode1, node1 in enumerate(path[:-1])]:
+                    for node1, node2 in [(node1, path[inode1 + 1]) for inode1, node1 in enumerate(path[:-1])]:
                         this_path_deltas_new = []
                         for edge_data in self._connected_subgraph[node1][node2].values():
                             delta = get_delta(node1, node2, edge_data)
@@ -465,9 +464,9 @@ class ConnectedComponent(MSONable):
                     this_node_cell_img_vectors.extend(this_path_deltas)
                     this_node_cell_img_vectors = get_linearly_independent_vectors(this_node_cell_img_vectors)
                     if len(this_node_cell_img_vectors) == 3:
-                        breaknodeloop = True
+                        break_node_loop = True
                         break
-                if breaknodeloop:
+                if break_node_loop:
                     break
             this_node_cell_img_vectors = get_linearly_independent_vectors(this_node_cell_img_vectors)
             independent_cell_img_vectors = this_node_cell_img_vectors
@@ -494,7 +493,7 @@ class ConnectedComponent(MSONable):
             mycyc = list(cyc)
             mycyc.append(cyc[0])
             this_cycle_deltas = [np.zeros(3, int)]
-            for (node1, node2) in [(node1, mycyc[inode1 + 1]) for inode1, node1 in enumerate(mycyc[:-1])]:
+            for node1, node2 in [(node1, mycyc[inode1 + 1]) for inode1, node1 in enumerate(mycyc[:-1])]:
                 this_cycle_deltas_new = []
                 for edge_data in self._connected_subgraph[node1][node2].values():
                     delta = get_delta(node1, node2, edge_data)
@@ -504,7 +503,6 @@ class ConnectedComponent(MSONable):
             all_deltas.extend(this_cycle_deltas)
             all_deltas = get_linearly_independent_vectors(all_deltas)
             if len(all_deltas) == 3:
-                self._periodicity_vectors = all_deltas
                 return
         # One has to consider pairs of nodes with parallel edges (these are not considered in the simple graph cycles)
         edges = my_simple_graph.edges()
@@ -539,22 +537,17 @@ class ConnectedComponent(MSONable):
         supergraph = make_supergraph(self._connected_subgraph, multiplicity, self._periodicity_vectors)
         return supergraph
 
-    def show_graph(self, graph=None, save_file=None, drawing_type="internal", pltshow=True):
+    def show_graph(self, graph=None, save_file=None, drawing_type="internal", pltshow=True) -> None:
         """
         Args:
             graph ():
             save_file ():
             drawing_type ():
             pltshow ():
-
-        Returns:
         """
         import matplotlib.pyplot as plt
 
-        if graph is None:
-            shown_graph = self._connected_subgraph
-        else:
-            shown_graph = graph
+        shown_graph = self._connected_subgraph if graph is None else graph
 
         plt.figure()
         # pos = nx.spring_layout(shown_graph)
@@ -590,46 +583,50 @@ class ConnectedComponent(MSONable):
         return self._connected_subgraph
 
     @property
-    def is_periodic(self):
+    def is_periodic(self) -> bool:
         """
         Returns:
         """
         return not self.is_0d
 
     @property
-    def is_0d(self):
+    def is_0d(self) -> bool:
         """
         Returns:
         """
         if self._periodicity_vectors is None:
             self.compute_periodicity()
+        assert self._periodicity_vectors is not None  # fix mypy arg 1 to len has incompatible type Optional
         return len(self._periodicity_vectors) == 0
 
     @property
-    def is_1d(self):
+    def is_1d(self) -> bool:
         """
         Returns:
         """
         if self._periodicity_vectors is None:
             self.compute_periodicity()
+        assert self._periodicity_vectors is not None  # fix mypy arg 1 to len has incompatible type Optional
         return len(self._periodicity_vectors) == 1
 
     @property
-    def is_2d(self):
+    def is_2d(self) -> bool:
         """
         Returns:
         """
         if self._periodicity_vectors is None:
             self.compute_periodicity()
+        assert self._periodicity_vectors is not None  # fix mypy arg 1 to len has incompatible type Optional
         return len(self._periodicity_vectors) == 2
 
     @property
-    def is_3d(self):
+    def is_3d(self) -> bool:
         """
         Returns:
         """
         if self._periodicity_vectors is None:
             self.compute_periodicity()
+        assert self._periodicity_vectors is not None  # fix mypy arg 1 to len has incompatible type Optional
         return len(self._periodicity_vectors) == 3
 
     @staticmethod
@@ -684,6 +681,7 @@ class ConnectedComponent(MSONable):
             start_node ():
 
         Returns:
+            nx.MultiGraph: Elastic centered subgraph.
         """
         logging.info("In elastic centering")
         # Loop on start_nodes, sometimes some nodes cannot be elastically taken
@@ -726,16 +724,15 @@ class ConnectedComponent(MSONable):
                             if edata["delta"] == (0, 0, 0):
                                 already_inside = True
                                 thisdelta = edata["delta"]
+                            elif edata["start"] == node.isite and edata["end"] != node.isite:
+                                thisdelta = edata["delta"]
+                            elif edata["end"] == node.isite:
+                                thisdelta = tuple(-dd for dd in edata["delta"])
                             else:
-                                if edata["start"] == node.isite and edata["end"] != node.isite:
-                                    thisdelta = edata["delta"]
-                                elif edata["end"] == node.isite:
-                                    thisdelta = tuple(-dd for dd in edata["delta"])
-                                else:
-                                    raise ValueError("Should not be here ...")
+                                raise ValueError("Should not be here ...")
                             ddeltas.append(thisdelta)
                     logging.debug(
-                        "        ddeltas : " + ", ".join([f"({', '.join(str(ddd) for ddd in dd)})" for dd in ddeltas])
+                        "        ddeltas : " + ", ".join(f"({', '.join(str(ddd) for ddd in dd)})" for dd in ddeltas)
                     )
                     if ddeltas.count((0, 0, 0)) > 1:
                         raise ValueError("Should not have more than one 000 delta ...")
@@ -750,8 +747,8 @@ class ConnectedComponent(MSONable):
                         nbunch=[node_neighbor], data=True, keys=True
                     )
                     logging.debug(
-                        f"            Delta image from node {str(node)} to neighbor {str(node_neighbor)} : "
-                        f"({', '.join([str(iii) for iii in myddelta])})"
+                        f"            Delta image from node {node} to neighbor {node_neighbor} : "
+                        f"({', '.join(map(str, myddelta))})"
                     )
                     # Loop on the edges of this neighbor
                     for n1, n2, key, edata in node_neighbor_edges:
@@ -833,7 +830,7 @@ class ConnectedComponent(MSONable):
             dict: Edge data dictionary with the lists transformed back into tuples when applicable.
         """
         edata["delta"] = tuple(edata["delta"])
-        edata["ligands"] = [tuple([lig[0], tuple(lig[1]), tuple(lig[2])]) for lig in edata["ligands"]]
+        edata["ligands"] = [(lig[0], tuple(lig[1]), tuple(lig[2])) for lig in edata["ligands"]]
         return edata
 
     def as_dict(self):
@@ -897,6 +894,7 @@ class ConnectedComponent(MSONable):
 
         Args:
             g (MultiGraph): Graph of the connected component.
+
         Returns:
             ConnectedComponent: The connected component representing the links of a given set of environments.
         """
@@ -905,13 +903,14 @@ class ConnectedComponent(MSONable):
     def description(self, full=False):
         """
         Args:
-            full ():
+            full (bool): Whether to return a short or full description.
 
         Returns:
+            str: A description of the connected component.
         """
         out = ["Connected component with environment nodes :"]
         if not full:
-            out.extend([str(en) for en in sorted(self.graph.nodes())])
+            out.extend(map(str, sorted(self.graph.nodes())))
             return "\n".join(out)
         for en in sorted(self.graph.nodes()):
             out.append(f"{en}, connected to :")
