@@ -2,6 +2,8 @@
 Environment nodes module.
 """
 
+from __future__ import annotations
+
 import abc
 
 from monty.json import MSONable
@@ -25,13 +27,13 @@ class AbstractEnvironmentNode(MSONable):
     CE_NNBCES_NBCES_LIGANDS = -1
     DEFAULT_EXTENSIONS = (ATOM, COORDINATION_ENVIRONMENT)
 
-    def __init__(self, central_site, i_central_site):
+    def __init__(self, central_site, i_central_site) -> None:
         """
         Constructor for the AbstractEnvironmentNode object.
 
         Args:
             central_site (Site or subclass of Site): central site as a pymatgen Site or
-                                                     subclass of Site (e.g. PeriodicSite, ...).
+                subclass of Site (e.g. PeriodicSite, ...).
             i_central_site (int): Index of the central site in the structure.
         """
         self.central_site = central_site
@@ -63,7 +65,8 @@ class AbstractEnvironmentNode(MSONable):
 
     def everything_equal(self, other):
         """Checks equality with respect to another AbstractEnvironmentNode using the index of the central site
-        as well as the central site itself."""
+        as well as the central site itself.
+        """
         return self == other and self.central_site == other.central_site
 
     @property
@@ -102,13 +105,13 @@ class EnvironmentNode(AbstractEnvironmentNode):
     Class used to define an environment as a node in a graph.
     """
 
-    def __init__(self, central_site, i_central_site, ce_symbol):
+    def __init__(self, central_site, i_central_site, ce_symbol) -> None:
         """
         Constructor for the EnvironmentNode object.
 
         Args:
             central_site (Site or subclass of Site): central site as a pymatgen Site or
-                                                     subclass of Site (e.g. PeriodicSite, ...).
+                subclass of Site (e.g. PeriodicSite, ...).
             i_central_site (int): Index of the central site in the structure.
             ce_symbol (str): Symbol of the identified environment.
         """
@@ -167,6 +170,7 @@ def get_environment_node(central_site, i_central_site, ce_symbol):
         central_site (Site or subclass of Site): Central site of the environment.
         i_central_site (int): Index of the central site in the structure.
         ce_symbol: Symbol of the environment.
+
     Returns:
         An EnvironmentNode object.
     """
