@@ -1,6 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module contains the class describing the coordination geometries that can exist in a given structure. These
 "model" coordination geometries are described in the following articles :
@@ -10,13 +7,7 @@ The module also contains descriptors of part of these geometries (plane of separ
 identification algorithms.
 """
 
-__author__ = "David Waroquiers"
-__copyright__ = "Copyright 2012, The Materials Project"
-__credits__ = "Geoffroy Hautier"
-__version__ = "2.0"
-__maintainer__ = "David Waroquiers"
-__email__ = "david.waroquiers@gmail.com"
-__date__ = "Feb 20, 2016"
+from __future__ import annotations
 
 import abc
 import itertools
@@ -27,6 +18,14 @@ import numpy as np
 from monty.json import MontyDecoder, MSONable
 from scipy.special import factorial
 
+__author__ = "David Waroquiers"
+__copyright__ = "Copyright 2012, The Materials Project"
+__credits__ = "Geoffroy Hautier"
+__version__ = "2.0"
+__maintainer__ = "David Waroquiers"
+__email__ = "david.waroquiers@gmail.com"
+__date__ = "Feb 20, 2016"
+
 module_dir = os.path.dirname(os.path.abspath(__file__))
 
 UNKNOWN_ENVIRONMENT_SYMBOL = "UNKNOWN"
@@ -239,6 +238,7 @@ class SeparationPlane(AbstractChemenvAlgorithm):
         Simple and safe permutations for this separation plane.
 
         This is not meant to be used in production. Default configuration for ChemEnv does not use this method.
+
         Args:
             ordered_plane: Whether the order of the points in the plane can be used to reduce the
                 number of permutations.
@@ -327,7 +327,7 @@ class SeparationPlane(AbstractChemenvAlgorithm):
         }
 
     @classmethod
-    def from_dict(cls, dd):
+    def from_dict(cls, dct):
         """
         Reconstructs the SeparationPlane algorithm from its JSON-serializable dict representation.
 
@@ -336,29 +336,25 @@ class SeparationPlane(AbstractChemenvAlgorithm):
 
         Returns: a SeparationPlane algorithm.
         """
-        eop = (
-            [np.array(eoperm) for eoperm in dd["explicit_optimized_permutations"]]
-            if ("explicit_optimized_permutations" in dd and dd["explicit_optimized_permutations"] is not None)
-            else None
-        )
+        eop = [np.array(eo_perm) for eo_perm in dct.get("explicit_optimized_permutations", [])] or None
         return cls(
-            plane_points=dd["plane_points"],
-            mirror_plane=dd["mirror_plane"],
-            ordered_plane=dd["ordered_plane"],
-            point_groups=dd["point_groups"],
-            ordered_point_groups=dd["ordered_point_groups"],
-            explicit_permutations=[np.array(eperm) for eperm in dd["explicit_permutations"]],
+            plane_points=dct["plane_points"],
+            mirror_plane=dct["mirror_plane"],
+            ordered_plane=dct["ordered_plane"],
+            point_groups=dct["point_groups"],
+            ordered_point_groups=dct["ordered_point_groups"],
+            explicit_permutations=[np.array(eperm) for eperm in dct["explicit_permutations"]],
             explicit_optimized_permutations=eop,
-            multiplicity=dd["multiplicity"] if "multiplicity" in dd else None,
-            other_plane_points=dd["other_plane_points"] if "other_plane_points" in dd else None,
-            minimum_number_of_points=dd["minimum_number_of_points"],
+            multiplicity=dct.get("multiplicity"),
+            other_plane_points=dct.get("other_plane_points"),
+            minimum_number_of_points=dct["minimum_number_of_points"],
         )
 
     def __str__(self):
         out = "Separation plane algorithm with the following reference separation :\n"
-        out += f"[{'-'.join(str(pp) for pp in [self.point_groups[0]])}] | "
-        out += f"[{'-'.join(str(pp) for pp in [self.plane_points])}] | "
-        out += f"[{'-'.join(str(pp) for pp in [self.point_groups[1]])}]"
+        out += f"[{'-'.join(map(str, [self.point_groups[0]]))}] | "
+        out += f"[{'-'.join(map(str, [self.plane_points]))}] | "
+        out += f"[{'-'.join(map(str, [self.point_groups[1]]))}]"
         return out
 
 
@@ -390,7 +386,7 @@ class CoordinationGeometry:
                     neighbors set could be found from a "cap hint".
             """
             if hints_type not in self.ALLOWED_HINTS_TYPES:
-                raise ValueError(f'Type "{type}" for NeighborsSetsHints is not allowed')
+                raise ValueError(f"Type {type!r} for NeighborsSetsHints is not allowed")
             self.hints_type = hints_type
             self.options = options
 
@@ -451,11 +447,7 @@ class CoordinationGeometry:
             new_site_voronoi_indices2.remove(second_cap_voronoi_index)
             new_site_voronoi_indices3.remove(first_cap_voronoi_index)
             new_site_voronoi_indices3.remove(second_cap_voronoi_index)
-            return [
-                new_site_voronoi_indices1,
-                new_site_voronoi_indices2,
-                new_site_voronoi_indices3,
-            ]
+            return new_site_voronoi_indices1, new_site_voronoi_indices2, new_site_voronoi_indices3
 
         def triple_cap_hints(self, hints_info):
             """
@@ -603,12 +595,12 @@ class CoordinationGeometry:
             "IUCr_symbol": self.IUCrsymbol,
             "coordination": self.coordination,
             "central_site": [float(xx) for xx in self.central_site],
-            "points": [[float(xx) for xx in pp] for pp in self.points] if self.points is not None else None,
-            "solid_angles": [float(ang) for ang in self._solid_angles] if self._solid_angles is not None else None,
+            "points": [[float(xx) for xx in pp] for pp in (self.points or [])] or None,
+            "solid_angles": [float(ang) for ang in (self._solid_angles or [])] or None,
             "deactivate": self.deactivate,
             "_faces": self._faces,
             "_edges": self._edges,
-            "_algorithms": [algo.as_dict for algo in self._algorithms] if self._algorithms is not None else None,
+            "_algorithms": [algo.as_dict for algo in (self._algorithms or [])] or None,
             "equivalent_indices": self.equivalent_indices,
             "neighbors_sets_hints": [nbsh.as_dict() for nbsh in self.neighbors_sets_hints]
             if self.neighbors_sets_hints is not None
@@ -616,37 +608,39 @@ class CoordinationGeometry:
         }
 
     @classmethod
-    def from_dict(cls, dd):
+    def from_dict(cls, dct):
         """
         Reconstructs the CoordinationGeometry from its JSON-serializable dict representation.
 
         Args:
-            dd: a JSON-serializable dict representation of a CoordinationGeometry.
+            dct: a JSON-serializable dict representation of a CoordinationGeometry.
 
         Returns: a CoordinationGeometry.
         """
         dec = MontyDecoder()
         return cls(
-            mp_symbol=dd["mp_symbol"],
-            name=dd["name"],
-            alternative_names=dd["alternative_names"],
-            IUPAC_symbol=dd["IUPAC_symbol"],
-            IUCr_symbol=dd["IUCr_symbol"],
-            coordination=dd["coordination"],
-            central_site=dd["central_site"],
-            points=dd["points"],
+            mp_symbol=dct["mp_symbol"],
+            name=dct["name"],
+            alternative_names=dct["alternative_names"],
+            IUPAC_symbol=dct["IUPAC_symbol"],
+            IUCr_symbol=dct["IUCr_symbol"],
+            coordination=dct["coordination"],
+            central_site=dct["central_site"],
+            points=dct["points"],
             solid_angles=(
-                dd["solid_angles"] if "solid_angles" in dd else [4.0 * np.pi / dd["coordination"]] * dd["coordination"]
+                dct["solid_angles"]
+                if "solid_angles" in dct
+                else [4.0 * np.pi / dct["coordination"]] * dct["coordination"]
             ),
-            deactivate=dd["deactivate"],
-            faces=dd["_faces"],
-            edges=dd["_edges"],
-            algorithms=[dec.process_decoded(algo_d) for algo_d in dd["_algorithms"]]
-            if dd["_algorithms"] is not None
+            deactivate=dct["deactivate"],
+            faces=dct["_faces"],
+            edges=dct["_edges"],
+            algorithms=[dec.process_decoded(algo_d) for algo_d in dct["_algorithms"]]
+            if dct["_algorithms"] is not None
             else None,
-            equivalent_indices=dd["equivalent_indices"] if "equivalent_indices" in dd else None,
-            neighbors_sets_hints=[cls.NeighborsSetsHints.from_dict(nbshd) for nbshd in dd["neighbors_sets_hints"]]
-            if ("neighbors_sets_hints" in dd and dd["neighbors_sets_hints"] is not None)
+            equivalent_indices=dct.get("equivalent_indices"),
+            neighbors_sets_hints=[cls.NeighborsSetsHints.from_dict(nbshd) for nbshd in dct["neighbors_sets_hints"]]
+            if ("neighbors_sets_hints" in dct and dct["neighbors_sets_hints"] is not None)
             else None,
         )
 
@@ -769,7 +763,7 @@ class CoordinationGeometry:
         """
         return self.coordination
 
-    def is_implemented(self):
+    def is_implemented(self) -> bool:
         """
         Returns True if this coordination geometry is implemented.
         """
@@ -855,10 +849,7 @@ class CoordinationGeometry:
         Returns the list of faces of this coordination geometry. Each face is given as a
         list of its vertices coordinates.
         """
-        if permutation is None:
-            coords = [site.coords for site in sites]
-        else:
-            coords = [sites[ii].coords for ii in permutation]
+        coords = [site.coords for site in sites] if permutation is None else [sites[ii].coords for ii in permutation]
         return [[coords[ii] for ii in f] for f in self._faces]
 
     def edges(self, sites, permutation=None, input="sites"):
@@ -893,10 +884,7 @@ class CoordinationGeometry:
         """
         pmeshes = []
         # _vertices = [site.coords for site in sites]
-        if permutation is None:
-            _vertices = [site.coords for site in sites]
-        else:
-            _vertices = [sites[ii].coords for ii in permutation]
+        _vertices = [site.coords for site in sites] if permutation is None else [sites[ii].coords for ii in permutation]
         _face_centers = []
         number_of_faces = 0
         for face in self._faces:
@@ -1169,7 +1157,7 @@ class AllCoordinationGeometries(dict):
         for gg in self.cg_list:
             if gg.name == name or name in gg.alternative_names:
                 return gg
-        raise LookupError(f'No coordination geometry found with name "{name}"')
+        raise LookupError(f"No coordination geometry found with name {name!r}")
 
     def get_geometry_from_IUPAC_symbol(self, IUPAC_symbol):
         """
@@ -1181,7 +1169,7 @@ class AllCoordinationGeometries(dict):
         for gg in self.cg_list:
             if gg.IUPAC_symbol == IUPAC_symbol:
                 return gg
-        raise LookupError(f'No coordination geometry found with IUPAC symbol "{IUPAC_symbol}"')
+        raise LookupError(f"No coordination geometry found with IUPAC symbol {IUPAC_symbol!r}")
 
     def get_geometry_from_IUCr_symbol(self, IUCr_symbol):
         """
@@ -1193,7 +1181,7 @@ class AllCoordinationGeometries(dict):
         for gg in self.cg_list:
             if gg.IUCr_symbol == IUCr_symbol:
                 return gg
-        raise LookupError(f'No coordination geometry found with IUCr symbol "{IUCr_symbol}"')
+        raise LookupError(f"No coordination geometry found with IUCr symbol {IUCr_symbol!r}")
 
     def get_geometry_from_mp_symbol(self, mp_symbol):
         """
@@ -1205,9 +1193,11 @@ class AllCoordinationGeometries(dict):
         for gg in self.cg_list:
             if gg.mp_symbol == mp_symbol:
                 return gg
-        raise LookupError(f'No coordination geometry found with mp_symbol "{mp_symbol}"')
+        raise LookupError(f"No coordination geometry found with mp_symbol {mp_symbol!r}")
 
-    def is_a_valid_coordination_geometry(self, mp_symbol=None, IUPAC_symbol=None, IUCr_symbol=None, name=None, cn=None):
+    def is_a_valid_coordination_geometry(
+        self, mp_symbol=None, IUPAC_symbol=None, IUCr_symbol=None, name=None, cn=None
+    ) -> bool:
         """
         Checks whether a given coordination geometry is valid (exists) and whether the parameters are coherent with
         each other.
@@ -1229,36 +1219,30 @@ class AllCoordinationGeometries(dict):
         if mp_symbol is not None:
             try:
                 cg = self.get_geometry_from_mp_symbol(mp_symbol)
-                if IUPAC_symbol is not None:
-                    if IUPAC_symbol != cg.IUPAC_symbol:
-                        return False
-                if IUCr_symbol is not None:
-                    if IUCr_symbol != cg.IUCr_symbol:
-                        return False
-                if cn is not None:
-                    if int(cn) != int(cg.coordination_number):
-                        return False
+                if IUPAC_symbol is not None and IUPAC_symbol != cg.IUPAC_symbol:
+                    return False
+                if IUCr_symbol is not None and IUCr_symbol != cg.IUCr_symbol:
+                    return False
+                if cn is not None and int(cn) != int(cg.coordination_number):
+                    return False
                 return True
             except LookupError:
                 return False
         elif IUPAC_symbol is not None:
             try:
                 cg = self.get_geometry_from_IUPAC_symbol(IUPAC_symbol)
-                if IUCr_symbol is not None:
-                    if IUCr_symbol != cg.IUCr_symbol:
-                        return False
-                if cn is not None:
-                    if cn != cg.coordination_number:
-                        return False
+                if IUCr_symbol is not None and IUCr_symbol != cg.IUCr_symbol:
+                    return False
+                if cn is not None and cn != cg.coordination_number:
+                    return False
                 return True
             except LookupError:
                 return False
         elif IUCr_symbol is not None:
             try:
                 cg = self.get_geometry_from_IUCr_symbol(IUCr_symbol)
-                if cn is not None:
-                    if cn != cg.coordination_number:
-                        return False
+                if cn is not None and cn != cg.coordination_number:
+                    return False
                 return True
             except LookupError:
                 return True
@@ -1314,10 +1298,7 @@ class AllCoordinationGeometries(dict):
                     for cg in self.get_implemented_geometries(coordination=cn):
                         if additional_info is not None:
                             if "nb_hints" in additional_info:
-                                if cg.neighbors_sets_hints is not None:
-                                    addinfo = " *"
-                                else:
-                                    addinfo = ""
+                                addinfo = " *" if cg.neighbors_sets_hints is not None else ""
                             else:
                                 addinfo = ""
                         else:
