@@ -1,8 +1,10 @@
+from __future__ import annotations
+
 import json
 import os
-import unittest
 
 import pytest
+from pytest import approx
 
 from pymatgen.analysis.chemenv.coordination_environments.chemenv_strategies import (
     AngleNbSetWeight,
@@ -14,9 +16,7 @@ from pymatgen.analysis.chemenv.coordination_environments.chemenv_strategies impo
     NormalizedAngleDistanceNbSetWeight,
     SelfCSMNbSetWeight,
 )
-from pymatgen.analysis.chemenv.coordination_environments.structure_environments import (
-    StructureEnvironments,
-)
+from pymatgen.analysis.chemenv.coordination_environments.structure_environments import StructureEnvironments
 from pymatgen.util.testing import PymatgenTest
 
 __author__ = "waroquiers"
@@ -57,33 +57,33 @@ class StrategyWeightsTest(PymatgenTest):
             2.2695472184920042,
             2.2695338778592387,
         ]
-        angle_weight = AngleNbSetWeight(aa=1.0)
+        angle_weight = AngleNbSetWeight(aa=1)
         aw = angle_weight.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
         assert abs(aw - 0.9634354419021528) < 1e-8
-        angle_weight = AngleNbSetWeight(aa=2.0)
+        angle_weight = AngleNbSetWeight(aa=2)
         aw = angle_weight.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
         assert abs(aw - 0.92820785071319645) < 1e-8
         angle_weight = AngleNbSetWeight(aa=0.5)
         aw = angle_weight.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
         assert abs(aw - 0.98154747307613843) < 1e-8
 
-        assert AngleNbSetWeight(1.0) != AngleNbSetWeight(2.0)
+        assert AngleNbSetWeight(1) != AngleNbSetWeight(2)
 
         # nb_set with no neighbor
         fake_nb_set.angles = []
-        angle_weight = AngleNbSetWeight(aa=1.0)
+        angle_weight = AngleNbSetWeight(aa=1)
         aw = angle_weight.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        assert abs(aw - 0.0) < 1e-8
-        angle_weight = AngleNbSetWeight(aa=2.0)
+        assert abs(aw - 0) < 1e-8
+        angle_weight = AngleNbSetWeight(aa=2)
         aw = angle_weight.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        assert abs(aw - 0.0) < 1e-8
+        assert abs(aw - 0) < 1e-8
 
         # nb_set with one neighbor
         fake_nb_set.angles = [3.08570351705799]
-        angle_weight = AngleNbSetWeight(aa=1.0)
+        angle_weight = AngleNbSetWeight(aa=1)
         aw = angle_weight.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
         assert abs(aw - 0.24555248382791284) < 1e-8
-        angle_weight = AngleNbSetWeight(aa=2.0)
+        angle_weight = AngleNbSetWeight(aa=2)
         aw = angle_weight.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
         assert abs(aw - 0.060296022314057396) < 1e-8
         angle_weight = AngleNbSetWeight(aa=0.5)
@@ -99,15 +99,15 @@ class StrategyWeightsTest(PymatgenTest):
             2.2695472184920042,
             2.2695338778592387,
         ]
-        angle_weight = AngleNbSetWeight(aa=1.0)
+        angle_weight = AngleNbSetWeight(aa=1)
         aw = angle_weight.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        assert abs(aw - 1.0) < 1e-8
-        angle_weight = AngleNbSetWeight(aa=2.0)
+        assert abs(aw - 1) < 1e-8
+        angle_weight = AngleNbSetWeight(aa=2)
         aw = angle_weight.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        assert abs(aw - 1.0) < 1e-8
+        assert abs(aw - 1) < 1e-8
         angle_weight = AngleNbSetWeight(aa=0.5)
         aw = angle_weight.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        assert abs(aw - 1.0) < 1e-8
+        assert abs(aw - 1) < 1e-8
 
     def test_normalized_angle_distance_weight(self):
         fake_nb_set = FakeNbSet()
@@ -129,21 +129,21 @@ class StrategyWeightsTest(PymatgenTest):
         with pytest.raises(ValueError, match="Both exponents are 0."):
             NormalizedAngleDistanceNbSetWeight(average_type="arithmetic", aa=0, bb=0)
         with pytest.raises(
-            ValueError, match='Average type is "arithmetix" ' 'while it should be "geometric" or "arithmetic"'
+            ValueError, match="Average type is 'arithmetix' while it should be 'geometric' or 'arithmetic'"
         ):
             NormalizedAngleDistanceNbSetWeight(average_type="arithmetix", aa=1, bb=1)
 
         fake_nb_set.normalized_distances = [
             1.2632574171572457,
             1.1231971151388764,
-            1.0,
+            1,
             1.1887986376446249,
             1.188805134890625,
         ]
         fake_nb_set.normalized_angles = [
             0.6026448601336767,
             0.8498933334305273,
-            1.0,
+            1,
             0.7355039801931018,
             0.7354996568248028,
         ]
@@ -175,14 +175,14 @@ class StrategyWeightsTest(PymatgenTest):
     def test_CN_bias_weight(self):
         fake_nb_set = FakeNbSet()
         dummy_se = DummyStructureEnvironments()
-        bias_weight1 = CNBiasNbSetWeight.linearly_equidistant(weight_cn1=1.0, weight_cn13=13.0)
-        bias_weight2 = CNBiasNbSetWeight.geometrically_equidistant(weight_cn1=1.0, weight_cn13=1.1**12)
+        bias_weight1 = CNBiasNbSetWeight.linearly_equidistant(weight_cn1=1, weight_cn13=13)
+        bias_weight2 = CNBiasNbSetWeight.geometrically_equidistant(weight_cn1=1, weight_cn13=1.1**12)
         bias_weight3 = CNBiasNbSetWeight.explicit(
             cn_weights={
-                1: 1.0,
-                2: 3.0,
+                1: 1,
+                2: 3,
                 3: 3.2,
-                4: 4.0,
+                4: 4,
                 5: 4.1,
                 6: 4.2,
                 7: 4.3,
@@ -195,78 +195,78 @@ class StrategyWeightsTest(PymatgenTest):
             }
         )
         with pytest.raises(ValueError, match="Weights should be provided for CN 1 to 13"):
-            CNBiasNbSetWeight.explicit(cn_weights={1: 1.0, 13: 2.0})
+            CNBiasNbSetWeight.explicit(cn_weights={1: 1, 13: 2})
 
         fake_nb_set.cn = 1
         w1 = bias_weight1.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        assert abs(w1 - 1.0) < 1e-8
+        assert abs(w1 - 1) < 1e-8
         w2 = bias_weight2.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        assert abs(w2 - 1.0) < 1e-8
+        assert abs(w2 - 1) < 1e-8
         w3 = bias_weight3.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        assert abs(w3 - 1.0) < 1e-8
+        assert abs(w3 - 1) < 1e-8
         fake_nb_set.cn = 7
         w1 = bias_weight1.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        assert abs(w1 - 7.0) < 1e-8
+        assert abs(w1 - 7) < 1e-8
         w2 = bias_weight2.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
         assert abs(w2 - 1.1**6) < 1e-8
         w3 = bias_weight3.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
         assert abs(w3 - 4.3) < 1e-8
         fake_nb_set.cn = 13
         w1 = bias_weight1.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
-        assert abs(w1 - 13.0) < 1e-8
+        assert abs(w1 - 13) < 1e-8
         w2 = bias_weight2.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
         assert abs(w2 - 1.1**12) < 1e-8
         w3 = bias_weight3.weight(nb_set=fake_nb_set, structure_environments=dummy_se)
         assert abs(w3 - 4.8) < 1e-8
 
         bias_weight4 = CNBiasNbSetWeight.from_description(
-            {"type": "linearly_equidistant", "weight_cn1": 2.0, "weight_cn13": 26.0}
+            {"type": "linearly_equidistant", "weight_cn1": 2, "weight_cn13": 26}
         )
-        for cn in range(1, 14):
-            assert round(abs(bias_weight4.cn_weights[cn] - 2.0 * cn), 7) == 0
+        for idx in range(1, 14):
+            assert bias_weight4.cn_weights[idx] == approx(2 * idx)
 
         bias_weight5 = CNBiasNbSetWeight.from_description(
             {
                 "type": "geometrically_equidistant",
-                "weight_cn1": 1.0,
-                "weight_cn13": 13.0,
+                "weight_cn1": 1,
+                "weight_cn13": 13,
             }
         )
-        assert round(abs(bias_weight5.cn_weights[1] - 1.0), 7) == 0
-        assert round(abs(bias_weight5.cn_weights[3] - 1.5334062370163877), 7) == 0
-        assert round(abs(bias_weight5.cn_weights[9] - 5.5287748136788739), 7) == 0
-        assert round(abs(bias_weight5.cn_weights[12] - 10.498197520079623), 7) == 0
+        assert bias_weight5.cn_weights[1] == approx(1)
+        assert bias_weight5.cn_weights[3] == approx(1.5334062370163877)
+        assert bias_weight5.cn_weights[9] == approx(5.5287748136788739)
+        assert bias_weight5.cn_weights[12] == approx(10.498197520079623)
 
-        cn_weights = {cn: 0.0 for cn in range(1, 14)}
-        cn_weights[6] = 2.0
-        cn_weights[4] = 1.0
+        cn_weights = {cn: 0 for cn in range(1, 14)}
+        cn_weights[6] = 2
+        cn_weights[4] = 1
         bias_weight6 = CNBiasNbSetWeight.from_description({"type": "explicit", "cn_weights": cn_weights})
 
-        assert round(abs(bias_weight6.cn_weights[1] - 0.0), 7) == 0
-        assert round(abs(bias_weight6.cn_weights[4] - 1.0), 7) == 0
-        assert round(abs(bias_weight6.cn_weights[6] - 2.0), 7) == 0
+        assert bias_weight6.cn_weights[1] == approx(0)
+        assert bias_weight6.cn_weights[4] == approx(1)
+        assert bias_weight6.cn_weights[6] == approx(2)
 
     def test_self_csms_weight(self):
         # Get the StructureEnvironments for K2NaNb2Fe7Si8H4O31 (mp-743972)
         with open(os.path.join(se_files_dir, "se_mp-743972.json")) as f:
-            dd = json.load(f)
-        se = StructureEnvironments.from_dict(dd)
+            dct = json.load(f)
+        struct_envs = StructureEnvironments.from_dict(dct)
 
         # Get neighbors sets for which we get the weights
         cn_maps = [(12, 3), (12, 2), (13, 2), (12, 0), (12, 1)]
-        nbsets = {cn_map: se.neighbors_sets[0][cn_map[0]][cn_map[1]] for cn_map in cn_maps}
+        nbsets = {cn_map: struct_envs.neighbors_sets[0][cn_map[0]][cn_map[1]] for cn_map in cn_maps}
 
         effective_csm_estimator = {
             "function": "power2_inverse_decreasing",
-            "options": {"max_csm": 8.0},
+            "options": {"max_csm": 8},
         }
         weight_estimator = {
             "function": "power2_decreasing_exp",
-            "options": {"max_csm": 8.0, "alpha": 1.0},
+            "options": {"max_csm": 8, "alpha": 1},
         }
         weight_estimator2 = {
             "function": "power2_decreasing_exp",
-            "options": {"max_csm": 8.1, "alpha": 1.0},
+            "options": {"max_csm": 8.1, "alpha": 1},
         }
         symmetry_measure_type = "csm_wcs_ctwcc"
         self_weight = SelfCSMNbSetWeight(
@@ -285,7 +285,7 @@ class StrategyWeightsTest(PymatgenTest):
         cn_map = (12, 3)
         self_w = self_weight.weight(
             nb_set=nbsets[cn_map],
-            structure_environments=se,
+            structure_environments=struct_envs,
             cn_map=cn_map,
             additional_info=additional_info,
         )
@@ -293,31 +293,31 @@ class StrategyWeightsTest(PymatgenTest):
         cn_map = (12, 2)
         self_w = self_weight.weight(
             nb_set=nbsets[cn_map],
-            structure_environments=se,
+            structure_environments=struct_envs,
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        assert abs(self_w - 0.0) < 1e-8
+        assert abs(self_w - 0) < 1e-8
         cn_map = (12, 0)
         self_w = self_weight.weight(
             nb_set=nbsets[cn_map],
-            structure_environments=se,
+            structure_environments=struct_envs,
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        assert abs(self_w - 0.0) < 1e-8
+        assert abs(self_w - 0) < 1e-8
         cn_map = (12, 1)
         self_w = self_weight.weight(
             nb_set=nbsets[cn_map],
-            structure_environments=se,
+            structure_environments=struct_envs,
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        assert abs(self_w - 0.0) < 1e-8
+        assert abs(self_w - 0) < 1e-8
         cn_map = (13, 2)
         self_w = self_weight.weight(
             nb_set=nbsets[cn_map],
-            structure_environments=se,
+            structure_environments=struct_envs,
             cn_map=cn_map,
             additional_info=additional_info,
         )
@@ -325,21 +325,21 @@ class StrategyWeightsTest(PymatgenTest):
 
         # Get the StructureEnvironments for SiO2 (mp-7000)
         with open(os.path.join(se_files_dir, "se_mp-7000.json")) as f:
-            dd = json.load(f)
-        se = StructureEnvironments.from_dict(dd)
+            dct = json.load(f)
+        struct_envs = StructureEnvironments.from_dict(dct)
 
         # Get neighbors sets for which we get the weights
         cn_maps = [(2, 0), (4, 0)]
-        nbsets = {cn_map: se.neighbors_sets[6][cn_map[0]][cn_map[1]] for cn_map in cn_maps}
+        nbsets = {cn_map: struct_envs.neighbors_sets[6][cn_map[0]][cn_map[1]] for cn_map in cn_maps}
 
         effective_csm_estimator = {
             "function": "power2_inverse_decreasing",
-            "options": {"max_csm": 8.0},
+            "options": {"max_csm": 8},
         }
 
         weight_estimator = {
             "function": "power2_decreasing_exp",
-            "options": {"max_csm": 8.0, "alpha": 1.0},
+            "options": {"max_csm": 8, "alpha": 1},
         }
         symmetry_measure_type = "csm_wcs_ctwcc"
         self_weight = SelfCSMNbSetWeight(
@@ -352,7 +352,7 @@ class StrategyWeightsTest(PymatgenTest):
         cn_map = (2, 0)
         self_w = self_weight.weight(
             nb_set=nbsets[cn_map],
-            structure_environments=se,
+            structure_environments=struct_envs,
             cn_map=cn_map,
             additional_info=additional_info,
         )
@@ -360,7 +360,7 @@ class StrategyWeightsTest(PymatgenTest):
         cn_map = (4, 0)
         self_w = self_weight.weight(
             nb_set=nbsets[cn_map],
-            structure_environments=se,
+            structure_environments=struct_envs,
             cn_map=cn_map,
             additional_info=additional_info,
         )
@@ -370,19 +370,19 @@ class StrategyWeightsTest(PymatgenTest):
         # Get the StructureEnvironments for K2NaNb2Fe7Si8H4O31 (mp-743972)
         with open(os.path.join(se_files_dir, "se_mp-743972.json")) as f:
             dd = json.load(f)
-        se = StructureEnvironments.from_dict(dd)
+        struct_envs = StructureEnvironments.from_dict(dd)
 
         # Get neighbors sets for which we get the weights
         cn_maps = [(12, 3), (12, 2), (13, 2), (12, 0), (12, 1), (13, 0), (13, 1)]
-        nbsets = {cn_map: se.neighbors_sets[0][cn_map[0]][cn_map[1]] for cn_map in cn_maps}
+        nbsets = {cn_map: struct_envs.neighbors_sets[0][cn_map[0]][cn_map[1]] for cn_map in cn_maps}
 
         effective_csm_estimator = {
             "function": "power2_inverse_decreasing",
-            "options": {"max_csm": 8.0},
+            "options": {"max_csm": 8},
         }
         weight_estimator = {
             "function": "smootherstep",
-            "options": {"delta_csm_min": 0.5, "delta_csm_max": 3.0},
+            "options": {"delta_csm_min": 0.5, "delta_csm_max": 3},
         }
         symmetry_measure_type = "csm_wcs_ctwcc"
         delta_weight = DeltaCSMNbSetWeight(
@@ -395,68 +395,68 @@ class StrategyWeightsTest(PymatgenTest):
         cn_map = (12, 3)
         delta_w = delta_weight.weight(
             nb_set=nbsets[cn_map],
-            structure_environments=se,
+            structure_environments=struct_envs,
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        assert abs(delta_w - 0.0) < 1e-8
+        assert abs(delta_w - 0) < 1e-8
         cn_map = (12, 2)
         delta_w = delta_weight.weight(
             nb_set=nbsets[cn_map],
-            structure_environments=se,
+            structure_environments=struct_envs,
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        assert abs(delta_w - 0.0) < 1e-8
+        assert abs(delta_w - 0) < 1e-8
         cn_map = (12, 0)
         delta_w = delta_weight.weight(
             nb_set=nbsets[cn_map],
-            structure_environments=se,
+            structure_environments=struct_envs,
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        assert abs(delta_w - 0.0) < 1e-8
+        assert abs(delta_w - 0) < 1e-8
         cn_map = (12, 1)
         delta_w = delta_weight.weight(
             nb_set=nbsets[cn_map],
-            structure_environments=se,
+            structure_environments=struct_envs,
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        assert abs(delta_w - 0.0) < 1e-8
+        assert abs(delta_w - 0) < 1e-8
         cn_map = (13, 2)
         delta_w = delta_weight.weight(
             nb_set=nbsets[cn_map],
-            structure_environments=se,
+            structure_environments=struct_envs,
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        assert abs(delta_w - 1.0) < 1e-8
+        assert abs(delta_w - 1) < 1e-8
         cn_map = (13, 0)
         delta_w = delta_weight.weight(
             nb_set=nbsets[cn_map],
-            structure_environments=se,
+            structure_environments=struct_envs,
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        assert abs(delta_w - 0.0) < 1e-8
+        assert abs(delta_w - 0) < 1e-8
         cn_map = (13, 1)
         delta_w = delta_weight.weight(
             nb_set=nbsets[cn_map],
-            structure_environments=se,
+            structure_environments=struct_envs,
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        assert abs(delta_w - 0.0) < 1e-8
+        assert abs(delta_w - 0) < 1e-8
 
         effective_csm_estimator = {
             "function": "power2_inverse_decreasing",
-            "options": {"max_csm": 8.0},
+            "options": {"max_csm": 8},
         }
 
         weight_estimator = {
             "function": "smootherstep",
-            "options": {"delta_csm_min": -1.0, "delta_csm_max": 3.0},
+            "options": {"delta_csm_min": -1, "delta_csm_max": 3},
         }
         symmetry_measure_type = "csm_wcs_ctwcc"
         delta_weight = DeltaCSMNbSetWeight(
@@ -469,7 +469,7 @@ class StrategyWeightsTest(PymatgenTest):
         cn_map = (12, 3)
         delta_w = delta_weight.weight(
             nb_set=nbsets[cn_map],
-            structure_environments=se,
+            structure_environments=struct_envs,
             cn_map=cn_map,
             additional_info=additional_info,
         )
@@ -477,15 +477,15 @@ class StrategyWeightsTest(PymatgenTest):
         cn_map = (13, 2)
         delta_w = delta_weight.weight(
             nb_set=nbsets[cn_map],
-            structure_environments=se,
+            structure_environments=struct_envs,
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        assert abs(delta_w - 1.0) < 1e-8
+        assert abs(delta_w - 1) < 1e-8
         cn_map = (13, 0)
         delta_w = delta_weight.weight(
             nb_set=nbsets[cn_map],
-            structure_environments=se,
+            structure_environments=struct_envs,
             cn_map=cn_map,
             additional_info=additional_info,
         )
@@ -493,7 +493,7 @@ class StrategyWeightsTest(PymatgenTest):
         cn_map = (13, 1)
         delta_w = delta_weight.weight(
             nb_set=nbsets[cn_map],
-            structure_environments=se,
+            structure_environments=struct_envs,
             cn_map=cn_map,
             additional_info=additional_info,
         )
@@ -502,20 +502,20 @@ class StrategyWeightsTest(PymatgenTest):
         # Get the StructureEnvironments for SiO2 (mp-7000)
         with open(os.path.join(se_files_dir, "se_mp-7000.json")) as f:
             dd = json.load(f)
-        se = StructureEnvironments.from_dict(dd)
+        struct_envs = StructureEnvironments.from_dict(dd)
 
         # Get neighbors sets for which we get the weights
         cn_maps = [(2, 0), (4, 0)]
-        nbsets = {cn_map: se.neighbors_sets[6][cn_map[0]][cn_map[1]] for cn_map in cn_maps}
+        nbsets = {cn_map: struct_envs.neighbors_sets[6][cn_map[0]][cn_map[1]] for cn_map in cn_maps}
 
         effective_csm_estimator = {
             "function": "power2_inverse_decreasing",
-            "options": {"max_csm": 8.0},
+            "options": {"max_csm": 8},
         }
 
         weight_estimator = {
             "function": "smootherstep",
-            "options": {"delta_csm_min": 0.5, "delta_csm_max": 3.0},
+            "options": {"delta_csm_min": 0.5, "delta_csm_max": 3},
         }
         symmetry_measure_type = "csm_wcs_ctwcc"
         delta_weight = DeltaCSMNbSetWeight(
@@ -528,22 +528,21 @@ class StrategyWeightsTest(PymatgenTest):
         cn_map = (2, 0)
         delta_w = delta_weight.weight(
             nb_set=nbsets[cn_map],
-            structure_environments=se,
+            structure_environments=struct_envs,
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        assert abs(delta_w - 0.0) < 1e-8
+        assert abs(delta_w - 0) < 1e-8
         cn_map = (4, 0)
         delta_w = delta_weight.weight(
             nb_set=nbsets[cn_map],
-            structure_environments=se,
+            structure_environments=struct_envs,
             cn_map=cn_map,
             additional_info=additional_info,
         )
-        assert abs(delta_w - 1.0) < 1e-8
+        assert abs(delta_w - 1) < 1e-8
 
     def test_dist_angle_area_weight(self):
-
         surface_definition = {
             "type": "standard_elliptic",
             "distance_bounds": {"lower": 1.2, "upper": 1.8},
@@ -587,7 +586,6 @@ class StrategyWeightsTest(PymatgenTest):
         assert da_area_weight.rectangle_crosses_area(d1=d1, d2=d2, a1=a1, a2=a2)
 
     def test_dist_nb_set_weight(self):
-
         dnbset_weight = DistanceNbSetWeight()
         dnbset_weight2 = DistanceNbSetWeight(
             weight_function={
@@ -634,7 +632,7 @@ class StrategyWeightsTest(PymatgenTest):
         dummy_voronoi = DummyVoronoiContainer()
         dummy_voronoi.voronoi_list2 = []
         dummy_voronoi.voronoi_list2.append([])
-        dummy_voronoi.voronoi_list2[0].append({"normalized_distance": 1.0})  # 0
+        dummy_voronoi.voronoi_list2[0].append({"normalized_distance": 1})  # 0
         dummy_voronoi.voronoi_list2[0].append({"normalized_distance": 1.2})  # 1
         dummy_voronoi.voronoi_list2[0].append({"normalized_distance": 1.225})  # 2
         dummy_voronoi.voronoi_list2[0].append({"normalized_distance": 1.25})  # 3
@@ -671,7 +669,7 @@ class StrategyWeightsTest(PymatgenTest):
         cn_map7 = (7, 0)
 
         myweight1 = dnbset_weight.weight(fake_nb_set1, dummy_se, cn_map=cn_map1, additional_info=None)
-        assert abs(myweight1 - 0.0) < 1e-8
+        assert abs(myweight1 - 0) < 1e-8
         myweight2 = dnbset_weight.weight(fake_nb_set2, dummy_se, cn_map=cn_map2, additional_info=None)
         assert abs(myweight2 - 0.103515625) < 1e-8
         myweight3 = dnbset_weight.weight(fake_nb_set3, dummy_se, cn_map=cn_map3, additional_info=None)
@@ -679,11 +677,11 @@ class StrategyWeightsTest(PymatgenTest):
         myweight4 = dnbset_weight.weight(fake_nb_set4, dummy_se, cn_map=cn_map4, additional_info=None)
         assert abs(myweight4 - 0.896484375) < 1e-8
         myweight5 = dnbset_weight.weight(fake_nb_set5, dummy_se, cn_map=cn_map5, additional_info=None)
-        assert abs(myweight5 - 1.0) < 1e-8
+        assert abs(myweight5 - 1) < 1e-8
         myweight5_m2 = dnbset_weight.weight(fake_nb_set5_m2, dummy_se, cn_map=cn_map5_m2, additional_info=None)
         assert abs(myweight5_m2 - 0.103515625) < 1e-8
         myweight7 = dnbset_weight.weight(fake_nb_set7, dummy_se, cn_map=cn_map7, additional_info=None)
-        assert abs(myweight7 - 1.0) < 1e-8
+        assert abs(myweight7 - 1) < 1e-8
 
         myweight_2_3 = dnbset_weight2.weight(fake_nb_set3, dummy_se, cn_map=cn_map3, additional_info=None)
         assert abs(myweight_2_3 - 0.5) < 1e-8
@@ -708,7 +706,7 @@ class StrategyWeightsTest(PymatgenTest):
         )
 
         myweight_3_6 = dnbset_weight3.weight(fake_nb_set6, dummy_se, cn_map=cn_map6, additional_info=None)
-        assert abs(myweight_3_6 - 1.0) < 1e-8
+        assert abs(myweight_3_6 - 1) < 1e-8
         myweight_4_6 = dnbset_weight4.weight(fake_nb_set6, dummy_se, cn_map=cn_map6, additional_info=None)
         assert abs(myweight_4_6 - 0.15625) < 1e-8
 
@@ -720,11 +718,11 @@ class StrategyWeightsTest(PymatgenTest):
         )
 
         myweightdelta1 = deltadnbset_weight.weight(fake_nb_set1, dummy_se, cn_map=cn_map1, additional_info=None)
-        assert abs(myweightdelta1 - 1.0) < 1e-8
+        assert abs(myweightdelta1 - 1) < 1e-8
         myweightdelta2 = deltadnbset_weight.weight(fake_nb_set2, dummy_se, cn_map=cn_map2, additional_info=None)
-        assert abs(myweightdelta2 - 0.0) < 1e-8
+        assert abs(myweightdelta2 - 0) < 1e-8
         myweightdelta3 = deltadnbset_weight.weight(fake_nb_set3, dummy_se, cn_map=cn_map3, additional_info=None)
-        assert abs(myweightdelta3 - 0.0) < 1e-8
+        assert abs(myweightdelta3 - 0) < 1e-8
 
         deltadnbset_weight2 = DeltaDistanceNbSetWeight(
             weight_function={
@@ -736,9 +734,9 @@ class StrategyWeightsTest(PymatgenTest):
         myweightdelta1 = deltadnbset_weight2.weight(fake_nb_set1, dummy_se, cn_map=cn_map1, additional_info=None)
         assert abs(myweightdelta1 - 0.5) < 1e-8
         myweightdelta2 = deltadnbset_weight2.weight(fake_nb_set2, dummy_se, cn_map=cn_map2, additional_info=None)
-        assert abs(myweightdelta2 - 0.0) < 1e-8
+        assert abs(myweightdelta2 - 0) < 1e-8
         myweightdelta3 = deltadnbset_weight2.weight(fake_nb_set3, dummy_se, cn_map=cn_map3, additional_info=None)
-        assert abs(myweightdelta3 - 0.0) < 1e-8
+        assert abs(myweightdelta3 - 0) < 1e-8
 
         deltadnbset_weight3 = DeltaDistanceNbSetWeight(
             weight_function={
@@ -763,8 +761,4 @@ class StrategyWeightsTest(PymatgenTest):
         myweightdelta1 = deltadnbset_weight4.weight(fake_nb_set1, dummy_se, cn_map=cn_map1, additional_info=None)
         assert abs(myweightdelta1 - 0.15625) < 1e-8
         myweightdelta6 = deltadnbset_weight4.weight(fake_nb_set6, dummy_se, cn_map=cn_map6, additional_info=None)
-        assert abs(myweightdelta6 - 1.0) < 1e-8
-
-
-if __name__ == "__main__":
-    unittest.main()
+        assert abs(myweightdelta6 - 1) < 1e-8
