@@ -1,18 +1,15 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module contains some script utils that are used in the chemenv package.
 """
 
 
+from __future__ import annotations
+
 import re
 
 import numpy as np
 
-from pymatgen.analysis.chemenv.coordination_environments.chemenv_strategies import (
-    SimplestChemenvStrategy,
-)
+from pymatgen.analysis.chemenv.coordination_environments.chemenv_strategies import SimplestChemenvStrategy
 from pymatgen.analysis.chemenv.coordination_environments.coordination_geometries import (
     UNCLEAR_ENVIRONMENT_SYMBOL,
     AllCoordinationGeometries,
@@ -21,9 +18,7 @@ from pymatgen.analysis.chemenv.coordination_environments.coordination_geometry_f
     AbstractGeometry,
     LocalGeometryFinder,
 )
-from pymatgen.analysis.chemenv.utils.chemenv_errors import (
-    NeighborsNotComputedChemenvError,
-)
+from pymatgen.analysis.chemenv.utils.chemenv_errors import NeighborsNotComputedChemenvError
 from pymatgen.analysis.chemenv.utils.coordination_geometry_utils import rotateCoords
 from pymatgen.core.sites import PeriodicSite
 from pymatgen.core.structure import Molecule
@@ -99,30 +94,26 @@ def draw_cg(
     if len(neighbors) < 3:
         if show_distorted:
             vis.add_bonds(neighbors, site, color=[0.0, 1.0, 0.0], opacity=0.4, radius=0.175)
-        if show_perfect:
-            if len(neighbors) == 2:
-                perfect_geometry = AbstractGeometry.from_cg(cg)
-                trans = csm_info["other_symmetry_measures"][f"translation_vector_{csm_suffix}"]
-                rot = csm_info["other_symmetry_measures"][f"rotation_matrix_{csm_suffix}"]
-                scale = csm_info["other_symmetry_measures"][f"scaling_factor_{csm_suffix}"]
-                points = perfect_geometry.points_wcs_ctwcc()
-                rotated_points = rotateCoords(points, rot)
-                points = [scale * pp + trans for pp in rotated_points]
-                if "wcs" in csm_suffix:
-                    ef_points = points[1:]
-                else:
-                    ef_points = points
-                edges = cg.edges(ef_points, input="coords")
-                vis.add_edges(edges, color=[1.0, 0.0, 0.0])
-                for point in points:
-                    vis.add_partial_sphere(
-                        coords=point,
-                        radius=perf_radius,
-                        color=[0.0, 0.0, 0.0],
-                        start=0,
-                        end=360,
-                        opacity=1,
-                    )
+        if show_perfect and len(neighbors) == 2:
+            perfect_geometry = AbstractGeometry.from_cg(cg)
+            trans = csm_info["other_symmetry_measures"][f"translation_vector_{csm_suffix}"]
+            rot = csm_info["other_symmetry_measures"][f"rotation_matrix_{csm_suffix}"]
+            scale = csm_info["other_symmetry_measures"][f"scaling_factor_{csm_suffix}"]
+            points = perfect_geometry.points_wcs_ctwcc()
+            rotated_points = rotateCoords(points, rot)
+            points = [scale * pp + trans for pp in rotated_points]
+            ef_points = points[1:] if "wcs" in csm_suffix else points
+            edges = cg.edges(ef_points, input="coords")
+            vis.add_edges(edges, color=[1.0, 0.0, 0.0])
+            for point in points:
+                vis.add_partial_sphere(
+                    coords=point,
+                    radius=perf_radius,
+                    color=[0.0, 0.0, 0.0],
+                    start=0,
+                    end=360,
+                    opacity=1,
+                )
     else:
         if show_distorted:
             if perm is not None:
@@ -149,10 +140,7 @@ def draw_cg(
             points = perfect_geometry.points_wcs_ctwcc()
             rotated_points = rotateCoords(points, rot)
             points = [scale * pp + trans for pp in rotated_points]
-            if "wcs" in csm_suffix:
-                ef_points = points[1:]
-            else:
-                ef_points = points
+            ef_points = points[1:] if "wcs" in csm_suffix else points
             edges = cg.edges(ef_points, input="coords")
             vis.add_edges(edges, color=[1.0, 0.0, 0.0])
             for point in points:
@@ -305,13 +293,16 @@ def compute_environments(chemenv_configuration):
                             cg = allcg.get_geometry_from_mp_symbol(ce[0])
                             csm = ce[1]["other_symmetry_measures"]["csm_wcs_ctwcc"]
                             mystring += f" - {cg.name} ({cg.mp_symbol}): {ce[2]:.2%} (csm : {csm:2f})\n"
-                    if test in ["d", "g"] and strategy.uniquely_determines_coordination_environments:
-                        if thecg.mp_symbol != UNCLEAR_ENVIRONMENT_SYMBOL:
-                            mystring += "  <Continuous symmetry measures>  "
-                            mingeoms = se.ce_list[isite][thecg.coordination_number][0].minimum_geometries()
-                            for mingeom in mingeoms:
-                                csm = mingeom[1]["other_symmetry_measures"]["csm_wcs_ctwcc"]
-                                mystring += f"{mingeom[0]} : {csm:.2f}       "
+                    if (
+                        test in ["d", "g"]
+                        and strategy.uniquely_determines_coordination_environments
+                        and thecg.mp_symbol != UNCLEAR_ENVIRONMENT_SYMBOL
+                    ):
+                        mystring += "  <Continuous symmetry measures>  "
+                        mingeoms = se.ce_list[isite][thecg.coordination_number][0].minimum_geometries()
+                        for mingeom in mingeoms:
+                            csm = mingeom[1]["other_symmetry_measures"]["csm_wcs_ctwcc"]
+                            mystring += f"{mingeom[0]} : {csm:.2f}       "
                     print(mystring)
             if test == "g":
                 while True:
