@@ -1,6 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module is used to estimate the cost of various compounds. Costs are taken
 from the a CostDB instance, for example a CSV file via CostDBCSV.
@@ -9,6 +6,8 @@ optimization is performed to determine a set of compositions that can be mixed
 to give the desired compound with lowest total cost.
 """
 
+from __future__ import annotations
+
 import abc
 import csv
 import itertools
@@ -36,8 +35,7 @@ module_dir = os.path.dirname(os.path.abspath(__file__))
 
 class CostEntry(PDEntry):
     """
-    Extends PDEntry to include a BibTeX reference and include language about
-    cost
+    Extends PDEntry to include a BibTeX reference and include language about cost
     """
 
     def __init__(self, composition, cost, name, reference):
@@ -158,8 +156,8 @@ class CostAnalyzer:
         """
         entries_list = []
         elements = [e.symbol for e in composition.elements]
-        for i in range(len(elements)):
-            for combi in itertools.combinations(elements, i + 1):
+        for idx in range(len(elements)):
+            for combi in itertools.combinations(elements, idx + 1):
                 chemsys = [Element(e) for e in combi]
                 x = self.costdb.get_entries(chemsys)
                 entries_list.extend(x)
