@@ -1,19 +1,21 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module implements core classes for calculation of diffraction patterns.
 """
 
+from __future__ import annotations
+
 import abc
 import collections
+from typing import TYPE_CHECKING
 
 import numpy as np
 
 from pymatgen.core.spectrum import Spectrum
-from pymatgen.core.structure import Structure
 from pymatgen.util.plotting import add_fig_kwargs
 
+if TYPE_CHECKING:
+    from pymatgen.core import Structure
+
 
 class DiffractionPattern(Spectrum):
     """
@@ -119,7 +121,7 @@ class AbstractDiffractionPatternCalculator(abc.ABC):
         for two_theta, i, hkls in zip(xrd.x, xrd.y, xrd.hkls):
             if two_theta_range[0] <= two_theta <= two_theta_range[1]:
                 hkl_tuples = [hkl["hkl"] for hkl in hkls]
-                label = ", ".join([str(hkl_tuple) for hkl_tuple in hkl_tuples])  # 'full' label
+                label = ", ".join(map(str, hkl_tuples))  # 'full' label
                 ax.plot([two_theta, two_theta], [0, i], color="k", linewidth=3, label=label)
 
                 if annotate_peaks == "full":
@@ -131,7 +133,7 @@ class AbstractDiffractionPatternCalculator(abc.ABC):
                     )
                 elif annotate_peaks == "compact":
                     if all(all(i < 10 for i in hkl_tuple) for hkl_tuple in hkl_tuples):
-                        label = ",".join(["".join([str(i) for i in hkl_tuple]) for hkl_tuple in hkl_tuples])
+                        label = ",".join("".join(map(str, hkl_tuple)) for hkl_tuple in hkl_tuples)
                         # 'compact' label. Would be unclear for indices >= 10
                         # It would have more than 3 figures, e.g. 1031
 
@@ -224,7 +226,7 @@ def get_unique_families(hkls):
     """
 
     # TODO: Definitely can be sped up.
-    def is_perm(hkl1, hkl2):
+    def is_perm(hkl1, hkl2) -> bool:
         h1 = np.abs(hkl1)
         h2 = np.abs(hkl2)
         return all(i == j for i, j in zip(sorted(h1), sorted(h2)))
