@@ -1,6 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module implements a neutron diffraction (ND) pattern calculator.
 """
@@ -10,6 +7,7 @@ from __future__ import annotations
 import json
 import os
 from math import asin, cos, degrees, pi, radians, sin
+from typing import TYPE_CHECKING
 
 import numpy as np
 
@@ -18,9 +16,11 @@ from pymatgen.analysis.diffraction.core import (
     DiffractionPattern,
     get_unique_families,
 )
-from pymatgen.core.structure import Structure
 from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
 
+if TYPE_CHECKING:
+    from pymatgen.core import Structure
+
 __author__ = "Yuta Suzuki"
 __copyright__ = "Copyright 2018, The Materials Project"
 __version__ = "0.1"
@@ -140,7 +140,6 @@ class NDCalculator(AbstractDiffractionPatternCalculator):
             # Force miller indices to be integers.
             hkl = [int(round(i)) for i in hkl]
             if g_hkl != 0:
-
                 d_hkl = 1 / g_hkl
 
                 # Bragg condition
