@@ -1,7 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-# Credit to Dr. Shyue Ping Ong for the template of the calculator
-
 """
 This module implements a TEM pattern calculator.
 """
@@ -12,8 +8,7 @@ import json
 import os
 from collections import namedtuple
 from fractions import Fraction
-from functools import lru_cache
-from typing import List, Tuple, cast
+from typing import TYPE_CHECKING, List, Tuple, cast
 
 import numpy as np
 import pandas as pd
@@ -21,10 +16,12 @@ import plotly.graph_objs as go
 import scipy.constants as sc
 
 from pymatgen.analysis.diffraction.core import AbstractDiffractionPatternCalculator
-from pymatgen.core.structure import Structure
 from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
 from pymatgen.util.string import latexify_spacegroup, unicodeify_spacegroup
 
+if TYPE_CHECKING:
+    from pymatgen.core import Structure
+
 with open(os.path.join(os.path.dirname(__file__), "atomic_scattering_params.json")) as f:
     ATOMIC_SCATTERING_PARAMS = json.load(f)
 
@@ -47,11 +44,11 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
 
     def __init__(
         self,
-        symprec: float = None,
+        symprec: float | None = None,
         voltage: float = 200,
         beam_direction: tuple[int, int, int] = (0, 0, 1),
         camera_length: int = 160,
-        debye_waller_factors: dict[str, float] = None,
+        debye_waller_factors: dict[str, float] | None = None,
         cs: float = 1,
     ) -> None:
         """
@@ -78,32 +75,27 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         self.debye_waller_factors = debye_waller_factors or {}
         self.cs = cs
 
-    @lru_cache(1)
     def wavelength_rel(self) -> float:
         """
         Calculates the wavelength of the electron beam with relativistic kinematic effects taken
             into account.
-        Args:
-            none
+
         Returns:
-            Relativistic Wavelength (in angstroms)
+            float: Relativistic Wavelength (in angstroms)
         """
-        wavelength_rel = (
-            sc.h
-            / np.sqrt(
-                2 * sc.m_e * sc.e * 1000 * self.voltage * (1 + (sc.e * 1000 * self.voltage) / (2 * sc.m_e * sc.c**2))
-            )
-            * (10**10)
-        )
+        sqr = 2 * sc.m_e * sc.e * 1000 * self.voltage * (1 + (sc.e * 1000 * self.voltage) / (2 * sc.m_e * sc.c**2))
+        wavelength_rel = sc.h / np.sqrt(sqr) * (10**10)
         return wavelength_rel
 
     @staticmethod
     def generate_points(coord_left: int = -10, coord_right: int = 10) -> np.ndarray:
         """
         Generates a bunch of 3D points that span a cube.
+
         Args:
             coord_left (int): The minimum coordinate value.
             coord_right (int): The maximum coordinate value.
+
         Returns:
             Numpy 2d array
         """
@@ -119,9 +111,11 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
     ) -> list[tuple[int, int, int]]:
         """
         Filters out all points that exist within the specified Laue zone according to the zone axis rule.
+
         Args:
             points (np.ndarray): The list of points to be filtered.
             laue_zone (int): The desired Laue zone.
+
         Returns:
             list of 3-tuples
         """
@@ -141,13 +135,14 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         Args:
             structure (Structure): the input structure.
             points (tuple): the desired hkl indices.
+
         Returns:
             Dict of hkl to its interplanar spacing, in angstroms (float).
         """
         points_filtered = self.zone_axis_filter(points)
         if (0, 0, 0) in points_filtered:
             points_filtered.remove((0, 0, 0))
-        interplanar_spacings_val = np.array(list(map(lambda x: structure.lattice.d_hkl(x), points_filtered)))
+        interplanar_spacings_val = np.array([structure.lattice.d_hkl(x) for x in points_filtered])
         interplanar_spacings = dict(zip(points_filtered, interplanar_spacings_val))
         return interplanar_spacings
 
@@ -156,6 +151,7 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
     ) -> dict[tuple[int, int, int], float]:
         """
         Gets the Bragg angles for every hkl point passed in (where n = 1).
+
         Args:
             interplanar_spacings (dict): dictionary of hkl to interplanar spacing
         Returns:
@@ -170,8 +166,10 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
     def get_s2(self, bragg_angles: dict[tuple[int, int, int], float]) -> dict[tuple[int, int, int], float]:
         """
         Calculates the s squared parameter (= square of sin theta over lambda) for each hkl plane.
+
         Args:
             bragg_angles (dict): The bragg angles for each hkl plane.
+
         Returns:
             Dict of hkl plane to s2 parameter, calculates the s squared parameter
                 (= square of sin theta over lambda).
@@ -188,9 +186,11 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         """
         Calculates x-ray factors, which are required to calculate atomic scattering factors. Method partially inspired
         by the equivalent process in the xrd module.
+
         Args:
             structure (Structure): The input structure.
             bragg_angles (dict): Dictionary of hkl plane to Bragg angle.
+
         Returns:
             dict of atomic symbol to another dict of hkl plane to x-ray factor (in angstroms).
         """
@@ -214,9 +214,11 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
     ) -> dict[str, dict[tuple[int, int, int], float]]:
         """
         Calculates atomic scattering factors for electrons using the Mott-Bethe formula (1st order Born approximation).
+
         Args:
             structure (Structure): The input structure.
             bragg_angles (dict of 3-tuple to float): The Bragg angles for each hkl plane.
+
         Returns:
             dict from atomic symbol to another dict of hkl plane to factor (in angstroms)
         """
@@ -239,9 +241,11 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
     ) -> dict[tuple[int, int, int], int]:
         """
         Calculates the scattering factor for the whole cell.
+
         Args:
             structure (Structure): The input structure.
             bragg_angles (dict of 3-tuple to float): The Bragg angles for each hkl plane.
+
         Returns:
             dict of hkl plane (3-tuple) to scattering factor (in angstroms).
         """
@@ -264,30 +268,32 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
     ) -> dict[tuple[int, int, int], float]:
         """
         Calculates cell intensity for each hkl plane. For simplicity's sake, take I = |F|**2.
+
         Args:
             structure (Structure): The input structure.
             bragg_angles (dict of 3-tuple to float): The Bragg angles for each hkl plane.
+
         Returns:
             dict of hkl plane to cell intensity
         """
         csf = self.cell_scattering_factors(structure, bragg_angles)
-        plane = bragg_angles.keys()
         csf_val = np.array(list(csf.values()))
         cell_intensity_val = (csf_val * csf_val.conjugate()).real
-        cell_intensity = dict(zip(plane, cell_intensity_val))
+        cell_intensity = dict(zip(bragg_angles, cell_intensity_val))
         return cell_intensity
 
     def get_pattern(
         self,
         structure: Structure,
-        scaled: bool = None,
-        two_theta_range: tuple[float, float] = None,
+        scaled: bool | None = None,
+        two_theta_range: tuple[float, float] | None = None,
     ) -> pd.DataFrame:
         """
         Returns all relevant TEM DP info in a pandas dataframe.
+
         Args:
             structure (Structure): The input structure.
-            scaled (boolean): Required value for inheritance, does nothing in TEM pattern
+            scaled (bool): Required value for inheritance, does nothing in TEM pattern
             two_theta_range (Tuple): Required value for inheritance, does nothing in TEM pattern
         Returns:
             PandasDataFrame
@@ -322,9 +328,11 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
     ) -> dict[tuple[int, int, int], float]:
         """
         Normalizes the cell_intensity dict to 1, for use in plotting.
+
         Args:
             structure (Structure): The input structure.
             bragg_angles (dict of 3-tuple to float): The Bragg angles for each hkl plane.
+
         Returns:
             dict of hkl plane to normalized cell intensity
         """
@@ -344,10 +352,12 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
     ) -> bool:
         """
         Checks if two hkl planes are parallel in reciprocal space.
+
         Args:
             structure (Structure): The input structure.
             plane (3-tuple): The first plane to be compared.
             other_plane (3-tuple): The other plane to be compared.
+
         Returns:
             boolean
         """
@@ -357,9 +367,11 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
     def get_first_point(self, structure: Structure, points: list) -> dict[tuple[int, int, int], float]:
         """
         Gets the first point to be plotted in the 2D DP, corresponding to maximum d/minimum R.
+
         Args:
             structure (Structure): The input structure.
             points (list): All points to be checked.
+
         Returns:
             dict of a hkl plane to max interplanar distance.
         """
@@ -378,6 +390,7 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         """
         Returns the interplanar angle (in degrees) between the normal of two crystal planes.
         Formulas from International Tables for Crystallography Volume C pp. 2-9.
+
         Args:
             structure (Structure): The input structure.
             p1 (3-tuple): plane 1
@@ -434,10 +447,12 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         """
         Calculates coefficients of the vector addition required to generate positions for each DP point
         by the Moore-Penrose inverse method.
+
         Args:
             p1 (3-tuple): The first point. Fixed.
             p2 (3-tuple): The second point. Fixed.
             p3 (3-tuple): The point whose coefficients are to be calculted.
+
         Returns:
             Numpy array
         """
@@ -451,9 +466,11 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         """
         Calculates all the positions of each hkl point in the 2D diffraction pattern by vector addition.
         Distance in centimeters.
+
         Args:
             structure (Structure): The input structure.
             points (list): All points to be checked.
+
         Returns:
             dict of hkl plane to xy-coordinates.
         """
@@ -501,9 +518,11 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
     def tem_dots(self, structure: Structure, points) -> list:
         """
         Generates all TEM_dot as named tuples that will appear on the 2D diffraction pattern.
+
         Args:
             structure (Structure): The input structure.
             points (list): All points to be checked.
+
         Returns:
             list of TEM_dots
         """
@@ -524,8 +543,10 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
     def get_plot_2d(self, structure: Structure) -> go.Figure:
         """
         Generates the 2D diffraction pattern of the input structure.
+
         Args:
             structure (Structure): The input structure.
+
         Returns:
             Figure
         """
@@ -551,13 +572,13 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
                 text=hkls,
                 hoverinfo="text",
                 mode="markers",
-                marker=dict(
-                    size=8,
-                    cmax=1,
-                    cmin=0,
-                    color=intensities,
-                    colorscale=[[0, "black"], [1.0, "white"]],
-                ),
+                marker={
+                    "size": 8,
+                    "cmax": 1,
+                    "cmin": 0,
+                    "color": intensities,
+                    "colorscale": [[0, "black"], [1, "white"]],
+                },
                 showlegend=False,
             ),
             go.Scatter(
@@ -566,30 +587,30 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
                 text="(0, 0, 0): Direct beam",
                 hoverinfo="text",
                 mode="markers",
-                marker=dict(size=14, cmax=1, cmin=0, color="white"),
+                marker={"size": 14, "cmax": 1, "cmin": 0, "color": "white"},
                 showlegend=False,
             ),
         ]
         layout = go.Layout(
             title="2D Diffraction Pattern<br>Beam Direction: " + "".join(str(e) for e in self.beam_direction),
-            font=dict(size=14, color="#7f7f7f"),
+            font={"size": 14, "color": "#7f7f7f"},
             hovermode="closest",
-            xaxis=dict(
-                range=[-4, 4],
-                showgrid=False,
-                zeroline=False,
-                showline=False,
-                ticks="",
-                showticklabels=False,
-            ),
-            yaxis=dict(
-                range=[-4, 4],
-                showgrid=False,
-                zeroline=False,
-                showline=False,
-                ticks="",
-                showticklabels=False,
-            ),
+            xaxis={
+                "range": [-4, 4],
+                "showgrid": False,
+                "zeroline": False,
+                "showline": False,
+                "ticks": "",
+                "showticklabels": False,
+            },
+            yaxis={
+                "range": [-4, 4],
+                "showgrid": False,
+                "zeroline": False,
+                "showline": False,
+                "ticks": "",
+                "showticklabels": False,
+            },
             width=550,
             height=550,
             paper_bgcolor="rgba(100,110,110,0.5)",
@@ -602,8 +623,10 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         """
         Generates the concise 2D diffraction pattern of the input structure of a smaller size and without layout.
         Does not display.
+
         Args:
             structure (Structure): The input structure.
+
         Returns:
             Figure
         """
@@ -629,33 +652,33 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
                 text=hkls,
                 mode="markers",
                 hoverinfo="skip",
-                marker=dict(
-                    size=4,
-                    cmax=1,
-                    cmin=0,
-                    color=intensities,
-                    colorscale=[[0, "black"], [1.0, "white"]],
-                ),
+                marker={
+                    "size": 4,
+                    "cmax": 1,
+                    "cmin": 0,
+                    "color": intensities,
+                    "colorscale": [[0, "black"], [1, "white"]],
+                },
                 showlegend=False,
             )
         ]
         layout = go.Layout(
-            xaxis=dict(
-                range=[-4, 4],
-                showgrid=False,
-                zeroline=False,
-                showline=False,
-                ticks="",
-                showticklabels=False,
-            ),
-            yaxis=dict(
-                range=[-4, 4],
-                showgrid=False,
-                zeroline=False,
-                showline=False,
-                ticks="",
-                showticklabels=False,
-            ),
+            xaxis={
+                "range": [-4, 4],
+                "showgrid": False,
+                "zeroline": False,
+                "showline": False,
+                "ticks": "",
+                "showticklabels": False,
+            },
+            yaxis={
+                "range": [-4, 4],
+                "showgrid": False,
+                "zeroline": False,
+                "showline": False,
+                "ticks": "",
+                "showticklabels": False,
+            },
             plot_bgcolor="black",
             margin={"l": 0, "r": 0, "t": 0, "b": 0},
             width=121,
