@@ -1,16 +1,13 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 Unit tests for TEM calculator.
 """
 
-import unittest
+from __future__ import annotations
 
 import numpy as np
 import pandas as pd
 import plotly.graph_objs as go
-import pytest
+from pytest import approx
 
 from pymatgen.analysis.diffraction.tem import TEMCalculator
 from pymatgen.core.lattice import Lattice
@@ -27,12 +24,12 @@ __date__ = "2/20/20"
 
 class TEMCalculatorTest(PymatgenTest):
     def test_wavelength_rel(self):
-        # Tests that the relativistic wavelength formula (for 200kv electron beam) is correct
+        # Test that the relativistic wavelength formula (for 200kv electron beam) is correct
         c = TEMCalculator()
-        assert c.wavelength_rel() == pytest.approx(0.025079, rel=1e-4)
+        assert c.wavelength_rel() == approx(0.025079, rel=1e-4)
 
     def test_generate_points(self):
-        # Tests that 3d points are properly generated
+        # Test that 3d points are properly generated
         c = TEMCalculator()
         actual = c.generate_points(-1, 1)
         expected = np.array(
@@ -66,10 +63,10 @@ class TEMCalculatorTest(PymatgenTest):
                 [1, 1, 1],
             ]
         )
-        self.assertArrayEqual(expected, actual)
+        assert expected == approx(actual)
 
     def test_zone_axis_filter(self):
-        # Tests that the appropriate Laue-Zoned points are returned
+        # Test that the appropriate Laue-Zoned points are returned
         c = TEMCalculator()
         empty_points = np.asarray([])
         assert c.zone_axis_filter(empty_points) == []
@@ -79,7 +76,7 @@ class TEMCalculatorTest(PymatgenTest):
         assert c.zone_axis_filter(laue_1, 1) == [(0, 0, 1)]
 
     def test_get_interplanar_spacings(self):
-        # Tests that the appropriate interplacing spacing is returned
+        # Test that the appropriate interplacing spacing is returned
         c = TEMCalculator()
         point = [(3, 9, 0)]
         latt = Lattice.cubic(4.209)
@@ -94,14 +91,14 @@ class TEMCalculatorTest(PymatgenTest):
         spacings_ortho = c.get_interplanar_spacings(ortho, point)
         spacings_mono = c.get_interplanar_spacings(mono, point)
         for p in point:
-            assert spacings_cubic[p] == pytest.approx(0.4436675557216236)
-            assert spacings_tet[p] == pytest.approx(0.9164354445646701)
-            assert spacings_hexa[p] == pytest.approx(0.19775826179547752)
-            assert spacings_ortho[p] == pytest.approx(0.5072617738916)
-            assert spacings_mono[p] == pytest.approx(0.84450786041677972)
+            assert spacings_cubic[p] == approx(0.4436675557216236)
+            assert spacings_tet[p] == approx(0.9164354445646701)
+            assert spacings_hexa[p] == approx(0.19775826179547752)
+            assert spacings_ortho[p] == approx(0.5072617738916)
+            assert spacings_mono[p] == approx(0.84450786041677972)
 
     def test_bragg_angles(self):
-        # Tests that the appropriate bragg angle is returned. Testing formula with values of x-ray diffraction in
+        # Test that the appropriate bragg angle is returned. Testing formula with values of x-ray diffraction in
         # materials project.
         c = TEMCalculator()
         latt = Lattice.cubic(4.209)
@@ -109,10 +106,10 @@ class TEMCalculatorTest(PymatgenTest):
         point = [(1, 1, 0)]
         spacings = c.get_interplanar_spacings(cubic, point)
         bragg_angles_val = np.arcsin(1.5406 / (2 * spacings[point[0]]))
-        assert bragg_angles_val == pytest.approx(0.26179, rel=1e-4)
+        assert bragg_angles_val == approx(0.26179, rel=1e-4)
 
     def test_get_s2(self):
-        # Tests that the appropriate s2 factor is returned.
+        # Test that the appropriate s2 factor is returned.
         c = TEMCalculator()
         latt = Lattice.cubic(4.209)
         cubic = Structure(latt, ["Cs", "Cl"], [[0, 0, 0], [0.5, 0.5, 0.5]])
@@ -121,7 +118,7 @@ class TEMCalculatorTest(PymatgenTest):
         angles = c.bragg_angles(spacings)
         s2 = c.get_s2(angles)
         for p in s2:
-            assert s2[p] == pytest.approx(1.5381852947115047)
+            assert s2[p] == approx(1.5381852947115047)
 
     def test_x_ray_factors(self):
         c = TEMCalculator()
@@ -131,8 +128,8 @@ class TEMCalculatorTest(PymatgenTest):
         spacings = c.get_interplanar_spacings(cubic, point)
         angles = c.bragg_angles(spacings)
         x_ray = c.x_ray_factors(cubic, angles)
-        assert x_ray["Cs"][(-10, 3, 0)] == pytest.approx(14.42250869579648)
-        assert x_ray["Cl"][(-10, 3, 0)] == pytest.approx(2.7804915737999103)
+        assert x_ray["Cs"][(-10, 3, 0)] == approx(14.42250869579648)
+        assert x_ray["Cl"][(-10, 3, 0)] == approx(2.7804915737999103)
 
     def test_electron_scattering_factors(self):
         # Test the electron atomic scattering factor, values approximate with
@@ -150,10 +147,10 @@ class TEMCalculatorTest(PymatgenTest):
         angles_nacl = c.bragg_angles(spacings_nacl)
         elscatt = c.electron_scattering_factors(cubic, angles)
         elscatt_nacl = c.electron_scattering_factors(nacl, angles_nacl)
-        assert elscatt["Cs"][(2, 1, 3)] == pytest.approx(2.848, rel=1e-3)
-        assert elscatt["Cl"][(2, 1, 3)] == pytest.approx(1.1305, rel=1e-3)
-        assert elscatt_nacl["Na"][(4, 2, 0)] == pytest.approx(0.8352, rel=1e-3)
-        assert elscatt_nacl["Cl"][(4, 2, 0)] == pytest.approx(1.3673, rel=1e-3)
+        assert elscatt["Cs"][(2, 1, 3)] == approx(2.848, rel=1e-3)
+        assert elscatt["Cl"][(2, 1, 3)] == approx(1.1305, rel=1e-3)
+        assert elscatt_nacl["Na"][(4, 2, 0)] == approx(0.8352, rel=1e-3)
+        assert elscatt_nacl["Cl"][(4, 2, 0)] == approx(1.3673, rel=1e-3)
 
     def test_cell_scattering_factors(self):
         # Test that fcc structure gives 0 intensity for mixed even, odd hkl.
@@ -163,7 +160,7 @@ class TEMCalculatorTest(PymatgenTest):
         spacings = c.get_interplanar_spacings(nacl, point)
         angles = c.bragg_angles(spacings)
         cellscatt = c.cell_scattering_factors(nacl, angles)
-        assert cellscatt[(2, 1, 0)] == pytest.approx(0)
+        assert cellscatt[(2, 1, 0)] == approx(0)
 
     def test_cell_intensity(self):
         # Test that bcc structure gives lower intensity for h + k + l != even.
@@ -189,7 +186,7 @@ class TEMCalculatorTest(PymatgenTest):
         spacings = c.get_interplanar_spacings(cubic, point)
         angles = c.bragg_angles(spacings)
         cellint = c.normalized_cell_intensity(cubic, angles)
-        assert cellint[(2, 0, 0)] == pytest.approx(1)
+        assert cellint[(2, 0, 0)] == approx(1)
 
     def test_is_parallel(self):
         c = TEMCalculator()
@@ -212,30 +209,30 @@ class TEMCalculatorTest(PymatgenTest):
         latt = Lattice.cubic(4.209)
         cubic = Structure(latt, ["Cs", "Cl"], [[0, 0, 0], [0.5, 0.5, 0.5]])
         phi = c.get_interplanar_angle(cubic, (0, 0, -1), (0, -1, 0))
-        assert phi == pytest.approx(90)
+        assert phi == approx(90)
         tet = self.get_structure("Li10GeP2S12")
         phi = c.get_interplanar_angle(tet, (0, 0, 1), (1, 0, 3))
-        assert phi == pytest.approx(25.7835, rel=1e-4)
+        assert phi == approx(25.7835, rel=1e-4)
         latt = Lattice.hexagonal(2, 4)
         hex = Structure(latt, ["Ab"], [[0, 0, 0]])
         phi = c.get_interplanar_angle(hex, (0, 0, 1), (1, 0, 6))
-        assert phi == pytest.approx(21.0517, rel=1e-4)
+        assert phi == approx(21.0517, rel=1e-4)
 
     def test_get_plot_coeffs(self):
         # Test if x * p1 + y * p2 yields p3.
         c = TEMCalculator()
         coeffs = c.get_plot_coeffs((1, 1, 0), (1, -1, 0), (2, 0, 0))
-        self.assertArrayAlmostEqual(np.array([1.0, 1.0]), coeffs)
+        self.assert_all_close(np.array([1, 1]), coeffs)
 
     def test_get_positions(self):
         c = TEMCalculator()
         points = c.generate_points(-2, 2)
         structure = self.get_structure("Si")
         positions = c.get_positions(structure, points)
-        self.assertArrayEqual([0, 0], positions[(0, 0, 0)])
+        assert [0, 0] == positions[(0, 0, 0)].tolist()
         # Test silicon diffraction data spot rough positions:
         # see https://www.doitpoms.ac.uk/tlplib/diffraction-patterns/printall.php
-        self.assertArrayAlmostEqual([1, 0], positions[(-1, 0, 0)], 0)
+        self.assert_all_close([1, 0], positions[(-1, 0, 0)], 0)
 
     def test_TEM_dots(self):
         # All dependencies in TEM_dots method are tested. Only make sure each object created is
@@ -244,7 +241,7 @@ class TEMCalculatorTest(PymatgenTest):
         points = c.generate_points(-2, 2)
         structure = self.get_structure("Si")
         dots = c.tem_dots(structure, points)
-        assert all([isinstance(x, tuple) for x in dots])
+        assert all(isinstance(x, tuple) for x in dots)
 
     def test_get_pattern(self):
         # All dependencies in get_pattern method are tested.
@@ -263,9 +260,6 @@ class TEMCalculatorTest(PymatgenTest):
         structure = self.get_structure("Si")
         fig = c.get_plot_2d_concise(structure)
         width = fig.layout.width
+        assert width == 121
         height = fig.layout.height
-        assert width == 121 and height == 121
-
-
-if __name__ == "__main__":
-    unittest.main()
+        assert height == 121
