@@ -20,6 +20,8 @@ get_dimensionality_gorai:
     J. Mater. Chem. A 2, 4136 (2016).
 """
 
+from __future__ import annotations
+
 import copy
 import itertools
 from collections import defaultdict
@@ -192,7 +194,7 @@ def calculate_dimensionality_of_site(bonded_structure, site_index, inc_vertices=
         vertices is a list of tuples. E.g. [(0, 0, 0), (1, 1, 1)].
     """
 
-    def neighbours(comp_index):
+    def neighbors(comp_index):
         return [(s.index, s.jimage) for s in bonded_structure.get_connected_sites(comp_index)]
 
     def rank(vertices):
@@ -205,10 +207,10 @@ def calculate_dimensionality_of_site(bonded_structure, site_index, inc_vertices=
 
     def rank_increase(seen, candidate):
         rank0 = len(seen) - 1
-        rank1 = rank(seen.union({candidate}))
+        rank1 = rank(seen | {candidate})
         return rank1 > rank0
 
-    connected_sites = {i: neighbours(i) for i in range(bonded_structure.structure.num_sites)}
+    connected_sites = {i: neighbors(i) for i in range(bonded_structure.structure.num_sites)}
 
     seen_vertices = set()
     seen_comp_vertices = defaultdict(set)
@@ -227,7 +229,6 @@ def calculate_dimensionality_of_site(bonded_structure, site_index, inc_vertices=
         seen_comp_vertices[comp_i].add(image_i)
 
         for comp_j, image_j in connected_sites[comp_i]:
-
             image_j = tuple(np.add(image_j, image_i))
 
             if (comp_j, image_j) in seen_vertices:
@@ -272,13 +273,12 @@ def zero_d_graph_to_molecule_graph(bonded_structure, graph):
         comp_i, image_i, site_i = queue.pop(0)
 
         if comp_i in [x[0] for x in seen_indices]:
-            raise ValueError("Graph component is not 0D")
+            raise ValueError("Graph component is not zero-dimensional")
 
         seen_indices.append((comp_i, image_i))
         sites.append(site_i)
 
         for site_j in bonded_structure.get_connected_sites(comp_i, jimage=image_i):
-
             if (site_j.index, site_j.jimage) not in seen_indices and (
                 site_j.index,
                 site_j.jimage,
@@ -350,10 +350,7 @@ def get_dimensionality_cheon(
         connected_list3 = find_connected_atoms(structure, tolerance=tolerance, ldict=ldict)
         max3, min3, clusters3 = find_clusters(structure, connected_list3)
         if min3 == min1:
-            if max3 == max1:
-                dim = "0D"
-            else:
-                dim = "intercalated molecule"
+            dim = "0D" if max3 == max1 else "intercalated molecule"
         else:
             dim = np.log2(float(max3) / max1) / np.log2(3)
             if dim == int(dim):
@@ -367,10 +364,7 @@ def get_dimensionality_cheon(
         if min2 == 1:
             dim = "intercalated ion"
         elif min2 == min1:
-            if max2 == max1:
-                dim = "0D"
-            else:
-                dim = "intercalated molecule"
+            dim = "0D" if max2 == max1 else "intercalated molecule"
         else:
             dim = np.log2(float(max2) / max1)
             if dim == int(dim):
@@ -381,10 +375,7 @@ def get_dimensionality_cheon(
                 connected_list3 = find_connected_atoms(structure, tolerance=tolerance, ldict=ldict)
                 max3, min3, clusters3 = find_clusters(structure, connected_list3)
                 if min3 == min2:
-                    if max3 == max2:
-                        dim = "0D"
-                    else:
-                        dim = "intercalated molecule"
+                    dim = "0D" if max3 == max2 else "intercalated molecule"
                 else:
                     dim = np.log2(float(max3) / max1) / np.log2(3)
                     if dim == int(dim):
@@ -427,21 +418,20 @@ def find_connected_atoms(struct, tolerance=0.45, ldict=None):
     fc_diff = fc_copy - neighbors
     species = list(map(str, struct.species))
     # in case of charged species
-    for i, item in enumerate(species):
+    for ii, item in enumerate(species):
         if item not in ldict:
-            species[i] = str(Species.from_string(item).element)
-    latmat = struct.lattice.matrix
+            species[ii] = str(Species.from_string(item).element)
     connected_matrix = np.zeros((n_atoms, n_atoms))
 
-    for i in range(n_atoms):
-        for j in range(i + 1, n_atoms):
-            max_bond_length = ldict[species[i]] + ldict[species[j]] + tolerance
-            frac_diff = fc_diff[j] - fc_copy[i]
-            distance_ij = np.dot(latmat.T, frac_diff)
+    for ii in range(n_atoms):
+        for jj in range(ii + 1, n_atoms):
+            max_bond_length = ldict[species[ii]] + ldict[species[jj]] + tolerance
+            frac_diff = fc_diff[jj] - fc_copy[ii]
+            distance_ij = np.dot(struct.lattice.matrix.T, frac_diff)
             # print(np.linalg.norm(distance_ij,axis=0))
             if sum(np.linalg.norm(distance_ij, axis=0) < max_bond_length) > 0:
-                connected_matrix[i, j] = 1
-                connected_matrix[j, i] = 1
+                connected_matrix[ii, jj] = 1
+                connected_matrix[jj, ii] = 1
     return connected_matrix
 
 
@@ -453,8 +443,8 @@ def find_clusters(struct, connected_matrix):
     If there are atoms that are not bonded to anything, returns [0,1,0]. (For
     faster computation time)
 
-    Author: "Gowoon Cheon"
-    Email: "gcheon@stanford.edu"
+    Author: Gowoon Cheon
+    Email: gcheon@stanford.edu
 
     Args:
         struct (Structure): Input structure
@@ -480,7 +470,7 @@ def find_clusters(struct, connected_matrix):
 
     def visit(atom, atom_cluster):
         visited[atom] = True
-        new_cluster = set(np.where(connected_matrix[atom] != 0)[0]).union(atom_cluster)
+        new_cluster = set(np.where(connected_matrix[atom] != 0)[0]) | atom_cluster
         atom_cluster = new_cluster
         for new_atom in atom_cluster:
             if not visited[new_atom]:
@@ -549,13 +539,13 @@ def get_dimensionality_gorai(
         bonds = get_max_bond_lengths(structure, el_radius_updates)
 
     num_surfaces = 0
-    for h in range(max_hkl):
-        for k in range(max_hkl):
-            for l in range(max_hkl):
-                if max([h, k, l]) > 0 and num_surfaces < 2:
+    for hh in range(max_hkl):
+        for kk in range(max_hkl):
+            for ll in range(max_hkl):
+                if max([hh, kk, ll]) > 0 and num_surfaces < 2:
                     sg = SlabGenerator(
                         structure,
-                        (h, k, l),
+                        (hh, kk, ll),
                         min_slab_size=min_slab_size,
                         min_vacuum_size=min_vacuum_size,
                     )
