@@ -1,6 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module provides a class used to describe the elastic tensor,
 including methods used to fit the elastic tensor from linear response
@@ -11,6 +8,7 @@ from __future__ import annotations
 
 import itertools
 import warnings
+from typing import TYPE_CHECKING
 
 import numpy as np
 import sympy as sp
@@ -20,16 +18,13 @@ from scipy.special import factorial
 
 from pymatgen.analysis.elasticity.strain import Strain
 from pymatgen.analysis.elasticity.stress import Stress
-from pymatgen.core.structure import Structure
-from pymatgen.core.tensors import (
-    DEFAULT_QUAD,
-    SquareTensor,
-    Tensor,
-    TensorCollection,
-    get_uvec,
-)
+from pymatgen.core.tensors import DEFAULT_QUAD, SquareTensor, Tensor, TensorCollection, get_uvec
 from pymatgen.core.units import Unit
 
+if TYPE_CHECKING:
+    from pymatgen.core import Structure
+
+
 __author__ = "Joseph Montoya"
 __copyright__ = "Copyright 2012, The Materials Project"
 __credits__ = "Maarten de Jong, Ian Winter, Shyam Dwaraknath, Mark Asta, Anubhav Jain"
@@ -60,7 +55,7 @@ class NthOrderElasticTensor(Tensor):
         if obj.rank % 2 != 0:
             raise ValueError("ElasticTensor must have even rank")
         if not obj.is_voigt_symmetric(tol):
-            warnings.warn("Input elastic tensor does not satisfy standard voigt symmetries")
+            warnings.warn("Input elastic tensor does not satisfy standard Voigt symmetries")
         return obj.view(cls)
 
     @property
@@ -97,14 +92,18 @@ class NthOrderElasticTensor(Tensor):
     @classmethod
     def from_diff_fit(cls, strains, stresses, eq_stress=None, order=2, tol: float = 1e-10):
         """
+        Takes a list of strains and stresses, and returns a list of coefficients for a
+        polynomial fit of the given order.
+
         Args:
-            strains ():
-            stresses ():
-            eq_stress ():
-            order ():
-            tol ():
+            strains: a list of strain values
+            stresses: the stress values
+            eq_stress: The stress at which the material is assumed to be elastic.
+            order: The order of the polynomial to fit. Defaults to 2
+            tol (float): tolerance for the fit.
 
         Returns:
+            NthOrderElasticTensor: the fitted elastic tensor
         """
         return cls(diff_fit(strains, stresses, eq_stress, order, tol)[order - 2])
 
@@ -160,7 +159,7 @@ class ElasticTensor(NthOrderElasticTensor):
     @property
     def compliance_tensor(self):
         """
-        returns the Voigt-notation compliance tensor,
+        Returns the Voigt-notation compliance tensor,
         which is the matrix inverse of the
         Voigt-notation elastic tensor
         """
@@ -170,48 +169,48 @@ class ElasticTensor(NthOrderElasticTensor):
     @property
     def k_voigt(self):
         """
-        returns the K_v bulk modulus
+        Returns the K_v bulk modulus
         """
         return self.voigt[:3, :3].mean()
 
     @property
     def g_voigt(self):
         """
-        returns the G_v shear modulus
+        Returns the G_v shear modulus
         """
         return (
-            2.0 * self.voigt[:3, :3].trace() - np.triu(self.voigt[:3, :3]).sum() + 3 * self.voigt[3:, 3:].trace()
+            2 * self.voigt[:3, :3].trace() - np.triu(self.voigt[:3, :3]).sum() + 3 * self.voigt[3:, 3:].trace()
         ) / 15.0
 
     @property
     def k_reuss(self):
         """
-        returns the K_r bulk modulus
+        Returns the K_r bulk modulus
         """
-        return 1.0 / self.compliance_tensor.voigt[:3, :3].sum()
+        return 1 / self.compliance_tensor.voigt[:3, :3].sum()
 
     @property
     def g_reuss(self):
         """
-        returns the G_r shear modulus
+        Returns the G_r shear modulus
         """
-        return 15.0 / (
-            8.0 * self.compliance_tensor.voigt[:3, :3].trace()
-            - 4.0 * np.triu(self.compliance_tensor.voigt[:3, :3]).sum()
-            + 3.0 * self.compliance_tensor.voigt[3:, 3:].trace()
+        return 15 / (
+            8 * self.compliance_tensor.voigt[:3, :3].trace()
+            - 4 * np.triu(self.compliance_tensor.voigt[:3, :3]).sum()
+            + 3 * self.compliance_tensor.voigt[3:, 3:].trace()
         )
 
     @property
     def k_vrh(self):
         """
-        returns the K_vrh (Voigt-Reuss-Hill) average bulk modulus
+        Returns the K_vrh (Voigt-Reuss-Hill) average bulk modulus
         """
         return 0.5 * (self.k_voigt + self.k_reuss)
 
     @property
     def g_vrh(self):
         """
-        returns the G_vrh (Voigt-Reuss-Hill) average shear modulus
+        Returns the G_vrh (Voigt-Reuss-Hill) average shear modulus
         """
         return 0.5 * (self.g_voigt + self.g_reuss)
 
@@ -221,7 +220,7 @@ class ElasticTensor(NthOrderElasticTensor):
         Calculates Young's modulus (in SI units) using the
         Voigt-Reuss-Hill averages of bulk and shear moduli
         """
-        return 9.0e9 * self.k_vrh * self.g_vrh / (3.0 * self.k_vrh + self.g_vrh)
+        return 9.0e9 * self.k_vrh * self.g_vrh / (3 * self.k_vrh + self.g_vrh)
 
     def directional_poisson_ratio(self, n, m, tol: float = 1e-8):
         """
@@ -248,7 +247,7 @@ class ElasticTensor(NthOrderElasticTensor):
         return self.einsum_sequence([n] * 4)
 
     @raise_error_if_unphysical
-    def trans_v(self, structure):
+    def trans_v(self, structure: Structure):
         """
         Calculates transverse sound velocity (in SI units) using the
         Voigt-Reuss-Hill average bulk modulus
@@ -268,7 +267,7 @@ class ElasticTensor(NthOrderElasticTensor):
         return (1e9 * self.g_vrh / mass_density) ** 0.5
 
     @raise_error_if_unphysical
-    def long_v(self, structure):
+    def long_v(self, structure: Structure):
         """
         Calculates longitudinal sound velocity (in SI units)
         using the Voigt-Reuss-Hill average bulk modulus
@@ -285,10 +284,10 @@ class ElasticTensor(NthOrderElasticTensor):
         mass_density = 1.6605e3 * nsites * weight / (natoms * volume)
         if self.g_vrh < 0:
             raise ValueError("k_vrh or g_vrh is negative, sound velocity is undefined")
-        return (1e9 * (self.k_vrh + 4.0 / 3.0 * self.g_vrh) / mass_density) ** 0.5
+        return (1e9 * (self.k_vrh + 4 / 3 * self.g_vrh) / mass_density) ** 0.5
 
     @raise_error_if_unphysical
-    def snyder_ac(self, structure):
+    def snyder_ac(self, structure: Structure):
         """
         Calculates Snyder's acoustic sound velocity (in SI units)
 
@@ -306,12 +305,12 @@ class ElasticTensor(NthOrderElasticTensor):
         return (
             0.38483
             * avg_mass
-            * ((self.long_v(structure) + 2.0 * self.trans_v(structure)) / 3.0) ** 3.0
-            / (300.0 * num_density ** (-2.0 / 3.0) * nsites ** (1.0 / 3.0))
+            * ((self.long_v(structure) + 2 * self.trans_v(structure)) / 3) ** 3.0
+            / (300 * num_density ** (-2 / 3) * nsites ** (1 / 3))
         )
 
     @raise_error_if_unphysical
-    def snyder_opt(self, structure):
+    def snyder_opt(self, structure: Structure):
         """
         Calculates Snyder's optical sound velocity (in SI units)
 
@@ -325,14 +324,14 @@ class ElasticTensor(NthOrderElasticTensor):
         num_density = 1e30 * nsites / volume
         return (
             1.66914e-23
-            * (self.long_v(structure) + 2.0 * self.trans_v(structure))
+            * (self.long_v(structure) + 2 * self.trans_v(structure))
             / 3.0
-            / num_density ** (-2.0 / 3.0)
-            * (1 - nsites ** (-1.0 / 3.0))
+            / num_density ** (-2 / 3)
+            * (1 - nsites ** (-1 / 3))
         )
 
     @raise_error_if_unphysical
-    def snyder_total(self, structure):
+    def snyder_total(self, structure: Structure):
         """
         Calculates Snyder's total sound velocity (in SI units)
 
@@ -344,7 +343,7 @@ class ElasticTensor(NthOrderElasticTensor):
         return self.snyder_ac(structure) + self.snyder_opt(structure)
 
     @raise_error_if_unphysical
-    def clarke_thermalcond(self, structure):
+    def clarke_thermalcond(self, structure: Structure):
         """
         Calculates Clarke's thermal conductivity (in SI units)
 
@@ -360,10 +359,10 @@ class ElasticTensor(NthOrderElasticTensor):
         weight = float(structure.composition.weight)
         avg_mass = 1.6605e-27 * tot_mass / natoms
         mass_density = 1.6605e3 * nsites * weight / (natoms * volume)
-        return 0.87 * 1.3806e-23 * avg_mass ** (-2.0 / 3.0) * mass_density ** (1.0 / 6.0) * self.y_mod**0.5
+        return 0.87 * 1.3806e-23 * avg_mass ** (-2 / 3) * mass_density ** (1 / 6) * self.y_mod**0.5
 
     @raise_error_if_unphysical
-    def cahill_thermalcond(self, structure):
+    def cahill_thermalcond(self, structure: Structure):
         """
         Calculates Cahill's thermal conductivity (in SI units)
 
@@ -375,10 +374,10 @@ class ElasticTensor(NthOrderElasticTensor):
         nsites = structure.num_sites
         volume = structure.volume
         num_density = 1e30 * nsites / volume
-        return 1.3806e-23 / 2.48 * num_density ** (2.0 / 3.0) * (self.long_v(structure) + 2 * self.trans_v(structure))
+        return 1.3806e-23 / 2.48 * num_density ** (2 / 3) * (self.long_v(structure) + 2 * self.trans_v(structure))
 
     @raise_error_if_unphysical
-    def debye_temperature(self, structure):
+    def debye_temperature(self, structure: Structure):
         """
         Estimates the debye temperature from longitudinal and
         transverse sound velocities
@@ -390,23 +389,23 @@ class ElasticTensor(NthOrderElasticTensor):
         """
         v0 = structure.volume * 1e-30 / structure.num_sites
         vl, vt = self.long_v(structure), self.trans_v(structure)
-        vm = 3 ** (1.0 / 3.0) * (1 / vl**3 + 2 / vt**3) ** (-1.0 / 3.0)
-        td = 1.05457e-34 / 1.38065e-23 * vm * (6 * np.pi**2 / v0) ** (1.0 / 3.0)
+        vm = 3 ** (1 / 3) * (1 / vl**3 + 2 / vt**3) ** (-1 / 3)
+        td = 1.05457e-34 / 1.38065e-23 * vm * (6 * np.pi**2 / v0) ** (1 / 3)
         return td
 
     @property
     def universal_anisotropy(self):
         """
-        returns the universal anisotropy value
+        Returns the universal anisotropy value
         """
-        return 5.0 * self.g_voigt / self.g_reuss + self.k_voigt / self.k_reuss - 6.0
+        return 5 * self.g_voigt / self.g_reuss + self.k_voigt / self.k_reuss - 6.0
 
     @property
     def homogeneous_poisson(self):
         """
-        returns the homogeneous poisson ratio
+        Returns the homogeneous poisson ratio
         """
-        return (1.0 - 2.0 / 3.0 * self.g_vrh / self.k_vrh) / (2.0 + 2.0 / 3.0 * self.g_vrh / self.k_vrh)
+        return (1 - 2 / 3 * self.g_vrh / self.k_vrh) / (2 + 2 / 3 * self.g_vrh / self.k_vrh)
 
     def green_kristoffel(self, u):
         """
@@ -417,7 +416,7 @@ class ElasticTensor(NthOrderElasticTensor):
     @property
     def property_dict(self):
         """
-        returns a dictionary of properties derived from the elastic tensor
+        Returns a dictionary of properties derived from the elastic tensor
         """
         props = [
             "k_voigt",
@@ -436,7 +435,7 @@ class ElasticTensor(NthOrderElasticTensor):
         self, structure: Structure, include_base_props: bool = True, ignore_errors: bool = False
     ) -> dict[str, float | Structure | None]:
         """
-        returns a dictionary of properties derived from the elastic tensor
+        Returns a dictionary of properties derived from the elastic tensor
         and an associated structure
 
         Args:
@@ -500,7 +499,7 @@ class ElasticTensor(NthOrderElasticTensor):
             stresses (list of Stresses): list of stress objects to use in fit
                 corresponding to the list of strains
             eq_stress (Stress): equilibrium stress to use in fitting
-            vasp (boolean): flag for whether the stress tensor should be
+            vasp (bool): flag for whether the stress tensor should be
                 converted based on vasp units/convention for stress
             tol (float): tolerance for removing near-zero elements of the
                 resulting tensor
@@ -717,7 +716,7 @@ class ElasticTensorExpansion(TensorCollection):
             structure (Structure): Structure to be used in directional heat
                 capacity determination, only necessary if temperature
                 is specified
-            mode (string): mode for finding average heat-capacity,
+            mode (str): mode for finding average heat-capacity,
                 current supported modes are 'debye' and 'dulong-petit'
         """
         soec = ElasticTensor(self[0])
@@ -971,10 +970,7 @@ def get_strain_state_dict(strains, stresses, eq_stress=None, tol: float = 1e-10,
     independent = {tuple(np.nonzero(vstrain)[0].tolist()) for vstrain in vstrains}
     strain_state_dict = {}
     if add_eq:
-        if eq_stress is not None:
-            veq_stress = Stress(eq_stress).voigt
-        else:
-            veq_stress = find_eq_stress(strains, stresses).voigt
+        veq_stress = Stress(eq_stress).voigt if eq_stress is not None else find_eq_stress(strains, stresses).voigt
 
     for ind in independent:
         # match strains with templates
@@ -1063,7 +1059,7 @@ def get_symbol_list(rank, dim=6):
     c_vec = np.zeros(len(indices), dtype=object)
     c_arr = np.zeros([dim] * rank, dtype=object)
     for n, idx in enumerate(indices):
-        c_vec[n] = sp.Symbol("c_" + "".join([str(i) for i in idx]))
+        c_vec[n] = sp.Symbol("c_" + "".join(map(str, idx)))
         for perm in itertools.permutations(idx):
             c_arr[perm] = c_vec[n]
     return c_vec, c_arr
