@@ -1,6 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module provides classes and methods used to describe deformations and
 strains, including applying those deformations to structure objects and
@@ -11,14 +8,19 @@ from __future__ import annotations
 
 import collections
 import itertools
+from typing import TYPE_CHECKING, Literal
 
 import numpy as np
 import scipy
 
 from pymatgen.core.lattice import Lattice
-from pymatgen.core.structure import Structure
 from pymatgen.core.tensors import SquareTensor, symmetry_reduce
 
+if TYPE_CHECKING:
+    from numpy.typing import ArrayLike
+
+    from pymatgen.core.structure import Structure
+
 __author__ = "Joseph Montoya"
 __copyright__ = "Copyright 2012, The Materials Project"
 __credits__ = "Maarten de Jong, Mark Asta, Anubhav Jain"
@@ -70,7 +72,7 @@ class Deformation(SquareTensor):
         """
         return Strain.from_deformation(self)
 
-    def apply_to_structure(self, structure):
+    def apply_to_structure(self, structure: Structure):
         """
         Apply the deformation gradient to a structure.
 
@@ -109,8 +111,8 @@ class DeformedStructureSet(collections.abc.Sequence):
 
     def __init__(self, structure: Structure, norm_strains=None, shear_strains=None, symmetry=False):
         """
-        constructs the deformed geometries of a structure. Generates
-        m + n deformed structures according to the supplied parameters.
+        Construct the deformed geometries of a structure. Generates m + n deformed structures
+        according to the supplied parameters.
 
         Args:
             structure (Structure): structure to undergo deformation
@@ -169,7 +171,7 @@ class Strain(SquareTensor):
         does not include the deformation gradient
 
         Args:
-            strain_matrix (3x3 array-like): the 3x3 array-like
+            strain_matrix (ArrayLike): 3x3 matrix or length-6 Voigt notation vector
                 representing the Green-Lagrange strain
         """
         vscale = np.ones((6,))
@@ -177,9 +179,7 @@ class Strain(SquareTensor):
         obj = super().__new__(cls, strain_matrix, vscale=vscale)
         if not obj.is_symmetric():
             raise ValueError(
-                "Strain objects must be initialized "
-                "with a symmetric array or a voigt-notation "
-                "vector with six entries."
+                "Strain must be initialized with a symmetric array or a Voigt-notation vector with six entries."
             )
         return obj.view(cls)
 
@@ -190,13 +190,13 @@ class Strain(SquareTensor):
         self._vscale = getattr(obj, "_vscale", None)
 
     @classmethod
-    def from_deformation(cls, deformation):
+    def from_deformation(cls, deformation: ArrayLike) -> Strain:
         """
         Factory method that returns a Strain object from a deformation
         gradient
 
         Args:
-            deformation (3x3 array-like):
+            deformation (ArrayLike): 3x3 array defining the deformation
         """
         dfm = Deformation(deformation)
         return cls(0.5 * (np.dot(dfm.trans, dfm) - np.eye(3)))
@@ -205,13 +205,12 @@ class Strain(SquareTensor):
     def from_index_amount(cls, idx, amount):
         """
         Like Deformation.from_index_amount, except generates
-        a strain from the zero 3x3 tensor or voigt vector with
+        a strain from the zero 3x3 tensor or Voigt vector with
         the amount specified in the index location. Ensures
         symmetric strain.
 
         Args:
-            idx (tuple or integer): index to be perturbed, can be voigt or
-                full-tensor notation
+            idx (tuple or integer): index to be perturbed, can be Voigt or full-tensor notation
             amount (float): amount to perturb selected index
         """
         if np.array(idx).ndim == 0:
@@ -223,11 +222,17 @@ class Strain(SquareTensor):
             for i in itertools.permutations(idx):
                 v[i] = amount
             return cls(v)
-        raise ValueError("Index must either be 2-tuple or integer corresponding to full-tensor or voigt index")
+        raise ValueError("Index must either be 2-tuple or integer corresponding to full-tensor or Voigt index")
 
-    def get_deformation_matrix(self, shape="upper"):
+    def get_deformation_matrix(self, shape: Literal["upper", "lower", "symmetric"] = "upper"):
         """
-        returns the deformation matrix
+        Returns the deformation matrix.
+
+        Args:
+            shape ('upper' | 'lower' | 'symmetric'): method for determining deformation
+                'upper' produces an upper triangular defo
+                'lower' produces a lower triangular defo
+                'symmetric' produces a symmetric defo
         """
         return convert_strain_to_deformation(self, shape=shape)
 
@@ -241,24 +246,24 @@ class Strain(SquareTensor):
         return np.sqrt(np.sum(eps * eps) * 2 / 3)
 
 
-def convert_strain_to_deformation(strain, shape="upper"):
+def convert_strain_to_deformation(strain, shape: Literal["upper", "lower", "symmetric"]):
     """
     This function converts a strain to a deformation gradient that will
     produce that strain. Supports three methods:
 
     Args:
         strain (3x3 array-like): strain matrix
-        shape: (string): method for determining deformation, supports
-            "upper" produces an upper triangular defo
-            "lower" produces a lower triangular defo
-            "symmetric" produces a symmetric defo
+        shape: ('upper' | 'lower' | 'symmetric'): method for determining deformation
+            'upper' produces an upper triangular defo
+            'lower' produces a lower triangular defo
+            'symmetric' produces a symmetric defo
     """
     strain = SquareTensor(strain)
-    ftdotf = 2 * strain + np.eye(3)
+    ft_dot_f = 2 * strain + np.eye(3)
     if shape == "upper":
-        result = scipy.linalg.cholesky(ftdotf)
+        result = scipy.linalg.cholesky(ft_dot_f)
     elif shape == "symmetric":
-        result = scipy.linalg.sqrtm(ftdotf)
+        result = scipy.linalg.sqrtm(ft_dot_f)
     else:
         raise ValueError('shape must be "upper" or "symmetric"')
     return Deformation(result)
