@@ -1,11 +1,10 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module provides the Stress class used to create, manipulate, and
 calculate relevant properties of the stress tensor.
 """
 
+from __future__ import annotations
+
 import math
 
 import numpy as np
@@ -46,7 +45,7 @@ class Stress(SquareTensor):
     @property
     def dev_principal_invariants(self):
         """
-        returns the principal invariants of the deviatoric stress tensor,
+        Returns the principal invariants of the deviatoric stress tensor,
         which is calculated by finding the coefficients of the characteristic
         polynomial of the stress tensor minus the identity times the mean
         stress
@@ -56,7 +55,7 @@ class Stress(SquareTensor):
     @property
     def von_mises(self):
         """
-        returns the von mises stress
+        Returns the von Mises stress
         """
         if not self.is_symmetric():
             raise ValueError(
@@ -67,14 +66,14 @@ class Stress(SquareTensor):
     @property
     def mean_stress(self):
         """
-        returns the mean stress
+        Returns the mean stress
         """
-        return 1.0 / 3.0 * self.trace()
+        return 1 / 3 * self.trace()
 
     @property
     def deviator_stress(self):
         """
-        returns the deviatoric component of the stress
+        Returns the deviatoric component of the stress
         """
         if not self.is_symmetric:
             raise ValueError("The stress tensor is not symmetric, so deviator stress will not be either")
@@ -82,7 +81,7 @@ class Stress(SquareTensor):
 
     def piola_kirchoff_1(self, def_grad):
         """
-        calculates the first Piola-Kirchoff stress
+        Calculates the first Piola-Kirchoff stress
 
         Args:
             def_grad (3x3 array-like): deformation gradient tensor
@@ -97,7 +96,7 @@ class Stress(SquareTensor):
 
     def piola_kirchoff_2(self, def_grad):
         """
-        calculates the second Piola-Kirchoff stress
+        Calculates the second Piola-Kirchoff stress
 
         Args:
             def_grad (3x3 array-like): rate of deformation tensor
