@@ -1,15 +1,11 @@
-import unittest
+from __future__ import annotations
+
 import warnings
 
 import numpy as np
 import pytest
 
-from pymatgen.analysis.elasticity.strain import (
-    Deformation,
-    DeformedStructureSet,
-    Strain,
-    convert_strain_to_deformation,
-)
+from pymatgen.analysis.elasticity.strain import Deformation, DeformedStructureSet, Strain, convert_strain_to_deformation
 from pymatgen.core.lattice import Lattice
 from pymatgen.core.structure import Structure
 from pymatgen.core.tensors import Tensor
@@ -20,7 +16,7 @@ class DeformationTest(PymatgenTest):
     def setUp(self):
         self.norm_defo = Deformation.from_index_amount((0, 0), 0.02)
         self.ind_defo = Deformation.from_index_amount((0, 1), 0.02)
-        self.non_ind_defo = Deformation([[1.0, 0.02, 0.02], [0.0, 1.0, 0.0], [0.0, 0.0, 1.0]])
+        self.non_ind_defo = Deformation([[1, 0.02, 0.02], [0, 1, 0], [0, 0, 1]])
         lattice = Lattice(
             [
                 [3.8401979337, 0.00, 0.00],
@@ -32,13 +28,13 @@ class DeformationTest(PymatgenTest):
 
     def test_properties(self):
         # green_lagrange_strain
-        self.assertArrayAlmostEqual(
+        self.assert_all_close(
             self.ind_defo.green_lagrange_strain,
-            [[0.0, 0.01, 0.0], [0.01, 0.0002, 0.0], [0.0, 0.0, 0.0]],
+            [[0, 0.01, 0], [0.01, 0.0002, 0], [0, 0, 0]],
         )
-        self.assertArrayAlmostEqual(
+        self.assert_all_close(
             self.non_ind_defo.green_lagrange_strain,
-            [[0.0, 0.01, 0.01], [0.01, 0.0002, 0.0002], [0.01, 0.0002, 0.0002]],
+            [[0, 0.01, 0.01], [0.01, 0.0002, 0.0002], [0.01, 0.0002, 0.0002]],
         )
 
     def test_independence(self):
@@ -50,7 +46,7 @@ class DeformationTest(PymatgenTest):
         strained_ind = self.ind_defo.apply_to_structure(self.structure)
         strained_non = self.non_ind_defo.apply_to_structure(self.structure)
         # Check lattices
-        self.assertArrayAlmostEqual(
+        self.assert_all_close(
             strained_norm.lattice.matrix,
             [
                 [3.9170018886, 0, 0],
@@ -58,7 +54,7 @@ class DeformationTest(PymatgenTest):
                 [0, -2.21713849, 3.13550906],
             ],
         )
-        self.assertArrayAlmostEqual(
+        self.assert_all_close(
             strained_ind.lattice.matrix,
             [
                 [3.84019793, 0, 0],
@@ -66,7 +62,7 @@ class DeformationTest(PymatgenTest):
                 [-0.04434277, -2.21713849, 3.13550906],
             ],
         )
-        self.assertArrayAlmostEqual(
+        self.assert_all_close(
             strained_non.lattice.matrix,
             [
                 [3.84019793, 0, 0],
@@ -75,17 +71,17 @@ class DeformationTest(PymatgenTest):
             ],
         )
         # Check coordinates
-        self.assertArrayAlmostEqual(strained_norm.sites[1].coords, [3.91700189, 1.224e-06, 2.3516318])
-        self.assertArrayAlmostEqual(strained_ind.sites[1].coords, [3.84019793, 1.224e-6, 2.3516318])
-        self.assertArrayAlmostEqual(strained_non.sites[1].coords, [3.8872306, 1.224e-6, 2.3516318])
+        self.assert_all_close(strained_norm.sites[1].coords, [3.91700189, 1.224e-06, 2.3516318])
+        self.assert_all_close(strained_ind.sites[1].coords, [3.84019793, 1.224e-6, 2.3516318])
+        self.assert_all_close(strained_non.sites[1].coords, [3.8872306, 1.224e-6, 2.3516318])
 
         # Check convention for applying transformation
         for vec, defo_vec in zip(self.structure.lattice.matrix, strained_non.lattice.matrix):
             new_vec = np.dot(self.non_ind_defo, np.transpose(vec))
-            self.assertArrayAlmostEqual(new_vec, defo_vec)
+            self.assert_all_close(new_vec, defo_vec)
         for coord, defo_coord in zip(self.structure.cart_coords, strained_non.cart_coords):
             new_coord = np.dot(self.non_ind_defo, np.transpose(coord))
-            self.assertArrayAlmostEqual(new_coord, defo_coord)
+            self.assert_all_close(new_coord, defo_coord)
 
 
 class StrainTest(PymatgenTest):
@@ -97,20 +93,23 @@ class StrainTest(PymatgenTest):
 
         with warnings.catch_warnings(record=True):
             warnings.simplefilter("always")
-            self.no_dfm = Strain([[0.0, 0.01, 0.0], [0.01, 0.0002, 0.0], [0.0, 0.0, 0.0]])
+            self.no_dfm = Strain([[0, 0.01, 0], [0.01, 0.0002, 0], [0, 0, 0]])
 
     def test_new(self):
-        test_strain = Strain([[0.0, 0.01, 0.0], [0.01, 0.0002, 0.0], [0.0, 0.0, 0.0]])
-        self.assertArrayAlmostEqual(test_strain, test_strain.get_deformation_matrix().green_lagrange_strain)
-        with pytest.raises(ValueError):
+        test_strain = Strain([[0, 0.01, 0], [0.01, 0.0002, 0], [0, 0, 0]])
+        self.assert_all_close(test_strain, test_strain.get_deformation_matrix().green_lagrange_strain)
+        with pytest.raises(
+            ValueError,
+            match="Strain must be initialized with a symmetric array or a Voigt-notation vector",
+        ):
             Strain([[0.1, 0.1, 0], [0, 0, 0], [0, 0, 0]])
 
     def test_from_deformation(self):
-        self.assertArrayAlmostEqual(self.norm_str, [[0.0202, 0, 0], [0, 0, 0], [0, 0, 0]])
-        self.assertArrayAlmostEqual(self.ind_str, [[0.0, 0.01, 0.0], [0.01, 0.0002, 0.0], [0.0, 0.0, 0.0]])
-        self.assertArrayAlmostEqual(
+        self.assert_all_close(self.norm_str, [[0.0202, 0, 0], [0, 0, 0], [0, 0, 0]])
+        self.assert_all_close(self.ind_str, [[0, 0.01, 0], [0.01, 0.0002, 0], [0, 0, 0]])
+        self.assert_all_close(
             self.non_ind_str,
-            [[0.0, 0.01, 0.01], [0.01, 0.0002, 0.0002], [0.01, 0.0002, 0.0002]],
+            [[0, 0.01, 0.01], [0.01, 0.0002, 0.0002], [0.01, 0.0002, 0.0002]],
         )
 
     def test_from_index_amount(self):
@@ -118,22 +117,22 @@ class StrainTest(PymatgenTest):
         test = Strain.from_index_amount(2, 0.01)
         should_be = np.zeros((3, 3))
         should_be[2, 2] = 0.01
-        self.assertArrayAlmostEqual(test, should_be)
+        self.assert_all_close(test, should_be)
         # from full-tensor index
         test = Strain.from_index_amount((1, 2), 0.01)
         should_be = np.zeros((3, 3))
         should_be[1, 2] = should_be[2, 1] = 0.01
-        self.assertArrayAlmostEqual(test, should_be)
+        self.assert_all_close(test, should_be)
 
     def test_properties(self):
         # deformation matrix
-        self.assertArrayAlmostEqual(self.ind_str.get_deformation_matrix(), [[1, 0.02, 0], [0, 1, 0], [0, 0, 1]])
+        self.assert_all_close(self.ind_str.get_deformation_matrix(), [[1, 0.02, 0], [0, 1, 0], [0, 0, 1]])
         symm_dfm = Strain(self.no_dfm).get_deformation_matrix(shape="symmetric")
-        self.assertArrayAlmostEqual(symm_dfm, [[0.99995, 0.0099995, 0], [0.0099995, 1.00015, 0], [0, 0, 1]])
-        self.assertArrayAlmostEqual(self.no_dfm.get_deformation_matrix(), [[1, 0.02, 0], [0, 1, 0], [0, 0, 1]])
+        self.assert_all_close(symm_dfm, [[0.99995, 0.0099995, 0], [0.0099995, 1.00015, 0], [0, 0, 1]])
+        self.assert_all_close(self.no_dfm.get_deformation_matrix(), [[1, 0.02, 0], [0, 1, 0], [0, 0, 1]])
 
         # voigt
-        self.assertArrayAlmostEqual(self.non_ind_str.voigt, [0, 0.0002, 0.0002, 0.0004, 0.02, 0.02])
+        self.assert_all_close(self.non_ind_str.voigt, [0, 0.0002, 0.0002, 0.0004, 0.02, 0.02])
 
     def test_convert_strain_to_deformation(self):
         strain = Tensor(np.random.random((3, 3))).symmetrized
@@ -141,10 +140,10 @@ class StrainTest(PymatgenTest):
             strain = Tensor(np.random.random((3, 3))).symmetrized
         upper = convert_strain_to_deformation(strain, shape="upper")
         symm = convert_strain_to_deformation(strain, shape="symmetric")
-        self.assertArrayAlmostEqual(np.triu(upper), upper)
+        self.assert_all_close(np.triu(upper), upper)
         assert Tensor(symm).is_symmetric()
         for defo in upper, symm:
-            self.assertArrayAlmostEqual(defo.green_lagrange_strain, strain)
+            self.assert_all_close(defo.green_lagrange_strain, strain)
 
 
 class DeformedStructureSetTest(PymatgenTest):
@@ -159,7 +158,3 @@ class DeformedStructureSetTest(PymatgenTest):
         # Should be 4 strains for normal, 2 for shear (since +/- shear
         # are symmetrically equivalent)
         assert len(dss_symm) == 6
-
-
-if __name__ == "__main__":
-    unittest.main()
