@@ -1,6 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module implements various equation of states.
 
@@ -29,7 +26,7 @@ logger = logging.getLogger(__file__)
 
 class EOSBase(metaclass=ABCMeta):
     """
-    Abstract class that must be subcalssed by all equation of state
+    Abstract class that must be subclassed by all equation of state
     implementations.
     """
 
@@ -170,7 +167,7 @@ class EOSBase(metaclass=ABCMeta):
         Returns:
             dict
         """
-        return dict(e0=self.e0, b0=self.b0, b1=self.b1, v0=self.v0)
+        return {"e0": self.e0, "b0": self.b0, "b1": self.b1, "v0": self.v0}
 
     def plot(self, width=8, height=None, plt=None, dpi=None, **kwargs):
         """
@@ -309,8 +306,8 @@ class Birch(EOSBase):
         e0, b0, b1, v0 = tuple(params)
         return (
             e0
-            + 9.0 / 8.0 * b0 * v0 * ((v0 / volume) ** (2.0 / 3.0) - 1.0) ** 2
-            + 9.0 / 16.0 * b0 * v0 * (b1 - 4.0) * ((v0 / volume) ** (2.0 / 3.0) - 1.0) ** 3
+            + 9 / 8 * b0 * v0 * ((v0 / volume) ** (2 / 3.0) - 1.0) ** 2
+            + 9 / 16 * b0 * v0 * (b1 - 4.0) * ((v0 / volume) ** (2 / 3.0) - 1.0) ** 3
         )
 
 
@@ -324,8 +321,8 @@ class BirchMurnaghan(EOSBase):
         BirchMurnaghan equation from PRB 70, 224107
         """
         e0, b0, b1, v0 = tuple(params)
-        eta = (v0 / volume) ** (1.0 / 3.0)
-        return e0 + 9.0 * b0 * v0 / 16.0 * (eta**2 - 1) ** 2 * (6 + b1 * (eta**2 - 1.0) - 4.0 * eta**2)
+        eta = (v0 / volume) ** (1 / 3)
+        return e0 + 9 * b0 * v0 / 16 * (eta**2 - 1) ** 2 * (6 + b1 * (eta**2 - 1.0) - 4 * eta**2)
 
 
 class PourierTarantola(EOSBase):
@@ -338,9 +335,9 @@ class PourierTarantola(EOSBase):
         Pourier-Tarantola equation from PRB 70, 224107
         """
         e0, b0, b1, v0 = tuple(params)
-        eta = (volume / v0) ** (1.0 / 3.0)
-        squiggle = -3.0 * np.log(eta)
-        return e0 + b0 * v0 * squiggle**2 / 6.0 * (3.0 + squiggle * (b1 - 2))
+        eta = (volume / v0) ** (1 / 3)
+        squiggle = -3 * np.log(eta)
+        return e0 + b0 * v0 * squiggle**2 / 6 * (3 + squiggle * (b1 - 2))
 
 
 class Vinet(EOSBase):
@@ -353,9 +350,9 @@ class Vinet(EOSBase):
         Vinet equation from PRB 70, 224107
         """
         e0, b0, b1, v0 = tuple(params)
-        eta = (volume / v0) ** (1.0 / 3.0)
-        return e0 + 2.0 * b0 * v0 / (b1 - 1.0) ** 2 * (
-            2.0 - (5.0 + 3.0 * b1 * (eta - 1.0) - 3.0 * eta) * np.exp(-3.0 * (b1 - 1.0) * (eta - 1.0) / 2.0)
+        eta = (volume / v0) ** (1 / 3)
+        return e0 + 2 * b0 * v0 / (b1 - 1.0) ** 2 * (
+            2 - (5 + 3 * b1 * (eta - 1.0) - 3 * eta) * np.exp(-3 * (b1 - 1.0) * (eta - 1.0) / 2.0)
         )
 
 
@@ -405,14 +402,14 @@ class DeltaFactor(PolynomialEOS):
     """
 
     def _func(self, volume, params):
-        x = volume ** (-2.0 / 3.0)
+        x = volume ** (-2 / 3.0)
         return np.poly1d(list(params))(x)
 
     def fit(self, order=3):
         """
         Overridden since this eos works with volume**(2/3) instead of volume.
         """
-        x = self.volumes ** (-2.0 / 3.0)
+        x = self.volumes ** (-2 / 3.0)
         self.eos_params = np.polyfit(x, self.energies, order)
         self._set_params()
 
@@ -428,18 +425,18 @@ class DeltaFactor(PolynomialEOS):
 
         for x in np.roots(deriv1):
             if x > 0 and deriv2(x) > 0:
-                v0 = x ** (-3.0 / 2.0)
+                v0 = x ** (-3 / 2.0)
                 break
         else:
             raise EOSError("No minimum could be found")
 
-        derivV2 = 4.0 / 9.0 * x**5.0 * deriv2(x)
-        derivV3 = -20.0 / 9.0 * x ** (13.0 / 2.0) * deriv2(x) - 8.0 / 27.0 * x ** (15.0 / 2.0) * deriv3(x)
-        b0 = derivV2 / x ** (3.0 / 2.0)
-        b1 = -1 - x ** (-3.0 / 2.0) * derivV3 / derivV2
+        derivV2 = 4 / 9 * x**5 * deriv2(x)
+        derivV3 = -20 / 9 * x ** (13 / 2.0) * deriv2(x) - 8 / 27 * x ** (15 / 2.0) * deriv3(x)
+        b0 = derivV2 / x ** (3 / 2.0)
+        b1 = -1 - x ** (-3 / 2.0) * derivV3 / derivV2
 
         # e0, b0, b1, v0
-        self._params = [deriv0(v0 ** (-2.0 / 3.0)), b0, b1, v0]
+        self._params = [deriv0(v0 ** (-2 / 3.0)), b0, b1, v0]
 
 
 class NumericalEOS(PolynomialEOS):
@@ -598,7 +595,7 @@ class EOS:
         """
         if eos_name not in self.MODELS:
             raise EOSError(
-                f"The equation of state '{eos_name}' is not supported. "
+                f"The equation of state {eos_name!r} is not supported. "
                 f"Please choose one from the following list: {list(self.MODELS)}"
             )
         self._eos_name = eos_name
