@@ -1,6 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module provides classes for calculating the Ewald sum of a structure.
 """
@@ -120,9 +117,7 @@ class EwaldSummation(MSONable):
         # Define the private attributes to lazy compute reciprocal and real
         # space terms.
         self._initialized = False
-        self._recip = None
-        self._real, self._point = None, None
-        self._forces = None
+        self._recip = self._real = self._point = self._forces = None
 
         # Compute the correction for a charged cell
         self._charged_cell_energy = (
@@ -135,9 +130,9 @@ class EwaldSummation(MSONable):
         out.
         """
         total_energy_matrix = self.total_energy_matrix.copy()
-        for i in removed_indices:
-            total_energy_matrix[i, :] = 0
-            total_energy_matrix[:, i] = 0
+        for idx in removed_indices:
+            total_energy_matrix[idx, :] = 0
+            total_energy_matrix[:, idx] = 0
         return sum(sum(total_energy_matrix))
 
     def compute_sub_structure(self, sub_structure, tol: float = 1e-3):
@@ -297,7 +292,8 @@ class EwaldSummation(MSONable):
         Args:
             site_index (int): Index of site
         ReturnS:
-            (float) - Energy of that site"""
+        (float) - Energy of that site
+        """
         if not self._initialized:
             self._calc_ewald_terms()
             self._initialized = True
@@ -351,7 +347,6 @@ class EwaldSummation(MSONable):
         simags = np.sum(oxistates[None, :] * np.sin(grs), 1)
 
         for g, g2, gr, expval, sreal, simag in zip(gs, g2s, grs, expvals, sreals, simags):
-
             # Uses the identity sin(x)+cos(x) = 2**0.5 sin(x + pi/4)
             m = (gr[None, :] + pi / 4) - gr[:, None]
             np.sin(m, m)
@@ -374,7 +369,7 @@ class EwaldSummation(MSONable):
         Determines the self energy -(eta/pi)**(1/2) * sum_{i=1}^{N} q_i**2
         """
         fcoords = self._s.frac_coords
-        forcepf = 2.0 * self._sqrt_eta / sqrt(pi)
+        forcepf = 2 * self._sqrt_eta / sqrt(pi)
         coords = self._coords
         numsites = self._s.num_sites
         ereal = np.empty((numsites, numsites), dtype=np.float_)
@@ -471,7 +466,7 @@ class EwaldSummation(MSONable):
         return d
 
     @classmethod
-    def from_dict(cls, d: dict[str, Any], fmt: str = None, **kwargs) -> EwaldSummation:
+    def from_dict(cls, d: dict[str, Any], fmt: str | None = None, **kwargs) -> EwaldSummation:
         """Create an EwaldSummation instance from JSON-serialized dictionary.
 
         Args:
@@ -550,11 +545,11 @@ class EwaldMinimizer:
         # Setup and checking of inputs
         self._matrix = copy(matrix)
         # Make the matrix diagonally symmetric (so matrix[i,:] == matrix[:,j])
-        for i in range(len(self._matrix)):
-            for j in range(i, len(self._matrix)):
-                value = (self._matrix[i, j] + self._matrix[j, i]) / 2
-                self._matrix[i, j] = value
-                self._matrix[j, i] = value
+        for ii in range(len(self._matrix)):
+            for jj in range(ii, len(self._matrix)):
+                value = (self._matrix[ii, jj] + self._matrix[jj, ii]) / 2
+                self._matrix[ii, jj] = value
+                self._matrix[jj, ii] = value
 
         # sort the m_list based on number of permutations
         self._m_list = sorted(m_list, key=lambda x: comb(len(x[2]), x[1]), reverse=True)
@@ -670,10 +665,7 @@ class EwaldMinimizer:
         f = manipulation[0]
         indices = list(indices_left.intersection(manipulation[2]))
         sums = np.sum(matrix[indices], axis=1)
-        if f < 1:
-            next_index = indices[sums.argmax(axis=0)]
-        else:
-            next_index = indices[sums.argmin(axis=0)]
+        next_index = indices[sums.argmax(axis=0)] if f < 1 else indices[sums.argmin(axis=0)]
 
         return next_index
 
@@ -711,9 +703,8 @@ class EwaldMinimizer:
         if m_list[-1][1] > len(indices.intersection(m_list[-1][2])):
             return
 
-        if len(m_list) == 1 or m_list[-1][1] > 1:
-            if self.best_case(matrix, m_list, indices) > self._current_minimum:
-                return
+        if (len(m_list) == 1 or m_list[-1][1] > 1) and self.best_case(matrix, m_list, indices) > self._current_minimum:
+            return
 
         index = self.get_next_index(matrix, m_list[-1], indices)
 
