@@ -1,6 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 r"""
 This module contains classes useful for analyzing ferroelectric candidates.
 The Polarization class can recover the spontaneous polarization using
@@ -47,6 +44,8 @@ determine the spontaneous polarization because it serves as a reference point.
 """
 
 
+from __future__ import annotations
+
 import numpy as np
 
 from pymatgen.core.lattice import Lattice
@@ -96,7 +95,6 @@ def get_total_ionic_dipole(structure, zval_dict):
     center (np.array with shape [3,1]) : dipole center used by VASP
     tiny (float) : tolerance for determining boundary of calculation.
     """
-
     tot_ionic = []
     for site in structure:
         zval = zval_dict[str(site.specie)]
@@ -112,6 +110,7 @@ class PolarizationLattice(Structure):
     def get_nearest_site(self, coords, site, r=None):
         """
         Given coords and a site, find closet site to coords.
+
         Args:
             coords (3x1 array): Cartesian coords of center of sphere
             site: site to find closest to coords
@@ -218,7 +217,7 @@ class Polarization:
             volumes = [s.lattice.volume for s in self.structures]
             e_to_muC = -1.6021766e-13
             cm2_to_A2 = 1e16
-            units = 1.0 / np.array(volumes)
+            units = 1 / np.array(volumes)
             units *= e_to_muC * cm2_to_A2
 
             p_elecs = np.matmul(units, p_elecs)
@@ -279,7 +278,7 @@ class Polarization:
 
         e_to_muC = -1.6021766e-13
         cm2_to_A2 = 1e16
-        units = 1.0 / np.array(volumes)
+        units = 1 / np.array(volumes)
         units *= e_to_muC * cm2_to_A2
 
         # convert polarizations and lattice lengths prior to adjustment
@@ -309,12 +308,9 @@ class Polarization:
             d = PolarizationLattice(lattice, ["C"], [np.array(frac_coord).ravel()])
             d_structs.append(d)
             site = d[0]
-            if i == 0:
-                # Adjust nonpolar polarization to be closest to zero.
-                # This is compatible with both a polarization of zero or a half quantum.
-                prev_site = [0, 0, 0]
-            else:
-                prev_site = sites[-1].coords
+            # Adjust nonpolar polarization to be closest to zero.
+            # This is compatible with both a polarization of zero or a half quantum.
+            prev_site = [0, 0, 0] if i == 0 else sites[-1].coords
             new_site = d.get_nearest_site(prev_site, site)
             sites.append(new_site[0])
 
@@ -338,7 +334,7 @@ class Polarization:
 
         e_to_muC = -1.6021766e-13
         cm2_to_A2 = 1e16
-        units = 1.0 / np.array(volumes)
+        units = 1 / np.array(volumes)
         units *= e_to_muC * cm2_to_A2
 
         # convert polarizations and lattice lengths prior to adjustment
@@ -352,7 +348,7 @@ class Polarization:
                 lattice = lattices[-1]
                 lattices[i] = Lattice.from_parameters(*(np.array(lattice.lengths) * units.ravel()[-1]), *lattice.angles)
 
-        quanta = np.array([np.array(l.lengths) for l in lattices])
+        quanta = np.array([np.array(latt.lengths) for latt in lattices])
 
         return quanta
 
