@@ -2,9 +2,8 @@
 Module that implements various algorithms related to interface construction and analysis
 """
 
+from __future__ import annotations
+
 from pymatgen.analysis.interfaces.coherent_interfaces import CoherentInterfaceBuilder
-from pymatgen.analysis.interfaces.substrate_analyzer import (
-    SubstrateAnalyzer,
-    SubstrateMatch,
-)
+from pymatgen.analysis.interfaces.substrate_analyzer import SubstrateAnalyzer, SubstrateMatch
 from pymatgen.analysis.interfaces.zsl import ZSLGenerator, ZSLMatch
