@@ -1,6 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module provides classes to identify optimal substrates for film growth
 """
@@ -8,14 +5,14 @@ This module provides classes to identify optimal substrates for film growth
 from __future__ import annotations
 
 from dataclasses import dataclass
+from typing import TYPE_CHECKING
 
 from pymatgen.analysis.elasticity.strain import Deformation, Strain
 from pymatgen.analysis.interfaces.zsl import ZSLGenerator, ZSLMatch, reduce_vectors
-from pymatgen.core import Structure
-from pymatgen.core.surface import (
-    SlabGenerator,
-    get_symmetrically_distinct_miller_indices,
-)
+from pymatgen.core.surface import SlabGenerator, get_symmetrically_distinct_miller_indices
+
+if TYPE_CHECKING:
+    from pymatgen.core import Structure
 
 
 @dataclass
@@ -44,7 +41,6 @@ class SubstrateMatch(ZSLMatch):
         ground_state_energy=0,
     ):
         """Generate a substrate match from a ZSL match plus metadata"""
-
         # Get the appropriate surface structure
         struct = SlabGenerator(film, film_miller, 20, 15, primitive=False).get_slab().oriented_unit_cell
 
@@ -56,7 +52,7 @@ class SubstrateMatch(ZSLMatch):
         if elasticity_tensor is not None:
             energy_density = elasticity_tensor.energy_density(strain)
 
-            elastic_energy = film.volume * energy_density / len(film.sites)
+            elastic_energy = film.volume * energy_density / len(film)
         else:
             elastic_energy = 0
 
@@ -89,7 +85,7 @@ class SubstrateMatch(ZSLMatch):
 class SubstrateAnalyzer(ZSLGenerator):
     """
     This class applies a set of search criteria to identify suitable
-    substrates for film growth. It first uses a topoplogical search by Zur
+    substrates for film growth. It first uses a topological search by Zur
     and McGill to identify matching super-lattices on various faces of the
     two materials. Additional criteria can then be used to identify the most
     suitable substrate. Currently, the only additional criteria is the
@@ -187,7 +183,6 @@ class SubstrateAnalyzer(ZSLGenerator):
             substrate_miller,
         ] in surface_vector_sets:
             for match in self(film_vectors, substrate_vectors, lowest):
-
                 sub_match = SubstrateMatch.from_zsl(
                     match=match,
                     film=film,
