@@ -1,8 +1,4 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
-
-import unittest
+from __future__ import annotations
 
 from pymatgen.analysis.interfaces.coherent_interfaces import (
     CoherentInterfaceBuilder,
@@ -17,17 +13,15 @@ from pymatgen.util.testing import PymatgenTest
 class InterfaceBuilderTest(PymatgenTest):
     @classmethod
     def setUpClass(cls):
-
         si_struct = cls.get_structure("Si")
         sio2_struct = cls.get_structure("SiO2")
         cls.si_conventional = SpacegroupAnalyzer(si_struct).get_conventional_standard_structure()
         cls.sio2_conventional = SpacegroupAnalyzer(sio2_struct).get_conventional_standard_structure()
 
     def test_utils(self):
-
-        self.assertArrayAlmostEqual(from_2d_to_3d([[1, 2], [3, 4]]), [[1, 2, 0], [3, 4, 0], [0, 0, 1]])
-        self.assertArrayAlmostEqual(get_2d_transform([[1, 0], [0, 1]], [[1, 2], [3, 4]]), [[1, 2], [3, 4]])
-        self.assertArrayAlmostEqual(
+        self.assert_all_close(from_2d_to_3d([[1, 2], [3, 4]]), [[1, 2, 0], [3, 4, 0], [0, 0, 1]])
+        self.assert_all_close(get_2d_transform([[1, 0], [0, 1]], [[1, 2], [3, 4]]), [[1, 2], [3, 4]])
+        self.assert_all_close(
             get_rot_3d_for_2d([[1, 0, 0], [0, 1, 0]], [[1, 1, 0], [0, 1, 1]]),
             [
                 [0.78867513, -0.21132487, 0.57735027],
@@ -45,10 +39,6 @@ class InterfaceBuilderTest(PymatgenTest):
         )
 
         assert len(builder.terminations) == 2
-        # SP: I am commenting out this test which is super fragile and the result fluctates between 6 and 30 for
+        # SP: I am commenting out this test which is super fragile and the result fluctuates between 6 and 30 for
         # no apparent reason. The author should fix this.
-        # self.assertEqual(len(list(builder.get_interfaces(termination=("O2_Pmmm_1", "Si_R-3m_1")))), 30)
-
-
-if __name__ == "__main__":
-    unittest.main()
+        # assert len(list(builder.get_interfaces(termination=("O2_Pmmm_1", "Si_R-3m_1")))) == 30
