@@ -1,6 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 JahnTeller distortion analysis.
 """
@@ -9,19 +6,18 @@ from __future__ import annotations
 
 import os
 import warnings
-from typing import Any, Literal, cast
+from typing import TYPE_CHECKING, Any, Literal, cast
 
 import numpy as np
 
 from pymatgen.analysis.bond_valence import BVAnalyzer
-from pymatgen.analysis.local_env import (
-    LocalStructOrderParams,
-    get_neighbors_of_site_with_index,
-)
+from pymatgen.analysis.local_env import LocalStructOrderParams, get_neighbors_of_site_with_index
 from pymatgen.core.periodic_table import Species, get_el_sp
-from pymatgen.core.structure import Structure
 from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
 
+if TYPE_CHECKING:
+    from pymatgen.core import Structure
+
 MODULE_DIR = os.path.dirname(os.path.abspath(__file__))
 
 
@@ -128,13 +124,11 @@ class JahnTellerAnalyzer:
         non_jt_sites = []
 
         for indices in symmetrized_structure.equivalent_indices:
-
             idx = indices[0]
             site = symmetrized_structure[idx]
 
             # only interested in sites with oxidation states
             if isinstance(site.specie, Species) and site.specie.element.is_transition_metal:
-
                 # get motif around site
                 order_params = op.get_order_parameters(symmetrized_structure, idx)
 
@@ -149,12 +143,10 @@ class JahnTellerAnalyzer:
                     motif_order_parameter = None
 
                 if motif in ["oct", "tet"]:
-
                     motif = cast(Literal["oct", "tet"], motif)  # mypy needs help
 
                     # guess spin of metal ion
                     if guesstimate_spin and "magmom" in site.properties:
-
                         # estimate if high spin or low spin
                         magmom = site.properties["magmom"]
                         spin_state = self._estimate_spin_state(site.specie, motif, magmom)
@@ -164,7 +156,6 @@ class JahnTellerAnalyzer:
                     magnitude = self.get_magnitude_of_effect_from_species(site.specie, spin_state, motif)
 
                     if magnitude != "none":
-
                         ligands = get_neighbors_of_site_with_index(structure, idx, approach="min_dist", delta=0.15)
                         ligand_bond_lengths = [ligand.distance(structure[idx]) for ligand in ligands]
                         ligands_species = list({str(ligand.specie) for ligand in ligands})
@@ -384,7 +375,6 @@ class JahnTellerAnalyzer:
 
         # has to be Species; we need to know the oxidation state
         if isinstance(sp, Species) and sp.element.is_transition_metal:
-
             d_electrons = self._get_number_of_d_electrons(sp)
 
             if motif in self.spin_configs:
