@@ -1,6 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module provides classes to perform fitting of molecule with arbitrary
 atom orders.
@@ -12,10 +9,7 @@ The implementation is based on an excellent python package called `rmsd` that
 you can find at https://github.com/charnley/rmsd.
 """
 
-__author__ = "Xiaohui Qu, Adam Fekete"
-__version__ = "1.0"
-__email__ = "xhqu1981@gmail.com"
-
+from __future__ import annotations
 
 import abc
 import copy
@@ -40,6 +34,10 @@ from scipy.spatial.distance import cdist
 
 from pymatgen.core.structure import Molecule  # pylint: disable=ungrouped-imports
 
+__author__ = "Xiaohui Qu, Adam Fekete"
+__version__ = "1.0"
+__email__ = "xhqu1981@gmail.com"
+
 logger = logging.getLogger(__name__)
 
 
@@ -92,7 +90,6 @@ class AbstractMolAtomMapper(MSONable, metaclass=abc.ABCMeta):
             AbstractMolAtomMapper
         """
         for trans_modules in ["molecule_matcher"]:
-
             level = 0  # Python 3.x
             mod = __import__(
                 "pymatgen.analysis." + trans_modules,
@@ -221,7 +218,7 @@ class InchiMolAtomMapper(AbstractMolAtomMapper):
     def as_dict(self):
         """
         Returns:
-            MSONAble dict.
+            MSONable dict.
         """
         return {
             "version": __version__,
@@ -254,13 +251,13 @@ class InchiMolAtomMapper(AbstractMolAtomMapper):
             original label
             List of equivalent atoms.
         """
-        obconv = openbabel.OBConversion()
-        obconv.SetOutFormat("inchi")
-        obconv.AddOption("a", openbabel.OBConversion.OUTOPTIONS)
-        obconv.AddOption("X", openbabel.OBConversion.OUTOPTIONS, "DoNotAddH")
-        inchi_text = obconv.WriteString(mol)
+        ob_conv = openbabel.OBConversion()
+        ob_conv.SetOutFormat("inchi")
+        ob_conv.AddOption("a", openbabel.OBConversion.OUTOPTIONS)
+        ob_conv.AddOption("X", openbabel.OBConversion.OUTOPTIONS, "DoNotAddH")
+        inchi_text = ob_conv.WriteString(mol)
         match = re.search(
-            r"InChI=(?P<inchi>.+)\nAuxInfo=.+" r"/N:(?P<labels>[0-9,;]+)/(E:(?P<eq_atoms>[0-9," r";\(\)]*)/)?",
+            r"InChI=(?P<inchi>.+)\nAuxInfo=.+/N:(?P<labels>[0-9,;]+)/(E:(?P<eq_atoms>[0-9,;\(\)]*)/)?",
             inchi_text,
         )
         inchi = match.group("inchi")
@@ -300,12 +297,12 @@ class InchiMolAtomMapper(AbstractMolAtomMapper):
 
     def _virtual_molecule(self, mol, ilabels, eq_atoms):
         """
-        Create a virtual molecule by unique atoms, the centriods of the
+        Create a virtual molecule by unique atoms, the centroids of the
         equivalent atoms
 
         Args:
             mol: The molecule. OpenBabel OBMol object
-            ilables: inchi label map
+            ilabels: inchi label map
             eq_atoms: equivalent atom labels
             farthest_group_idx: The equivalent atom group index in which
                 there is the farthest atom to the centroid
@@ -713,7 +710,7 @@ class MoleculeMatcher(MSONable):
     def as_dict(self):
         """
         Returns:
-            MSONAble dict.
+            MSONable dict.
         """
         return {
             "version": __version__,
@@ -861,7 +858,7 @@ class BruteForceOrderMatcher(KabschMatcher):
         of atoms from the same species.
     """
 
-    def match(self, p: Molecule, ignore_warning=False):
+    def match(self, mol: Molecule, ignore_warning: bool = False) -> tuple[np.ndarray, np.ndarray, np.ndarray, float]:
         """Similar as `KabschMatcher.match` but this method also finds the order of
         atoms which belongs to the best match.
 
@@ -869,7 +866,7 @@ class BruteForceOrderMatcher(KabschMatcher):
         become unfeasible (more than a million combination).
 
         Args:
-            p: a `Molecule` object what will be matched with the target one.
+            mol: a `Molecule` object what will be matched with the target one.
             ignore_warning: ignoring error when the number of combination is too large
 
         Returns:
@@ -878,23 +875,23 @@ class BruteForceOrderMatcher(KabschMatcher):
             V: Translation vector
             rmsd: Root mean squared deviation between P and Q
         """
-        q = self.target
+        target_mol = self.target
 
-        if sorted(p.atomic_numbers) != sorted(q.atomic_numbers):
+        if sorted(mol.atomic_numbers) != sorted(target_mol.atomic_numbers):
             raise ValueError("The number of the same species aren't matching!")
 
-        _, count = np.unique(p.atomic_numbers, return_counts=True)
+        _, count = np.unique(mol.atomic_numbers, return_counts=True)
         total_permutations = 1
         for c in count:
             total_permutations *= np.math.factorial(c)  # type: ignore
 
         if not ignore_warning and total_permutations > 1_000_000:
             raise ValueError(
-                "The number of all possible permutations " f"({total_permutations}) is not feasible to run this method!"
+                f"The number of all possible permutations ({total_permutations}) is not feasible to run this method!"
             )
 
-        p_coord, q_coord = p.cart_coords, q.cart_coords
-        p_atoms, q_atoms = np.array(p.atomic_numbers), np.array(q.atomic_numbers)
+        p_coord, q_coord = mol.cart_coords, target_mol.cart_coords
+        p_atoms, q_atoms = np.array(mol.atomic_numbers), np.array(target_mol.atomic_numbers)
 
         # Both sets of coordinates must be translated first, so that
         # their centroid coincides with the origin of the coordinate system.
@@ -910,7 +907,6 @@ class BruteForceOrderMatcher(KabschMatcher):
 
         # Generate all permutation grouped/sorted by the elements
         for p_inds_test in self.permutations(p_atoms):
-
             p_centroid_test = p_centroid[p_inds_test]
             U_test = self.kabsch(p_centroid_test, q_centroid)
 
@@ -925,9 +921,9 @@ class BruteForceOrderMatcher(KabschMatcher):
         V = q_trans - np.dot(p_trans, U)
 
         # Using the original order of the indices
-        inds = p_inds[np.argsort(q_inds)]
+        indices = p_inds[np.argsort(q_inds)]
 
-        return inds, U, V, rmsd
+        return indices, U, V, rmsd
 
     def fit(self, p: Molecule, ignore_warning=False):
         """Order, rotate and transform `p` molecule according to the best match.
@@ -1008,7 +1004,6 @@ class HungarianOrderMatcher(KabschMatcher):
 
         # Generate all permutation grouped/sorted by the elements
         for p_inds_test in self.permutations(p_atoms, p_centroid, p_weights, q_atoms, q_centroid, q_weights):
-
             p_centroid_test = p_centroid[p_inds_test]
             U_test = self.kabsch(p_centroid_test, q_centroid)
 
@@ -1128,7 +1123,6 @@ class HungarianOrderMatcher(KabschMatcher):
         Ixx = Iyy = Izz = Ixy = Ixz = Iyz = 0.0
 
         for (x, y, z), wt in zip(coords, weights):
-
             Ixx += wt * (y * y + z * z)
             Iyy += wt * (x * x + z * z)
             Izz += wt * (x * x + y * y)
@@ -1282,28 +1276,26 @@ class GeneticOrderMatcher(KabschMatcher):
         # starting matches (only based on element)
         partial_matches = [[j] for j in range(self.N) if p_atoms[j] == q_atoms[0]]
 
-        for i in range(1, self.N):
+        for idx in range(1, self.N):
             # extending the target fragment with then next atom
-            f_coords = q_coords[: i + 1]
-            f_atom = q_atoms[i]
+            f_coords = q_coords[: idx + 1]
+            f_atom = q_atoms[idx]
 
             f_trans = f_coords.mean(axis=0)
             f_centroid = f_coords - f_trans
 
             matches = []
             for indices in partial_matches:
-
-                for j in range(self.N):
-
+                for jdx in range(self.N):
                     # skipping if the this index is already matched
-                    if j in indices:
+                    if jdx in indices:
                         continue
 
                     # skipping if they are different species
-                    if p_atoms[j] != f_atom:
+                    if p_atoms[jdx] != f_atom:
                         continue
 
-                    inds = indices + [j]
+                    inds = [*indices, jdx]
                     P = p_coords[inds]
 
                     # Both sets of coordinates must be translated first, so that
@@ -1326,6 +1318,6 @@ class GeneticOrderMatcher(KabschMatcher):
 
             partial_matches = matches
 
-            logger.info(f"number of atom in the fragment: {i + 1}, number of possible matches: {len(matches)}")
+            logger.info(f"number of atom in the fragment: {idx + 1}, number of possible matches: {len(matches)}")
 
         return matches
