@@ -1,6 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module provides classes to comparison the structures of the two
 molecule. As long as the two molecule have the same bond connection tables,
@@ -11,6 +8,8 @@ correspondence prerequisite, while molecule_matcher is supposed to do exact
 comparisons without the atom order correspondence prerequisite.
 """
 
+from __future__ import annotations
+
 import itertools
 
 from monty.json import MSONable
@@ -122,7 +121,7 @@ class CovalentRadius:
         "Ra": 2.21,
         "Ac": 2.15,
         "Th": 2.06,
-        "Pa": 2.00,
+        "Pa": 2,
         "U": 1.96,
         "Np": 1.90,
         "Pu": 1.87,
@@ -137,24 +136,8 @@ class MoleculeStructureComparator(MSONable):
     same. The atom in the two molecule must be paired accordingly.
     """
 
-    ionic_element_list = [
-        "Na",
-        "Mg",
-        "Al",
-        "Sc",
-        "V",
-        "Cr",
-        "Mn",
-        "Fe",
-        "Co",
-        "Ni",
-        "Cu",
-        "Zn",
-        "Ga",
-        "Rb",
-        "Sr",
-    ]
-    halogen_list = ["F", "Cl", "Br", "I"]
+    ionic_element_list = ("Na", "Mg", "Al", "Sc", "V", "Cr", "Mn", "Fe", "Co", "Ni", "Cu", "Zn", "Ga", "Rb", "Sr")
+    halogen_list = ("F", "Cl", "Br", "I")
 
     def __init__(
         self,
@@ -187,7 +170,7 @@ class MoleculeStructureComparator(MSONable):
         self.ignore_halogen_self_bond = True
         self.bond_13_cap = bond_13_cap
 
-    def are_equal(self, mol1, mol2):
+    def are_equal(self, mol1, mol2) -> bool:
         """
         Compare the bond table of the two molecules.
 
@@ -280,7 +263,7 @@ class MoleculeStructureComparator(MSONable):
         }
 
     @classmethod
-    def from_dict(cls, d):
+    def from_dict(cls, dct):
         """
         Args:
             d (dict): Dict representation
@@ -289,8 +272,8 @@ class MoleculeStructureComparator(MSONable):
             MoleculeStructureComparator
         """
         return cls(
-            bond_length_cap=d["bond_length_cap"],
-            covalent_radius=d["covalent_radius"],
-            priority_bonds=d["priority_bonds"],
-            priority_cap=d["priority_cap"],
+            bond_length_cap=dct["bond_length_cap"],
+            covalent_radius=dct["covalent_radius"],
+            priority_bonds=dct["priority_bonds"],
+            priority_cap=dct["priority_cap"],
         )
