@@ -2,12 +2,14 @@
 Piezo sensitivity analysis module.
 """
 
+from __future__ import annotations
+
 import warnings
+from typing import TYPE_CHECKING
 
 import numpy as np
 from monty.dev import requires
 
-from pymatgen.core.structure import Structure
 from pymatgen.core.tensors import Tensor
 from pymatgen.symmetry.analyzer import SpacegroupAnalyzer as sga
 
@@ -17,6 +19,10 @@ try:
 except ImportError:
     Phonopy = None
 
+
+if TYPE_CHECKING:
+    from pymatgen.core import Structure
+
 __author__ = "Handong Ling"
 __copyright__ = "Copyright 2019, The Materials Project"
 __version__ = "1.0"
@@ -36,7 +42,7 @@ class BornEffectiveCharge:
         Create an BornEffectiveChargeTensor object defined by a
         structure, point operations of the structure's atomic sites.
         Note that the constructor uses __new__ rather than __init__
-        according to the standard method ofsubclassing numpy ndarrays.
+        according to the standard method of subclassing numpy ndarrays.
 
         Args:
             input_matrix (Nx3x3 array-like): the Nx3x3 array-like
@@ -70,14 +76,14 @@ class BornEffectiveCharge:
         bec = self.bec
         struct = self.structure
         ops = sga(struct).get_symmetry_operations(cartesian=True)
-        uniquepointops = []
+        uniq_point_ops = []
         for op in ops:
-            uniquepointops.append(op)
+            uniq_point_ops.append(op)
 
         for ops in self.pointops:
             for op in ops:
-                if op not in uniquepointops:
-                    uniquepointops.append(op)
+                if op not in uniq_point_ops:
+                    uniq_point_ops.append(op)
 
         passed = []
         relations = []
@@ -85,22 +91,22 @@ class BornEffectiveCharge:
             unique = 1
             eig1, vecs1 = np.linalg.eig(val)
             index = np.argsort(eig1)
-            neweig = np.real([eig1[index[0]], eig1[index[1]], eig1[index[2]]])
+            new_eig = np.real([eig1[index[0]], eig1[index[1]], eig1[index[2]]])
             for index, p in enumerate(passed):
-                if np.allclose(neweig, p[1], atol=eigtol):
+                if np.allclose(new_eig, p[1], atol=eigtol):
                     relations.append([site, index])
                     unique = 0
-                    passed.append([site, p[0], neweig])
+                    passed.append([site, p[0], new_eig])
                     break
             if unique == 1:
                 relations.append([site, site])
-                passed.append([site, neweig])
+                passed.append([site, new_eig])
         BEC_operations = []
         for atom, r in enumerate(relations):
             BEC_operations.append(r)
             BEC_operations[atom].append([])
 
-            for op in uniquepointops:
+            for op in uniq_point_ops:
                 new = op.transform_tensor(self.bec[relations[atom][1]])
 
                 # Check the matrix it references
@@ -108,6 +114,7 @@ class BornEffectiveCharge:
                     BEC_operations[atom][2].append(op)
 
         self.BEC_operations = BEC_operations
+        return BEC_operations
 
     def get_rand_BEC(self, max_charge=1):
         """
@@ -120,12 +127,8 @@ class BornEffectiveCharge:
         Return:
             np.array Born effective charge tensor
         """
-        struct = self.structure
-        symstruc = sga(struct)
-        symstruc = symstruc.get_symmetrized_structure()
-
-        l = len(struct)
-        BEC = np.zeros((l, 3, 3))
+        n_atoms = len(self.structure)
+        BEC = np.zeros((n_atoms, 3, 3))
         for atom, ops in enumerate(self.BEC_operations):
             if ops[0] == ops[1]:
                 temp_tensor = Tensor(np.random.rand(3, 3) - 0.5)
@@ -136,18 +139,16 @@ class BornEffectiveCharge:
             else:
                 tempfcm = np.zeros([3, 3])
                 for op in ops[2]:
-
                     tempfcm += op.transform_tensor(BEC[self.BEC_operations[atom][1]])
                 BEC[ops[0]] = tempfcm
                 if len(ops[2]) != 0:
                     BEC[ops[0]] = BEC[ops[0]] / len(ops[2])
 
         #     Enforce Acoustic Sum
-        disp_charge = np.einsum("ijk->jk", BEC) / l
-        add = np.zeros([l, 3, 3])
+        disp_charge = np.einsum("ijk->jk", BEC) / n_atoms
+        add = np.zeros([n_atoms, 3, 3])
 
         for atom, ops in enumerate(self.BEC_operations):
-
             if ops[0] == ops[1]:
                 temp_tensor = Tensor(disp_charge)
                 temp_tensor = sum(temp_tensor.transform(symm_op) for symm_op in self.pointops[atom]) / len(
@@ -157,7 +158,6 @@ class BornEffectiveCharge:
             else:
                 temp_tensor = np.zeros([3, 3])
                 for op in ops[2]:
-
                     temp_tensor += op.transform_tensor(add[self.BEC_operations[atom][1]])
 
                 add[ops[0]] = temp_tensor
@@ -244,8 +244,8 @@ class InternalStrainTensor:
         Return:
             InternalStrainTensor object
         """
-        l = len(self.structure)
-        IST = np.zeros((l, 3, 3, 3))
+        n_atoms = len(self.structure)
+        IST = np.zeros((n_atoms, 3, 3, 3))
         for atom, ops in enumerate(self.IST_operations):
             temp_tensor = np.zeros([3, 3, 3])
             for op in ops:
@@ -349,12 +349,7 @@ class ForceConstantMatrix:
             if r[0] == r[2] and r[1] == r[3]:
                 good = 1
             if good == 0:
-                FCM_operations[entry] = [
-                    r[0],
-                    r[1],
-                    r[3],
-                    r[2],
-                ]
+                FCM_operations[entry] = [r[0], r[1], r[3], r[2]]
                 FCM_operations[entry].append([])
                 for op in uniquepointops:
                     new = op.transform_tensor(self.fcm[r[2]][r[3]])
@@ -381,8 +376,8 @@ class ForceConstantMatrix:
         struct = self.structure
         operations = self.FCM_operations
         # set max force in reciprocal space
-        numsites = len(struct.sites)
-        D = (1 / max_force) * 2 * (np.ones([numsites * 3, numsites * 3]))
+        n_sites = len(struct)
+        D = (1 / max_force) * 2 * (np.ones([n_sites * 3, n_sites * 3]))
         for op in operations:
             same = 0
             transpose = 0
@@ -395,7 +390,6 @@ class ForceConstantMatrix:
                 D[3 * op[1] : 3 * op[1] + 3, 3 * op[0] : 3 * op[0] + 3] = np.zeros([3, 3])
 
                 for symop in op[4]:
-
                     tempfcm = D[3 * op[2] : 3 * op[2] + 3, 3 * op[3] : 3 * op[3] + 3]
                     tempfcm = symop.transform_tensor(tempfcm)
                     D[3 * op[0] : 3 * op[0] + 3, 3 * op[1] : 3 * op[1] + 3] += tempfcm
@@ -416,7 +410,6 @@ class ForceConstantMatrix:
             temp_tensor_sum = temp_tensor_sum / (len(self.sharedops[op[0]][op[1]]))
             if op[0] != op[1]:
                 for pair in range(len(op[4])):
-
                     temp_tensor2 = temp_tensor_sum.T
                     temp_tensor2 = op[4][pair].transform_tensor(temp_tensor2)
                     temp_tensor_sum = (temp_tensor_sum + temp_tensor2) / 2
@@ -453,7 +446,6 @@ class ForceConstantMatrix:
                 D[3 * op[0] : 3 * op[0] + 3, 3 * op[1] : 3 * op[1] + 3] = np.zeros([3, 3])
 
                 for symop in op[4]:
-
                     tempfcm = D[3 * op[2] : 3 * op[2] + 3, 3 * op[3] : 3 * op[3] + 3]
                     tempfcm = symop.transform_tensor(tempfcm)
 
@@ -475,9 +467,7 @@ class ForceConstantMatrix:
 
             # Apply the proper transformation if there is an equivalent already
             if op[0] != op[1]:
-
                 for pair in range(len(op[4])):
-
                     temp_tensor2 = temp_tensor_sum.T
                     temp_tensor2 = op[4][pair].transform_tensor(temp_tensor2)
                     temp_tensor_sum = (temp_tensor_sum + temp_tensor2) / 2
@@ -580,7 +570,6 @@ class ForceConstantMatrix:
                     D[3 * op[0] : 3 * op[0] + 3, 3 * op[1] : 3 * op[1] + 3] = np.zeros([3, 3])
 
                     for symop in op[4]:
-
                         tempfcm = D[3 * op[2] : 3 * op[2] + 3, 3 * op[3] : 3 * op[3] + 3]
                         tempfcm = symop.transform_tensor(tempfcm)
 
@@ -614,9 +603,7 @@ class ForceConstantMatrix:
 
                 # Apply the proper transformation if there is an equivalent already
                 if op[0] != op[1]:
-
                     for pair in range(len(op[4])):
-
                         temp_tensor2 = temp_tensor_sum.T
                         temp_tensor2 = op[4][pair].transform_tensor(temp_tensor2)
                         temp_tensor_sum = (temp_tensor_sum + temp_tensor2) / 2
@@ -647,22 +634,22 @@ class ForceConstantMatrix:
         """
         from pymatgen.io.phonopy import get_phonopy_structure
 
-        numsites = len(self.structure.sites)
+        n_sites = len(self.structure)
         structure = get_phonopy_structure(self.structure)
         pnstruc = Phonopy(structure, np.eye(3), np.eye(3))
 
         dyn = self.get_unstable_FCM(force)
         dyn = self.get_stable_FCM(dyn)
 
-        dyn = np.reshape(dyn, (numsites, 3, numsites, 3)).swapaxes(1, 2)
+        dyn = np.reshape(dyn, (n_sites, 3, n_sites, 3)).swapaxes(1, 2)
 
         dynmass = np.zeros([len(self.structure), len(self.structure), 3, 3])
         masses = []
-        for j in range(numsites):
-            masses.append(self.structure.sites[j].specie.atomic_mass)
-        dynmass = np.zeros([numsites, numsites, 3, 3])
-        for m in range(numsites):
-            for n in range(numsites):
+        for idx in range(n_sites):
+            masses.append(self.structure[idx].specie.atomic_mass)
+        dynmass = np.zeros([n_sites, n_sites, 3, 3])
+        for m in range(n_sites):
+            for n in range(n_sites):
                 dynmass[m][n] = dyn[m][n] * np.sqrt(masses[m]) * np.sqrt(masses[n])
 
         supercell = pnstruc.get_supercell()
@@ -670,7 +657,7 @@ class ForceConstantMatrix:
 
         converter = dyntofc.DynmatToForceConstants(primitive, supercell)
 
-        dyn = np.reshape(np.swapaxes(dynmass, 1, 2), (numsites * 3, numsites * 3))
+        dyn = np.reshape(np.swapaxes(dynmass, 1, 2), (n_sites * 3, n_sites * 3))
 
         converter.set_dynamical_matrices(dynmat=[dyn])
 
@@ -694,7 +681,6 @@ def get_piezo(BEC, IST, FCM, rcond=0.0001):
     Return:
         3x3x3 calculated Piezo tensor
     """
-
     numsites = len(BEC)
     temp_fcm = np.reshape(np.swapaxes(FCM, 1, 2), (numsites * 3, numsites * 3))
 
