@@ -1,5 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
 """
 This module is intended to be used to compute Pourbaix diagrams
 of arbitrary compositions and formation energies. If you use
@@ -20,7 +18,7 @@ import logging
 import re
 import warnings
 from copy import deepcopy
-from functools import cmp_to_key, lru_cache, partial
+from functools import cmp_to_key, partial
 from multiprocessing import Pool
 
 import numpy as np
@@ -133,8 +131,6 @@ class PourbaixEntry(MSONable, Stringify):
     @property
     def energy(self):
         """
-        returns energy
-
         Returns (float): total energy of the Pourbaix
             entry (at pH, V = 0 vs. SHE)
         """
@@ -230,10 +226,7 @@ class PourbaixEntry(MSONable, Stringify):
         Invokes a PourbaixEntry from a dictionary
         """
         entry_type = d["entry_type"]
-        if entry_type == "Ion":
-            entry = IonEntry.from_dict(d["entry"])
-        else:
-            entry = MontyDecoder().process_decoded(d["entry"])
+        entry = IonEntry.from_dict(d["entry"]) if entry_type == "Ion" else MontyDecoder().process_decoded(d["entry"])
         entry_id = d["entry_id"]
         concentration = d["concentration"]
         return cls(entry, entry_id, concentration)
@@ -274,9 +267,6 @@ class PourbaixEntry(MSONable, Stringify):
             f"nPhi = {self.nPhi}, nH2O = {self.nH2O}, entry_id = {self.entry_id} "
         )
 
-    def __str__(self):
-        return self.__repr__()
-
 
 class MultiEntry(PourbaixEntry):
     """
@@ -298,12 +288,10 @@ class MultiEntry(PourbaixEntry):
             self.weights = weights
         self.entry_list = entry_list
 
-    @lru_cache
     def __getattr__(self, item):
         """
-        Because most of the attributes here are just weighted
-        averages of the entry_list, we save some space by
-        having a set of conditionals to define the attributes
+        Because most of the attributes here are just weighted averages of the entry_list,
+        we save some space by having a set of conditionals to define the attributes
         """
         # Attributes that are weighted averages of entry attributes
         if item in [
@@ -316,10 +304,7 @@ class MultiEntry(PourbaixEntry):
             "uncorrected_energy",
         ]:
             # TODO: Composition could be changed for compat with sum
-            if item == "composition":
-                start = Composition({})
-            else:
-                start = 0
+            start = Composition({}) if item == "composition" else 0
             return sum(
                 (getattr(e, item) * w for e, w in zip(self.entry_list, self.weights)),
                 start,
@@ -337,7 +322,7 @@ class MultiEntry(PourbaixEntry):
         """
         MultiEntry name, i. e. the name of each entry joined by ' + '
         """
-        return " + ".join([e.name for e in self.entry_list])
+        return " + ".join(e.name for e in self.entry_list)
 
     def __repr__(self):
         return (
@@ -345,9 +330,6 @@ class MultiEntry(PourbaixEntry):
             f"nH2O = {self.nH2O}, entry_id = {self.entry_id}, species: {self.name}"
         )
 
-    def __str__(self):
-        return self.__repr__()
-
     def as_dict(self):
         """
         Returns: MSONable dict
@@ -416,9 +398,6 @@ class IonEntry(PDEntry):
     def __repr__(self):
         return f"IonEntry : {self.composition} with energy = {self.energy:.4f}"
 
-    def __str__(self):
-        return self.__repr__()
-
 
 def ion_or_solid_comp_object(formula):
     """
@@ -449,6 +428,7 @@ ELEMENTS_HO = {Element("H"), Element("O")}
 #       heatmap plotter, because the reference states for decomposition
 #       don't include oxygen/hydrogen in the OER/HER regions
 
+
 # TODO: create a from_phase_diagram class method for non-formation energy
 #       invocation
 # TODO: invocation from a MultiEntry entry list could be a bit more robust
@@ -510,7 +490,7 @@ class PourbaixDiagram(MSONable):
         else:
             # Set default conc/comp dicts
             if not comp_dict:
-                comp_dict = {elt.symbol: 1.0 / len(self.pbx_elts) for elt in self.pbx_elts}
+                comp_dict = {elt.symbol: 1 / len(self.pbx_elts) for elt in self.pbx_elts}
             if not conc_dict:
                 conc_dict = {elt.symbol: 1e-6 for elt in self.pbx_elts}
             self._conc_dict = conc_dict
@@ -534,7 +514,7 @@ class PourbaixDiagram(MSONable):
             self._unprocessed_entries = solid_entries + ion_entries
 
             if not len(solid_entries + ion_entries) == len(entries):
-                raise ValueError("All supplied entries must have a phase type of " 'either "Solid" or "Ion"')
+                raise ValueError('All supplied entries must have a phase type of either "Solid" or "Ion"')
 
             if self.filter_solids:
                 # O is 2.46 b/c pbx entry finds energies referenced to H2O
@@ -612,7 +592,7 @@ class PourbaixDiagram(MSONable):
         hull = ConvexHull(points, qhull_options="QJ i")
 
         # Create facets and remove top
-        facets = [facet for facet in hull.simplices if not len(points) - 1 in facet]
+        facets = [facet for facet in hull.simplices if len(points) - 1 not in facet]
 
         if self.dim > 1:
             logger.debug("Filtering facets by Pourbaix composition")
@@ -750,8 +730,8 @@ class PourbaixDiagram(MSONable):
             # their charge state.
             entry_comps = [e.composition for e in entry_list]
             rxn = Reaction(entry_comps + dummy_oh, [prod_comp])
-            react_coeffs = [-rxn.get_coeff(comp) for comp in entry_comps]
-            all_coeffs = react_coeffs + [rxn.get_coeff(prod_comp)]
+            react_coeffs = [-coeff for coeff in rxn.coeffs[: len(entry_list)]]
+            all_coeffs = [*react_coeffs, rxn.get_coeff(prod_comp)]
 
             # Check if reaction coeff threshold met for Pourbaix compounds
             # All reactant/product coefficients must be positive nonzero
@@ -811,7 +791,7 @@ class PourbaixDiagram(MSONable):
             [0, 0, -1, 2 * g_max],
         ]
         hs_hyperplanes = np.vstack([hyperplanes, border_hyperplanes])
-        interior_point = np.average(limits, axis=1).tolist() + [g_max]
+        interior_point = [*np.average(limits, axis=1).tolist(), g_max]
         hs_int = HalfspaceIntersection(hs_hyperplanes, np.array(interior_point))
 
         # organize the boundary points by entry
@@ -948,25 +928,12 @@ class PourbaixDiagram(MSONable):
         """
         return self._unprocessed_entries
 
-    def as_dict(self, include_unprocessed_entries=None):
+    def as_dict(self):
         """
-        Args:
-            include_unprocessed_entries (): DEPRECATED. Whether to include unprocessed
-                entries (equivalent to filter_solids=False). Serialization now includes
-                all unprocessed entries by default. Set filter_solids=False before
-                serializing to include unstable solids from the generated Pourbaix Diagram.
-
         Returns:
             MSONable dict.
         """
-        if include_unprocessed_entries:
-            warnings.warn(
-                DeprecationWarning(
-                    "The include_unprocessed_entries kwarg is deprecated! "
-                    "Set filter_solids=True / False before serializing instead."
-                )
-            )
-        d = {
+        return {
             "@module": type(self).__module__,
             "@class": type(self).__name__,
             "entries": [e.as_dict() for e in self._unprocessed_entries],
@@ -974,7 +941,6 @@ class PourbaixDiagram(MSONable):
             "conc_dict": self._conc_dict,
             "filter_solids": self.filter_solids,
         }
-        return d
 
     @classmethod
     def from_dict(cls, d):
@@ -1133,7 +1099,7 @@ class PourbaixPlotter:
 
         # Set ticklabels
         # ticklabels = [t.get_text() for t in cbar.ax.get_yticklabels()]
-        # ticklabels[-1] = '>={}'.format(ticklabels[-1])
+        # ticklabels[-1] = f">={ticklabels[-1]}"
         # cbar.ax.set_yticklabels(ticklabels)
 
         return plt
@@ -1159,7 +1125,7 @@ def generate_entry_label(entry):
         entry (PourbaixEntry or MultiEntry): entry to get a label for
     """
     if isinstance(entry, MultiEntry):
-        return " + ".join([e.name for e in entry.entry_list])
+        return " + ".join(e.name for e in entry.entry_list)
 
     # TODO - a more elegant solution could be added later to Stringify
     # for example, the pattern re.sub(r"([-+][\d\.]*)", r"$^{\1}$", )
