@@ -1,6 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module implements the Quasi-harmonic Debye approximation that can
 be used to compute thermal properties.
@@ -50,12 +47,12 @@ class QuasiharmonicDebyeApprox:
         poisson=0.25,
         use_mie_gruneisen=False,
         anharmonic_contribution=False,
-    ):
+    ) -> None:
         """
         Args:
             energies (list): list of DFT energies in eV
             volumes (list): list of volumes in Ang^3
-            structure (Structure):
+            structure (Structure): pymatgen structure object
             t_min (float): min temperature
             t_step (float): temperature step
             t_max (float): max temperature
@@ -94,11 +91,11 @@ class QuasiharmonicDebyeApprox:
         self.avg_mass = physical_constants["atomic mass constant"][0] * self.mass / self.natoms  # kg
         self.kb = physical_constants["Boltzmann constant in eV/K"][0]
         self.hbar = physical_constants["Planck constant over 2 pi in eV s"][0]
-        self.gpa_to_ev_ang = 1.0 / 160.21766208  # 1 GPa in ev/Ang^3
-        self.gibbs_free_energy = []  # optimized values, eV
+        self.gpa_to_ev_ang = 1 / 160.21766208  # 1 GPa in ev/Ang^3
+        self.gibbs_free_energy: list[float] = []  # optimized values, eV
         # list of temperatures for which the optimized values are available, K
-        self.temperatures = []
-        self.optimum_volumes = []  # in Ang^3
+        self.temperatures: list[float] = []
+        self.optimum_volumes: list[float] = []  # in Ang^3
         # fit E and V and get the bulk modulus(used to compute the Debye
         # temperature)
         logger.info("Fitting E and V")
@@ -221,8 +218,8 @@ class QuasiharmonicDebyeApprox:
             float: debye temperature in K
         """
         term1 = (2.0 / 3.0 * (1.0 + self.poisson) / (1.0 - 2.0 * self.poisson)) ** 1.5
-        term2 = (1.0 / 3.0 * (1.0 + self.poisson) / (1.0 - self.poisson)) ** 1.5
-        f = (3.0 / (2.0 * term1 + term2)) ** (1.0 / 3.0)
+        term2 = (1 / 3 * (1.0 + self.poisson) / (1.0 - self.poisson)) ** 1.5
+        f = (3.0 / (2.0 * term1 + term2)) ** (1 / 3)
         debye = 2.9772e-11 * (volume / self.natoms) ** (-1.0 / 6.0) * f * np.sqrt(self.bulk_modulus / self.avg_mass)
         if self.anharmonic_contribution:
             gamma = self.gruneisen_parameter(0, self.ev_eos_fit.v0)  # 0K equilibrium Gruneisen parameter
@@ -252,16 +249,14 @@ class QuasiharmonicDebyeApprox:
     def gruneisen_parameter(self, temperature, volume):
         """
         Slater-gamma formulation(the default):
-            gruneisen parameter = - d log(theta)/ d log(V)
-                               = - ( 1/6 + 0.5 d log(B)/ d log(V) )
-                               = - (1/6 + 0.5 V/B dB/dV),
-                                    where dB/dV = d^2E/dV^2 + V * d^3E/dV^3
+            gruneisen parameter = - d log(theta)/ d log(V) = - (1/6 + 0.5 d log(B)/ d log(V))
+                                = - (1/6 + 0.5 V/B dB/dV), where dB/dV = d^2E/dV^2 + V * d^3E/dV^3
 
         Mie-gruneisen formulation:
             Eq(31) in doi.org/10.1016/j.comphy.2003.12.001
             Eq(7) in Blanco et. al. Joumal of Molecular Structure (Theochem)
                 368 (1996) 245-255
-            Also se J.P. Poirier, Introduction to the Physics of the Earth’s
+            Also se J.P. Poirier, Introduction to the Physics of the Earth's
                 Interior, 2nd ed. (Cambridge University Press, Cambridge,
                 2000) Eq(3.53)
 
@@ -317,14 +312,14 @@ class QuasiharmonicDebyeApprox:
         """
         gamma = self.gruneisen_parameter(temperature, volume)
         theta_d = self.debye_temperature(volume)  # K
-        theta_a = theta_d * self.natoms ** (-1.0 / 3.0)  # K
-        prefactor = (0.849 * 3 * 4 ** (1.0 / 3.0)) / (20.0 * np.pi**3)
+        theta_a = theta_d * self.natoms ** (-1 / 3)  # K
+        prefactor = (0.849 * 3 * 4 ** (1 / 3)) / (20.0 * np.pi**3)
         # kg/K^3/s^3
         prefactor = prefactor * (self.kb / self.hbar) ** 3 * self.avg_mass
         kappa = prefactor / (gamma**2 - 0.514 * gamma + 0.228)
         # kg/K/s^3 * Ang = (kg m/s^2)/(Ks)*1e-10
         # = N/(Ks)*1e-10 = Nm/(Kms)*1e-10 = W/K/m*1e-10
-        kappa = kappa * theta_a**2 * volume ** (1.0 / 3.0) * 1e-10
+        kappa = kappa * theta_a**2 * volume ** (1 / 3) * 1e-10
         return kappa
 
     def get_summary_dict(self):
