@@ -1,6 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module provides classes that define a chemical reaction.
 """
@@ -440,9 +437,9 @@ class ComputedReaction(Reaction):
         self._reactant_entries = reactant_entries
         self._product_entries = product_entries
         self._all_entries = reactant_entries + product_entries
-        reactant_comp = [e.composition.get_reduced_composition_and_factor()[0] for e in reactant_entries]
+        reactant_comp = [e.composition.reduced_composition for e in reactant_entries]
 
-        product_comp = [e.composition.get_reduced_composition_and_factor()[0] for e in product_entries]
+        product_comp = [e.composition.reduced_composition for e in product_entries]
 
         super().__init__(list(reactant_comp), list(product_comp))
 
@@ -469,7 +466,7 @@ class ComputedReaction(Reaction):
         calc_energies = {}
 
         for entry in self._reactant_entries + self._product_entries:
-            (comp, factor) = entry.composition.get_reduced_composition_and_factor()
+            comp, factor = entry.composition.get_reduced_composition_and_factor()
             calc_energies[comp] = min(calc_energies.get(comp, float("inf")), entry.energy / factor)
 
         return self.calculate_energy(calc_energies)
@@ -483,7 +480,7 @@ class ComputedReaction(Reaction):
         calc_energies = {}
 
         for entry in self._reactant_entries + self._product_entries:
-            (comp, factor) = entry.composition.get_reduced_composition_and_factor()
+            comp, factor = entry.composition.get_reduced_composition_and_factor()
             energy_ufloat = ufloat(entry.energy, entry.correction_uncertainty)
             calc_energies[comp] = min(calc_energies.get(comp, float("inf")), energy_ufloat / factor)
 
