@@ -1,8 +1,9 @@
+from __future__ import annotations
+
 import os
-import unittest
 import warnings
 
-import pytest
+from pytest import approx
 
 from pymatgen.analysis.solar.slme import optics, slme
 from pymatgen.util.testing import PymatgenTest
@@ -22,8 +23,4 @@ class SolarTest(PymatgenTest):
         en, abz, dirgap, indirgap = optics(path)
         abz = abz * 100.0
         eff = slme(en, abz, indirgap, indirgap, plot_current_voltage=False)
-        assert eff == pytest.approx(27.728998512)
-
-
-if __name__ == "__main__":
-    unittest.main()
+        assert eff == approx(27.728998512)
