@@ -1,12 +1,11 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module provides classes to perform fitting of structures.
 """
+from __future__ import annotations
+
 import abc
 import itertools
-from typing import Literal, Sequence
+from typing import Literal, Mapping, Sequence
 
 import numpy as np
 from monty.json import MSONable
@@ -35,7 +34,7 @@ class AbstractComparator(MSONable, metaclass=abc.ABCMeta):
     """
 
     @abc.abstractmethod
-    def are_equal(self, sp1, sp2):
+    def are_equal(self, sp1, sp2) -> bool:
         """
         Defines how the species of two sites are considered equal. For
         example, one can consider sites to have the same species only when
@@ -52,7 +51,7 @@ class AbstractComparator(MSONable, metaclass=abc.ABCMeta):
         Returns:
             Boolean indicating whether species are considered equal.
         """
-        return
+        return False
 
     @abc.abstractmethod
     def get_hash(self, composition):
@@ -73,7 +72,6 @@ class AbstractComparator(MSONable, metaclass=abc.ABCMeta):
         Returns:
             A hashable object. Examples can be string formulas, integers etc.
         """
-        return
 
     @classmethod
     def from_dict(cls, d):
@@ -107,11 +105,10 @@ class AbstractComparator(MSONable, metaclass=abc.ABCMeta):
 
 class SpeciesComparator(AbstractComparator):
     """
-    A Comparator that matches species exactly. The default used in
-    StructureMatcher.
+    A Comparator that matches species exactly. The default used in StructureMatcher.
     """
 
-    def are_equal(self, sp1, sp2):
+    def are_equal(self, sp1, sp2) -> bool:
         """
         True if species are exactly the same, i.e., Fe2+ == Fe2+ but not Fe3+.
 
@@ -140,7 +137,7 @@ class SpinComparator(AbstractComparator):
     structures with opposite spins, which are equivalent.
     """
 
-    def are_equal(self, sp1, sp2):
+    def are_equal(self, sp1, sp2) -> bool:
         """
         True if species are exactly the same, i.e., Fe2+ == Fe2+ but not
         Fe3+. and the spins are reversed. i.e., spin up maps to spin down,
@@ -180,7 +177,7 @@ class ElementComparator(AbstractComparator):
     ignored.
     """
 
-    def are_equal(self, sp1, sp2):
+    def are_equal(self, sp1, sp2) -> bool:
         """
         True if element:amounts are exactly the same, i.e.,
         oxidation state is not considered.
@@ -211,7 +208,7 @@ class FrameworkComparator(AbstractComparator):
     A Comparator that matches sites, regardless of species.
     """
 
-    def are_equal(self, sp1, sp2):
+    def are_equal(self, sp1, sp2) -> bool:
         """
         True if there are atoms on both sites.
 
@@ -239,7 +236,7 @@ class OrderDisorderElementComparator(AbstractComparator):
     composition
     """
 
-    def are_equal(self, sp1, sp2):
+    def are_equal(self, sp1, sp2) -> bool:
         """
         True if there is some overlap in composition between the species
 
@@ -269,7 +266,7 @@ class OccupancyComparator(AbstractComparator):
     irrespective of the species of those sites.
     """
 
-    def are_equal(self, sp1, sp2):
+    def are_equal(self, sp1, sp2) -> bool:
         """
         Args:
             sp1: First species. A dict of {specie/element: amt} as per the
@@ -344,10 +341,10 @@ class StructureMatcher(MSONable):
         scale: bool = True,
         attempt_supercell: bool = False,
         allow_subset: bool = False,
-        comparator: AbstractComparator = None,
+        comparator: AbstractComparator | None = None,
         supercell_size: Literal["num_sites", "num_atoms", "volume"] = "num_sites",
         ignored_species: Sequence[SpeciesLike] = (),
-    ):
+    ) -> None:
         """
         Args:
             ltol (float): Fractional length tolerance. Default is 0.2.
@@ -403,9 +400,8 @@ class StructureMatcher(MSONable):
 
     def _get_supercell_size(self, s1, s2):
         """
-        Returns the supercell size, and whether the supercell should
-        be applied to s1. If fu == 1, s1_supercell is returned as
-        true, to avoid ambiguity.
+        Returns the supercell size, and whether the supercell should be applied to s1.
+        If fu == 1, s1_supercell is returned as true, to avoid ambiguity.
         """
         if self._supercell_size == "num_sites":
             fu = s2.num_sites / s1.num_sites
@@ -439,7 +435,7 @@ class StructureMatcher(MSONable):
         cells in it
 
         Args:
-            target_lattice (Lattice):
+            target_lattice (Lattice): target lattice.
             s (Structure): input structure.
             supercell_size (int): Number of primitive cells in returned lattice
         """
@@ -449,9 +445,9 @@ class StructureMatcher(MSONable):
             atol=self.angle_tol,
             skip_rotation_matrix=True,
         )
-        for l, _, scale_m in lattices:
+        for latt, _, scale_m in lattices:
             if abs(abs(np.linalg.det(scale_m)) - supercell_size) < 0.5:
-                yield l, scale_m
+                yield latt, scale_m
 
     def _get_supercells(self, struct1, struct2, fu, s1_supercell):
         """
@@ -471,18 +467,18 @@ class StructureMatcher(MSONable):
             s2_fc = np.array(s2.frac_coords)
             if fu == 1:
                 cc = np.array(s1.cart_coords)
-                for l, sc_m in self._get_lattices(s2.lattice, s1, fu):
-                    fc = l.get_fractional_coords(cc)
+                for latt, sc_m in self._get_lattices(s2.lattice, s1, fu):
+                    fc = latt.get_fractional_coords(cc)
                     fc -= np.floor(fc)
-                    yield fc, s2_fc, av_lat(l, s2.lattice), sc_m
+                    yield fc, s2_fc, av_lat(latt, s2.lattice), sc_m
             else:
                 fc_init = np.array(s1.frac_coords)
-                for l, sc_m in self._get_lattices(s2.lattice, s1, fu):
+                for latt, sc_m in self._get_lattices(s2.lattice, s1, fu):
                     fc = np.dot(fc_init, np.linalg.inv(sc_m))
                     lp = lattice_points_in_supercell(sc_m)
                     fc = (fc[:, None, :] + lp[None, :, :]).reshape((-1, 3))
                     fc -= np.floor(fc)
-                    yield fc, s2_fc, av_lat(l, s2.lattice), sc_m
+                    yield fc, s2_fc, av_lat(latt, s2.lattice), sc_m
 
         if s1_supercell:
             for x in sc_generator(struct1, struct2):
@@ -512,14 +508,16 @@ class StructureMatcher(MSONable):
         fractional translation vector to minimize RMS distance
 
         Args:
-            s1, s2: numpy arrays of fractional coordinates. len(s1) >= len(s2)
+            s1: numpy array of fractional coordinates.
+            s2: numpy array of fractional coordinates. len(s1) >= len(s2)
             avg_lattice: Lattice on which to calculate distances
             mask: numpy array of booleans. mask[i, j] = True indicates
                 that s2[i] cannot be matched to s1[j]
             normalization (float): inverse normalization length
+            lll_frac_tol (float): tolerance for Lenstra-Lenstra-Lovász lattice basis reduction algorithm
 
         Returns:
-            Distances from s2 to s1, normalized by (V/Natom) ^ 1/3
+            Distances from s2 to s1, normalized by (V/atom) ^ 1/3
             Fractional translation vector to apply to s2.
             Mapping from s1 to s2, i.e. with numpy slicing, s1[mapping] => s2
         """
@@ -586,20 +584,19 @@ class StructureMatcher(MSONable):
         Args:
             struct1 (Structure): 1st structure
             struct2 (Structure): 2nd structure
-            symmetric (Bool): Defaults to False
+            symmetric (bool): Defaults to False
                 If True, check the equality both ways.
                 This only impacts a small percentage of structures
-            skip_structure_reduction (Bool): Defaults to False
+            skip_structure_reduction (bool): Defaults to False
                 If True, skip to get a primitive structure and perform Niggli reduction for struct1 and struct2
 
         Returns:
-            True or False.
+            bool: True if the structures are equivalent
         """
         struct1, struct2 = self._process_species([struct1, struct2])
 
-        if not self._subset and self._comparator.get_hash(struct1.composition) != self._comparator.get_hash(
-            struct2.composition
-        ):
+        hash_match = self._comparator.get_hash(struct1.composition) == self._comparator.get_hash(struct2.composition)
+        if not self._subset and not hash_match:
             return False
 
         if not symmetric:
@@ -700,7 +697,7 @@ class StructureMatcher(MSONable):
         s1_supercell=True,
         use_rms=False,
         break_on_match=False,
-    ):
+    ) -> tuple[float, float, np.ndarray, float, Mapping] | None:
         """
         Matches one struct onto the other
         """
@@ -725,25 +722,28 @@ class StructureMatcher(MSONable):
 
     def _strict_match(
         self,
-        struct1,
-        struct2,
-        fu,
-        s1_supercell=True,
-        use_rms=False,
-        break_on_match=False,
-    ):
+        struct1: Structure,
+        struct2: Structure,
+        fu: int,
+        s1_supercell: bool = True,
+        use_rms: bool = False,
+        break_on_match: bool = False,
+    ) -> tuple[float, float, np.ndarray, float, Mapping] | None:
         """
         Matches struct2 onto struct1 (which should contain all sites in
         struct2).
 
         Args:
-            struct1, struct2 (Structure): structures to be matched
+            struct1 (Structure): structure to match onto
+            struct2 (Structure): structure to match
             fu (int): size of supercell to create
-            s1_supercell (bool): whether to create the supercell of
-                struct1 (vs struct2)
+            s1_supercell (bool): whether to create the supercell of struct1 (vs struct2)
             use_rms (bool): whether to minimize the rms of the matching
-            break_on_match (bool): whether to stop search at first
-                valid match
+            break_on_match (bool): whether to stop search at first match
+
+        Returns:
+            tuple[float, float, np.ndarray, float, Mapping]: (rms, max_dist, mask, cost, mapping)
+                if a match is found, else None
         """
         if fu < 1:
             raise ValueError("fu cannot be less than 1")
@@ -775,10 +775,7 @@ class StructureMatcher(MSONable):
                     inv_lll_abc = np.array(avg_l.get_lll_reduced_lattice().reciprocal_lattice.abc)
                     lll_frac_tol = inv_lll_abc * self.stol / (np.pi * normalization)
                     dist, t_adj, mapping = self._cart_dists(s1fc, t_s2fc, avg_l, mask, normalization, lll_frac_tol)
-                    if use_rms:
-                        val = np.linalg.norm(dist) / len(dist) ** 0.5
-                    else:
-                        val = max(dist)
+                    val = np.linalg.norm(dist) / len(dist) ** 0.5 if use_rms else max(dist)
                     # pylint: disable=E1136
                     if best_match is None or val < best_match[0]:
                         total_t = t + t_adj
@@ -893,9 +890,9 @@ class StructureMatcher(MSONable):
 
     def _anonymous_match(
         self,
-        struct1,
-        struct2,
-        fu,
+        struct1: Structure,
+        struct2: Structure,
+        fu: int,
         s1_supercell=True,
         use_rms=False,
         break_on_match=False,
@@ -903,8 +900,16 @@ class StructureMatcher(MSONable):
     ):
         """
         Tries all permutations of matching struct1 to struct2.
+
         Args:
-            struct1, struct2 (Structure): Preprocessed input structures
+            struct1 (Structure): First structure
+            struct2 (Structure): Second structure
+            fu (int): Factor of unit cell of struct1 to match to struct2
+            s1_supercell (bool): whether to create the supercell of struct1 (vs struct2)
+            use_rms (bool): Whether to minimize the rms of the matching
+            break_on_match (bool): Whether to break search on first match
+            single_match (bool): Whether to return only the best match
+
         Returns:
             List of (mapping, match)
         """
@@ -989,7 +994,7 @@ class StructureMatcher(MSONable):
 
         return None, None
 
-    def get_best_electronegativity_anonymous_mapping(self, struct1, struct2):
+    def get_best_electronegativity_anonymous_mapping(self, struct1: Structure, struct2: Structure) -> dict | None:
         """
         Performs an anonymous fitting, which allows distinct species in one
         structure to map to another. E.g., to compare if the Li2O and Na2O
@@ -1011,13 +1016,13 @@ class StructureMatcher(MSONable):
 
         if matches:
             min_X_diff = np.inf
-            for m in matches:
+            for match in matches:
                 X_diff = 0
-                for k, v in m[0].items():
-                    X_diff += struct1.composition[k] * (k.X - v.X) ** 2
+                for key, val in match[0].items():
+                    X_diff += struct1.composition[key] * (key.X - val.X) ** 2
                 if X_diff < min_X_diff:
                     min_X_diff = X_diff
-                    best = m[0]
+                    best = match[0]
             return best
 
         return None
@@ -1051,17 +1056,16 @@ class StructureMatcher(MSONable):
 
     def fit_anonymous(
         self, struct1: Structure, struct2: Structure, niggli: bool = True, skip_structure_reduction: bool = False
-    ):
+    ) -> bool:
         """
-        Performs an anonymous fitting, which allows distinct species in one
-        structure to map to another. E.g., to compare if the Li2O and Na2O
-        structures are similar.
+        Performs an anonymous fitting, which allows distinct species in one structure to map
+        to another. E.g., to compare if the Li2O and Na2O structures are similar.
 
         Args:
             struct1 (Structure): 1st structure
             struct2 (Structure): 2nd structure
-            niggli (Bool): If true, perform Niggli reduction for struct1 and struct2
-            skip_structure_reduction (Bool): Defaults to False
+            niggli (bool): If true, perform Niggli reduction for struct1 and struct2
+            skip_structure_reduction (bool): Defaults to False
                 If True, skip to get a primitive structure and perform Niggli reduction for struct1 and struct2
 
         Returns:
@@ -1074,7 +1078,7 @@ class StructureMatcher(MSONable):
 
         return bool(matches)
 
-    def get_supercell_matrix(self, supercell, struct):
+    def get_supercell_matrix(self, supercell, struct) -> np.ndarray | None:
         """
         Returns the matrix for transforming struct to supercell. This
         can be used for very distorted 'supercells' where the primitive cell
@@ -1128,7 +1132,7 @@ class StructureMatcher(MSONable):
             if match is None:
                 return None
             # invert the mapping, since it needs to be from s1 to s2
-            mapping = [list(match[4]).index(i) if i in match[4] else None for i in range(len(s1))]
+            mapping = [list(match[4]).index(idx) if idx in match[4] else None for idx in range(len(s1))]
             return match[2], match[3], mapping
         # s2 is superset
         match = self._strict_match(s2, s1, fu=fu, s1_supercell=True, use_rms=True, break_on_match=False)
