@@ -2,13 +2,13 @@
 Predicting potential dopants
 """
 
+from __future__ import annotations
+
 import warnings
 
 import numpy as np
 
-from pymatgen.analysis.structure_prediction.substitution_probability import (
-    SubstitutionPredictor,
-)
+from pymatgen.analysis.structure_prediction.substitution_probability import SubstitutionPredictor
 from pymatgen.core.periodic_table import Element, Species
 
 
@@ -199,8 +199,8 @@ def _int_to_roman(number):
     roman_conv = [(10, "X"), (9, "IX"), (5, "V"), (4, "IV"), (1, "I")]
 
     result = []
-    for (arabic, roman) in roman_conv:
-        (factor, number) = divmod(number, arabic)
+    for arabic, roman in roman_conv:
+        factor, number = divmod(number, arabic)
         result.append(roman * factor)
         if number == 0:
             break
