@@ -1,11 +1,10 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module provides classes for representing species substitution
 probabilities.
 """
 
+from __future__ import annotations
+
 import functools
 import itertools
 import json
@@ -155,7 +154,7 @@ class SubstitutionProbability:
 
     def as_dict(self):
         """
-        Returns: MSONAble dict
+        Returns: MSONable dict
         """
         return {
             "name": type(self).__name__,
@@ -166,15 +165,15 @@ class SubstitutionProbability:
         }
 
     @classmethod
-    def from_dict(cls, d):
+    def from_dict(cls, dct):
         """
         Args:
-            d(dict): Dict representation
+            dct (dict): Dict representation
 
         Returns:
             Class
         """
-        return cls(**d["init_args"])
+        return cls(**dct["init_args"])
 
 
 class SubstitutionPredictor:
@@ -203,6 +202,7 @@ class SubstitutionPredictor:
                 will be found. If false, substitutions with this as a
                 starting composition will be found (these are slightly
                 different)
+
         Returns:
             List of predictions in the form of dictionaries.
             If to_this_composition is true, the values of the dictionary
@@ -237,11 +237,8 @@ class SubstitutionPredictor:
                     return
                 for sp in self.p.species:
                     i = len(output_prob)
-                    if to_this_composition:
-                        prob = self.p.cond_prob(sp, species[i])
-                    else:
-                        prob = self.p.cond_prob(species[i], sp)
-                    _recurse(output_prob + [prob], output_species + [sp])
+                    prob = self.p.cond_prob(sp, species[i]) if to_this_composition else self.p.cond_prob(species[i], sp)
+                    _recurse([*output_prob, prob], [*output_species, sp])
 
         _recurse([], [])
         logging.info(f"{len(output)} substitutions found")
@@ -270,10 +267,7 @@ class SubstitutionPredictor:
         preds = self.list_prediction(list(composition), to_this_composition)
         output = []
         for p in preds:
-            if to_this_composition:
-                subs = {v: k for k, v in p["substitutions"].items()}
-            else:
-                subs = p["substitutions"]
+            subs = {v: k for k, v in p["substitutions"].items()} if to_this_composition else p["substitutions"]
             charge = 0
             for k, v in composition.items():
                 charge += subs[k].oxi_state * v
