@@ -1,10 +1,9 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module provides classes for predicting new structures from existing ones.
 """
 
+from __future__ import annotations
+
 import functools
 import itertools
 import logging
@@ -15,9 +14,7 @@ from monty.json import MSONable
 from pymatgen.alchemy.filters import RemoveDuplicatesFilter, RemoveExistingFilter
 from pymatgen.alchemy.materials import TransformedStructure
 from pymatgen.alchemy.transmuters import StandardTransmuter
-from pymatgen.analysis.structure_prediction.substitution_probability import (
-    SubstitutionProbability,
-)
+from pymatgen.analysis.structure_prediction.substitution_probability import SubstitutionProbability
 from pymatgen.core.periodic_table import get_el_sp
 from pymatgen.transformations.standard_transformations import SubstitutionTransformation
 
@@ -60,7 +57,7 @@ class Substitutor(MSONable):
 
     def get_allowed_species(self):
         """
-        returns the species in the domain of the probability function
+        Returns the species in the domain of the probability function
         any other specie will not work
         """
         return self._sp.species
@@ -73,7 +70,7 @@ class Substitutor(MSONable):
         remove_existing=False,
     ):
         """
-        performs a structure prediction targeting compounds containing all of
+        Performs a structure prediction targeting compounds containing all of
         the target_species, based on a list of structure (those structures
         can for instance come from a database like the ICSD). It will return
         all the structures formed by ionic substitutions with a probability
@@ -124,7 +121,6 @@ class Substitutor(MSONable):
                     and len(list(set(els) & set(self.get_allowed_species()))) == len(els)
                     and self._sp.cond_prob_list(permut, els) > self._threshold
                 ):
-
                     clean_subst = {els[i]: permut[i] for i in range(0, len(els)) if els[i] != permut[i]}
 
                     if len(clean_subst) == 0:
@@ -162,14 +158,14 @@ class Substitutor(MSONable):
     @staticmethod
     def _is_charge_balanced(struct):
         """
-        checks if the structure object is charge balanced
+        Checks if the structure object is charge balanced
         """
-        return sum(s.specie.oxi_state for s in struct.sites) == 0.0
+        return sum(site.specie.oxi_state for site in struct) == 0.0
 
     @staticmethod
     def _is_from_chemical_system(chemical_system, struct):
         """
-        checks if the structure object is from the given chemical system
+        Checks if the structure object is from the given chemical system
         """
         return {sp.symbol for sp in struct.composition} == set(chemical_system)
 
@@ -222,7 +218,7 @@ class Substitutor(MSONable):
                 for sp in self._sp.species:
                     i = len(output_prob)
                     prob = self._sp.cond_prob(sp, species_list[i])
-                    _recurse(output_prob + [prob], output_species + [sp])
+                    _recurse([*output_prob, prob], [*output_species, sp])
 
         _recurse([], [])
         logging.info(f"{len(output)} substitutions found")
