@@ -1,10 +1,7 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
+from __future__ import annotations
 
 import json
 import os
-import unittest
 
 from pymatgen.analysis.structure_prediction.substitutor import Substitutor
 from pymatgen.core.composition import Composition
@@ -46,7 +43,3 @@ class SubstitutorTest(PymatgenTest):
 
     def test_as_dict(self):
         Substitutor.from_dict(self.s.as_dict())
-
-
-if __name__ == "__main__":
-    unittest.main()
