@@ -1,10 +1,9 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 Predict volumes of crystal structures.
 """
 
+from __future__ import annotations
+
 import os
 import warnings
 
@@ -20,10 +19,9 @@ bond_params = loadfn(os.path.join(MODULE_DIR, "DLS_bond_params.yaml"))
 
 
 def _is_ox(structure):
-    comp = structure.composition
-    for k in comp:
+    for elem in structure.composition:
         try:
-            k.oxi_state
+            elem.oxi_state  # noqa: B018
         except AttributeError:
             return False
     return True
@@ -60,6 +58,7 @@ class RLSVolumePredictor:
             structure (Structure): structure w/unknown volume
             ref_structure (Structure): A reference structure with a similar
                 structure but different species.
+
         Returns:
             a float value of the predicted volume
         """
@@ -124,10 +123,12 @@ class RLSVolumePredictor:
         """
         Given a structure, returns back the structure scaled to predicted
         volume.
+
         Args:
             structure (Structure): structure w/unknown volume
             ref_structure (Structure): A reference structure with a similar
                 structure but different species.
+
         Returns:
             a Structure object with predicted volume
         """
@@ -237,6 +238,7 @@ class DLSVolumePredictor:
         """
         Given a structure, returns back the structure scaled to predicted
         volume.
+
         Args:
             structure (Structure): structure w/unknown volume
 
