@@ -1,6 +1,4 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
+from __future__ import annotations
 
 import copy
 import os
@@ -10,14 +8,11 @@ from shutil import which
 
 import networkx as nx
 import networkx.algorithms.isomorphism as iso
+import pytest
 from monty.serialization import loadfn
+from pytest import approx
 
-from pymatgen.analysis.graphs import (
-    MoleculeGraph,
-    MolGraphSplitError,
-    PeriodicSite,
-    StructureGraph,
-)
+from pymatgen.analysis.graphs import MoleculeGraph, MolGraphSplitError, PeriodicSite, StructureGraph
 from pymatgen.analysis.local_env import (
     CovalentBondNN,
     CutOffDictNN,
@@ -53,7 +48,6 @@ molecule_dir = os.path.join(PymatgenTest.TEST_FILES_DIR, "molecules")
 
 class StructureGraphTest(PymatgenTest):
     def setUp(self):
-
         self.maxDiff = None
 
         # trivial example, simple square lattice for testing
@@ -100,10 +94,10 @@ class StructureGraphTest(PymatgenTest):
         c2o = Critic2Analysis(self.structure, reference_stdout)
         self.mos2_sg = c2o.structure_graph(include_critical_points=False)
 
-        latt = Lattice.cubic(4.17)
+        lattice = Lattice.cubic(4.17)
         species = ["Ni", "O"]
         coords = [[0, 0, 0], [0.5, 0.5, 0.5]]
-        self.NiO = Structure.from_spacegroup(225, latt, species, coords).get_primitive_structure()
+        self.NiO = Structure.from_spacegroup(225, lattice, species, coords).get_primitive_structure()
 
         # BCC example.
         self.bcc = Structure(Lattice.cubic(5.0), ["He", "He"], [[0, 0, 0], [0.5, 0.5, 0.5]])
@@ -115,29 +109,22 @@ class StructureGraphTest(PymatgenTest):
 
     def test_inappropriate_construction(self):
         # Check inappropriate strategy
-        with self.assertRaises(ValueError):
+        with pytest.raises(ValueError, match="Chosen strategy is not designed for use with structures"):
             StructureGraph.with_local_env_strategy(self.NiO, CovalentBondNN())
 
     def test_properties(self):
-
-        self.assertEqual(self.mos2_sg.name, "bonds")
-        self.assertEqual(self.mos2_sg.edge_weight_name, "bond_length")
-        self.assertEqual(self.mos2_sg.edge_weight_unit, "Å")
-        self.assertEqual(self.mos2_sg.get_coordination_of_site(0), 6)
-        self.assertEqual(len(self.mos2_sg.get_connected_sites(0)), 6)
-        self.assertTrue(isinstance(self.mos2_sg.get_connected_sites(0)[0].site, PeriodicSite))
-        self.assertEqual(str(self.mos2_sg.get_connected_sites(0)[0].site.specie), "S")
-        self.assertAlmostEqual(
-            self.mos2_sg.get_connected_sites(0, jimage=(0, 0, 100))[0].site.frac_coords[2],
-            100.303027,
-        )
+        assert self.mos2_sg.name == "bonds"
+        assert self.mos2_sg.edge_weight_name == "bond_length"
+        assert self.mos2_sg.edge_weight_unit == "Å"
+        assert self.mos2_sg.get_coordination_of_site(0) == 6
+        assert len(self.mos2_sg.get_connected_sites(0)) == 6
+        assert isinstance(self.mos2_sg.get_connected_sites(0)[0].site, PeriodicSite)
+        assert str(self.mos2_sg.get_connected_sites(0)[0].site.specie) == "S"
+        assert self.mos2_sg.get_connected_sites(0, jimage=(0, 0, 100))[0].site.frac_coords[2] == approx(100.303027)
 
         # these two graphs should be equivalent
         for n in range(len(self.bc_square_sg)):
-            self.assertEqual(
-                self.bc_square_sg.get_coordination_of_site(n),
-                self.bc_square_sg_r.get_coordination_of_site(n),
-            )
+            assert self.bc_square_sg.get_coordination_of_site(n) == self.bc_square_sg_r.get_coordination_of_site(n)
 
         # test we're not getting duplicate connected sites
         # thanks to Jack D. Sundberg for reporting this bug
@@ -155,8 +142,8 @@ class StructureGraphTest(PymatgenTest):
 
         nacl_graph = StructureGraph.with_local_env_strategy(nacl, CutOffDictNN({("Cl", "Cl"): 5.0}))
 
-        self.assertEqual(len(nacl_graph.get_connected_sites(1)), 12)
-        self.assertEqual(len(nacl_graph.graph.get_edge_data(1, 1)), 6)
+        assert len(nacl_graph.get_connected_sites(1)) == 12
+        assert len(nacl_graph.graph.get_edge_data(1, 1)) == 6
 
     def test_set_node_attributes(self):
         self.square_sg.set_node_attributes()
@@ -166,11 +153,11 @@ class StructureGraphTest(PymatgenTest):
         properties = nx.get_node_attributes(self.square_sg.graph, "properties")
 
         for idx, site in enumerate(self.square_sg.structure):
-            self.assertEqual(str(specie[idx]), str(site.specie))
-            self.assertEqual(coords[idx][0], site.coords[0])
-            self.assertEqual(coords[idx][1], site.coords[1])
-            self.assertEqual(coords[idx][2], site.coords[2])
-            self.assertEqual(properties[idx], site.properties)
+            assert str(specie[idx]) == str(site.specie)
+            assert coords[idx][0] == site.coords[0]
+            assert coords[idx][1] == site.coords[1]
+            assert coords[idx][2] == site.coords[2]
+            assert properties[idx] == site.properties
 
     def test_edge_editing(self):
         square = copy.deepcopy(self.square_sg)
@@ -183,32 +170,31 @@ class StructureGraphTest(PymatgenTest):
             new_edge_properties={"foo": "bar"},
         )
         new_edge = square.graph.get_edge_data(0, 0)[0]
-        self.assertEqual(new_edge["weight"], 0.0)
-        self.assertEqual(new_edge["foo"], "bar")
+        assert new_edge["weight"] == 0.0
+        assert new_edge["foo"] == "bar"
 
         square.break_edge(0, 0, to_jimage=(1, 0, 0))
 
-        self.assertEqual(len(square.graph.get_edge_data(0, 0)), 1)
+        assert len(square.graph.get_edge_data(0, 0)) == 1
 
     def test_insert_remove(self):
-
         struct_copy = copy.deepcopy(self.square_sg.structure)
         square_copy = copy.deepcopy(self.square_sg)
 
         # Ensure that insert_node appropriately wraps Structure.insert()
         struct_copy.insert(1, "O", [0.5, 0.5, 0.5])
         square_copy.insert_node(1, "O", [0.5, 0.5, 0.5])
-        self.assertEqual(struct_copy, square_copy.structure)
+        assert struct_copy == square_copy.structure
 
         # Test that removal is also equivalent between Structure and StructureGraph.structure
         struct_copy.remove_sites([1])
         square_copy.remove_nodes([1])
-        self.assertEqual(struct_copy, square_copy.structure)
+        assert struct_copy == square_copy.structure
 
         square_copy.insert_node(
             1, "O", [0.5, 0.5, 0.5], edges=[{"from_index": 1, "to_index": 0, "to_jimage": (0, 0, 0)}]
         )
-        self.assertEqual(square_copy.get_coordination_of_site(1), 1)
+        assert square_copy.get_coordination_of_site(1) == 1
 
         # Test that StructureGraph.graph is correctly updated
         square_copy.insert_node(
@@ -216,8 +202,8 @@ class StructureGraphTest(PymatgenTest):
         )
         square_copy.remove_nodes([1])
 
-        self.assertEqual(square_copy.graph.number_of_nodes(), 2)
-        self.assertEqual(square_copy.graph.number_of_edges(), 3)
+        assert square_copy.graph.number_of_nodes() == 2
+        assert square_copy.graph.number_of_edges() == 3
 
     def test_substitute(self):
         structure = Structure.from_file(os.path.join(PymatgenTest.TEST_FILES_DIR, "Li2O.cif"))
@@ -232,11 +218,11 @@ class StructureGraphTest(PymatgenTest):
         # Ensure that strings and molecules lead to equivalent substitutions
         sg.substitute_group(1, molecule, MinimumDistanceNN)
         sg_copy.substitute_group(1, "methyl", MinimumDistanceNN)
-        self.assertEqual(sg, sg_copy)
+        assert sg == sg_copy
 
         # Ensure that the underlying structure has been modified as expected
         structure_copy.substitute(1, "methyl")
-        self.assertEqual(structure_copy, sg.structure)
+        assert structure_copy == sg.structure
 
         # Test inclusion of graph dictionary
         graph_dict = {
@@ -248,17 +234,15 @@ class StructureGraphTest(PymatgenTest):
         sg_with_graph = StructureGraph.with_local_env_strategy(structure_copy_graph, MinimumDistanceNN())
         sg_with_graph.substitute_group(1, "methyl", MinimumDistanceNN, graph_dict=graph_dict)
         edge = sg_with_graph.graph.get_edge_data(11, 13)[0]
-        self.assertEqual(edge["weight"], 0.5)
+        assert edge["weight"] == 0.5
 
     def test_auto_image_detection(self):
-
         sg = StructureGraph.with_empty_graph(self.structure)
         sg.add_edge(0, 0)
 
-        self.assertEqual(len(list(sg.graph.edges(data=True))), 3)
+        assert len(list(sg.graph.edges(data=True))) == 3
 
     def test_str(self):
-
         square_sg_str_ref = """Structure Graph
 Structure:
 Full Formula (H1)
@@ -301,14 +285,12 @@ from    to  to_image      bond_length (A)
    0     2  (0, 0, 0)     2.417e+00
 """
 
-        # don't care about testing Py 2.7 unicode support,
         # change Å to A
         self.mos2_sg.graph.graph["edge_weight_units"] = "A"
-        self.assertStrContentEqual(str(self.square_sg), square_sg_str_ref)
-        self.assertStrContentEqual(str(self.mos2_sg), mos2_sg_str_ref)
+        self.assert_str_content_equal(str(self.square_sg), square_sg_str_ref)
+        self.assert_str_content_equal(str(self.mos2_sg), mos2_sg_str_ref)
 
     def test_mul(self):
-
         square_sg_mul = self.square_sg * (2, 1, 1)
 
         square_sg_mul_ref_str = """Structure Graph
@@ -340,22 +322,22 @@ from    to  to_image
         square_sg_mul_ref_str = "\n".join(square_sg_mul_ref_str.splitlines()[11:])
         square_sg_mul_actual_str = "\n".join(square_sg_mul_actual_str.splitlines()[11:])
 
-        self.assertStrContentEqual(square_sg_mul_actual_str, square_sg_mul_ref_str)
+        self.assert_str_content_equal(square_sg_mul_actual_str, square_sg_mul_ref_str)
 
         # test sequential multiplication
         sq_sg_1 = self.square_sg * (2, 2, 1)
         sq_sg_1 = sq_sg_1 * (2, 2, 1)
         sq_sg_2 = self.square_sg * (4, 4, 1)
-        self.assertEqual(sq_sg_1.graph.number_of_edges(), sq_sg_2.graph.number_of_edges())
+        assert sq_sg_1.graph.number_of_edges() == sq_sg_2.graph.number_of_edges()
         # TODO: the below test still gives 8 != 4
-        # self.assertEqual(self.square_sg.get_coordination_of_site(0), 4)
+        # assert self.square_sg.get_coordination_of_site(0) == 4
 
         mos2_sg_mul = self.mos2_sg * (3, 3, 1)
         for idx in mos2_sg_mul.structure.indices_from_symbol("Mo"):
-            self.assertEqual(mos2_sg_mul.get_coordination_of_site(idx), 6)
+            assert mos2_sg_mul.get_coordination_of_site(idx) == 6
 
         mos2_sg_premul = StructureGraph.with_local_env_strategy(self.structure * (3, 3, 1), MinimumDistanceNN())
-        self.assertTrue(mos2_sg_mul == mos2_sg_premul)
+        assert mos2_sg_mul == mos2_sg_premul
 
         # test 3D Structure
 
@@ -363,11 +345,10 @@ from    to  to_image
         nio_sg = nio_sg * 3
 
         for n in range(len(nio_sg)):
-            self.assertEqual(nio_sg.get_coordination_of_site(n), 6)
+            assert nio_sg.get_coordination_of_site(n) == 6
 
     @unittest.skipIf(pygraphviz is None or not (which("neato") and which("fdp")), "graphviz executables not present")
     def test_draw(self):
-
         # draw MoS2 graph
         self.mos2_sg.draw_graph_to_file("MoS2_single.pdf", image_labels=True, hide_image_edges=False)
         mos2_sg = self.mos2_sg * (9, 9, 1)
@@ -417,25 +398,25 @@ from    to  to_image
         d = self.mos2_sg.as_dict()
         sg = StructureGraph.from_dict(d)
         d2 = sg.as_dict()
-        self.assertDictEqual(d, d2)
+        assert d == d2
 
     def test_from_local_env_and_equality_and_diff(self):
         nn = MinimumDistanceNN()
         sg = StructureGraph.with_local_env_strategy(self.structure, nn)
 
-        self.assertEqual(sg.graph.number_of_edges(), 6)
+        assert sg.graph.number_of_edges() == 6
 
         nn2 = MinimumOKeeffeNN()
         sg2 = StructureGraph.with_local_env_strategy(self.structure, nn2)
 
-        self.assertTrue(sg == sg2)
-        self.assertTrue(sg == self.mos2_sg)
+        assert sg == sg2
+        assert sg == self.mos2_sg
 
         # TODO: find better test case where graphs are different
         diff = sg.diff(sg2)
-        self.assertEqual(diff["dist"], 0)
+        assert diff["dist"] == 0
 
-        self.assertEqual(self.square_sg.get_coordination_of_site(0), 2)
+        assert self.square_sg.get_coordination_of_site(0) == 2
 
     def test_from_edges(self):
         edges = {
@@ -449,52 +430,47 @@ from    to  to_image
 
         sg = StructureGraph.with_edges(structure, edges)
 
-        self.assertEqual(sg, self.square_sg)
+        assert sg == self.square_sg
 
     def test_extract_molecules(self):
-
         structure_file = os.path.join(
             PymatgenTest.TEST_FILES_DIR,
             "H6PbCI3N_mp-977013_symmetrized.cif",
         )
 
-        s = Structure.from_file(structure_file)
+        struct = Structure.from_file(structure_file)
 
         nn = MinimumDistanceNN()
-        sg = StructureGraph.with_local_env_strategy(s, nn)
+        sg = StructureGraph.with_local_env_strategy(struct, nn)
 
         molecules = sg.get_subgraphs_as_molecules()
-        self.assertEqual(molecules[0].composition.formula, "H3 C1")
-        self.assertEqual(len(molecules), 1)
+        assert molecules[0].composition.formula == "H3 C1"
+        assert len(molecules) == 1
 
         molecules = self.mos2_sg.get_subgraphs_as_molecules()
-        self.assertEqual(len(molecules), 0)
+        assert len(molecules) == 0
 
     def test_types_and_weights_of_connections(self):
-
         types = self.mos2_sg.types_and_weights_of_connections
 
-        self.assertEqual(len(types["Mo-S"]), 6)
-        self.assertAlmostEqual(types["Mo-S"][0], 2.416931678417331)
+        assert len(types["Mo-S"]) == 6
+        assert types["Mo-S"][0] == approx(2.416931678417331)
 
     def test_weight_statistics(self):
-
         weight_statistics = self.mos2_sg.weight_statistics
 
-        self.assertEqual(len(weight_statistics["all_weights"]), 6)
-        self.assertAlmostEqual(weight_statistics["min"], 2.4169314100201875)
-        self.assertAlmostEqual(weight_statistics["variance"], 0)
+        assert len(weight_statistics["all_weights"]) == 6
+        assert weight_statistics["min"] == approx(2.4169314100201875)
+        assert weight_statistics["variance"] == approx(0, abs=1e-10)
 
     def test_types_of_coordination_environments(self):
-
         types = self.mos2_sg.types_of_coordination_environments()
-        self.assertListEqual(types, ["Mo-S(6)", "S-Mo(3)"])
+        assert types == ["Mo-S(6)", "S-Mo(3)"]
 
         types_anonymous = self.mos2_sg.types_of_coordination_environments(anonymous=True)
-        self.assertListEqual(types_anonymous, ["A-B(3)", "A-B(6)"])
+        assert types_anonymous == ["A-B(3)", "A-B(6)"]
 
     def test_no_duplicate_hops(self):
-
         test_structure = Structure(
             lattice=[[2.990355, -5.149042, 0.0], [2.990355, 5.149042, 0.0], [0.0, 0.0, 24.51998]],
             species=["Ba"],
@@ -505,29 +481,23 @@ from    to  to_image
 
         sg = StructureGraph.with_local_env_strategy(test_structure, nn)
 
-        self.assertEqual(sg.graph.number_of_edges(), 3)
+        assert sg.graph.number_of_edges() == 3
 
     def test_sort(self):
-
         sg = copy.deepcopy(self.bc_square_sg_r)
         # insert an unsorted edge, don't use sg.add_edge as it auto-sorts
         sg.graph.add_edge(3, 1, to_jimage=(0, 0, 0))
         sg.graph.add_edge(2, 1, to_jimage=(0, 0, 0))
 
-        self.assertEqual(list(sg.graph.edges)[-2:], [(3, 1, 0), (2, 1, 0)])
+        assert list(sg.graph.edges)[-2:] == [(3, 1, 0), (2, 1, 0)]
         sg.sort()
-        self.assertEqual(list(sg.graph.edges)[-2:], [(1, 3, 0), (1, 2, 0)])
+        assert list(sg.graph.edges)[-2:] == [(1, 3, 0), (1, 2, 0)]
 
 
 class MoleculeGraphTest(unittest.TestCase):
     def setUp(self):
-
-        cyclohexene = Molecule.from_file(
-            os.path.join(
-                PymatgenTest.TEST_FILES_DIR,
-                "graphs/cyclohexene.xyz",
-            )
-        )
+        cyclohexene_xyz = os.path.join(PymatgenTest.TEST_FILES_DIR, "graphs/cyclohexene.xyz")
+        cyclohexene = Molecule.from_file(cyclohexene_xyz)
         self.cyclohexene = MoleculeGraph.with_empty_graph(
             cyclohexene, edge_weight_name="strength", edge_weight_units=""
         )
@@ -548,12 +518,7 @@ class MoleculeGraphTest(unittest.TestCase):
         self.cyclohexene.add_edge(5, 14, weight=1.0)
         self.cyclohexene.add_edge(5, 15, weight=1.0)
 
-        butadiene = Molecule.from_file(
-            os.path.join(
-                PymatgenTest.TEST_FILES_DIR,
-                "graphs/butadiene.xyz",
-            )
-        )
+        butadiene = Molecule.from_file(os.path.join(PymatgenTest.TEST_FILES_DIR, "graphs/butadiene.xyz"))
         self.butadiene = MoleculeGraph.with_empty_graph(butadiene, edge_weight_name="strength", edge_weight_units="")
         self.butadiene.add_edge(0, 1, weight=2.0)
         self.butadiene.add_edge(1, 2, weight=1.0)
@@ -565,12 +530,7 @@ class MoleculeGraphTest(unittest.TestCase):
         self.butadiene.add_edge(3, 8, weight=1.0)
         self.butadiene.add_edge(3, 9, weight=1.0)
 
-        ethylene = Molecule.from_file(
-            os.path.join(
-                PymatgenTest.TEST_FILES_DIR,
-                "graphs/ethylene.xyz",
-            )
-        )
+        ethylene = Molecule.from_file(os.path.join(PymatgenTest.TEST_FILES_DIR, "graphs/ethylene.xyz"))
         self.ethylene = MoleculeGraph.with_empty_graph(ethylene, edge_weight_name="strength", edge_weight_units="")
         self.ethylene.add_edge(0, 1, weight=2.0)
         self.ethylene.add_edge(0, 2, weight=1.0)
@@ -622,61 +582,49 @@ class MoleculeGraphTest(unittest.TestCase):
         del self.butadiene
         del self.cyclohexene
 
-    @unittest.skipIf(not openbabel, "OpenBabel not present. Skipping...")
     def test_construction(self):
+        pytest.importorskip("openbabel")
         edges_frag = {(e[0], e[1]): {"weight": 1.0} for e in self.pc_frag1_edges}
         mol_graph = MoleculeGraph.with_edges(self.pc_frag1, edges_frag)
         # dumpfn(mol_graph.as_dict(), os.path.join(module_dir,"pc_frag1_mg.json"))
         ref_mol_graph = loadfn(os.path.join(module_dir, "pc_frag1_mg.json"))
-        self.assertEqual(mol_graph, ref_mol_graph)
-        self.assertEqual(mol_graph.graph.adj, ref_mol_graph.graph.adj)
+        assert mol_graph == ref_mol_graph
+        assert mol_graph.graph.adj == ref_mol_graph.graph.adj
         for node in mol_graph.graph.nodes:
-            self.assertEqual(
-                mol_graph.graph.nodes[node]["specie"],
-                ref_mol_graph.graph.nodes[node]["specie"],
-            )
+            assert mol_graph.graph.nodes[node]["specie"] == ref_mol_graph.graph.nodes[node]["specie"]
             for ii in range(3):
-                self.assertEqual(
-                    mol_graph.graph.nodes[node]["coords"][ii],
-                    ref_mol_graph.graph.nodes[node]["coords"][ii],
-                )
+                assert mol_graph.graph.nodes[node]["coords"][ii] == ref_mol_graph.graph.nodes[node]["coords"][ii]
 
         edges_pc = {(e[0], e[1]): {"weight": 1.0} for e in self.pc_edges}
         mol_graph = MoleculeGraph.with_edges(self.pc, edges_pc)
         # dumpfn(mol_graph.as_dict(), os.path.join(module_dir,"pc_mg.json"))
         ref_mol_graph = loadfn(os.path.join(module_dir, "pc_mg.json"))
-        self.assertEqual(mol_graph, ref_mol_graph)
-        self.assertEqual(mol_graph.graph.adj, ref_mol_graph.graph.adj)
+        assert mol_graph == ref_mol_graph
+        assert mol_graph.graph.adj == ref_mol_graph.graph.adj
         for node in mol_graph.graph:
-            self.assertEqual(
-                mol_graph.graph.nodes[node]["specie"],
-                ref_mol_graph.graph.nodes[node]["specie"],
-            )
+            assert mol_graph.graph.nodes[node]["specie"] == ref_mol_graph.graph.nodes[node]["specie"]
             for ii in range(3):
-                self.assertEqual(
-                    mol_graph.graph.nodes[node]["coords"][ii],
-                    ref_mol_graph.graph.nodes[node]["coords"][ii],
-                )
+                assert mol_graph.graph.nodes[node]["coords"][ii] == ref_mol_graph.graph.nodes[node]["coords"][ii]
 
         mol_graph_edges = MoleculeGraph.with_edges(self.pc, edges=edges_pc)
         mol_graph_strat = MoleculeGraph.with_local_env_strategy(self.pc, OpenBabelNN())
 
-        self.assertTrue(mol_graph_edges.isomorphic_to(mol_graph_strat))
+        assert mol_graph_edges.isomorphic_to(mol_graph_strat)
 
         # Check inappropriate strategy
-        with self.assertRaises(ValueError):
+        with pytest.raises(ValueError, match="Strategy must be a LocalEnvStrategy"):
             MoleculeGraph.with_local_env_strategy(self.pc, VoronoiNN())
 
     def test_properties(self):
-        self.assertEqual(self.cyclohexene.name, "bonds")
-        self.assertEqual(self.cyclohexene.edge_weight_name, "strength")
-        self.assertEqual(self.cyclohexene.edge_weight_unit, "")
-        self.assertEqual(self.cyclohexene.get_coordination_of_site(0), 4)
-        self.assertEqual(self.cyclohexene.get_coordination_of_site(2), 3)
-        self.assertEqual(self.cyclohexene.get_coordination_of_site(15), 1)
-        self.assertEqual(len(self.cyclohexene.get_connected_sites(0)), 4)
-        self.assertTrue(isinstance(self.cyclohexene.get_connected_sites(0)[0].site, Site))
-        self.assertEqual(str(self.cyclohexene.get_connected_sites(0)[0].site.specie), "H")
+        assert self.cyclohexene.name == "bonds"
+        assert self.cyclohexene.edge_weight_name == "strength"
+        assert self.cyclohexene.edge_weight_unit == ""
+        assert self.cyclohexene.get_coordination_of_site(0) == 4
+        assert self.cyclohexene.get_coordination_of_site(2) == 3
+        assert self.cyclohexene.get_coordination_of_site(15) == 1
+        assert len(self.cyclohexene.get_connected_sites(0)) == 4
+        assert isinstance(self.cyclohexene.get_connected_sites(0)[0].site, Site)
+        assert str(self.cyclohexene.get_connected_sites(0)[0].site.specie) == "H"
 
     def test_set_node_attributes(self):
         self.ethylene.set_node_attributes()
@@ -686,31 +634,32 @@ class MoleculeGraphTest(unittest.TestCase):
         properties = nx.get_node_attributes(self.ethylene.graph, "properties")
 
         for idx, site in enumerate(self.ethylene.molecule):
-            self.assertEqual(str(specie[idx]), str(site.specie))
-            self.assertEqual(coords[idx][0], site.coords[0])
-            self.assertEqual(coords[idx][1], site.coords[1])
-            self.assertEqual(coords[idx][2], site.coords[2])
-            self.assertEqual(properties[idx], site.properties)
+            assert str(specie[idx]) == str(site.specie)
+            assert coords[idx][0] == site.coords[0]
+            assert coords[idx][1] == site.coords[1]
+            assert coords[idx][2] == site.coords[2]
+            assert properties[idx] == site.properties
 
     def test_coordination(self):
         molecule = Molecule(["C", "C"], [[0.0, 0.0, 0.0], [1.0, 0.0, 0.0]])
 
         mg = MoleculeGraph.with_empty_graph(molecule)
-        self.assertEqual(mg.get_coordination_of_site(0), 0)
+        assert mg.get_coordination_of_site(0) == 0
 
-        self.assertEqual(self.cyclohexene.get_coordination_of_site(0), 4)
+        assert self.cyclohexene.get_coordination_of_site(0) == 4
 
     def test_edge_editing(self):
-        self.cyclohexene.alter_edge(0, 1, new_weight=0.0, new_edge_properties={"foo": "bar"})
-        new_edge = self.cyclohexene.graph.get_edge_data(0, 1)[0]
-        self.assertEqual(new_edge["weight"], 0.0)
-        self.assertEqual(new_edge["foo"], "bar")
+        cyclohexene = copy.deepcopy(self.cyclohexene)
+        cyclohexene.alter_edge(0, 1, new_weight=0.0, new_edge_properties={"foo": "bar"})
+        new_edge = cyclohexene.graph.get_edge_data(0, 1)[0]
+        assert new_edge["weight"] == 0.0
+        assert new_edge["foo"] == "bar"
 
-        self.cyclohexene.break_edge(0, 1)
-        self.assertTrue(self.cyclohexene.graph.get_edge_data(0, 1) is None)
+        cyclohexene.break_edge(0, 1)
+        assert cyclohexene.graph.get_edge_data(0, 1) is None
 
         # Replace the now-broken edge
-        self.cyclohexene.add_edge(0, 1, weight=1.0)
+        cyclohexene.add_edge(0, 1, weight=1.0)
 
     def test_insert_remove(self):
         mol_copy = copy.deepcopy(self.ethylene.molecule)
@@ -719,12 +668,12 @@ class MoleculeGraphTest(unittest.TestCase):
         # Ensure that insert_node appropriately wraps Molecule.insert()
         mol_copy.insert(1, "O", [0.5, 0.5, 0.5])
         eth_copy.insert_node(1, "O", [0.5, 0.5, 0.5])
-        self.assertEqual(mol_copy, eth_copy.molecule)
+        assert mol_copy == eth_copy.molecule
 
         # Test that removal is also equivalent between Molecule and MoleculeGraph.molecule
         mol_copy.remove_sites([1])
         eth_copy.remove_nodes([1])
-        self.assertEqual(mol_copy, eth_copy.molecule)
+        assert mol_copy == eth_copy.molecule
 
         eth_copy.insert_node(
             1,
@@ -732,38 +681,32 @@ class MoleculeGraphTest(unittest.TestCase):
             [0.5, 0.5, 0.5],
             edges=[{"from_index": 1, "to_index": 2}, {"from_index": 1, "to_index": 3}],
         )
-        self.assertEqual(eth_copy.get_coordination_of_site(1), 2)
+        assert eth_copy.get_coordination_of_site(1) == 2
 
         # Test that MoleculeGraph.graph is correctly updated
         eth_copy.remove_nodes([1, 2])
-        self.assertEqual(eth_copy.graph.number_of_nodes(), 5)
-        self.assertEqual(eth_copy.graph.number_of_edges(), 2)
+        assert eth_copy.graph.number_of_nodes() == 5
+        assert eth_copy.graph.number_of_edges() == 2
 
     def test_get_disconnected(self):
         disconnected = Molecule(
             ["C", "H", "H", "H", "H", "He"],
             [
-                [0.0000, 0.0000, 0.0000],
+                [0, 0, 0],
                 [-0.3633, -0.5138, -0.8900],
-                [1.0900, 0.0000, 0.0000],
-                [-0.3633, 1.0277, 0.0000],
+                [1.0900, 0, 0],
+                [-0.3633, 1.0277, 0],
                 [-0.3633, -0.5138, -0.8900],
-                [5.0000, 5.0000, 5.0000],
+                [5, 5, 5],
             ],
         )
 
         no_he = Molecule(
             ["C", "H", "H", "H", "H"],
-            [
-                [0.0000, 0.0000, 0.0000],
-                [-0.3633, -0.5138, -0.8900],
-                [1.0900, 0.0000, 0.0000],
-                [-0.3633, 1.0277, 0.0000],
-                [-0.3633, -0.5138, -0.8900],
-            ],
+            [[0, 0, 0], [-0.3633, -0.5138, -0.8900], [1.0900, 0, 0], [-0.3633, 1.0277, 0], [-0.3633, -0.5138, -0.8900]],
         )
 
-        just_he = Molecule(["He"], [[5.0000, 5.0000, 5.0000]])
+        just_he = Molecule(["He"], [[5, 5, 5]])
 
         dis_mg = MoleculeGraph.with_empty_graph(disconnected)
         dis_mg.add_edge(0, 1)
@@ -772,17 +715,22 @@ class MoleculeGraphTest(unittest.TestCase):
         dis_mg.add_edge(0, 4)
 
         fragments = dis_mg.get_disconnected_fragments()
-        self.assertEqual(len(fragments), 2)
-        self.assertEqual(fragments[0].molecule, no_he)
-        self.assertEqual(fragments[1].molecule, just_he)
+        fragments_2, index_map = dis_mg.get_disconnected_fragments(return_index_map=True)
+        assert list(map(str, fragments)) == list(map(str, fragments_2))
+        assert len(fragments) == 2
+        assert fragments[0].molecule == no_he
+        assert fragments[1].molecule == just_he
+        assert index_map == {0: 0, 1: 1, 2: 2, 3: 3, 4: 4, 5: 5}
 
         con_mg = MoleculeGraph.with_empty_graph(no_he)
         con_mg.add_edge(0, 1)
         con_mg.add_edge(0, 2)
         con_mg.add_edge(0, 3)
         con_mg.add_edge(0, 4)
-        fragments = con_mg.get_disconnected_fragments()
-        self.assertEqual(len(fragments), 1)
+        # make sure get_disconnected_fragments() only returns fragments even if return_index_map=True
+        # when the graph is weakly connected
+        fragments = con_mg.get_disconnected_fragments(return_index_map=True)
+        assert len(fragments) == 1
 
     def test_split(self):
         bonds = [(0, 1), (4, 5)]
@@ -794,14 +742,14 @@ class MoleculeGraphTest(unittest.TestCase):
         }
         # Perform retro-Diels-Alder reaction - turn product into reactants
         reactants = self.cyclohexene.split_molecule_subgraphs(bonds, allow_reverse=True, alterations=alterations)
-        self.assertTrue(isinstance(reactants, list))
+        assert isinstance(reactants, list)
 
         reactants = sorted(reactants, key=len)
         # After alterations, reactants should be ethylene and butadiene
-        self.assertEqual(reactants[0], self.ethylene)
-        self.assertEqual(reactants[1], self.butadiene)
+        assert reactants[0] == self.ethylene
+        assert reactants[1] == self.butadiene
 
-        with self.assertRaises(MolGraphSplitError):
+        with pytest.raises(MolGraphSplitError, match="Cannot split molecule; MoleculeGraph is still connected."):
             self.cyclohexene.split_molecule_subgraphs([(0, 1)])
 
         # Test naive charge redistribution
@@ -813,9 +761,9 @@ class MoleculeGraphTest(unittest.TestCase):
         new_mgs = oh_mg.split_molecule_subgraphs([(0, 1)])
         for mg in new_mgs:
             if str(mg.molecule[0].specie) == "O":
-                self.assertEqual(mg.molecule.charge, -1)
+                assert mg.molecule.charge == -1
             else:
-                self.assertEqual(mg.molecule.charge, 0)
+                assert mg.molecule.charge == 0
 
         # Trying to test to ensure that remapping of nodes to atoms works
         diff_species = Molecule(
@@ -844,7 +792,7 @@ class MoleculeGraphTest(unittest.TestCase):
 
                 for j in range(len(split_mg.graph.nodes)):
                     atom = split_mg.molecule[j]
-                    self.assertEqual(species[j], str(atom.specie))
+                    assert species[j] == str(atom.specie)
 
     def test_build_unique_fragments(self):
         edges = {(e[0], e[1]): None for e in self.pc_edges}
@@ -854,50 +802,41 @@ class MoleculeGraphTest(unittest.TestCase):
         for key in unique_fragment_dict:
             for fragment in unique_fragment_dict[key]:
                 unique_fragments.append(fragment)
-        self.assertEqual(len(unique_fragments), 295)
+        assert len(unique_fragments) == 295
         nm = iso.categorical_node_match("specie", "ERROR")
         for ii in range(295):
             # Test that each fragment is unique
             for jj in range(ii + 1, 295):
-                self.assertFalse(
-                    nx.is_isomorphic(
-                        unique_fragments[ii].graph,
-                        unique_fragments[jj].graph,
-                        node_match=nm,
-                    )
+                assert not nx.is_isomorphic(
+                    unique_fragments[ii].graph,
+                    unique_fragments[jj].graph,
+                    node_match=nm,
                 )
 
             # Test that each fragment correctly maps between Molecule and graph
-            self.assertEqual(
-                len(unique_fragments[ii].molecule),
-                len(unique_fragments[ii].graph.nodes),
-            )
+            assert len(unique_fragments[ii].molecule) == len(unique_fragments[ii].graph.nodes)
             species = nx.get_node_attributes(unique_fragments[ii].graph, "specie")
             coords = nx.get_node_attributes(unique_fragments[ii].graph, "coords")
 
             mol = unique_fragments[ii].molecule
             for ss, site in enumerate(mol):
-                self.assertEqual(str(species[ss]), str(site.specie))
-                self.assertEqual(coords[ss][0], site.coords[0])
-                self.assertEqual(coords[ss][1], site.coords[1])
-                self.assertEqual(coords[ss][2], site.coords[2])
+                assert str(species[ss]) == str(site.specie)
+                assert coords[ss][0] == site.coords[0]
+                assert coords[ss][1] == site.coords[1]
+                assert coords[ss][2] == site.coords[2]
 
             # Test that each fragment is connected
-            self.assertTrue(nx.is_connected(unique_fragments[ii].graph.to_undirected()))
+            assert nx.is_connected(unique_fragments[ii].graph.to_undirected())
 
     def test_find_rings(self):
         rings = self.cyclohexene.find_rings(including=[0])
-        self.assertEqual(sorted(rings[0]), [(0, 5), (1, 0), (2, 1), (3, 2), (4, 3), (5, 4)])
+        assert sorted(rings[0]) == [(0, 1), (1, 2), (2, 3), (3, 4), (4, 5), (5, 0)]
         no_rings = self.butadiene.find_rings()
-        self.assertEqual(no_rings, [])
+        assert no_rings == []
 
     def test_isomorphic(self):
-        ethylene = Molecule.from_file(
-            os.path.join(
-                PymatgenTest.TEST_FILES_DIR,
-                "graphs/ethylene.xyz",
-            )
-        )
+        ethyl_xyz_path = os.path.join(PymatgenTest.TEST_FILES_DIR, "graphs/ethylene.xyz")
+        ethylene = Molecule.from_file(ethyl_xyz_path)
         # switch carbons
         ethylene[0], ethylene[1] = ethylene[1], ethylene[0]
 
@@ -913,8 +852,8 @@ class MoleculeGraphTest(unittest.TestCase):
         )
         # If they are equal, they must also be isomorphic
         eth_copy = copy.deepcopy(self.ethylene)
-        self.assertTrue(self.ethylene.isomorphic_to(eth_copy))
-        self.assertFalse(self.butadiene.isomorphic_to(self.ethylene))
+        assert self.ethylene.isomorphic_to(eth_copy)
+        assert not self.butadiene.isomorphic_to(self.ethylene)
 
     def test_substitute(self):
         molecule = FunctionalGroups["methyl"]
@@ -928,7 +867,7 @@ class MoleculeGraphTest(unittest.TestCase):
         # Ensure that strings and molecules lead to equivalent substitutions
         eth_mol.substitute_group(5, molecule, MinimumDistanceNN)
         eth_str.substitute_group(5, "methyl", MinimumDistanceNN)
-        self.assertEqual(eth_mol, eth_str)
+        assert eth_mol == eth_str
 
         graph_dict = {
             (0, 1): {"weight": 1.0},
@@ -941,8 +880,8 @@ class MoleculeGraphTest(unittest.TestCase):
         # Check that MoleculeGraph input is handled properly
         eth_graph.substitute_group(5, molecule, MinimumDistanceNN, graph_dict=graph_dict)
         eth_mg.substitute_group(5, molgraph, MinimumDistanceNN)
-        self.assertEqual(eth_graph.graph.get_edge_data(5, 6)[0]["weight"], 1.0)
-        self.assertEqual(eth_mg, eth_graph)
+        assert eth_graph.graph.get_edge_data(5, 6)[0]["weight"] == 1.0
+        assert eth_mg == eth_graph
 
     def test_replace(self):
         eth_copy_sub = copy.deepcopy(self.ethylene)
@@ -951,36 +890,28 @@ class MoleculeGraphTest(unittest.TestCase):
         eth_copy_sub.substitute_group(5, "methyl", MinimumDistanceNN)
         eth_copy_repl.replace_group(5, "methyl", MinimumDistanceNN)
         # Test that replacement on a terminal atom is equivalent to substitution
-        self.assertEqual(eth_copy_repl.molecule, eth_copy_sub.molecule)
-        self.assertEqual(eth_copy_repl, eth_copy_sub)
+        assert eth_copy_repl.molecule == eth_copy_sub.molecule
+        assert eth_copy_repl == eth_copy_sub
 
         # Methyl carbon should have coordination 4
-        self.assertEqual(eth_copy_repl.get_coordination_of_site(5), 4)
+        assert eth_copy_repl.get_coordination_of_site(5) == 4
         # Now swap one functional group for another
         eth_copy_repl.replace_group(5, "amine", MinimumDistanceNN)
-        self.assertEqual(
-            ["C", "C", "H", "H", "H", "N", "H", "H"],
-            [str(s) for s in eth_copy_repl.molecule.species],
-        )
-        self.assertEqual(len(eth_copy_repl.graph.nodes), 8)
+        assert ["C", "C", "H", "H", "H", "N", "H", "H"] == [str(s) for s in eth_copy_repl.molecule.species]
+        assert len(eth_copy_repl.graph.nodes) == 8
         # Amine nitrogen should have coordination 3
-        self.assertEqual(eth_copy_repl.get_coordination_of_site(5), 3)
+        assert eth_copy_repl.get_coordination_of_site(5) == 3
 
     def test_as_from_dict(self):
         d = self.cyclohexene.as_dict()
         mg = MoleculeGraph.from_dict(d)
         d2 = mg.as_dict()
-        self.assertEqual(str(d), str(d2))
+        assert str(d) == str(d2)
 
     def test_sort(self):
-
         sg = copy.deepcopy(self.ethylene)
         # insert an unsorted edge, don't use sg.add_edge as it auto-sorts
 
-        self.assertEqual(list(sg.graph.edges), [(0, 1, 0), (0, 2, 0), (0, 3, 0), (1, 4, 0), (1, 5, 0)])
+        assert list(sg.graph.edges) == [(0, 1, 0), (0, 2, 0), (0, 3, 0), (1, 4, 0), (1, 5, 0)]
         sg.sort()
-        self.assertEqual(list(sg.graph.edges), [(4, 5, 0), (0, 4, 0), (1, 4, 0), (2, 5, 0), (3, 5, 0)])
-
-
-if __name__ == "__main__":
-    unittest.main()
+        assert list(sg.graph.edges) == [(4, 5, 0), (0, 4, 0), (1, 4, 0), (2, 5, 0), (3, 5, 0)]
