@@ -1,5 +1,4 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
+from __future__ import annotations
 
 import collections
 import os
@@ -11,7 +10,7 @@ from pathlib import Path
 import numpy as np
 import pytest
 from monty.serialization import dumpfn, loadfn
-from monty.tempfile import ScratchDir
+from pytest import approx
 
 from pymatgen.analysis.phase_diagram import (
     CompoundPhaseDiagram,
@@ -115,10 +114,10 @@ class TransformedPDEntryTest(unittest.TestCase):
 
     def test_get_energy(self):
         assert self.transformed_entry.energy == 53, "Wrong energy!"
-        assert self.transformed_entry.original_entry.energy == pytest.approx(53.0)
+        assert self.transformed_entry.original_entry.energy == approx(53.0)
 
     def test_get_energy_per_atom(self):
-        assert self.transformed_entry.energy_per_atom == pytest.approx(53.0 / (23 / 15))
+        assert self.transformed_entry.energy_per_atom == approx(53.0 / (23 / 15))
 
     def test_get_name(self):
         assert self.transformed_entry.name == "LiFeO2", "Wrong name!"
@@ -135,7 +134,7 @@ class TransformedPDEntryTest(unittest.TestCase):
         d = self.transformed_entry.as_dict()
         entry = TransformedPDEntry.from_dict(d)
         assert entry.name == "LiFeO2", "Wrong name!"
-        assert entry.energy_per_atom == pytest.approx(53.0 / (23 / 15))
+        assert entry.energy_per_atom == approx(53.0 / (23 / 15))
 
     def test_str(self):
         assert str(self.transformed_entry) is not None
@@ -238,20 +237,16 @@ class PhaseDiagramTest(unittest.TestCase):
             "O2": 0.0,
         }
         for formula, energy in expected_formation_energies.items():
-            assert energy == pytest.approx(stable_formation_energies[formula])
+            assert energy == approx(stable_formation_energies[formula])
 
     def test_all_entries_hulldata(self):
         assert len(self.pd.all_entries_hulldata) == 490
 
     def test_planar_inputs(self):
-        e1 = PDEntry("H", 0)
-        e2 = PDEntry("He", 0)
-        e3 = PDEntry("Li", 0)
-        e4 = PDEntry("Be", 0)
-        e5 = PDEntry("B", 0)
-        e6 = PDEntry("Rb", 0)
+        elems = ["H", "He", "Li", "Be", "B", "Rb"]
+        e1, e2, e3, e4, e5, e6 = (PDEntry(elem, 0) for elem in elems)
 
-        pd = PhaseDiagram([e1, e2, e3, e4, e5, e6], map(Element, ["Rb", "He", "B", "Be", "Li", "H"]))
+        pd = PhaseDiagram([e1, e2, e3, e4, e5, e6], map(Element, elems))
 
         assert len(pd.facets) == 1
 
@@ -262,20 +257,18 @@ class PhaseDiagramTest(unittest.TestCase):
         for entry in self.pd.all_entries:
             for entry in self.pd.stable_entries:
                 decomp, e_hull = self.pd.get_decomp_and_e_above_hull(entry)
-                assert e_hull < 1e-11, "Stable entries should have e above hull of zero!"
+                assert e_hull < 1e-11, "Stable entries should have e_above_hull of zero!"
                 assert decomp[entry] == 1, "Decomposition of stable entry should be itself."
-            else:
-                e_ah = self.pd.get_e_above_hull(entry)
-                assert isinstance(e_ah, Number)
-                assert e_ah >= 0
+
+            e_ah = self.pd.get_e_above_hull(entry)
+            assert isinstance(e_ah, Number)
+            assert e_ah >= 0
 
     def test_get_decomp_and_e_above_hull_on_error(self):
-
         for method, expected in (
             (self.pd.get_e_above_hull, None),
             (self.pd.get_decomp_and_e_above_hull, (None, None)),
         ):
-
             # test raises ValueError on entry with element not in the phase diagram
             U_entry = PDEntry("U", 0)
             with pytest.raises(ValueError, match="Unable to get decomposition for PDEntry : U1 with energy"):
@@ -328,13 +321,12 @@ class PhaseDiagramTest(unittest.TestCase):
                 assert (
                     self.pd.get_phase_separation_energy(entry) >= 0
                 ), "Unstable entries should have positive decomposition energy!"
-            else:
-                if entry.is_element:
-                    el_ref = self.pd.el_refs[entry.composition.elements[0]]
-                    e_d = entry.energy_per_atom - el_ref.energy_per_atom
-                    assert self.pd.get_phase_separation_energy(entry) == pytest.approx(e_d)
-                # NOTE the remaining materials would require explicit tests as they
-                # could be either positive or negative
+            elif entry.is_element:
+                el_ref = self.pd.el_refs[entry.composition.elements[0]]
+                e_d = entry.energy_per_atom - el_ref.energy_per_atom
+                assert self.pd.get_phase_separation_energy(entry) == approx(e_d)
+            # NOTE the remaining materials would require explicit tests as they
+            # could be either positive or negative
 
         for entry in self.pd.stable_entries:
             if entry.composition.is_element:
@@ -345,11 +337,9 @@ class PhaseDiagramTest(unittest.TestCase):
                 assert (
                     self.pd.get_phase_separation_energy(entry) <= 0
                 ), "Stable entries should have negative decomposition energy!"
-                assert self.pd.get_phase_separation_energy(entry, stable_only=True) == pytest.approx(
+                assert self.pd.get_phase_separation_energy(entry, stable_only=True) == approx(
                     self.pd.get_equilibrium_reaction_energy(entry)
-                ), (
-                    "Using `stable_only=True` should give decomposition energy equal to " "equilibrium reaction energy!"
-                )
+                ), "Using `stable_only=True` should give decomposition energy equal to equilibrium reaction energy!"
 
         # Test that we get correct behavior with a polymorph
         toy_entries = {
@@ -362,9 +352,9 @@ class PhaseDiagramTest(unittest.TestCase):
         toy_pd = PhaseDiagram([PDEntry(c, e) for c, e in toy_entries.items()])
 
         # stable entry
-        assert toy_pd.get_phase_separation_energy(PDEntry("Li2O", -5)) == pytest.approx(-1.0)
+        assert toy_pd.get_phase_separation_energy(PDEntry("Li2O", -5)) == approx(-1.0)
         # polymorph
-        assert toy_pd.get_phase_separation_energy(PDEntry("Li2O", -4)) == pytest.approx(-2.0 / 3.0)
+        assert toy_pd.get_phase_separation_energy(PDEntry("Li2O", -4)) == approx(-2.0 / 3.0)
 
         # Test that the method works for novel entries
         novel_stable_entry = PDEntry("Li5FeO4", -999)
@@ -396,22 +386,22 @@ class PhaseDiagramTest(unittest.TestCase):
             ), "Stable composition should have only 1 decomposition!"
         dim = len(self.pd.elements)
         for entry in self.pd.all_entries:
-            ndecomp = len(self.pd.get_decomposition(entry.composition))
+            n_decomp = len(self.pd.get_decomposition(entry.composition))
+            assert n_decomp > 0
             assert (
-                ndecomp > 0 and ndecomp <= dim
+                n_decomp <= dim
             ), "The number of decomposition phases can at most be equal to the number of components."
 
         # Just to test decomposition for a fictitious composition
-        ansdict = {
+        actual = {
             entry.composition.formula: amt for entry, amt in self.pd.get_decomposition(Composition("Li3Fe7O11")).items()
         }
-        expected_ans = {
+        expected = {
             "Fe2 O2": 0.0952380952380949,
             "Li1 Fe1 O2": 0.5714285714285714,
             "Fe6 O8": 0.33333333333333393,
         }
-        for k, v in expected_ans.items():
-            assert ansdict[k] == pytest.approx(v)
+        assert actual == approx(expected)
 
     def test_get_transition_chempots(self):
         for el in self.pd.elements:
@@ -424,26 +414,14 @@ class PhaseDiagramTest(unittest.TestCase):
                     assert len(self.pd.get_element_profile(el, entry.composition)) <= len(self.pd.facets)
 
         expected = [
-            {
-                "evolution": 1.0,
-                "chempot": -4.2582781416666666,
-                "reaction": "Li2O + 0.5 O2 -> Li2O2",
-            },
-            {
-                "evolution": 0,
-                "chempot": -5.0885906699999968,
-                "reaction": "Li2O -> Li2O",
-            },
-            {
-                "evolution": -1.0,
-                "chempot": -10.487582010000001,
-                "reaction": "Li2O -> 2 Li + 0.5 O2",
-            },
+            {"evolution": 1.0, "chempot": -4.2582781416666666, "reaction": "Li2O + 0.5 O2 -> Li2O2"},
+            {"evolution": 0, "chempot": -5.0885906699999968, "reaction": "Li2O -> Li2O"},
+            {"evolution": -1.0, "chempot": -10.487582010000001, "reaction": "Li2O -> 2 Li + 0.5 O2"},
         ]
         result = self.pd.get_element_profile(Element("O"), Composition("Li2O"))
         for d1, d2 in zip(expected, result):
-            assert d1["evolution"] == pytest.approx(d2["evolution"])
-            assert d1["chempot"] == pytest.approx(d2["chempot"])
+            assert d1["evolution"] == approx(d2["evolution"])
+            assert d1["chempot"] == approx(d2["chempot"])
             assert d1["reaction"] == str(d2["reaction"])
 
     def test_get_get_chempot_range_map(self):
@@ -452,7 +430,7 @@ class PhaseDiagramTest(unittest.TestCase):
 
     def test_getmu_vertices_stability_phase(self):
         results = self.pd.getmu_vertices_stability_phase(Composition("LiFeO2"), Element("O"))
-        assert len(results) == pytest.approx(6)
+        assert len(results) == approx(6)
         test_equality = False
         for c in results:
             if (
@@ -465,28 +443,28 @@ class PhaseDiagramTest(unittest.TestCase):
 
     def test_getmu_range_stability_phase(self):
         results = self.pd.get_chempot_range_stability_phase(Composition("LiFeO2"), Element("O"))
-        assert results[Element("O")][1] == pytest.approx(-4.4501812249999997)
-        assert results[Element("Fe")][0] == pytest.approx(-6.5961470999999996)
-        assert results[Element("Li")][0] == pytest.approx(-3.6250022625000007)
+        assert results[Element("O")][1] == approx(-4.4501812249999997)
+        assert results[Element("Fe")][0] == approx(-6.5961470999999996)
+        assert results[Element("Li")][0] == approx(-3.6250022625000007)
 
     def test_get_hull_energy(self):
         for entry in self.pd.stable_entries:
             h_e = self.pd.get_hull_energy(entry.composition)
-            assert h_e == pytest.approx(entry.energy)
+            assert h_e == approx(entry.energy)
             n_h_e = self.pd.get_hull_energy(entry.composition.fractional_composition)
-            assert n_h_e == pytest.approx(entry.energy_per_atom)
+            assert n_h_e == approx(entry.energy_per_atom)
 
     def test_get_hull_energy_per_atom(self):
         for entry in self.pd.stable_entries:
             h_e = self.pd.get_hull_energy_per_atom(entry.composition)
-            assert h_e == pytest.approx(entry.energy_per_atom)
+            assert h_e == approx(entry.energy_per_atom)
 
     def test_1d_pd(self):
         entry = PDEntry("H", 0)
         pd = PhaseDiagram([entry])
         decomp, e = pd.get_decomp_and_e_above_hull(PDEntry("H", 1))
         assert e == 1
-        assert decomp[entry] == pytest.approx(1.0)
+        assert decomp[entry] == approx(1.0)
 
     def test_get_critical_compositions_fractional(self):
         c1 = Composition("Fe2O3").fractional_composition
@@ -546,7 +524,7 @@ class PhaseDiagramTest(unittest.TestCase):
 
         # For the moment, should also fail even if compositions are in the gppd
         # because it isn't handled properly
-        gppd = GrandPotentialPhaseDiagram(self.pd.all_entries, {"Xe": 1}, self.pd.elements + [Element("Xe")])
+        gppd = GrandPotentialPhaseDiagram(self.pd.all_entries, {"Xe": 1}, [*self.pd.elements, Element("Xe")])
         with pytest.raises(ValueError):
             gppd.get_critical_compositions(
                 Composition("Fe2O3"),
@@ -575,7 +553,7 @@ class PhaseDiagramTest(unittest.TestCase):
 
         cp = self.pd.get_composition_chempots(c1)
         calc_e2 = e1 + sum(cp[k] * v for k, v in (c2 - c1).items())
-        assert e2 == pytest.approx(calc_e2)
+        assert e2 == approx(calc_e2)
 
     def test_get_all_chempots(self):
         c1 = Composition("Fe3.1O4")
@@ -589,7 +567,7 @@ class PhaseDiagramTest(unittest.TestCase):
         }
 
         for elem, energy in cpresult.items():
-            assert cp1["Fe3O4-FeO-LiFeO2"][elem] == pytest.approx(energy)
+            assert cp1["Fe3O4-FeO-LiFeO2"][elem] == approx(energy)
 
         cp2 = self.pd.get_all_chempots(c2)
         cpresult = {
@@ -599,7 +577,10 @@ class PhaseDiagramTest(unittest.TestCase):
         }
 
         for elem, energy in cpresult.items():
-            assert cp2["FeO-LiFeO2-Fe"][elem] == pytest.approx(energy)
+            assert cp2["FeO-LiFeO2-Fe"][elem] == approx(energy)
+
+    def test_get_plot(self):
+        self.pd.get_plot()  # PDPlotter functionality is tested separately
 
     def test_to_from_dict(self):
         # test round-trip for other entry types such as ComputedEntry
@@ -615,9 +596,23 @@ class PhaseDiagramTest(unittest.TestCase):
         assert isinstance(pd.to_json(), str)
 
     def test_read_json(self):
-        with ScratchDir("."):
-            dumpfn(self.pd, "pd.json")
-            loadfn("pd.json")
+        dumpfn(self.pd, "pd.json")
+        loadfn("pd.json")
+
+    def test_el_refs(self):
+        # Create an imitation of pre_computed phase diagram with el_refs keys being
+        # tuple[str, PDEntry] instead of tuple[Element, PDEntry].
+        mock_el_refs = [(str(el), entry) for el, entry in self.pd.el_refs.items()]
+        mock_computed_data = {**self.pd.computed_data, "el_refs": mock_el_refs}
+        pd = PhaseDiagram(self.entries, computed_data=mock_computed_data)
+        # Check the keys in el_refs dict have been updated to Element object via PhaseDiagram class.
+        assert all(isinstance(el, Element) for el in pd.el_refs)
+
+    def test_val_err_on_no_entries(self):
+        # check that PhaseDiagram raises ValueError when building phase diagram with no entries
+        for entries in [None, [], set(), ()]:
+            with pytest.raises(ValueError, match="Unable to build phase diagram without entries."):
+                PhaseDiagram(entries=entries)
 
 
 class GrandPotentialPhaseDiagramTest(unittest.TestCase):
@@ -646,7 +641,7 @@ class GrandPotentialPhaseDiagramTest(unittest.TestCase):
             "Li2O2": 0.0,
         }
         for formula, energy in expected_formation_energies.items():
-            assert energy == pytest.approx(
+            assert energy == approx(
                 stable_formation_energies[formula]
             ), f"Calculated formation for {formula} is not correct!"
 
@@ -674,7 +669,7 @@ class CompoundPhaseDiagramTest(unittest.TestCase):
             "Li2O": 0,
         }
         for formula, energy in expected_formation_energies.items():
-            assert energy == pytest.approx(stable_formation_energies[formula])
+            assert energy == approx(stable_formation_energies[formula])
 
     def test_str(self):
         assert str(self.pd) is not None
@@ -711,7 +706,7 @@ class PatchedPhaseDiagramTest(unittest.TestCase):
         for comp in self.novel_comps:
             decomp_pd = self.pd.get_decomposition(comp)
             decomp_ppd = self.ppd.get_decomposition(comp)
-            assert decomp_pd == pytest.approx(decomp_ppd)
+            assert decomp_pd == approx(decomp_ppd)
 
     def test_get_phase_separation_energy(self):
         for entry in self.novel_entries:
@@ -747,7 +742,7 @@ class PatchedPhaseDiagramTest(unittest.TestCase):
     def test_get_decomp_and_e_above_hull(self):
         for entry in self.pd.stable_entries:
             decomp_pd, e_above_hull_pd = self.pd.get_decomp_and_e_above_hull(entry)
-            decomp_ppd, e_above_hull_ppd = self.ppd.get_decomp_and_e_above_hull(entry)
+            decomp_ppd, e_above_hull_ppd = self.ppd.get_decomp_and_e_above_hull(entry, check_stable=True)
             assert decomp_pd == decomp_ppd
             assert np.isclose(e_above_hull_pd, e_above_hull_ppd)
 
@@ -856,32 +851,44 @@ class PDPlotterTest(unittest.TestCase):
     def setUp(self):
         entries = list(EntrySet.from_csv(os.path.join(module_dir, "pdentries_test.csv")))
 
-        self.pd_ternary = PhaseDiagram(entries)
-        self.plotter_ternary_mpl = PDPlotter(self.pd_ternary, backend="matplotlib")
-        self.plotter_ternary_plotly = PDPlotter(self.pd_ternary, backend="plotly")
+        elemental_entries = [e for e in entries if e.composition.elements == [Element("Li")]]
+        self.pd_unary = PhaseDiagram(elemental_entries)
+        self.plotter_unary_plotly = PDPlotter(self.pd_unary, backend="plotly")
 
-        entrieslio = [e for e in entries if "Fe" not in e.composition]
-        self.pd_binary = PhaseDiagram(entrieslio)
+        entries_LiO = [e for e in entries if "Fe" not in e.composition]
+        self.pd_binary = PhaseDiagram(entries_LiO)
         self.plotter_binary_mpl = PDPlotter(self.pd_binary, backend="matplotlib")
         self.plotter_binary_plotly = PDPlotter(self.pd_binary, backend="plotly")
 
+        self.pd_ternary = PhaseDiagram(entries)
+        self.plotter_ternary_mpl = PDPlotter(self.pd_ternary, backend="matplotlib")
+        self.plotter_ternary_plotly_2d = PDPlotter(self.pd_ternary, backend="plotly", ternary_style="2d")
+        self.plotter_ternary_plotly_3d = PDPlotter(self.pd_ternary, backend="plotly", ternary_style="3d")
+
         entries.append(PDEntry("C", 0))
         self.pd_quaternary = PhaseDiagram(entries)
         self.plotter_quaternary_mpl = PDPlotter(self.pd_quaternary, backend="matplotlib")
         self.plotter_quaternary_plotly = PDPlotter(self.pd_quaternary, backend="plotly")
 
+    def test_plot_pd_with_no_unstable(self):
+        # https://github.com/materialsproject/pymatgen/issues/2885
+        pd_entries = [PDEntry(comp, 0) for comp in ["Li", "Co", "O"]]
+        pd = PhaseDiagram(pd_entries)
+        plotter = PDPlotter(pd, backend="plotly", show_unstable=False)
+        plotter.get_plot()
+
     def test_pd_plot_data(self):
-        (lines, labels, unstable_entries) = self.plotter_ternary_mpl.pd_plot_data
+        lines, labels, unstable_entries = self.plotter_ternary_mpl.pd_plot_data
         assert len(lines) == 22
         assert len(labels) == len(self.pd_ternary.stable_entries), "Incorrect number of lines generated!"
         assert len(unstable_entries) == len(self.pd_ternary.all_entries) - len(
             self.pd_ternary.stable_entries
         ), "Incorrect number of lines generated!"
-        (lines, labels, unstable_entries) = self.plotter_quaternary_mpl.pd_plot_data
+        lines, labels, unstable_entries = self.plotter_quaternary_mpl.pd_plot_data
         assert len(lines) == 33
         assert len(labels) == len(self.pd_quaternary.stable_entries)
         assert len(unstable_entries) == len(self.pd_quaternary.all_entries) - len(self.pd_quaternary.stable_entries)
-        (lines, labels, unstable_entries) = self.plotter_binary_mpl.pd_plot_data
+        lines, labels, unstable_entries = self.plotter_binary_mpl.pd_plot_data
         assert len(lines) == 3
         assert len(labels) == len(self.pd_binary.stable_entries)
 
@@ -896,8 +903,10 @@ class PDPlotterTest(unittest.TestCase):
 
     def test_plotly_plots(self):
         # Also very basic tests. Ensures callability and 2D vs 3D properties.
+        self.plotter_unary_plotly.get_plot()
         self.plotter_binary_plotly.get_plot()
-        self.plotter_ternary_plotly.get_plot()
+        self.plotter_ternary_plotly_2d.get_plot()
+        self.plotter_ternary_plotly_3d.get_plot()
         self.plotter_quaternary_plotly.get_plot()
 
 
@@ -917,7 +926,7 @@ class UtilityFunctionTest(unittest.TestCase):
             [400, 17, 20],
             [21, 17, 400],
         ]
-        expected_ans = {
+        expected = {
             (5, 393),
             (21, 353),
             (353, 400),
@@ -941,7 +950,7 @@ class UtilityFunctionTest(unittest.TestCase):
             (399, 400),
             (20, 400),
         }
-        assert uniquelines(testdata) == expected_ans
+        assert uniquelines(testdata) == expected
 
     def test_triangular_coord(self):
         coord = [0.5, 0.5]
@@ -952,7 +961,3 @@ class UtilityFunctionTest(unittest.TestCase):
         coord = [0.5, 0.5, 0.5]
         coord = tet_coord(coord)
         assert np.allclose(coord, [1.0, 0.57735027, 0.40824829])
-
-
-if __name__ == "__main__":
-    unittest.main()
