@@ -1,21 +1,14 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 Test for the piezo tensor class
 """
 
-__author__ = "Handong Ling"
-__version__ = "0.1"
-__maintainer__ = "Handong Ling"
-__email__ = "handongling@berkeley.edu"
-__status__ = "Development"
-__date__ = "4/23/19"
+from __future__ import annotations
 
 import os
-import unittest
+import pickle
 
 import numpy as np
+import pytest
 
 import pymatgen
 from pymatgen.analysis.piezo_sensitivity import (
@@ -32,6 +25,13 @@ try:
 except ImportError:
     Phonopy = None
 
+__author__ = "Handong Ling"
+__version__ = "0.1"
+__maintainer__ = "Handong Ling"
+__email__ = "handongling@berkeley.edu"
+__status__ = "Development"
+__date__ = "4/23/19"
+
 test_dir = os.path.join(PymatgenTest.TEST_FILES_DIR, "piezo_sensitivity")
 
 
@@ -43,9 +43,11 @@ class PiezoSensitivityTest(PymatgenTest):
         self.FCM = np.load(os.path.join(test_dir, "pztfcm.npy"), allow_pickle=True)
         self.pointops = np.load(os.path.join(test_dir, "pointops.npy"), allow_pickle=True)
         self.sharedops = np.load(os.path.join(test_dir, "sharedops.npy"), allow_pickle=True)
-        self.BEC_operations = np.load(os.path.join(test_dir, "becops.npy"), allow_pickle=True)
         self.IST_operations = np.load(os.path.join(test_dir, "istops.npy"), allow_pickle=True)
-        self.FCM_operations = np.load(os.path.join(test_dir, "fcmops.npy"), allow_pickle=True)
+        with open(os.path.join(test_dir, "becops.pkl"), "rb") as file:
+            self.BEC_operations = pickle.load(file)
+        with open(os.path.join(test_dir, "fcmops.pkl"), "rb") as file:
+            self.FCM_operations = pickle.load(file)
         self.piezo = np.array(
             [
                 [
@@ -68,20 +70,23 @@ class PiezoSensitivityTest(PymatgenTest):
 
     def test_BornEffectiveChargeTensor(self):
         bec = BornEffectiveCharge(self.piezo_struc, self.BEC, self.pointops)
-        self.assertArrayAlmostEqual(self.BEC, bec.bec)
+        self.assert_all_close(self.BEC, bec.bec)
 
     def test_InternalStrainTensor(self):
         ist = InternalStrainTensor(self.piezo_struc, self.IST, self.pointops)
-        self.assertArrayAlmostEqual(ist.ist, self.IST)
+        self.assert_all_close(ist.ist, self.IST)
 
     def test_ForceConstantMatrix(self):
         fcmt = ForceConstantMatrix(self.piezo_struc, self.FCM, self.pointops, self.sharedops)
-        self.assertArrayAlmostEqual(fcmt.fcm, self.FCM)
+        self.assert_all_close(fcmt.fcm, self.FCM)
 
     def test_get_BEC_operations(self):
         bec = BornEffectiveCharge(self.piezo_struc, self.BEC, self.pointops)
+        # update test file
+        # with open(os.path.join(test_dir, "becops.pkl"), "wb") as file:
+        #     pickle.dump(bec.get_BEC_operations(), file)
         bec.get_BEC_operations()
-        self.assertTrue(np.all(self.BEC_operations == bec.BEC_operations))
+        assert np.all(self.BEC_operations == bec.BEC_operations)
 
     def test_get_rand_BEC(self):
         bec = BornEffectiveCharge(self.piezo_struc, self.BEC, self.pointops)
@@ -89,12 +94,10 @@ class PiezoSensitivityTest(PymatgenTest):
         rand_BEC = bec.get_rand_BEC()
         for i in range(len(self.BEC_operations)):
             for j in range(len(self.BEC_operations[i][2])):
-                self.assertTrue(
-                    np.allclose(
-                        rand_BEC[self.BEC_operations[i][0]],
-                        self.BEC_operations[i][2][j].transform_tensor(rand_BEC[self.BEC_operations[i][1]]),
-                        atol=1e-03,
-                    )
+                assert np.allclose(
+                    rand_BEC[self.BEC_operations[i][0]],
+                    self.BEC_operations[i][2][j].transform_tensor(rand_BEC[self.BEC_operations[i][1]]),
+                    atol=1e-03,
                 )
 
     def test_get_rand_IST(self):
@@ -103,18 +106,19 @@ class PiezoSensitivityTest(PymatgenTest):
         rand_IST = ist.get_rand_IST()
         for i in range(len(self.IST_operations)):
             for j in range(len(self.IST_operations[i])):
-                self.assertTrue(
-                    np.allclose(
-                        rand_IST[i],
-                        self.IST_operations[i][j][1].transform_tensor(rand_IST[self.IST_operations[i][j][0]]),
-                        atol=1e-03,
-                    )
+                assert np.allclose(
+                    rand_IST[i],
+                    self.IST_operations[i][j][1].transform_tensor(rand_IST[self.IST_operations[i][j][0]]),
+                    atol=1e-03,
                 )
 
     def test_get_FCM_operations(self):
         fcm = ForceConstantMatrix(self.piezo_struc, self.FCM, self.pointops, self.sharedops)
+        # update test file
+        # with open(os.path.join(test_dir, "fcmops.pkl"), "wb") as file:
+        #     pickle.dump(fcm.get_FCM_operations(), file)
         fcm.get_FCM_operations()
-        self.assertTrue(np.all(fcm.FCM_operations == self.FCM_operations))
+        assert np.all(fcm.FCM_operations == self.FCM_operations)
 
     def test_get_unstable_FCM(self):
         fcm = ForceConstantMatrix(self.piezo_struc, self.FCM, self.pointops, self.sharedops)
@@ -123,14 +127,12 @@ class PiezoSensitivityTest(PymatgenTest):
         rand_FCM = np.reshape(rand_FCM, (10, 3, 10, 3)).swapaxes(1, 2)
         for i in range(len(self.FCM_operations)):
             for j in range(len(self.FCM_operations[i][4])):
-                self.assertTrue(
-                    np.allclose(
-                        self.FCM_operations[i][4][j].transform_tensor(
-                            rand_FCM[self.FCM_operations[i][2]][self.FCM_operations[i][3]]
-                        ),
-                        rand_FCM[self.FCM_operations[i][0]][self.FCM_operations[i][1]],
-                        atol=1e-04,
-                    )
+                assert np.allclose(
+                    self.FCM_operations[i][4][j].transform_tensor(
+                        rand_FCM[self.FCM_operations[i][2]][self.FCM_operations[i][3]]
+                    ),
+                    rand_FCM[self.FCM_operations[i][0]][self.FCM_operations[i][1]],
+                    atol=1e-04,
                 )
 
     def test_get_FCM_symmetry(self):
@@ -141,14 +143,12 @@ class PiezoSensitivityTest(PymatgenTest):
         fcm = np.reshape(fcm, (10, 3, 10, 3)).swapaxes(1, 2)
         for i in range(len(self.FCM_operations)):
             for j in range(len(self.FCM_operations[i][4])):
-                self.assertTrue(
-                    np.allclose(
-                        self.FCM_operations[i][4][j].transform_tensor(
-                            fcm[self.FCM_operations[i][2]][self.FCM_operations[i][3]]
-                        ),
-                        fcm[self.FCM_operations[i][0]][self.FCM_operations[i][1]],
-                        atol=1e-04,
-                    )
+                assert np.allclose(
+                    self.FCM_operations[i][4][j].transform_tensor(
+                        fcm[self.FCM_operations[i][2]][self.FCM_operations[i][3]]
+                    ),
+                    fcm[self.FCM_operations[i][0]][self.FCM_operations[i][1]],
+                    atol=1e-04,
                 )
 
     def test_get_asum_FCM(self):
@@ -160,14 +160,12 @@ class PiezoSensitivityTest(PymatgenTest):
 
         for i in range(len(self.FCM_operations)):
             for j in range(len(self.FCM_operations[i][4])):
-                self.assertTrue(
-                    np.allclose(
-                        self.FCM_operations[i][4][j].transform_tensor(
-                            rand_FCM[self.FCM_operations[i][2]][self.FCM_operations[i][3]]
-                        ),
-                        rand_FCM[self.FCM_operations[i][0]][self.FCM_operations[i][1]],
-                        atol=1e-04,
-                    )
+                assert np.allclose(
+                    self.FCM_operations[i][4][j].transform_tensor(
+                        rand_FCM[self.FCM_operations[i][2]][self.FCM_operations[i][3]]
+                    ),
+                    rand_FCM[self.FCM_operations[i][0]][self.FCM_operations[i][1]],
+                    atol=1e-04,
                 )
 
         for i in range(len(rand_FCM)):
@@ -176,8 +174,8 @@ class PiezoSensitivityTest(PymatgenTest):
             for j in range(len(rand_FCM[i])):
                 asum1 += rand_FCM[i][j]
                 asum2 += rand_FCM[j][i]
-            self.assertTrue(np.allclose(asum1, np.zeros([3, 3]), atol=1e-05))
-            self.assertTrue(np.allclose(asum2, np.zeros([3, 3]), atol=1e-05))
+            assert np.allclose(asum1, np.zeros([3, 3]), atol=1e-05)
+            assert np.allclose(asum2, np.zeros([3, 3]), atol=1e-05)
 
     def test_get_stable_FCM(self):
         fcm = ForceConstantMatrix(self.piezo_struc, self.FCM, self.pointops, self.sharedops)
@@ -188,20 +186,18 @@ class PiezoSensitivityTest(PymatgenTest):
         eigs, vecs = np.linalg.eig(rand_FCM1)
         eigsort = np.argsort(np.abs(eigs))
         for i in range(3, len(eigs)):
-            self.assertTrue(eigs[eigsort[i]] < 1e-06)
+            assert eigs[eigsort[i]] < 1e-06
 
         rand_FCM1 = np.reshape(rand_FCM1, (10, 3, 10, 3)).swapaxes(1, 2)
 
         for i in range(len(self.FCM_operations)):
             for j in range(len(self.FCM_operations[i][4])):
-                self.assertTrue(
-                    np.allclose(
-                        self.FCM_operations[i][4][j].transform_tensor(
-                            rand_FCM1[self.FCM_operations[i][2]][self.FCM_operations[i][3]]
-                        ),
-                        rand_FCM1[self.FCM_operations[i][0]][self.FCM_operations[i][1]],
-                        atol=1e-04,
-                    )
+                assert np.allclose(
+                    self.FCM_operations[i][4][j].transform_tensor(
+                        rand_FCM1[self.FCM_operations[i][2]][self.FCM_operations[i][3]]
+                    ),
+                    rand_FCM1[self.FCM_operations[i][0]][self.FCM_operations[i][1]],
+                    atol=1e-04,
                 )
 
         for i in range(len(rand_FCM1)):
@@ -210,11 +206,11 @@ class PiezoSensitivityTest(PymatgenTest):
             for j in range(len(rand_FCM1[i])):
                 asum1 += rand_FCM1[i][j]
                 asum2 += rand_FCM1[j][i]
-            self.assertTrue(np.allclose(asum1, np.zeros([3, 3]), atol=1e-05))
-            self.assertTrue(np.allclose(asum2, np.zeros([3, 3]), atol=1e-05))
+            assert np.allclose(asum1, np.zeros([3, 3]), atol=1e-05)
+            assert np.allclose(asum2, np.zeros([3, 3]), atol=1e-05)
 
-    @unittest.skipIf(Phonopy is None, "Phonopy not present")
     def test_rand_FCM(self):
+        pytest.importorskip("phonopy")
         fcm = ForceConstantMatrix(self.piezo_struc, self.FCM, self.pointops, self.sharedops)
         fcm.get_FCM_operations()
         rand_FCM = fcm.get_rand_FCM()
@@ -238,20 +234,18 @@ class PiezoSensitivityTest(PymatgenTest):
         eigs, vecs = np.linalg.eig(dynmass)
         eigsort = np.argsort(np.abs(eigs))
         for i in range(3, len(eigs)):
-            self.assertTrue(eigs[eigsort[i]] < 1e-06)
+            assert eigs[eigsort[i]] < 1e-06
         # rand_FCM1 = np.reshape(rand_FCM1, (10,3,10,3)).swapaxes(1,2)
 
         dynmass = np.reshape(dynmass, (10, 3, 10, 3)).swapaxes(1, 2)
         for i in range(len(self.FCM_operations)):
             for j in range(len(self.FCM_operations[i][4])):
-                self.assertTrue(
-                    np.allclose(
-                        self.FCM_operations[i][4][j].transform_tensor(
-                            dynmass[self.FCM_operations[i][2]][self.FCM_operations[i][3]]
-                        ),
-                        dynmass[self.FCM_operations[i][0]][self.FCM_operations[i][1]],
-                        atol=1e-04,
-                    )
+                assert np.allclose(
+                    self.FCM_operations[i][4][j].transform_tensor(
+                        dynmass[self.FCM_operations[i][2]][self.FCM_operations[i][3]]
+                    ),
+                    dynmass[self.FCM_operations[i][0]][self.FCM_operations[i][1]],
+                    atol=1e-04,
                 )
 
         for i in range(len(dynmass)):
@@ -260,15 +254,15 @@ class PiezoSensitivityTest(PymatgenTest):
             for j in range(len(dynmass[i])):
                 asum1 += dynmass[i][j]
                 asum2 += dynmass[j][i]
-            self.assertTrue(np.allclose(asum1, np.zeros([3, 3]), atol=1e-05))
-            self.assertTrue(np.allclose(asum2, np.zeros([3, 3]), atol=1e-05))
+            assert np.allclose(asum1, np.zeros([3, 3]), atol=1e-05)
+            assert np.allclose(asum2, np.zeros([3, 3]), atol=1e-05)
 
     def test_get_piezo(self):
         piezo = get_piezo(self.BEC, self.IST, self.FCM)
-        self.assertTrue(np.allclose(piezo, self.piezo, atol=1e-05))
+        assert np.allclose(piezo, self.piezo, atol=1e-05)
 
-    @unittest.skipIf(Phonopy is None, "Phonopy not present")
     def test_rand_piezo(self):
+        pytest.importorskip("phonopy")
         rand_BEC, rand_IST, rand_FCM, piezo = rand_piezo(
             self.piezo_struc,
             self.pointops,
@@ -280,22 +274,18 @@ class PiezoSensitivityTest(PymatgenTest):
 
         for i in range(len(self.BEC_operations)):
             for j in range(len(self.BEC_operations[i][2])):
-                self.assertTrue(
-                    np.allclose(
-                        rand_BEC[self.BEC_operations[i][0]],
-                        self.BEC_operations[i][2][j].transform_tensor(rand_BEC[self.BEC_operations[i][1]]),
-                        atol=1e-03,
-                    )
+                assert np.allclose(
+                    rand_BEC[self.BEC_operations[i][0]],
+                    self.BEC_operations[i][2][j].transform_tensor(rand_BEC[self.BEC_operations[i][1]]),
+                    atol=1e-03,
                 )
 
         for i in range(len(self.IST_operations)):
             for j in range(len(self.IST_operations[i])):
-                self.assertTrue(
-                    np.allclose(
-                        rand_IST[i],
-                        self.IST_operations[i][j][1].transform_tensor(rand_IST[self.IST_operations[i][j][0]]),
-                        atol=1e-03,
-                    )
+                assert np.allclose(
+                    rand_IST[i],
+                    self.IST_operations[i][j][1].transform_tensor(rand_IST[self.IST_operations[i][j][0]]),
+                    atol=1e-03,
                 )
 
         structure = pymatgen.io.phonopy.get_phonopy_structure(self.piezo_struc)
@@ -318,20 +308,18 @@ class PiezoSensitivityTest(PymatgenTest):
         eigs, vecs = np.linalg.eig(dynmass)
         eigsort = np.argsort(np.abs(eigs))
         for i in range(3, len(eigs)):
-            self.assertTrue(eigs[eigsort[i]] < 1e-06)
+            assert eigs[eigsort[i]] < 1e-06
         # rand_FCM1 = np.reshape(rand_FCM1, (10,3,10,3)).swapaxes(1,2)
 
         dynmass = np.reshape(dynmass, (10, 3, 10, 3)).swapaxes(1, 2)
         for i in range(len(self.FCM_operations)):
             for j in range(len(self.FCM_operations[i][4])):
-                self.assertTrue(
-                    np.allclose(
-                        self.FCM_operations[i][4][j].transform_tensor(
-                            dynmass[self.FCM_operations[i][2]][self.FCM_operations[i][3]]
-                        ),
-                        dynmass[self.FCM_operations[i][0]][self.FCM_operations[i][1]],
-                        atol=1e-04,
-                    )
+                assert np.allclose(
+                    self.FCM_operations[i][4][j].transform_tensor(
+                        dynmass[self.FCM_operations[i][2]][self.FCM_operations[i][3]]
+                    ),
+                    dynmass[self.FCM_operations[i][0]][self.FCM_operations[i][1]],
+                    atol=1e-04,
                 )
 
         for i in range(len(dynmass)):
@@ -340,9 +328,5 @@ class PiezoSensitivityTest(PymatgenTest):
             for j in range(len(dynmass[i])):
                 asum1 += dynmass[i][j]
                 asum2 += dynmass[j][i]
-            self.assertTrue(np.allclose(asum1, np.zeros([3, 3]), atol=1e-05))
-            self.assertTrue(np.allclose(asum2, np.zeros([3, 3]), atol=1e-05))
-
-
-if __name__ == "__main__":
-    unittest.main()
+            assert np.allclose(asum1, np.zeros([3, 3]), atol=1e-05)
+            assert np.allclose(asum2, np.zeros([3, 3]), atol=1e-05)
