@@ -1,4 +1,4 @@
-import unittest
+from __future__ import annotations
 
 from pymatgen.analysis.xps import XPS
 from pymatgen.io.vasp import Vasprun
@@ -10,10 +10,6 @@ class XPSTestCase(PymatgenTest):
         v = Vasprun(PymatgenTest.TEST_FILES_DIR / "vasprun.xml.LiF")
         dos = v.complete_dos
         xps = XPS.from_dos(dos)
-        self.assertEqual(len(xps), 301)
+        assert len(xps) == 301
         xps.smear(0.3)
-        self.assertEqual(len(xps), 301)
-
-
-if __name__ == "__main__":
-    unittest.main()
+        assert len(xps) == 301
