@@ -1,11 +1,12 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 A module to perform experimental thermochemical data analysis.
 """
 
 
+from __future__ import annotations
+
+from pymatgen.core.composition import Composition
+
 __author__ = "Shyue Ping Ong"
 __copyright__ = "Copyright 2012, The Materials Project"
 __version__ = "0.1"
@@ -13,9 +14,6 @@ __maintainer__ = "Shyue Ping Ong"
 __email__ = "shyuep@gmail.com"
 __date__ = "Jun 10, 2012"
 
-
-from pymatgen.core.composition import Composition
-
 STANDARD_TEMP = 298.0
 
 
@@ -41,7 +39,7 @@ class ThermoData:
             data_type: The thermochemical data type. Should be one of the
                 following: fH - Formation enthalpy, S - Entropy,
                 A, B, C, D, E, F, G, H - variables for use in the various
-                quations for generating formation enthaplies or Cp at
+                equations for generating formation enthalpies or Cp at
                 various temperatures.
             cpdname (str): A name for the compound. For example, hematite for
                 Fe2O3.
@@ -87,7 +85,7 @@ class ThermoData:
             d["ref"],
             d["method"],
             d["temp_range"],
-            d.get("uncertainty", None),
+            d.get("uncertainty"),
         )
 
     def as_dict(self):
@@ -109,19 +107,8 @@ class ThermoData:
         }
 
     def __repr__(self):
-        props = [
-            "formula",
-            "compound_name",
-            "phaseinfo",
-            "type",
-            "temp_range",
-            "value",
-            "method",
-            "ref",
-            "uncertainty",
-        ]
-        output = [f"{k} : {getattr(self, k)}" for k in props]
-        return "\n".join(output)
+        props = ["formula", "compound_name", "phaseinfo", "type", "temp_range", "value", "method", "ref", "uncertainty"]
+        return "\n".join(f"{k} : {getattr(self, k)}" for k in props)
 
     def __str__(self):
         return (
