@@ -16,16 +16,21 @@ Note that the atomic_subshell_photoionization_cross_sections.csv has been repars
 This version contains all detailed information for all orbitals.
 """
 
+from __future__ import annotations
+
 import collections
 import warnings
 from pathlib import Path
+from typing import TYPE_CHECKING
 
 import numpy as np
 import pandas as pd
 
 from pymatgen.core.periodic_table import Element
 from pymatgen.core.spectrum import Spectrum
-from pymatgen.electronic_structure.dos import CompleteDos
+
+if TYPE_CHECKING:
+    from pymatgen.electronic_structure.dos import CompleteDos
 
 
 def _load_cross_sections(fname):
@@ -38,15 +43,15 @@ def _load_cross_sections(fname):
         if el.Z > 92:
             continue
         orb = row.orbital
-        shell = int(orb[0])
-        orbtype = orb[1]
-        nelect = None
-        for l in el.full_electronic_structure:
-            if l[0] == shell and l[1] == orbtype:
-                nelect = l[2]
+        outer_shell = int(orb[0])
+        orb_type = orb[1]
+        n_elect = None
+        for shell, orb, n_ele in el.full_electronic_structure:
+            if shell == outer_shell and orb == orb_type:
+                n_elect = n_ele
                 break
-        if nelect is not None:
-            d[sym][orbtype] = row.weight / nelect
+        if n_elect is not None:
+            d[sym][orb_type] = row.weight / n_elect
     return d
 
 
@@ -72,7 +77,7 @@ class XPS(Spectrum):
         for el in dos.structure.composition:
             spd_dos = dos.get_element_spd_dos(el)
             for orb, pdos in spd_dos.items():
-                weight = CROSS_SECTIONS[el.symbol].get(str(orb), None)
+                weight = CROSS_SECTIONS[el.symbol].get(str(orb))
                 if weight is not None:
                     total += pdos.get_densities() * weight
                 else:
