@@ -1,6 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module defines the abstract base classes for battery-related classes.
 Regardless of the kind of electrode, conversion or insertion, there are many
@@ -9,15 +6,19 @@ can be defined in a general way. The Abc for battery classes implements some of
 these common definitions to allow sharing of common logic between them.
 """
 
+from __future__ import annotations
+
 from collections.abc import Sequence
 from dataclasses import dataclass
-from typing import Tuple
+from typing import TYPE_CHECKING
 
 from monty.json import MSONable
 from scipy.constants import N_A
 
 from pymatgen.core import Composition, Element
-from pymatgen.entries.computed_entries import ComputedEntry
+
+if TYPE_CHECKING:
+    from pymatgen.entries.computed_entries import ComputedEntry
 
 __author__ = "Anubhav Jain, Shyue Ping Ong"
 __copyright__ = "Copyright 2012, The Materials Project"
@@ -55,38 +56,31 @@ class AbstractVoltagePair(MSONable):
     frac_charge: float
     frac_discharge: float
     working_ion_entry: ComputedEntry
-    framework_formula: str  # should be made into Composition whenever the as_dict and from dict are fixed
+    framework_formula: str
 
     def __post_init__(self):
         # ensure the frame work is a reduced composition
-        self.framework_formula = self.framework.reduced_formula
+        fw = Composition(self.framework_formula)
+        self.framework_formula = fw.reduced_formula
 
     @property
     def working_ion(self) -> Element:
-        """
-        working ion as pymatgen Element object
-        """
+        """Working ion as pymatgen Element object."""
         return self.working_ion_entry.composition.elements[0]
 
     @property
     def framework(self) -> Composition:
-        """
-        The composition object representing the framework
-        """
+        """The composition object representing the framework."""
         return Composition(self.framework_formula)
 
     @property
     def x_charge(self) -> float:
-        """
-        The number of working ions per formula unit of host in the charged state
-        """
+        """The number of working ions per formula unit of host in the charged state."""
         return self.frac_charge * self.framework.num_atoms / (1 - self.frac_charge)
 
     @property
     def x_discharge(self) -> float:
-        """
-        The number of working ions per formula unit of host in the discharged state
-        """
+        """The number of working ions per formula unit of host in the discharged state."""
         return self.frac_discharge * self.framework.num_atoms / (1 - self.frac_discharge)
 
 
@@ -128,6 +122,7 @@ class AbstractElectrode(Sequence, MSONable):
 
     Developers implementing a new battery (other than the two general ones
     already implemented) need to implement a VoltagePair and an Electrode.
+
     Attributes:
         voltage_pairs: Objects that represent each voltage step
         working_ion: Representation of the working ion that only contains element type
@@ -135,7 +130,7 @@ class AbstractElectrode(Sequence, MSONable):
         framework_formula: The compositions of one formula unit of the host material
     """
 
-    voltage_pairs: Tuple[AbstractVoltagePair, ...]
+    voltage_pairs: tuple[AbstractVoltagePair, ...]
     working_ion_entry: ComputedEntry
     framework_formula: str  # should be made into Composition whenever the as_dict and from dict are fixed
 
@@ -157,37 +152,27 @@ class AbstractElectrode(Sequence, MSONable):
 
     @property
     def working_ion(self):
-        """
-        working ion as pymatgen Element object
-        """
+        """Working ion as pymatgen Element object."""
         return self.working_ion_entry.composition.elements[0]
 
     @property
     def framework(self):
-        """
-        The composition object representing the framework
-        """
+        """The composition object representing the framework."""
         return Composition(self.framework_formula)
 
     @property
     def x_charge(self) -> float:
-        """
-        The number of working ions per formula unit of host in the charged state
-        """
+        """The number of working ions per formula unit of host in the charged state."""
         return self.voltage_pairs[0].x_charge
 
     @property
     def x_discharge(self) -> float:
-        """
-        The number of working ions per formula unit of host in the discharged state
-        """
+        """The number of working ions per formula unit of host in the discharged state."""
         return self.voltage_pairs[-1].x_discharge
 
     @property
     def max_delta_volume(self):
-        """
-        Maximum volume change along insertion
-        """
+        """Maximum volume change along insertion."""
         vols = [v.vol_charge for v in self.voltage_pairs]
         vols.extend([v.vol_discharge for v in self.voltage_pairs])
         return max(vols) / min(vols) - 1
@@ -196,29 +181,23 @@ class AbstractElectrode(Sequence, MSONable):
     def num_steps(self):
         """
         The number of distinct voltage steps in from fully charge to discharge
-        based on the stable intermediate states
+        based on the stable intermediate states.
         """
         return len(self.voltage_pairs)
 
     @property
     def max_voltage(self):
-        """
-        Highest voltage along insertion
-        """
+        """Highest voltage along insertion."""
         return max(p.voltage for p in self.voltage_pairs)
 
     @property
     def min_voltage(self):
-        """
-        Lowest voltage along insertion
-        """
+        """Lowest voltage along insertion."""
         return min(p.voltage for p in self.voltage_pairs)
 
     @property
     def max_voltage_step(self):
-        """
-        Maximum absolute difference in adjacent voltage steps
-        """
+        """Maximum absolute difference in adjacent voltage steps."""
         steps = [
             self.voltage_pairs[i].voltage - self.voltage_pairs[i + 1].voltage
             for i in range(len(self.voltage_pairs) - 1)
@@ -246,6 +225,7 @@ class AbstractElectrode(Sequence, MSONable):
         If this electrode contains multiple voltage steps, then it is possible
         to use only a subset of the voltage steps to define other electrodes.
         Must be implemented for each electrode object.
+
         Args:
             adjacent_only: Only return electrodes from compounds that are
                 adjacent on the convex hull, i.e. no electrodes returned
