@@ -1,11 +1,10 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module defines the BorgQueen class, which manages drones to assimilate
 data using Python's multiprocessing.
 """
 
+from __future__ import annotations
+
 import json
 import logging
 import os
@@ -33,7 +32,7 @@ class BorgQueen:
             rootpath (str): The root directory to start assimilation. Leave it
                 as None if you want to do assimilation later, or is using the
                 BorgQueen to load previously assimilated data.
-            ndrones (int): Number of drones to parallelize over.
+            number_of_drones (int): Number of drones to parallelize over.
                 Typical machines today have up to four processors. Note that you
                 won't see a 100% improvement with two drones over one, but you
                 will definitely see a significant speedup of at least 50% or so.
@@ -51,12 +50,10 @@ class BorgQueen:
                 self.serial_assimilate(rootpath)
 
     def parallel_assimilate(self, rootpath):
-        """
-        Assimilate the entire subdirectory structure in rootpath.
-        """
+        """Assimilate the entire subdirectory structure in rootpath."""
         logger.info("Scanning for valid paths...")
         valid_paths = []
-        for (parent, subdirs, files) in os.walk(rootpath):
+        for parent, subdirs, files in os.walk(rootpath):
             valid_paths.extend(self._drone.get_valid_paths((parent, subdirs, files)))
         manager = Manager()
         data = manager.list()
@@ -73,11 +70,9 @@ class BorgQueen:
                 self._data.append(json.loads(d, cls=MontyDecoder))
 
     def serial_assimilate(self, rootpath):
-        """
-        Assimilate the entire subdirectory structure in rootpath serially.
-        """
+        """Assimilate the entire subdirectory structure in rootpath serially."""
         valid_paths = []
-        for (parent, subdirs, files) in os.walk(rootpath):
+        for parent, subdirs, files in os.walk(rootpath):
             valid_paths.extend(self._drone.get_valid_paths((parent, subdirs, files)))
         data = []
         count = 0
@@ -91,9 +86,7 @@ class BorgQueen:
             self._data.append(json.loads(d, cls=MontyDecoder))
 
     def get_data(self):
-        """
-        Returns an list of assimilated objects
-        """
+        """Returns an list of assimilated objects."""
         return self._data
 
     def save_data(self, filename):
@@ -109,17 +102,13 @@ class BorgQueen:
             json.dump(list(self._data), f, cls=MontyEncoder)
 
     def load_data(self, filename):
-        """
-        Load assimilated data from a file
-        """
+        """Load assimilated data from a file."""
         with zopen(filename, "rt") as f:
             self._data = json.load(f, cls=MontyDecoder)
 
 
 def order_assimilation(args):
-    """
-    Internal helper method for BorgQueen to process assimilation
-    """
+    """Internal helper method for BorgQueen to process assimilation."""
     (path, drone, data, status) = args
     newdata = drone.assimilate(path)
     if newdata:
