@@ -1,17 +1,9 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 Created on Mar 18, 2012
 """
 
 
-__author__ = "Shyue Ping Ong"
-__copyright__ = "Copyright 2012, The Materials Project"
-__version__ = "0.1"
-__maintainer__ = "Shyue Ping Ong"
-__email__ = "shyue@mit.edu"
-__date__ = "Mar 18, 2012"
+from __future__ import annotations
 
 import os
 import unittest
@@ -21,6 +13,13 @@ from pymatgen.apps.borg.hive import VaspToComputedEntryDrone
 from pymatgen.apps.borg.queen import BorgQueen
 from pymatgen.util.testing import PymatgenTest
 
+__author__ = "Shyue Ping Ong"
+__copyright__ = "Copyright 2012, The Materials Project"
+__version__ = "0.1"
+__maintainer__ = "Shyue Ping Ong"
+__email__ = "shyue@mit.edu"
+__date__ = "Mar 18, 2012"
+
 
 class BorgQueenTest(unittest.TestCase):
     def setUp(self):
@@ -33,14 +32,10 @@ class BorgQueenTest(unittest.TestCase):
         drone = VaspToComputedEntryDrone()
         self.queen = BorgQueen(drone, PymatgenTest.TEST_FILES_DIR, 1)
         data = self.queen.get_data()
-        self.assertEqual(len(data), 15)
+        assert len(data) == 15
 
     def test_load_data(self):
         drone = VaspToComputedEntryDrone()
         queen = BorgQueen(drone)
         queen.load_data(os.path.join(PymatgenTest.TEST_FILES_DIR, "assimilated.json"))
-        self.assertEqual(len(queen.get_data()), 1)
-
-
-if __name__ == "__main__":
-    unittest.main()
+        assert len(queen.get_data()) == 1
