@@ -1,9 +1,4 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
-"""
-Implementation for `pmg analyze` CLI.
-"""
+"""Implementation for `pmg analyze` CLI."""
 
 from __future__ import annotations
 
@@ -14,10 +9,7 @@ import re
 
 from tabulate import tabulate
 
-from pymatgen.apps.borg.hive import (
-    SimpleVaspToComputedEntryDrone,
-    VaspToComputedEntryDrone,
-)
+from pymatgen.apps.borg.hive import SimpleVaspToComputedEntryDrone, VaspToComputedEntryDrone
 from pymatgen.apps.borg.queen import BorgQueen
 from pymatgen.io.vasp import Outcar
 
@@ -34,6 +26,7 @@ SAVE_FILE = "vasp_data.gz"
 def get_energies(rootdir, reanalyze, verbose, quick, sort, fmt):
     """
     Get energies of all vaspruns in directory (nested).
+
     Args:
         rootdir (str): Root directory.
         reanalyze (bool): Whether to ignore saved results and reanalyze
@@ -104,7 +97,7 @@ def get_magnetizations(dir: str, ion_list: list[int]):
     Get magnetization info from OUTCARs.
 
     Args:
-        mydir (str): Directory name
+        dir (str): Directory name
         ion_list (list[int]): List of ions to obtain magnetization information for.
 
     Returns:
@@ -112,7 +105,7 @@ def get_magnetizations(dir: str, ion_list: list[int]):
     """
     data = []
     max_row = 0
-    for (parent, _subdirs, files) in os.walk(dir):
+    for parent, _subdirs, files in os.walk(dir):
         for f in files:
             if re.match(r"OUTCAR*", f):
                 try:
