@@ -1,12 +1,10 @@
 #!/usr/bin/env python
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
 
-"""
-Implementation for `pmg plot` CLI.
-"""
+"""Implementation for `pmg plot` CLI."""
 
 
+from __future__ import annotations
+
 from pymatgen.analysis.diffraction.xrd import XRDCalculator
 from pymatgen.core.structure import Structure
 from pymatgen.electronic_structure.plotter import DosPlotter
@@ -79,14 +77,14 @@ def get_chgint_plot(args):
 
 def get_xrd_plot(args):
     """
-    Plot XRD
+    Plot XRD.
 
     Args:
         args (dict): Args from argparse
     """
-    s = Structure.from_file(args.xrd_structure_file)
+    struct = Structure.from_file(args.xrd_structure_file)
     c = XRDCalculator()
-    return c.get_plot(s)
+    return c.get_plot(struct)
 
 
 def plot(args):
