@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 
-"""
-Implementation for `pmg potcar` CLI.
-"""
+"""Implementation for `pmg potcar` CLI."""
 
 
+from __future__ import annotations
+
 import os
 
 from pymatgen.io.vasp import Potcar
