@@ -1,9 +1,9 @@
 # Copyright (c) Materials Virtual Lab.
 # Distributed under the terms of the BSD License.
 
-"""
-Implementation for `pmg query` CLI.
-"""
+"""Implementation for `pmg query` CLI."""
+
+from __future__ import annotations
 
 import json
 import re
@@ -16,7 +16,7 @@ from pymatgen.ext.matproj import MPRester
 
 def do_query(args):
     """
-    Perform query to the Materials Project
+    Perform query to the Materials Project.
 
     Args:
         args (dict): Args from argparse.
@@ -47,13 +47,7 @@ def do_query(args):
         props += args.data
         entries = m.get_entries(criteria, property_data=props)
         t = []
-        headers = [
-            "mp-id",
-            "Formula",
-            "Spacegroup",
-            "E/atom (eV)",
-            "E above hull (eV)",
-        ] + args.data
+        headers = ["mp-id", "Formula", "Spacegroup", "E/atom (eV)", "E above hull (eV)", *args.data]
         for e in entries:
             row = [
                 e.entry_id,
