@@ -1,10 +1,7 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
-This module implements an interface to Thomas Manz's
-Chargemol code (https://sourceforge.net/projects/ddec/files) for
-calculating DDEC3, DDEC6, and CM5 population analyses.
+This module implements an interface to Thomas Manz's Chargemol code
+https://sourceforge.net/projects/ddec for calculating DDEC3, DDEC6, and CM5 population analyses.
+
 This module depends on a compiled chargemol executable being available in the path.
 If you use this module, please cite the following based on which modules you use:
 
@@ -43,17 +40,13 @@ and Non-Periodic Materials,” J. Chem. Theory Comput. 8 (2012) 2844-2867.
 Electrostatic Potential in Periodic and Nonperiodic Materials,” J. Chem. Theory Comput. 6
 (2010) 2455-2468.
 """
-__author__ = "Martin Siron, Andrew S. Rosen"
-__version__ = "0.1"
-__maintainer__ = "Shyue Ping Ong"
-__email__ = "shyuep@gmail.com"
-__date__ = "01/18/21"
+from __future__ import annotations
 
-import glob
 import os
 import shutil
 import subprocess
 import warnings
+from glob import glob
 from shutil import which
 
 import numpy as np
@@ -64,6 +57,12 @@ from pymatgen.core import Element
 from pymatgen.io.vasp.inputs import Potcar
 from pymatgen.io.vasp.outputs import Chgcar
 
+__author__ = "Martin Siron, Andrew S. Rosen"
+__version__ = "0.1"
+__maintainer__ = "Shyue Ping Ong"
+__email__ = "shyuep@gmail.com"
+__date__ = "01/18/21"
+
 CHARGEMOLEXE = (
     which("Chargemol_09_26_2017_linux_parallel") or which("Chargemol_09_26_2017_linux_serial") or which("chargemol")
 )
@@ -125,9 +124,7 @@ class ChargemolAnalysis:
             self.structure = self.chgcar.structure
             self.natoms = self.chgcar.poscar.natoms
         else:
-            self.chgcar = None
-            self.structure = None
-            self.natoms = None
+            self.chgcar = self.structure = self.natoms = None
             warnings.warn("No CHGCAR found. Some properties may be unavailable.", UserWarning)
         if self._potcarpath:
             self.potcar = Potcar.from_file(self._potcarpath)
@@ -155,8 +152,8 @@ class ChargemolAnalysis:
         Returns:
             (str): Absolute path to the file.
         """
-        name_pattern = filename + suffix + "*" if filename != "POTCAR" else filename + "*"
-        paths = glob.glob(os.path.join(path, name_pattern))
+        name_pattern = f"{filename}{suffix}*" if filename != "POTCAR" else f"{filename}*"
+        paths = glob(os.path.join(path, name_pattern))
         fpath = None
         if len(paths) >= 1:
             # using reverse=True because, if multiple files are present,
@@ -165,7 +162,8 @@ class ChargemolAnalysis:
             # however, better to use 'suffix' kwarg to avoid this!
             paths.sort(reverse=True)
             warning_msg = f"Multiple files detected, using {os.path.basename(paths[0])}" if len(paths) > 1 else None
-            warnings.warn(warning_msg)
+            if warning_msg:
+                warnings.warn(warning_msg)
             fpath = paths[0]
         return fpath
 
@@ -181,18 +179,14 @@ class ChargemolAnalysis:
             jobcontrol_kwargs: Keyword arguments for _write_jobscript_for_chargemol.
         """
         with ScratchDir("."):
-            with zopen(self._chgcarpath, "rt") as f_in:
-                with open("CHGCAR", "wt") as f_out:
-                    shutil.copyfileobj(f_in, f_out)
-            with zopen(self._potcarpath, "rt") as f_in:
-                with open("POTCAR", "wt") as f_out:
-                    shutil.copyfileobj(f_in, f_out)
-            with zopen(self._aeccar0path, "rt") as f_in:
-                with open("AECCAR0", "wt") as f_out:
-                    shutil.copyfileobj(f_in, f_out)
-            with zopen(self._aeccar2path, "rt") as f_in:
-                with open("AECCAR2", "wt") as f_out:
-                    shutil.copyfileobj(f_in, f_out)
+            with zopen(self._chgcarpath, "rt") as f_in, open("CHGCAR", "w") as f_out:
+                shutil.copyfileobj(f_in, f_out)
+            with zopen(self._potcarpath, "rt") as f_in, open("POTCAR", "w") as f_out:
+                shutil.copyfileobj(f_in, f_out)
+            with zopen(self._aeccar0path, "rt") as f_in, open("AECCAR0", "w") as f_out:
+                shutil.copyfileobj(f_in, f_out)
+            with zopen(self._aeccar2path, "rt") as f_in, open("AECCAR2", "w") as f_out:
+                shutil.copyfileobj(f_in, f_out)
 
             # write job_script file:
             self._write_jobscript_for_chargemol(**jobcontrol_kwargs)
@@ -233,8 +227,7 @@ class ChargemolAnalysis:
             self.bond_order_sums = self._get_data_from_xyz(bond_order_path)
             self.bond_order_dict = self._get_bond_order_info(bond_order_path)
         else:
-            self.bond_order_sums = None
-            self.bond_order_dict = None
+            self.bond_order_sums = self.bond_order_dict = None
 
         spin_moment_path = os.path.join(chargemol_output_path, "DDEC6_even_tempered_atomic_spin_moments.xyz")
         if os.path.exists(spin_moment_path):
@@ -352,10 +345,7 @@ class ChargemolAnalysis:
         """
         bonded_set = self.bond_order_dict[index_from]["bonded_to"]
         bond_orders = [v["bond_order"] for v in bonded_set if v["index"] == index_to]
-        if bond_orders == []:
-            sum_bo = 0.0
-        else:
-            sum_bo = np.sum(bond_orders)
+        sum_bo = 0.0 if bond_orders == [] else np.sum(bond_orders)
         return sum_bo
 
     def _write_jobscript_for_chargemol(
@@ -366,7 +356,7 @@ class ChargemolAnalysis:
         compute_bond_orders=True,
     ):
         """
-        Writes job_script.txt for Chargemol execution
+        Writes job_script.txt for Chargemol execution.
 
         Args:
             net_charge (float): Net charge of the system.
@@ -374,8 +364,8 @@ class ChargemolAnalysis:
             periodicity (tuple[bool]): Periodicity of the system.
                 Default: (True, True, True).
             method (str): Method to use for the analysis. Options include "ddec6"
-            and "ddec3".
-                Default: "ddec6"
+                and "ddec3". Default: "ddec6"
+            compute_bond_orders (bool): Whether to compute bond orders. Default: True.
         """
         self.net_charge = net_charge
         self.periodicity = periodicity
@@ -398,7 +388,7 @@ class ChargemolAnalysis:
             )
 
         # atomic_densities dir
-        atomic_densities_path = self._atomic_densities_path or os.environ.get("DDEC6_ATOMIC_DENSITIES_DIR", None)
+        atomic_densities_path = self._atomic_densities_path or os.getenv("DDEC6_ATOMIC_DENSITIES_DIR", None)
         if atomic_densities_path is None:
             raise OSError(
                 "The DDEC6_ATOMIC_DENSITIES_DIR environment variable must be set or the atomic_densities_path must"
@@ -411,9 +401,8 @@ class ChargemolAnalysis:
         if os.name == "nt":
             if atomic_densities_path[-1] != "\\":
                 atomic_densities_path += "\\"
-        else:
-            if atomic_densities_path[-1] != "/":
-                atomic_densities_path += "/"
+        elif atomic_densities_path[-1] != "/":
+            atomic_densities_path += "/"
 
         lines += (
             f"\n<atomic densities directory complete path>\n{atomic_densities_path}\n</atomic densities directory "
@@ -427,13 +416,13 @@ class ChargemolAnalysis:
             bo = ".true." if compute_bond_orders else ".false."
             lines += f"\n<compute BOs>\n{bo}\n</compute BOs>\n"
 
-        with open("job_control.txt", "wt") as fh:
+        with open("job_control.txt", "w") as fh:
             fh.write(lines)
 
     @staticmethod
     def _get_dipole_info(filepath):
         """
-        Internal command to process dipoles
+        Internal command to process dipoles.
 
         Args:
             filepath (str): The path to the DDEC6_even_tempered_net_atomic_charges.xyz file
@@ -459,7 +448,7 @@ class ChargemolAnalysis:
     @staticmethod
     def _get_bond_order_info(filename):
         """
-        Internal command to process pairwise bond order information
+        Internal command to process pairwise bond order information.
 
         Args:
             filename (str): The path to the DDEC6_even_tempered_bond_orders.xyz file
@@ -469,17 +458,17 @@ class ChargemolAnalysis:
 
         with open(filename) as r:
             for line in r:
-                l = line.strip().split()
+                split = line.strip().split()
                 if "Printing BOs" in line:
-                    start_idx = int(l[5]) - 1
-                    start_el = Element(l[7])
+                    start_idx = int(split[5]) - 1
+                    start_el = Element(split[7])
                     bond_order_info[start_idx] = {"element": start_el, "bonded_to": []}
                 elif "Bonded to the" in line:
-                    direction = tuple(int(i.split(")")[0].split(",")[0]) for i in l[4:7])
-                    end_idx = int(l[12]) - 1
-                    end_el = Element(l[14])
-                    bo = float(l[20])
-                    spin_bo = float(l[-1])
+                    direction = tuple(int(i.split(")")[0].split(",")[0]) for i in split[4:7])
+                    end_idx = int(split[12]) - 1
+                    end_el = Element(split[14])
+                    bo = float(split[20])
+                    spin_bo = float(split[-1])
                     bond_order_info[start_idx]["bonded_to"].append(
                         {
                             "index": end_idx,
@@ -490,7 +479,7 @@ class ChargemolAnalysis:
                         }
                     )
                 elif "The sum of bond orders for this atom" in line:
-                    bond_order_info[start_idx]["bond_order_sum"] = float(l[-1])
+                    bond_order_info[start_idx]["bond_order_sum"] = float(split[-1])
 
         return bond_order_info
 
@@ -499,7 +488,7 @@ class ChargemolAnalysis:
         Takes CHGCAR's structure object and updates it with properties
         from the Chargemol analysis.
 
-        Returns
+        Returns:
             Pymatgen structure with site properties added
         """
         struct = self.structure.copy()
@@ -531,7 +520,7 @@ class ChargemolAnalysis:
                 "cm5": {
                             "partial_charges": List[float],
                         }
-            }
+            }.
         """
         summary = {}
         ddec_summary = {
@@ -552,10 +541,7 @@ class ChargemolAnalysis:
         if self.bond_order_dict:
             ddec_summary["bond_order_dict"] = self.bond_order_dict
 
-        if self.cm5_charges:
-            cm5_summary = {"partial_charges": self.cm5_charges}
-        else:
-            cm5_summary = None
+        cm5_summary = {"partial_charges": self.cm5_charges} if self.cm5_charges else None
 
         summary["ddec"] = ddec_summary
         summary["cm5"] = cm5_summary
@@ -565,7 +551,7 @@ class ChargemolAnalysis:
     @staticmethod
     def _get_data_from_xyz(xyz_path):
         """
-        Internal command to process Chargemol XYZ files
+        Internal command to process Chargemol XYZ files.
 
         Args:
             xyz_path (str): Path to XYZ file
@@ -590,7 +576,7 @@ class ChargemolAnalysis:
     @staticmethod
     def _get_cm5_data_from_output(ddec_analysis_path):
         """
-        Internal command to process Chargemol CM5 data
+        Internal command to process Chargemol CM5 data.
 
         Args:
             ddec_analysis_path (str): Path VASP_DDEC_analysis.output file
