@@ -39,13 +39,14 @@ V. Luaña, Comput. Phys. Communications 180, 157-166 (2009)
 
 from __future__ import annotations
 
-import glob
 import logging
 import os
 import subprocess
 import warnings
 from enum import Enum
+from glob import glob
 from shutil import which
+from typing import TYPE_CHECKING
 
 import numpy as np
 from monty.dev import requires
@@ -56,18 +57,18 @@ from scipy.spatial import KDTree
 
 from pymatgen.analysis.graphs import StructureGraph
 from pymatgen.core.periodic_table import DummySpecies
-from pymatgen.core.structure import Structure
 from pymatgen.io.vasp.inputs import Potcar
 from pymatgen.io.vasp.outputs import Chgcar, VolumetricData
 
+if TYPE_CHECKING:
+    from pymatgen.core import Structure
+
 logging.basicConfig(level=logging.INFO)
 logger = logging.getLogger(__name__)
 
 
 class Critic2Caller:
-    """
-    Class to call critic2 and store standard output for further processing.
-    """
+    """Class to call critic2 and store standard output for further processing."""
 
     @requires(
         which("critic2"),
@@ -76,7 +77,7 @@ class Critic2Caller:
     )
     def __init__(self, input_script):
         """
-        Run Critic2 on a given input script
+        Run Critic2 on a given input script.
 
         :param input_script: string defining the critic2 input
         """
@@ -102,16 +103,10 @@ class Critic2Caller:
         self._stdout = stdout
         self._stderr = stderr
 
-        if os.path.exists("cpreport.json"):
-            cpreport = loadfn("cpreport.json")
-        else:
-            cpreport = None
+        cpreport = loadfn("cpreport.json") if os.path.exists("cpreport.json") else None
         self._cpreport = cpreport
 
-        if os.path.exists("yt.json"):
-            yt = loadfn("yt.json")
-        else:
-            yt = None
+        yt = loadfn("yt.json") if os.path.exists("yt.json") else None
         self._yt = yt
 
     @classmethod
@@ -193,7 +188,7 @@ class Critic2Caller:
         if chgcar:
             input_script += ["load int.CHGCAR id chg_int", "integrable chg_int"]
             if zpsp:
-                zpsp_str = " zpsp " + " ".join([f"{symbol} {zval}" for symbol, zval in zpsp.items()])
+                zpsp_str = " zpsp " + " ".join(f"{symbol} {zval}" for symbol, zval in zpsp.items())
                 input_script[-2] += zpsp_str
 
         # Command to run automatic analysis
@@ -219,10 +214,7 @@ class Critic2Caller:
 
         input_script = "\n".join(input_script)
 
-        with ScratchDir(".") as temp_dir:
-
-            os.chdir(temp_dir)
-
+        with ScratchDir("."):
             structure.to(filename="POSCAR")
 
             if chgcar and isinstance(chgcar, VolumetricData):
@@ -251,8 +243,8 @@ class Critic2Caller:
     @classmethod
     def from_path(cls, path, suffix="", zpsp=None):
         """
-        Convenience method to run critic2 analysis on a folder containing
-        typical VASP output files.
+        Convenience method to run critic2 analysis on a folder with typical VASP output files.
+
         This method will:
 
         1. Look for files CHGCAR, AECAR0, AECAR2, POTCAR or their gzipped
@@ -275,7 +267,6 @@ class Critic2Caller:
         chgcar_ref = None
 
         if not zpsp:
-
             potcar_path = get_filepath(
                 "POTCAR",
                 "Could not find POTCAR, will not be able to calculate charge transfer.",
@@ -311,9 +302,7 @@ class Critic2Caller:
 
 
 class CriticalPointType(Enum):
-    """
-    Enum type for the different varieties of critical point.
-    """
+    """Enum type for the different varieties of critical point."""
 
     nucleus = "nucleus"  # (3, -3)
     bond = "bond"  # (3, -1)
@@ -330,7 +319,7 @@ def get_filepath(filename, warning, path, suffix):
         path: Path to search
         suffix: Suffixes to search.
     """
-    paths = glob.glob(os.path.join(path, filename + suffix + "*"))
+    paths = glob(os.path.join(path, filename + suffix + "*"))
     if not paths:
         warnings.warn(warning)
         return None
@@ -346,9 +335,7 @@ def get_filepath(filename, warning, path, suffix):
 
 
 class CriticalPoint(MSONable):
-    """
-    Access information about a critical point and the field values at that point.
-    """
+    """Access information about a critical point and the field values at that point."""
 
     def __init__(
         self,
@@ -391,9 +378,7 @@ class CriticalPoint(MSONable):
 
     @property
     def type(self):
-        """
-        Returns: Instance of CriticalPointType
-        """
+        """Returns: Instance of CriticalPointType."""
         return CriticalPointType(self._type)
 
     def __str__(self):
@@ -401,9 +386,7 @@ class CriticalPoint(MSONable):
 
     @property
     def laplacian(self):
-        """
-        Returns: The Laplacian of the field at the critical point
-        """
+        """Returns: The Laplacian of the field at the critical point."""
         return np.trace(self.field_hessian)
 
     @property
@@ -413,7 +396,7 @@ class CriticalPoint(MSONable):
         can be physically interpreted as e.g. degree
         of pi-bonding in organic molecules. Consult
         literature for more information.
-        Returns: The ellpiticity of the field at the critical point
+        Returns: The ellpiticity of the field at the critical point.
         """
         eig, _ = np.linalg.eig(self.field_hessian)
         eig.sort()
@@ -421,9 +404,7 @@ class CriticalPoint(MSONable):
 
 
 class Critic2Analysis(MSONable):
-    """
-    Class to process the standard output from critic2 into pymatgen-compatible objects.
-    """
+    """Class to process the standard output from critic2 into pymatgen-compatible objects."""
 
     def __init__(self, structure: Structure, stdout=None, stderr=None, cpreport=None, yt=None, zpsp=None):
         """
@@ -489,6 +470,7 @@ class Critic2Analysis(MSONable):
         """
         A StructureGraph object describing bonding information
         in the crystal.
+
         Args:
             include_critical_points: add DummySpecies for
             the critical points themselves, a list of
@@ -536,21 +518,20 @@ class Critic2Analysis(MSONable):
         for idx, edge in edges.items():
             unique_idx = self.nodes[idx]["unique_idx"]
             # only check edges representing bonds, not rings
-            if self.critical_points[unique_idx].type == CriticalPointType.bond:
-                if idx not in idx_to_delete:
-                    for idx2, edge2 in edges.items():
-                        if idx != idx2 and edge == edge2:
-                            idx_to_delete.append(idx2)
-                            warnings.warn(
-                                "Duplicate edge detected, try re-running "
-                                "critic2 with custom parameters to fix this. "
-                                "Mostly harmless unless user is also "
-                                "interested in rings/cages."
-                            )
-                            logger.debug(
-                                f"Duplicate edge between points {idx} (unique point {self.nodes[idx]['unique_idx']})"
-                                f"and {idx2} ({self.nodes[idx2]['unique_idx']})."
-                            )
+            if self.critical_points[unique_idx].type == CriticalPointType.bond and idx not in idx_to_delete:
+                for idx2, edge2 in edges.items():
+                    if idx != idx2 and edge == edge2:
+                        idx_to_delete.append(idx2)
+                        warnings.warn(
+                            "Duplicate edge detected, try re-running "
+                            "critic2 with custom parameters to fix this. "
+                            "Mostly harmless unless user is also "
+                            "interested in rings/cages."
+                        )
+                        logger.debug(
+                            f"Duplicate edge between points {idx} (unique point {self.nodes[idx]['unique_idx']})"
+                            f"and {idx2} ({self.nodes[idx2]['unique_idx']})."
+                        )
         # and remove any duplicate bonds present
         for idx in idx_to_delete:
             del edges[idx]
@@ -559,7 +540,6 @@ class Critic2Analysis(MSONable):
             unique_idx = self.nodes[idx]["unique_idx"]
             # only add edges representing bonds, not rings
             if self.critical_points[unique_idx].type == CriticalPointType.bond:
-
                 from_idx = edge["from_idx"]
                 to_idx = edge["to_idx"]
 
@@ -607,7 +587,7 @@ class Critic2Analysis(MSONable):
     def get_critical_point_for_site(self, n: int):
         """
         Args:
-            n (int): Site index
+            n (int): Site index.
 
         Returns: A CriticalPoint instance
         """
@@ -616,7 +596,7 @@ class Critic2Analysis(MSONable):
     def get_volume_and_charge_for_site(self, n):
         """
         Args:
-            n: Site index n
+            n: Site index n.
 
         Returns: A dict containing "volume" and "charge" keys,
         or None if YT integration not performed
@@ -708,9 +688,7 @@ class Critic2Analysis(MSONable):
 
     @staticmethod
     def _annotate_structure_with_yt(yt, structure: Structure, zpsp):
-
-        volume_idx = None
-        charge_idx = None
+        volume_idx = charge_idx = None
 
         for prop in yt["integration"]["properties"]:
             if prop["label"] == "Volume":
@@ -761,7 +739,6 @@ class Critic2Analysis(MSONable):
         return structure
 
     def _parse_stdout(self, stdout):
-
         warnings.warn(
             "Parsing critic2 standard output is deprecated and will not be maintained, "
             "please use the native JSON output in future."
@@ -791,27 +768,27 @@ class Critic2Analysis(MSONable):
         unique_critical_points = []
 
         # parse unique critical points
-        for i, line in enumerate(stdout):
+        for idx, line in enumerate(stdout):
             if "mult  name            f             |grad|           lap" in line:
-                start_i = i + 1
+                start_i = idx + 1
             elif "* Analysis of system bonds" in line:
-                end_i = i - 2
+                end_i = idx - 2
         # if start_i and end_i haven't been found, we
         # need to re-evaluate assumptions in this parser!
 
-        for i, line in enumerate(stdout):
-            if start_i <= i <= end_i:
-                l = line.replace("(", "").replace(")", "").split()
+        for idx, line in enumerate(stdout):
+            if start_i <= idx <= end_i:
+                split = line.replace("(", "").replace(")", "").split()
 
-                unique_idx = int(l[0]) - 1
-                point_group = l[1]
+                unique_idx = int(split[0]) - 1
+                point_group = split[1]
                 # type = l[2]  # type from definition of critical point e.g. (3, -3)
-                critical_point_type = l[3]  # type from name, e.g. nucleus
-                frac_coords = [float(l[4]), float(l[5]), float(l[6])]
-                multiplicity = float(l[7])
+                critical_point_type = split[3]  # type from name, e.g. nucleus
+                frac_coords = [float(split[4]), float(split[5]), float(split[6])]
+                multiplicity = float(split[7])
                 # name = float(l[8])
-                field = float(l[9])
-                field_gradient = float(l[10])
+                field = float(split[9])
+                field_gradient = float(split[10])
                 # laplacian = float(l[11])
 
                 point = CriticalPoint(
@@ -825,13 +802,13 @@ class Critic2Analysis(MSONable):
                 )
                 unique_critical_points.append(point)
 
-        for i, line in enumerate(stdout):
+        for idx, line in enumerate(stdout):
             if "+ Critical point no." in line:
                 unique_idx = int(line.split()[4]) - 1
             elif "Hessian:" in line:
-                l1 = list(map(float, stdout[i + 1].split()))
-                l2 = list(map(float, stdout[i + 2].split()))
-                l3 = list(map(float, stdout[i + 3].split()))
+                l1 = list(map(float, stdout[idx + 1].split()))
+                l2 = list(map(float, stdout[idx + 2].split()))
+                l3 = list(map(float, stdout[idx + 3].split()))
                 hessian = [
                     [l1[0], l1[1], l1[2]],
                     [l2[0], l2[1], l2[2]],
@@ -842,33 +819,32 @@ class Critic2Analysis(MSONable):
         self.critical_points = unique_critical_points
 
         # parse graph connecting critical points
-        for i, line in enumerate(stdout):
+        for idx, line in enumerate(stdout):
             if "#cp  ncp   typ        position " in line:
-                start_i = i + 1
+                start_i = idx + 1
             elif "* Attractor connectivity matrix" in line:
-                end_i = i - 2
+                end_i = idx - 2
         # if start_i and end_i haven't been found, we
         # need to re-evaluate assumptions in this parser!
 
-        for i, line in enumerate(stdout):
-            if start_i <= i <= end_i:
+        for idx, line in enumerate(stdout):
+            if start_i <= idx <= end_i:
+                split = line.replace("(", "").replace(")", "").split()
 
-                l = line.replace("(", "").replace(")", "").split()
-
-                idx = int(l[0]) - 1
-                unique_idx = int(l[1]) - 1
-                frac_coords = [float(l[3]), float(l[4]), float(l[5])]
+                idx = int(split[0]) - 1
+                unique_idx = int(split[1]) - 1
+                frac_coords = [float(split[3]), float(split[4]), float(split[5])]
 
                 self._add_node(idx, unique_idx, frac_coords)
-                if len(l) > 6:
-                    from_idx = int(l[6]) - 1
-                    to_idx = int(l[10]) - 1
+                if len(split) > 6:
+                    from_idx = int(split[6]) - 1
+                    to_idx = int(split[10]) - 1
                     self._add_edge(
                         idx,
                         from_idx=from_idx,
-                        from_lvec=(int(l[7]), int(l[8]), int(l[9])),
+                        from_lvec=(int(split[7]), int(split[8]), int(split[9])),
                         to_idx=to_idx,
-                        to_lvec=(int(l[11]), int(l[12]), int(l[13])),
+                        to_lvec=(int(split[11]), int(split[12]), int(split[13])),
                     )
 
     def _add_node(self, idx, unique_idx, frac_coords):
