@@ -1,19 +1,10 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 Interface with command line GULP.
 http://projects.ivec.org
 WARNING: you need to have GULP installed on your system.
 """
 
-__author__ = "Bharat Medasani, Wenhao Sun"
-__copyright__ = "Copyright 2013, The Materials Project"
-__version__ = "1.0"
-__maintainer__ = "Bharat Medasani"
-__email__ = "bkmedasani@lbl.gov,wenhao@mit.edu"
-__status__ = "Production"
-__date__ = "$Jun 22, 2013M$"
+from __future__ import annotations
 
 import os
 import re
@@ -27,6 +18,14 @@ from pymatgen.core.periodic_table import Element
 from pymatgen.core.structure import Structure
 from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
 
+__author__ = "Bharat Medasani, Wenhao Sun"
+__copyright__ = "Copyright 2013, The Materials Project"
+__version__ = "1.0"
+__maintainer__ = "Bharat Medasani"
+__email__ = "bkmedasani@lbl.gov,wenhao@mit.edu"
+__status__ = "Production"
+__date__ = "Jun 22, 2013M"
+
 _anions = set(map(Element, ["O", "S", "F", "Cl", "Br", "N", "P"]))
 _cations = set(
     map(
@@ -180,7 +179,7 @@ _gulp_kw = {
     "nomolecularinternalke",
     "voight",
     "zsisa",
-    # Optimisation method
+    # Optimization method
     "conjugate",
     "dfp",
     "lbfgs",
@@ -205,7 +204,6 @@ _gulp_kw = {
     "meanke",
     "nodensity_out",
     "nodpsym",
-    "nofirst_point",
     "nofrequency",
     "nokpoints",
     "operators",
@@ -218,8 +216,6 @@ _gulp_kw = {
     "save",
     "terse",
     # Structure control
-    "full",
-    "hexagonal",
     "lower_symmetry",
     "nosymmetry",
     # PDF control
@@ -238,9 +234,7 @@ _gulp_kw = {
 
 
 class GulpIO:
-    """
-    To generate GULP input and process output
-    """
+    """To generate GULP input and process output."""
 
     @staticmethod
     def keyword_line(*args):
@@ -272,7 +266,7 @@ class GulpIO:
         Args:
             structure: pymatgen Structure object
             cell_flg (default = True): Option to use lattice parameters.
-            fractional_flg (default = True): If True, fractional coordinates
+            frac_flg (default = True): If True, fractional coordinates
                 are used. Else, Cartesian coordinates in Angstroms are used.
                 ******
                 GULP convention is to use fractional coordinates for periodic
@@ -300,12 +294,12 @@ class GulpIO:
 
         if frac_flg:
             gin += "frac\n"
-            coord_attr = "frac_coords"
+            coords_key = "frac_coords"
         else:
             gin += "cart\n"
-            coord_attr = "coords"
-        for site in structure.sites:
-            coord = [str(i) for i in getattr(site, coord_attr)]
+            coords_key = "coords"
+        for site in structure:
+            coord = [str(i) for i in getattr(site, coords_key)]
             specie = site.specie
             core_site_desc = specie.symbol + " core " + " ".join(coord) + "\n"
             gin += core_site_desc
@@ -437,9 +431,7 @@ class GulpIO:
         for key in val_dict:
             use_bush = True
             el = re.sub(r"[1-9,+,\-]", "", key)
-            if el not in bpb.species_dict:
-                use_bush = False
-            elif val_dict[key] != bpb.species_dict[el]["oxi"]:
+            if el not in bpb.species_dict or val_dict[key] != bpb.species_dict[el]["oxi"]:
                 use_bush = False
             if use_bush:
                 gin += "species \n"
@@ -475,7 +467,7 @@ class GulpIO:
 
     def tersoff_input(self, structure: Structure, periodic=False, uc=True, *keywords):
         """
-        Gets a GULP input with Tersoff potential for an oxide structure
+        Gets a GULP input with Tersoff potential for an oxide structure.
 
         Args:
             structure: pymatgen.core.structure.Structure
@@ -501,7 +493,7 @@ class GulpIO:
     @staticmethod
     def tersoff_potential(structure):
         """
-        Generate the species, tersoff potential lines for an oxide structure
+        Generate the species, tersoff potential lines for an oxide structure.
 
         Args:
             structure: pymatgen.core.structure.Structure
@@ -533,29 +525,27 @@ class GulpIO:
         return gin
 
     @staticmethod
-    def get_energy(gout):
+    def get_energy(gout: str):
         """
         Args:
-            gout ():
+            gout (str): GULP output string.
 
         Returns:
             Energy
         """
         energy = None
         for line in gout.split("\n"):
-            if "Total lattice energy" in line and "eV" in line:
-                energy = line.split()
-            elif "Non-primitive unit cell" in line and "eV" in line:
+            if "Total lattice energy" in line and "eV" in line or "Non-primitive unit cell" in line and "eV" in line:
                 energy = line.split()
         if energy:
             return float(energy[4])
         raise GulpError("Energy not found in Gulp output")
 
     @staticmethod
-    def get_relaxed_structure(gout):
+    def get_relaxed_structure(gout: str):
         """
         Args:
-            gout ():
+            gout (str): GULP output string.
 
         Returns:
             (Structure) relaxed structure.
@@ -627,7 +617,7 @@ class GulpIO:
                 fields = line.split()
                 if fields[2] == "c":
                     sp.append(fields[1])
-                    coords.append(list(float(x) for x in fields[3:6]))
+                    coords.append([float(x) for x in fields[3:6]])
         else:
             raise OSError("No structure found")
 
@@ -644,19 +634,17 @@ class GulpIO:
 
 
 class GulpCaller:
-    """
-    Class to run gulp from commandline
-    """
+    """Class to run gulp from commandline."""
 
     def __init__(self, cmd="gulp"):
         """
-        Initialize with the executable if not in the standard path
+        Initialize with the executable if not in the standard path.
 
         Args:
             cmd: Command. Defaults to gulp.
         """
 
-        def is_exe(f):
+        def is_exe(f) -> bool:
             return os.path.isfile(f) and os.access(f, os.X_OK)
 
         fpath, fname = os.path.split(cmd)
@@ -675,7 +663,7 @@ class GulpCaller:
 
     def run(self, gin):
         """
-        Run GULP using the gin as input
+        Run GULP using the gin as input.
 
         Args:
             gin: GULP input string
@@ -690,7 +678,6 @@ class GulpCaller:
                 stdin=subprocess.PIPE,
                 stderr=subprocess.PIPE,
             ) as p:
-
                 out, err = p.communicate(bytearray(gin, "utf-8"))
             out = out.decode("utf-8")
             err = err.decode("utf-8")
@@ -709,10 +696,10 @@ class GulpCaller:
             if "ERROR" in out:
                 raise GulpError(out)
 
-            # Sometimes optimisation may fail to reach convergence
+            # Sometimes optimization may fail to reach convergence
             conv_err_string = "Conditions for a minimum have not been satisfied"
             if conv_err_string in out:
-                raise GulpConvergenceError()
+                raise GulpConvergenceError(out)
 
             gout = ""
             for line in out.split("\n"):
@@ -776,13 +763,13 @@ def get_energy_relax_structure_buckingham(structure, gulp_cmd="gulp", keywords=(
 class GulpError(Exception):
     """
     Exception class for GULP.
-    Raised when the GULP gives an error
+    Raised when the GULP gives an error.
     """
 
     def __init__(self, msg):
         """
         Args:
-            msg (str): Message
+            msg (str): Message.
         """
         self.msg = msg
 
@@ -794,13 +781,13 @@ class GulpConvergenceError(Exception):
     """
     Exception class for GULP.
     Raised when proper convergence is not reached in Mott-Littleton
-    defect energy optimisation procedure in GULP
+    defect energy optimization procedure in GULP.
     """
 
     def __init__(self, msg=""):
         """
         Args:
-            msg (str): Message
+            msg (str): Message.
         """
         self.msg = msg
 
@@ -889,14 +876,10 @@ class BuckinghamPotential:
 
 
 class TersoffPotential:
-    """
-    Generate Tersoff Potential Table from "OxideTersoffPotentialentials" file
-    """
+    """Generate Tersoff Potential Table from "OxideTersoffPotentialentials" file."""
 
     def __init__(self):
-        """
-        Init TersoffPotential
-        """
+        """Init TersoffPotential."""
         module_dir = os.path.dirname(os.path.abspath(__file__))
         with open(os.path.join(module_dir, "OxideTersoffPotentials")) as f:
             data = {}
