@@ -1,6 +1,6 @@
 """
 Module to call mcsqs, distributed with AT-AT
-https://www.brown.edu/Departments/Engineering/Labs/avdw/atat/
+https://www.brown.edu/Departments/Engineering/Labs/avdw/atat/.
 """
 
 from __future__ import annotations
@@ -67,13 +67,12 @@ def run_mcsqs(
             function (default = 1)
         wn (int or float): Multiplicative decrease in weight per additional point in cluster (default: 1)
         wd (int or float): Exponent of decay in weight as function of cluster diameter (default: 0.5)
-        tol (int or float): Tolerance for matching correlations (default: 1e-3)
+        tol (int or float): Tolerance for matching correlations (default: 1e-3).
 
     Returns:
         Tuple of Pymatgen structure SQS of the input structure, the mcsqs objective function,
             list of all SQS structures, and the directory where calculations are run
     """
-
     num_atoms = len(structure)
 
     if structure.is_ordered:
@@ -89,13 +88,11 @@ def run_mcsqs(
     os.chdir(directory)
 
     if isinstance(scaling, (int, float)):
-
         if scaling % 1:
             raise ValueError(f"Scaling should be an integer, not {scaling}")
         mcsqs_find_sqs_cmd = ["mcsqs", f"-n {scaling * num_atoms}"]
 
     else:
-
         # Set supercell to identity (will make supercell with pymatgen)
         with open("sqscell.out", "w") as f:
             f.write("1\n1 0 0\n0 1 0\n0 0 1\n")
@@ -156,7 +153,6 @@ def run_mcsqs(
 
         # Find the best sqs structures
         if instances and instances > 1:
-
             if not os.path.exists("bestcorr1.out"):
                 raise RuntimeError(
                     "mcsqs did not generate output files, "
@@ -178,13 +174,12 @@ def _parse_sqs_path(path) -> Sqs:
     """
     Private function to parse mcsqs output directory
     Args:
-        path: directory to perform parsing
+        path: directory to perform parsing.
 
     Returns:
         Tuple of Pymatgen structure SQS of the input structure, the mcsqs objective function,
             list of all SQS structures, and the directory where calculations are run
     """
-
     path = Path(path)
 
     # detected instances will be 0 if mcsqs was run in series, or number of instances
@@ -204,10 +199,7 @@ def _parse_sqs_path(path) -> Sqs:
 
     objective_function_str = lines[-1].split("=")[-1].strip()
     objective_function: float | str
-    if objective_function_str != "Perfect_match":
-        objective_function = float(objective_function_str)
-    else:
-        objective_function = "Perfect_match"
+    objective_function = float(objective_function_str) if objective_function_str != "Perfect_match" else "Perfect_match"
 
     # Get all SQS structures and objective functions
     allsqs = []
@@ -226,10 +218,7 @@ def _parse_sqs_path(path) -> Sqs:
 
         objective_function_str = lines[-1].split("=")[-1].strip()
         obj: float | str
-        if objective_function_str != "Perfect_match":
-            obj = float(objective_function_str)
-        else:
-            obj = "Perfect_match"
+        obj = float(objective_function_str) if objective_function_str != "Perfect_match" else "Perfect_match"
         allsqs.append({"structure": sqs, "objective_function": obj})
 
     clusters = _parse_clusters(path / "clusters.out")
@@ -247,12 +236,11 @@ def _parse_clusters(filename):
     """
     Private function to parse clusters.out file
     Args:
-        path: directory to perform parsing
+        path: directory to perform parsing.
 
     Returns:
         List of dicts
     """
-
     with open(filename) as f:
         lines = f.readlines()
 
