@@ -1,6 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module implements a Composition class to represent compositions,
 and a ChemicalPotential class to represent potentials.
@@ -96,27 +93,27 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
         Very flexible Composition construction, similar to the built-in Python
         dict(). Also extended to allow simple string init.
 
+        Takes any inputs supported by the Python built-in dict function.
+
+        1. A dict of either {Element/Species: amount},
+
+            {string symbol:amount}, or {atomic number:amount} or any mixture
+            of these. E.g., {Element("Li"): 2, Element("O"): 1},
+            {"Li":2, "O":1}, {3: 2, 8: 1} all result in a Li2O composition.
+        2. Keyword arg initialization, similar to a dict, e.g.,
+
+            Composition(Li = 2, O = 1)
+
+        In addition, the Composition constructor also allows a single
+        string as an input formula. E.g., Composition("Li2O").
+
         Args:
-            Any form supported by the Python built-in {} function.
-
-            1. A dict of either {Element/Species: amount},
-
-               {string symbol:amount}, or {atomic number:amount} or any mixture
-               of these. E.g., {Element("Li"):2 ,Element("O"):1},
-               {"Li":2, "O":1}, {3:2, 8:1} all result in a Li2O composition.
-            2. Keyword arg initialization, similar to a dict, e.g.,
-
-               Composition(Li = 2, O = 1)
-
-            In addition, the Composition constructor also allows a single
-            string as an input formula. E.g., Composition("Li2O").
-
-            strict: Only allow valid Elements and Species in the Composition.
-
-            allow_negative: Whether to allow negative compositions. This
-                argument must be popped from the **kwargs due to *args
-                ambiguity.
+            *args: Any number of 2-tuples as key-value pairs.
+            strict (bool): Only allow valid Elements and Species in the Composition. Defaults to False.
+            allow_negative (bool): Whether to allow negative compositions. Defaults to False.
+            **kwargs: Additional kwargs supported by the dict() constructor.
         """
+        # allow_negative must be popped from **kwargs due to *args ambiguity
         self.allow_negative = kwargs.pop("allow_negative", False)
         # it's much faster to recognize a composition and use the el_map than
         # to pass the composition to {}
@@ -128,22 +125,22 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
             elem_map = dict(*args, **kwargs)  # type: ignore
         elem_amt = {}
         self._natoms = 0
-        for k, v in elem_map.items():
-            if v < -Composition.amount_tolerance and not self.allow_negative:
+        for key, val in elem_map.items():
+            if val < -Composition.amount_tolerance and not self.allow_negative:
                 raise ValueError("Amounts in Composition cannot be negative!")
-            if abs(v) >= Composition.amount_tolerance:
-                elem_amt[get_el_sp(k)] = v
-                self._natoms += abs(v)
+            if abs(val) >= Composition.amount_tolerance:
+                elem_amt[get_el_sp(key)] = val
+                self._natoms += abs(val)
         self._data = elem_amt
         if strict and not self.valid:
             raise ValueError(f"Composition is not valid, contains: {', '.join(map(str, self.elements))}")
 
-    def __getitem__(self, item: SpeciesLike) -> float:
+    def __getitem__(self, key: SpeciesLike) -> float:
         try:
-            sp = get_el_sp(item)
+            sp = get_el_sp(key)
             return self._data.get(sp, 0)
-        except ValueError as ex:
-            raise TypeError(f"Invalid key {item}, {type(item)} for Composition\nValueError exception:\n{ex}")
+        except ValueError as exc:
+            raise KeyError(f"Invalid {key=}") from exc
 
     def __len__(self) -> int:
         return len(self._data)
@@ -222,7 +219,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
     def __mul__(self, other: object) -> Composition:
         """
         Multiply a Composition by an integer or a float.
-        Fe2O3 * 4 -> Fe8O12
+        Fe2O3 * 4 -> Fe8O12.
         """
         if not isinstance(other, (int, float)):
             return NotImplemented
@@ -238,23 +235,17 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
     __div__ = __truediv__
 
     def __hash__(self) -> int:
-        """
-        Hash based on the chemical system
-        """
+        """Hash based on the chemical system."""
         return hash(frozenset(self._data))
 
     @property
     def average_electroneg(self) -> float:
-        """
-        :return: Average electronegativity of the composition.
-        """
+        """:return: Average electronegativity of the composition."""
         return sum((el.X * abs(amt) for el, amt in self.items())) / self.num_atoms
 
     @property
     def total_electrons(self) -> float:
-        """
-        :return: Total number of electrons in composition.
-        """
+        """:return: Total number of electrons in composition."""
         return sum((el.Z * abs(amt) for el, amt in self.items()))
 
     def almost_equals(self, other: Composition, rtol: float = 0.1, atol: float = 1e-8) -> bool:
@@ -277,15 +268,11 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
 
     @property
     def is_element(self) -> bool:
-        """
-        True if composition is an element.
-        """
+        """True if composition is an element."""
         return len(self) == 1
 
     def copy(self) -> Composition:
-        """
-        :return: A copy of the composition.
-        """
+        """:return: A copy of the composition."""
         return Composition(self, allow_negative=self.allow_negative)
 
     @property
@@ -296,7 +283,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
         """
         sym_amt = self.get_el_amt_dict()
         syms = sorted(sym_amt, key=lambda sym: get_el_sp(sym).X)
-        formula = [s + formula_double_format(sym_amt[s], False) for s in syms]
+        formula = [f"{s}{formula_double_format(sym_amt[s], False)}" for s in syms]
         return " ".join(formula)
 
     @property
@@ -305,7 +292,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
         Returns a formula string, with elements sorted by alphabetically
         e.g., Fe4 Li4 O16 P4.
         """
-        return " ".join(sorted(self.formula.split(" ")))
+        return " ".join(sorted(self.formula.split()))
 
     @property
     def iupac_formula(self) -> str:
@@ -316,11 +303,11 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
         effectively follows the groups and rows of the periodic table, except
         the Lanthanides, Actinides and hydrogen. Polyanions are still determined
         based on the true electronegativity of the elements.
-        e.g. CH2(SO4)2
+        e.g. CH2(SO4)2.
         """
         sym_amt = self.get_el_amt_dict()
         syms = sorted(sym_amt, key=lambda s: get_el_sp(s).iupac_ordering)
-        formula = [s + formula_double_format(sym_amt[s], False) for s in syms]
+        formula = [f"{s}{formula_double_format(sym_amt[s], False)}" for s in syms]
         return " ".join(formula)
 
     @property
@@ -415,7 +402,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
         g = gcd_float(list(el_amt.values()), 1 / max_denominator)
 
         d = {k: round(v / g) for k, v in el_amt.items()}
-        (formula, factor) = reduce_formula(d, iupac_ordering=iupac_ordering)
+        formula, factor = reduce_formula(d, iupac_ordering=iupac_ordering)
         if formula in Composition.special_formulas:
             formula = Composition.special_formulas[formula]
             factor /= 2
@@ -443,21 +430,25 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
         """
         c = self.element_composition
         elements = sorted(el.symbol for el in c)
+        hill_elements = []
         if "C" in elements:
-            elements = ["C"] + [el for el in elements if el != "C"]
+            hill_elements.append("C")
+            elements.remove("C")
+            if "H" in elements:
+                hill_elements.append("H")
+                elements.remove("H")
+        hill_elements += elements
 
-        formula = [f"{el}{formula_double_format(c[el]) if c[el] != 1 else ''}" for el in elements]
+        formula = [f"{el}{formula_double_format(c[el]) if c[el] != 1 else ''}" for el in hill_elements]
         return " ".join(formula)
 
     @property
     def elements(self) -> list[Element | Species | DummySpecies]:
-        """
-        Returns view of elements in Composition.
-        """
+        """Returns view of elements in Composition."""
         return list(self)
 
     def __str__(self):
-        return " ".join([f"{k}{formula_double_format(v, ignore_ones=False)}" for k, v in self.as_dict().items()])
+        return " ".join(f"{k}{formula_double_format(v, ignore_ones=False)}" for k, v in self.as_dict().items())
 
     def to_pretty_string(self) -> str:
         """
@@ -470,15 +461,13 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
     def num_atoms(self) -> float:
         """
         Total number of atoms in Composition. For negative amounts, sum
-        of absolute values
+        of absolute values.
         """
         return self._natoms
 
     @property
     def weight(self) -> float:
-        """
-        Total molecular weight of Composition
-        """
+        """Total molecular weight of Composition."""
         return Mass(sum(amount * el.atomic_mass for el, amount in self.items()), "amu")
 
     def get_atomic_fraction(self, el: SpeciesLike) -> float:
@@ -549,7 +538,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
     def _parse_formula(self, formula: str) -> dict[str, float]:
         """
         Args:
-            formula (str): A string formula, e.g. Fe2O3, Li3Fe2(PO4)3
+            formula (str): A string formula, e.g. Fe2O3, Li3Fe2(PO4)3.
 
         Returns:
             Composition with that formula.
@@ -580,7 +569,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
             if m.group(2) != "":
                 factor = float(m.group(2))
             unit_sym_dict = get_sym_dict(m.group(1), factor)
-            expanded_sym = "".join([f"{el}{amt}" for el, amt in unit_sym_dict.items()])
+            expanded_sym = "".join(f"{el}{amt}" for el, amt in unit_sym_dict.items())
             expanded_formula = formula.replace(m.group(), expanded_sym)
             return self._parse_formula(expanded_formula)
         return get_sym_dict(formula, 1)
@@ -643,11 +632,30 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
         """
         return cls(d)
 
+    @classmethod
+    def from_weight_dict(cls, weight_dict) -> Composition:
+        """
+        Creates a Composition based on a dict of atomic fractions calculated
+        from a dict of weight fractions. Allows for quick creation of the class
+        from weight-based notations commonly used in the industry, such as
+        Ti6V4Al and Ni60Ti40.
+
+        Args:
+            weight_dict (dict): {symbol: weight_fraction} dict.
+
+        Returns:
+            Composition
+        """
+        weight_sum = sum(val / Element(el).atomic_mass for el, val in weight_dict.items())
+        comp_dict = {el: val / Element(el).atomic_mass / weight_sum for el, val in weight_dict.items()}
+
+        return cls(comp_dict)
+
     def get_el_amt_dict(self) -> dict[str, float]:
         """
         Returns:
             dict[str, float]: element symbol and (unreduced) amount. E.g.
-            {"Fe": 4.0, "O":6.0} or {"Fe3+": 4.0, "O2-":6.0}
+                {"Fe": 4.0, "O":6.0} or {"Fe3+": 4.0, "O2-":6.0}.
         """
         dic: dict[str, float] = collections.defaultdict(float)
         for el, amt in self.items():
@@ -656,23 +664,32 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
 
     def as_dict(self) -> dict[str, float]:
         """
+        Note: Subtly different from get_el_amt_dict in that they keys here are str(Element) instead of Element.symbol.
+
         Returns:
-            dict with species symbol and (unreduced) amount e.g.,
-            {"Fe": 4.0, "O":6.0} or {"Fe3+": 4.0, "O2-":6.0}
+            dict[str, float]: element symbol and (unreduced) amount. E.g.
+                {"Fe": 4.0, "O":6.0} or {"Fe3+": 4.0, "O2-":6.0}
         """
-        d: dict[str, float] = collections.defaultdict(float)
-        for e, a in self.items():
-            d[str(e)] += a
-        return d
+        dic: dict[str, float] = collections.defaultdict(float)
+        for el, amt in self.items():
+            dic[str(el)] += amt
+        return dic
 
     @property
-    def to_reduced_dict(self) -> dict:
+    def to_reduced_dict(self) -> dict[str, float]:
         """
         Returns:
-            Dict with element symbol and reduced amount e.g.,
-            {"Fe": 2.0, "O":3.0}
+            dict[str, float]: element symbols mapped to reduced amount e.g. {"Fe": 2.0, "O":3.0}.
         """
-        return self.get_reduced_composition_and_factor()[0].as_dict()
+        return self.reduced_composition.as_dict()
+
+    @property
+    def to_weight_dict(self) -> dict[str, float]:
+        """
+        Returns:
+            dict[str, float] with weight fraction of each component {"Ti": 0.90, "V": 0.06, "Al": 0.04}.
+        """
+        return {str(el): self.get_wt_fraction(el) for el in self.elements}
 
     @property
     def to_data_dict(self) -> dict:
@@ -683,19 +700,19 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
             reduced_cell_formula, elements and nelements.
         """
         return {
-            "reduced_cell_composition": self.get_reduced_composition_and_factor()[0],
+            "reduced_cell_composition": self.reduced_composition,
             "unit_cell_composition": self.as_dict(),
             "reduced_cell_formula": self.reduced_formula,
-            "elements": list(self.as_dict()),
-            "nelements": len(self.as_dict()),
+            "elements": list(map(str, self)),
+            "nelements": len(self),
         }
 
     def oxi_state_guesses(
         self,
-        oxi_states_override: dict = None,
+        oxi_states_override: dict | None = None,
         target_charge: float = 0,
         all_oxi_states: bool = False,
-        max_sites: int = None,
+        max_sites: int | None = None,
     ) -> list[dict[str, float]]:
         """
         Checks if the composition is charge-balanced and returns back all
@@ -757,7 +774,6 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
         new_comp = {elem: amount for elem, amount in self.as_dict().items() if elem not in elem_map}
 
         for old_elem, new_elem in elem_map.items():
-
             amount = self[old_elem]
 
             # build a dictionary of substitutions to be made
@@ -786,10 +802,10 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
 
     def add_charges_from_oxi_state_guesses(
         self,
-        oxi_states_override: dict = None,
+        oxi_states_override: dict | None = None,
         target_charge: float = 0,
         all_oxi_states: bool = False,
-        max_sites: int = None,
+        max_sites: int | None = None,
     ) -> Composition:
         """
         Assign oxidation states based on guessed oxidation states.
@@ -932,7 +948,6 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
             # get all possible combinations of oxidation states
             # and sum each combination
             for oxid_combo in combinations_with_replacement(oxids, int(el_amt[el])):
-
                 # List this sum as a possible option
                 oxid_sum = sum(oxid_combo)
                 if oxid_sum not in el_sums[idx]:
@@ -991,7 +1006,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
         """
         Takes in a formula where capitalization might not be correctly entered,
         and suggests a ranked list of potential Composition matches.
-        Author: Anubhav Jain
+        Author: Anubhav Jain.
 
         Args:
             fuzzy_formula (str): A formula string, such as "co2o3" or "MN",
@@ -1026,14 +1041,14 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
     @staticmethod
     def _comps_from_fuzzy_formula(
         fuzzy_formula: str,
-        m_dict: dict[str, float] = None,
+        m_dict: dict[str, float] | None = None,
         m_points: int = 0,
         factor: int | float = 1,
     ) -> Generator[tuple[Composition, int], None, None]:
         """
         A recursive helper method for formula parsing that helps in
         interpreting and ranking indeterminate formulas.
-        Author: Anubhav Jain
+        Author: Anubhav Jain.
 
         Args:
             fuzzy_formula (str): A formula string, such as "co2o3" or "MN",
@@ -1055,7 +1070,7 @@ class Composition(collections.abc.Hashable, collections.abc.Mapping, MSONable, S
             """
             A helper method for formula parsing that helps in interpreting and
             ranking indeterminate formulas
-            Author: Anubhav Jain
+            Author: Anubhav Jain.
 
             Args:
                 m: A regex match, with the first group being the element and
@@ -1208,13 +1223,12 @@ def reduce_formula(sym_amt, iupac_ordering: bool = False) -> tuple[str, float]:
         syms = sorted(syms, key=lambda x: [get_el_sp(x).iupac_ordering, x])
 
     reduced_form = []
-    for s in syms:
-        normamt = sym_amt[s] * 1.0 / factor
-        reduced_form.append(s)
-        reduced_form.append(formula_double_format(normamt))
+    for sym in syms:
+        norm_amt = sym_amt[sym] * 1.0 / factor
+        reduced_form.append(sym)
+        reduced_form.append(str(formula_double_format(norm_amt)))
 
-    reduced_form = "".join(reduced_form + polyanion)  # type: ignore
-    return reduced_form, factor  # type: ignore
+    return "".join([*reduced_form, *polyanion]), factor
 
 
 class ChemicalPotential(dict, MSONable):
@@ -1226,11 +1240,12 @@ class ChemicalPotential(dict, MSONable):
     def __init__(self, *args, **kwargs):
         """
         Args:
-            *args, **kwargs: any valid dict init arguments
+            *args: any valid dict init arguments
+            **kwargs: any valid dict init arguments.
         """
-        d = dict(*args, **kwargs)
-        super().__init__((get_el_sp(k), v) for k, v in d.items())
-        if len(d) != len(self):
+        dct = dict(*args, **kwargs)
+        super().__init__((get_el_sp(k), v) for k, v in dct.items())
+        if len(dct) != len(self):
             raise ValueError("Duplicate potential specified")
 
     def __mul__(self, other: object) -> ChemicalPotential:
@@ -1249,13 +1264,13 @@ class ChemicalPotential(dict, MSONable):
 
     def __sub__(self, other: object) -> ChemicalPotential:
         if isinstance(other, ChemicalPotential):
-            els = set(self).union(other)
+            els = {*self} | {*other}
             return ChemicalPotential({e: self.get(e, 0) - other.get(e, 0) for e in els})
         return NotImplemented
 
     def __add__(self, other: object) -> ChemicalPotential:
         if isinstance(other, ChemicalPotential):
-            els = set(self).union(other)
+            els = {*self} | {*other}
             return ChemicalPotential({e: self.get(e, 0) + other.get(e, 0) for e in els})
         return NotImplemented
 
@@ -1277,7 +1292,7 @@ class ChemicalPotential(dict, MSONable):
 
 
 class CompositionError(Exception):
-    """Exception class for composition errors"""
+    """Exception class for composition errors."""
 
 
 if __name__ == "__main__":
