@@ -1,10 +1,7 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module provides a base class for tensor-like objects and methods for
 basic tensor manipulation. It also provides a class, SquareTensor,
-that provides basic methods for creating and manipulating rank 2 tensors
+that provides basic methods for creating and manipulating rank 2 tensors.
 """
 
 from __future__ import annotations
@@ -14,7 +11,7 @@ import itertools
 import os
 import string
 import warnings
-from typing import Sequence
+from typing import TYPE_CHECKING, Sequence
 
 import numpy as np
 from monty.json import MSONable
@@ -24,9 +21,11 @@ from scipy.linalg import polar
 from pymatgen.analysis.structure_matcher import StructureMatcher
 from pymatgen.core.lattice import Lattice
 from pymatgen.core.operations import SymmOp
-from pymatgen.core.structure import Structure
 from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
 
+if TYPE_CHECKING:
+    from pymatgen.core import Structure
+
 __author__ = "Joseph Montoya"
 __credits__ = "Maarten de Jong, Shyam Dwaraknath, Wei Chen, Mark Asta, Anubhav Jain, Terence Lew"
 
@@ -40,7 +39,7 @@ DEFAULT_QUAD = loadfn(os.path.join(os.path.dirname(__file__), "quad_data.json"))
 class Tensor(np.ndarray, MSONable):
     """
     Base class for doing useful general operations on Nth order tensors,
-    without restrictions on the type (stress, elastic, strain, piezo, etc.)
+    without restrictions on the type (stress, elastic, strain, piezo, etc.).
     """
 
     symbol = "T"
@@ -70,13 +69,11 @@ class Tensor(np.ndarray, MSONable):
         if vscale is not None:
             obj._vscale = vscale
         if obj._vscale.shape != vshape:
-            raise ValueError("Voigt scaling matrix must be the shape of the voigt notation matrix or vector.")
+            raise ValueError("Voigt scaling matrix must be the shape of the Voigt notation matrix or vector.")
         if not all(i == 3 for i in obj.shape):
             raise ValueError(
-                "Pymatgen only supports 3-dimensional tensors, "
-                "and default tensor constructor uses standard "
-                "notation. To construct from voigt notation, use"
-                f" {type(obj).__name__}.from_voigt"
+                "Pymatgen only supports 3-dimensional tensors, and default tensor constructor uses standard "
+                f"notation. To construct from Voigt notation, use {type(obj).__name__}.from_voigt"
             )
         return obj
 
@@ -90,25 +87,21 @@ class Tensor(np.ndarray, MSONable):
     def __array_wrap__(self, obj):
         """
         Overrides __array_wrap__ methods in ndarray superclass to avoid errors
-        associated with functions that return scalar values
+        associated with functions that return scalar values.
         """
         if len(obj.shape) == 0:
             return obj[()]
         return np.ndarray.__array_wrap__(self, obj)
 
     def __hash__(self):
-        """
-        Define a hash function, since numpy arrays have their own __eq__ method
-        """
+        """Define a hash function, since numpy arrays have their own __eq__ method."""
         return hash(self.tostring())
 
     def __repr__(self):
         return f"{type(self).__name__}({self})"
 
     def zeroed(self, tol: float = 1e-3):
-        """
-        Returns the matrix with all entries below a certain threshold (i.e. tol) set to zero.
-        """
+        """Returns the matrix with all entries below a certain threshold (i.e. tol) set to zero."""
         new_tensor = self.copy()
         new_tensor[abs(new_tensor) < tol] = 0
         return new_tensor
@@ -138,9 +131,7 @@ class Tensor(np.ndarray, MSONable):
         return self.transform(sop)
 
     def einsum_sequence(self, other_arrays, einsum_string=None):
-        """
-        Calculates the result of an einstein summation expression
-        """
+        """Calculates the result of an einstein summation expression."""
         if not isinstance(other_arrays, list):
             raise ValueError("other tensors must be list of tensors or tensor input")
 
@@ -154,7 +145,7 @@ class Tensor(np.ndarray, MSONable):
                 einsum_string += "," + lc[idx : idx + length]
                 idx += length
 
-        einsum_args = [self] + list(other_arrays)
+        einsum_args = [self, *other_arrays]
         return np.einsum(einsum_string, *einsum_args)
 
     def project(self, n):
@@ -192,7 +183,7 @@ class Tensor(np.ndarray, MSONable):
 
     def get_grouped_indices(self, voigt=False, **kwargs):
         """
-        Gets index sets for equivalent tensor values
+        Gets index sets for equivalent tensor values.
 
         Args:
             voigt (bool): whether to get grouped indices
@@ -211,10 +202,7 @@ class Tensor(np.ndarray, MSONable):
             list of index groups where tensor values are equivalent to
             within tolerances
         """
-        if voigt:
-            array = self.voigt
-        else:
-            array = self
+        array = self.voigt if voigt else self
 
         indices = list(itertools.product(*(range(n) for n in array.shape)))
         remaining = indices.copy()
@@ -231,7 +219,7 @@ class Tensor(np.ndarray, MSONable):
 
     def get_symbol_dict(self, voigt=True, zero_index=False, **kwargs):
         """
-        Creates a summary dict for tensor with associated symbol
+        Creates a summary dict for tensor with associated symbol.
 
         Args:
             voigt (bool): whether to get symbol dict for voigt
@@ -253,28 +241,22 @@ class Tensor(np.ndarray, MSONable):
             list of index groups where tensor values are equivalent to
             within tolerances
         """
-        d = {}
-        if voigt:
-            array = self.voigt
-        else:
-            array = self
+        dct = {}
+        array = self.voigt if voigt else self
         grouped = self.get_grouped_indices(voigt=voigt, **kwargs)
-        if zero_index:
-            p = 0
-        else:
-            p = 1
+        p = 0 if zero_index else 1
         for indices in grouped:
             sym_string = self.symbol + "_"
-            sym_string += "".join([str(i + p) for i in indices[0]])
+            sym_string += "".join(str(i + p) for i in indices[0])
             value = array[indices[0]]
             if not np.isclose(value, 0):
-                d[sym_string] = array[indices[0]]
-        return d
+                dct[sym_string] = array[indices[0]]
+        return dct
 
     def round(self, decimals=0):
         """
         Wrapper around numpy.round to ensure object
-        of same type is returned
+        of same type is returned.
 
         Args:
             decimals :Number of decimal places to round to (default: 0).
@@ -291,7 +273,7 @@ class Tensor(np.ndarray, MSONable):
         """
         Returns a generally symmetrized tensor, calculated by taking
         the sum of the tensor and its transpose with respect to all
-        possible permutations of indices
+        possible permutations of indices.
         """
         perms = list(itertools.permutations(range(self.rank)))
         return sum(np.transpose(self, ind) for ind in perms) / len(perms)
@@ -300,7 +282,7 @@ class Tensor(np.ndarray, MSONable):
     def voigt_symmetrized(self):
         """
         Returns a "voigt"-symmetrized tensor, i. e. a voigt-notation
-        tensor such that it is invariant wrt permutation of indices
+        tensor such that it is invariant wrt permutation of indices.
         """
         if not (self.rank % 2 == 0 and self.rank >= 2):
             raise ValueError("V-symmetrization requires rank even and >= 2")
@@ -313,7 +295,7 @@ class Tensor(np.ndarray, MSONable):
     def is_symmetric(self, tol: float = 1e-5):
         """
         Tests whether a tensor is symmetric or not based on the residual
-        with its symmetric part, from self.symmetrized
+        with its symmetric part, from self.symmetrized.
 
         Args:
             tol (float): tolerance to test for symmetry
@@ -323,7 +305,7 @@ class Tensor(np.ndarray, MSONable):
     def fit_to_structure(self, structure: Structure, symprec: float = 0.1):
         """
         Returns a tensor that is invariant with respect to symmetry
-        operations corresponding to a structure
+        operations corresponding to a structure.
 
         Args:
             structure (Structure): structure from which to generate
@@ -340,7 +322,7 @@ class Tensor(np.ndarray, MSONable):
         Tests whether a tensor is invariant with respect to the
         symmetry operations of a particular structure by testing
         whether the residual of the symmetric portion is below a
-        tolerance
+        tolerance.
 
         Args:
             structure (Structure): structure to be fit to
@@ -350,9 +332,7 @@ class Tensor(np.ndarray, MSONable):
 
     @property
     def voigt(self):
-        """
-        Returns the tensor in Voigt notation
-        """
+        """Returns the tensor in Voigt notation."""
         v_matrix = np.zeros(self._vscale.shape, dtype=self.dtype)
         this_voigt_map = self.get_voigt_dict(self.rank)
         for ind, v in this_voigt_map.items():
@@ -365,7 +345,7 @@ class Tensor(np.ndarray, MSONable):
         """
         Tests symmetry of tensor to that necessary for voigt-conversion
         by grouping indices into pairs and constructing a sequence of
-        possible permutations to be used in a tensor transpose
+        possible permutations to be used in a tensor transpose.
         """
         transpose_pieces = [[[0 for i in range(self.rank % 2)]]]
         transpose_pieces += [[list(range(j, j + 2))] for j in range(self.rank % 2, self.rank, 2)]
@@ -374,7 +354,7 @@ class Tensor(np.ndarray, MSONable):
                 transpose_pieces[n] += [transpose_pieces[n][0][::-1]]
         for trans_seq in itertools.product(*transpose_pieces):
             transpose_seq = list(itertools.chain(*trans_seq))
-            if (self - self.transpose(transpose_seq) > tol).any():
+            if (self - self.transpose(transpose_seq) > tol).any():  # type: ignore
                 return False
         return True
 
@@ -382,7 +362,7 @@ class Tensor(np.ndarray, MSONable):
     def get_voigt_dict(rank):
         """
         Returns a dictionary that maps indices in the tensor to those
-        in a voigt representation based on input rank
+        in a voigt representation based on input rank.
 
         Args:
             rank (int): Tensor rank to generate the voigt map
@@ -582,10 +562,7 @@ class Tensor(np.ndarray, MSONable):
         base = np.zeros(shape.astype(int))
         for v, idx in zip(values, indices):
             base[tuple(idx)] = v
-        if 6 in shape:
-            obj = cls.from_voigt(base)
-        else:
-            obj = cls(base)
+        obj = cls.from_voigt(base) if 6 in shape else cls(base)
         if populate:
             assert structure, "Populate option must include structure input"
             obj = obj.populate(structure, vsym=vsym, verbose=verbose)
@@ -613,7 +590,7 @@ class Tensor(np.ndarray, MSONable):
         3. Reset the non-zero entries of the original tensor
 
         Args:
-            structure (structure object)
+            structure (Structure): structure to base population on
             prec (float): precision for determining a non-zero value
             maxiter (int): maximum iterations for populating the tensor
             verbose (bool): whether to populate verbosely
@@ -679,7 +656,7 @@ class Tensor(np.ndarray, MSONable):
 
     def as_dict(self, voigt: bool = False) -> dict:
         """
-        Serializes the tensor object
+        Serializes the tensor object.
 
         Args:
             voigt (bool): flag for whether to store entries in
@@ -701,7 +678,7 @@ class Tensor(np.ndarray, MSONable):
 
     @classmethod
     def from_dict(cls, d) -> Tensor:
-        """Instantiate Tensors from dicts (using MSONAble API).
+        """Instantiate Tensors from dicts (using MSONable API).
 
         Returns:
             Tensor: hydrated tensor object
@@ -714,7 +691,7 @@ class Tensor(np.ndarray, MSONable):
 class TensorCollection(collections.abc.Sequence, MSONable):
     """
     A sequence of tensors that can be used for fitting data
-    or for having a tensor expansion
+    or for having a tensor expansion.
     """
 
     def __init__(self, tensor_list, base_class=Tensor):
@@ -761,9 +738,7 @@ class TensorCollection(collections.abc.Sequence, MSONable):
 
     @property
     def symmetrized(self):
-        """
-        :return: TensorCollection where all tensors are symmetrized.
-        """
+        """:return: TensorCollection where all tensors are symmetrized."""
         return self.__class__([t.symmetrized for t in self])
 
     def is_symmetric(self, tol: float = 1e-5):
@@ -793,16 +768,12 @@ class TensorCollection(collections.abc.Sequence, MSONable):
 
     @property
     def voigt(self):
-        """
-        :return: TensorCollection where all tensors are in voight form.
-        """
+        """:return: TensorCollection where all tensors are in voight form."""
         return [t.voigt for t in self]
 
     @property
     def ranks(self):
-        """
-        :return: Ranks for all tensors.
-        """
+        """:return: Ranks for all tensors."""
         return [t.rank for t in self]
 
     def is_voigt_symmetric(self, tol: float = 1e-6):
@@ -846,9 +817,7 @@ class TensorCollection(collections.abc.Sequence, MSONable):
 
     @property
     def voigt_symmetrized(self):
-        """
-        :return: TensorCollection where all tensors are voigt symmetrized.
-        """
+        """:return: TensorCollection where all tensors are voigt symmetrized."""
         return self.__class__([t.voigt_symmetrized for t in self])
 
     def as_dict(self, voigt=False):
@@ -903,19 +872,19 @@ class SquareTensor(Tensor):
 
     @property
     def trans(self):
-        """Shorthand for transpose on SquareTensor"""
+        """Shorthand for transpose on SquareTensor."""
         return SquareTensor(np.transpose(self))
 
     @property
     def inv(self):
-        """Shorthand for matrix inverse on SquareTensor"""
+        """Shorthand for matrix inverse on SquareTensor."""
         if self.det == 0:
             raise ValueError("SquareTensor is non-invertible")
         return SquareTensor(np.linalg.inv(self))
 
     @property
     def det(self):
-        """Shorthand for the determinant of the SquareTensor"""
+        """Shorthand for the determinant of the SquareTensor."""
         return np.linalg.det(self)
 
     def is_rotation(self, tol: float = 1e-3, include_improper=True):
@@ -923,7 +892,7 @@ class SquareTensor(Tensor):
         Test to see if tensor is a valid rotation matrix, performs a
         test to check whether the inverse is equal to the transpose
         and if the determinant is equal to one within the specified
-        tolerance
+        tolerance.
 
         Args:
             tol (float): tolerance to both tests of whether the
@@ -942,7 +911,7 @@ class SquareTensor(Tensor):
         Helper method for refining rotation matrix by ensuring
         that second and third rows are perpendicular to the first.
         Gets new y vector from an orthogonal projection of x onto y
-        and the new z vector from a cross product of the new x and y
+        and the new z vector from a cross product of the new x and y.
 
         Args:
             tol to test for rotation
@@ -958,7 +927,7 @@ class SquareTensor(Tensor):
 
     def get_scaled(self, scale_factor):
         """
-        Scales the tensor by a certain multiplicative scale factor
+        Scales the tensor by a certain multiplicative scale factor.
 
         Args:
             scale_factor (float): scalar multiplier to be applied to the
@@ -971,23 +940,21 @@ class SquareTensor(Tensor):
         """
         Returns a list of principal invariants for the tensor,
         which are the values of the coefficients of the characteristic
-        polynomial for the matrix
+        polynomial for the matrix.
         """
         return np.poly(self)[1:] * np.array([-1, 1, -1])
 
     def polar_decomposition(self, side="right"):
-        """
-        Calculates matrices for polar decomposition
-        """
+        """Calculates matrices for polar decomposition."""
         return polar(self, side=side)
 
 
 def get_uvec(vec):
-    """Gets a unit vector parallel to input vector"""
-    l = np.linalg.norm(vec)
-    if l < 1e-8:
+    """Gets a unit vector parallel to input vector."""
+    norm = np.linalg.norm(vec)
+    if norm < 1e-8:
         return vec
-    return vec / l
+    return vec / norm
 
 
 def symmetry_reduce(tensors, structure: Structure, tol: float = 1e-8, **kwargs):
@@ -995,7 +962,7 @@ def symmetry_reduce(tensors, structure: Structure, tol: float = 1e-8, **kwargs):
     Function that converts a list of tensors corresponding to a structure
     and returns a dictionary consisting of unique tensor keys with symmop
     values corresponding to transformations that will result in derivative
-    tensors from the original list
+    tensors from the original list.
 
     Args:
         tensors (list of tensors): list of Tensor objects to test for
@@ -1037,7 +1004,7 @@ class TensorMapping(collections.abc.MutableMapping):
     """
 
     def __init__(self, tensors: Sequence[Tensor] = (), values: Sequence = (), tol: float = 1e-5):
-        """Initialize a TensorMapping
+        """Initialize a TensorMapping.
 
         Args:
             tensors (Sequence[Tensor], optional): Defaults to (,).
@@ -1080,19 +1047,15 @@ class TensorMapping(collections.abc.MutableMapping):
         yield from self._tensor_list
 
     def values(self):
-        """
-        :return: Values in mapping.
-        """
+        """:return: Values in mapping."""
         return self._value_list
 
     def items(self):
-        """
-        :return: Items in mapping.
-        """
+        """:return: Items in mapping."""
         return zip(self._tensor_list, self._value_list)
 
     def __contains__(self, item):
-        return not self._get_item_index(item) is None
+        return self._get_item_index(item) is not None
 
     def _get_item_index(self, item):
         if len(self._tensor_list) == 0:
