@@ -1,18 +1,12 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
+from __future__ import annotations
 
 import unittest
 import warnings
 
 import pytest
+from pytest import approx
 
-from pymatgen.core.bonds import (
-    CovalentBond,
-    get_bond_length,
-    get_bond_order,
-    obtain_all_bond_lengths,
-)
+from pymatgen.core.bonds import CovalentBond, get_bond_length, get_bond_order, obtain_all_bond_lengths
 from pymatgen.core.periodic_table import Element
 from pymatgen.core.sites import Site
 
@@ -34,14 +28,14 @@ class CovalentBondTest(unittest.TestCase):
     def test_length(self):
         site1 = Site("C", [0, 0, 0])
         site2 = Site("H", [0, 0.7, 0.6])
-        assert pytest.approx(CovalentBond(site1, site2).length - 0.92195444572928864) == 0
+        assert approx(CovalentBond(site1, site2).length - 0.92195444572928864) == 0
 
     def test_get_bond_order(self):
         site1 = Site("C", [0, 0, 0])
         site2 = Site("H", [0, 0, 1.08])
-        assert pytest.approx(CovalentBond(site1, site2).get_bond_order() - 1) == 0
+        assert approx(CovalentBond(site1, site2).get_bond_order() - 1) == 0
         bond = CovalentBond(Site("C", [0, 0, 0]), Site("Br", [0, 0, 2]))
-        assert pytest.approx(bond.get_bond_order(0.5, 1.9) - 0.894736842105263) == 0
+        assert approx(bond.get_bond_order(0.5, 1.9) - 0.894736842105263) == 0
 
     def test_is_bonded(self):
         site1 = Site("C", [0, 0, 0])
@@ -50,7 +44,7 @@ class CovalentBondTest(unittest.TestCase):
         site2 = Site("H", [0, 0, 1.5])
         assert not CovalentBond.is_bonded(site1, site2)
         site1 = Site("U", [0, 0, 0])
-        with pytest.raises(ValueError):
+        with pytest.raises(ValueError, match="No bond data for elements H - U"):
             CovalentBond.is_bonded(site1, site2)
         assert CovalentBond.is_bonded(site1, site2, default_bl=2)
 
@@ -62,15 +56,15 @@ class CovalentBondTest(unittest.TestCase):
 
 class FuncTest(unittest.TestCase):
     def test_get_bond_length(self):
-        assert pytest.approx(get_bond_length("C", "C", 1) - 1.54) == 0
-        assert pytest.approx(get_bond_length("C", "C", 2) - 1.34) == 0
-        assert pytest.approx(get_bond_length("C", "H", 1) - 1.08) == 0
+        assert approx(get_bond_length("C", "C", 1) - 1.54) == 0
+        assert approx(get_bond_length("C", "C", 2) - 1.34) == 0
+        assert approx(get_bond_length("C", "H", 1) - 1.08) == 0
         assert get_bond_length("C", "H", 2) == 0.95
-        assert pytest.approx(get_bond_length("C", "Br", 1) - 1.85) == 0
+        assert approx(get_bond_length("C", "Br", 1) - 1.85) == 0
 
     def test_obtain_all_bond_lengths(self):
         assert obtain_all_bond_lengths("C", "C") == {1.0: 1.54, 2.0: 1.34, 3.0: 1.2}
-        with pytest.raises(ValueError):
+        with pytest.raises(ValueError, match="No bond data for elements Br - C"):
             obtain_all_bond_lengths("Br", Element("C"))
         assert obtain_all_bond_lengths("C", Element("Br"), 1.76) == {1: 1.76}
         bond_lengths_dict = obtain_all_bond_lengths("C", "N")
@@ -78,22 +72,18 @@ class FuncTest(unittest.TestCase):
         assert obtain_all_bond_lengths("C", "N") == {1.0: 1.47, 2.0: 1.3, 3.0: 1.16}
 
     def test_get_bond_order(self):
-        assert pytest.approx(get_bond_order("C", "C", 1) - 3) == 0
-        assert pytest.approx(get_bond_order("C", "C", 1.2) - 3) == 0
-        assert pytest.approx(get_bond_order("C", "C", 1.25) - 2.642857142857143) == 0
-        assert pytest.approx(get_bond_order("C", "C", 1.34) - 2) == 0
-        assert pytest.approx(get_bond_order("C", "C", 1.4) - 1.7) == 0  # bond length in benzene
-        assert pytest.approx(get_bond_order("C", "C", 1.54) - 1) == 0
-        assert pytest.approx(get_bond_order("C", "C", 2.5) - 0) == 0
-        assert pytest.approx(get_bond_order("C", "C", 9999) - 0) == 0
-        assert pytest.approx(get_bond_order("C", "Br", 1.9, default_bl=1.9) - 1) == 0
-        assert pytest.approx(get_bond_order("C", "Br", 2, default_bl=1.9) - 0.7368421052631575) == 0
-        assert pytest.approx(get_bond_order("C", "Br", 1.9, tol=0.5, default_bl=1.9) - 1) == 0
-        assert pytest.approx(get_bond_order("C", "Br", 2, tol=0.5, default_bl=1.9) - 0.894736842105263) == 0
-        with pytest.raises(ValueError):
+        assert approx(get_bond_order("C", "C", 1) - 3) == 0
+        assert approx(get_bond_order("C", "C", 1.2) - 3) == 0
+        assert approx(get_bond_order("C", "C", 1.25) - 2.642857142857143) == 0
+        assert approx(get_bond_order("C", "C", 1.34) - 2) == 0
+        assert approx(get_bond_order("C", "C", 1.4) - 1.7) == 0  # bond length in benzene
+        assert approx(get_bond_order("C", "C", 1.54) - 1) == 0
+        assert approx(get_bond_order("C", "C", 2.5) - 0) == 0
+        assert approx(get_bond_order("C", "C", 9999) - 0) == 0
+        assert approx(get_bond_order("C", "Br", 1.9, default_bl=1.9) - 1) == 0
+        assert approx(get_bond_order("C", "Br", 2, default_bl=1.9) - 0.7368421052631575) == 0
+        assert approx(get_bond_order("C", "Br", 1.9, tol=0.5, default_bl=1.9) - 1) == 0
+        assert approx(get_bond_order("C", "Br", 2, tol=0.5, default_bl=1.9) - 0.894736842105263) == 0
+        with pytest.raises(ValueError, match="No bond data for elements Br - C"):
             get_bond_order("C", "Br", 1.9)
-        assert pytest.approx(get_bond_order("N", "N", 1.25) - 2) == 0
-
-
-if __name__ == "__main__":
-    unittest.main()
+        assert approx(get_bond_order("N", "N", 1.25) - 2) == 0
