@@ -1,7 +1,4 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
-import unittest
+from __future__ import annotations
 
 import numpy as np
 
@@ -32,15 +29,8 @@ class InterfaceTest(PymatgenTest):
         assert interface.substrate_layers == 2
 
         iface_dict = interface.as_dict()
-        for k in [
-            "lattice",
-            "sites",
-            "in_plane_offset",
-            "gap",
-            "vacuum_over_film",
-            "interface_properties",
-        ]:
-            assert k in iface_dict
+        expected_keys = {"lattice", "sites", "in_plane_offset", "gap", "vacuum_over_film", "interface_properties"}
+        assert expected_keys <= {*iface_dict}
         assert isinstance(interface.from_dict(iface_dict), Interface)
 
     def test_gap_setter(self):
@@ -63,7 +53,6 @@ class InterfaceTest(PymatgenTest):
         assert np.allclose(interface.gap, gap)
 
     def test_in_plane_offset_setter(self):
-
         interface = self.interface
         init_coords = np.array(self.interface.frac_coords)
         interface.in_plane_offset = np.array([0.2, 0.2])
@@ -102,7 +91,3 @@ class InterfaceTest(PymatgenTest):
 
         interface = Interface.from_slabs(film_slab=si_slab, substrate_slab=sio2_slab)
         assert isinstance(interface, Interface)
-
-
-if __name__ == "__main__":
-    unittest.main()
