@@ -1,6 +1,4 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
+from __future__ import annotations
 
 import math
 import os
@@ -12,24 +10,18 @@ from copy import deepcopy
 import numpy as np
 import pytest
 
-from pymatgen.core.periodic_table import (
-    DummySpecies,
-    Element,
-    ElementBase,
-    Species,
-    get_el_sp,
-)
+from pymatgen.core.periodic_table import DummySpecies, Element, ElementBase, Species, get_el_sp
 from pymatgen.util.testing import PymatgenTest
 
 
 class ElementTestCase(PymatgenTest):
     def test_init(self):
-        assert "Fe" == Element("Fe").symbol, "Fe test failed"
+        assert Element("Fe").symbol == "Fe"
 
         fictional_symbols = ["D", "T", "Zebra"]
 
         for sym in fictional_symbols:
-            with pytest.raises(ValueError):
+            with pytest.raises(ValueError, match=f"{sym!r} is not a valid Element"):
                 Element(sym)
 
         # Test caching
@@ -52,7 +44,7 @@ class ElementTestCase(PymatgenTest):
         assert fe == Element.from_dict(d)
 
     def test_block(self):
-        testsets = {
+        cases = {
             "O": "p",
             "Fe": "d",
             "Li": "s",
@@ -61,11 +53,11 @@ class ElementTestCase(PymatgenTest):
             "Lu": "d",
             "Lr": "d",
         }
-        for k, v in testsets.items():
-            assert Element(k).block == v
+        for key, val in cases.items():
+            assert Element(key).block == val
 
     def test_full_electronic_structure(self):
-        testsets = {
+        cases = {
             "O": [(1, "s", 2), (2, "s", 2), (2, "p", 4)],
             "Fe": [
                 (1, "s", 2),
@@ -98,13 +90,13 @@ class ElementTestCase(PymatgenTest):
                 (7, "s", 2),
             ],
         }
-        for k, v in testsets.items():
+        for k, v in cases.items():
             assert Element(k).full_electronic_structure == v
 
         assert Element.Ac.electronic_structure == "[Rn].6d1.7s2"
 
     def test_group(self):
-        testsets = {
+        cases = {
             "H": 1,
             "He": 18,
             "Li": 1,
@@ -117,11 +109,11 @@ class ElementTestCase(PymatgenTest):
             "Lr": 3,
             "Og": 18,
         }
-        for k, v in testsets.items():
+        for k, v in cases.items():
             assert Element(k).group == v
 
     def test_row(self):
-        testsets = {
+        cases = {
             "H": 1,
             "He": 1,
             "Li": 2,
@@ -134,11 +126,11 @@ class ElementTestCase(PymatgenTest):
             "Lr": 7,
             "Og": 7,
         }
-        for k, v in testsets.items():
+        for k, v in cases.items():
             assert Element(k).row == v
 
     def test_from_name(self):
-        testsets = {
+        cases = {
             "H": "hydrogen",
             "He": "Helium",
             "Li": "lithium",
@@ -148,11 +140,11 @@ class ElementTestCase(PymatgenTest):
             "Ce": "Cerium",
             "U": "Uranium",
         }
-        for k, v in testsets.items():
+        for k, v in cases.items():
             assert ElementBase.from_name(v) == Element(k)
 
     def test_from_row_and_group(self):
-        testsets = {
+        cases = {
             "H": (1, 1),
             "He": (1, 18),
             "Li": (2, 1),
@@ -165,23 +157,23 @@ class ElementTestCase(PymatgenTest):
             "Lr": (9, 17),
             "Og": (7, 18),
         }
-        for k, v in testsets.items():
+        for k, v in cases.items():
             assert ElementBase.from_row_and_group(v[0], v[1]) == Element(k)
 
     def test_valence(self):
-        testsets = {"O": (1, 4), "Fe": (2, 6), "Li": (0, 1), "Be": (0, 2)}
-        for k, v in testsets.items():
+        cases = {"O": (1, 4), "Fe": (2, 6), "Li": (0, 1), "Be": (0, 2)}
+        for k, v in cases.items():
             assert Element(k).valence == v
 
-        with pytest.raises(ValueError):
-            Element("U").valence
+        with pytest.raises(ValueError, match="U has ambiguous valence"):
+            _ = Element("U").valence
 
         valence = Element("He").valence
         assert np.isnan(valence[0])
         assert valence[1] == 0
 
     def test_term_symbols(self):
-        testsets = {
+        cases = {
             "Li": [["2S0.5"]],  # s1
             "C": [["1D2.0"], ["3P0.0", "3P1.0", "3P2.0"], ["1S0.0"]],  # p2
             "Ti": [
@@ -211,18 +203,18 @@ class ElementTestCase(PymatgenTest):
                 ["4S1.5"],
             ],  # f3
         }
-        for k, v in testsets.items():
+        for k, v in cases.items():
             assert Element(k).term_symbols == v
 
     def test_ground_state_term_symbol(self):
-        testsets = {
+        cases = {
             "Li": "2S0.5",  # s1
             "C": "3P0.0",  # p2
             "O": "3P2.0",  # p4
             "Ti": "3F2.0",  # d2
             "Pr": "4I4.5",
         }  # f3
-        for k, v in testsets.items():
+        for k, v in cases.items():
             assert Element(k).ground_state_term_symbol == v
 
     def test_attributes(self):
@@ -284,8 +276,8 @@ class ElementTestCase(PymatgenTest):
         ]
 
         # Test all elements up to Uranium
-        for i in range(1, 104):
-            el = Element.from_Z(i)
+        for idx in range(1, 104):
+            el = Element.from_Z(idx)
             d = el.data
             for k in keys:
                 k_str = k.capitalize().replace("_", " ")
@@ -296,7 +288,7 @@ class ElementTestCase(PymatgenTest):
                 elif k == "iupac_ordering":
                     assert "IUPAC ordering" in d
                     assert getattr(el, k) is not None
-            el = Element.from_Z(i)
+            el = Element.from_Z(idx)
             if len(el.oxidation_states) > 0:
                 assert max(el.oxidation_states) == el.max_oxidation_state
                 assert min(el.oxidation_states) == el.min_oxidation_state
@@ -304,13 +296,13 @@ class ElementTestCase(PymatgenTest):
             if el.symbol not in ["He", "Ne", "Ar"]:
                 assert el.X > 0, f"No electroneg for {el}"
 
-        with pytest.raises(ValueError):
+        with pytest.raises(ValueError, match="Unexpected atomic number Z=1000"):
             Element.from_Z(1000)
 
     def test_ie_ea(self):
-        assert round(abs(Element.Fe.ionization_energies[2] - 30.651), 7) == 0
+        assert Element.Fe.ionization_energies[2] == pytest.approx(30.651)
         assert Element.Fe.ionization_energy == Element.Fe.ionization_energies[0]
-        assert round(abs(Element.Br.electron_affinity - 3.3635883), 7) == 0
+        assert Element.Br.electron_affinity == pytest.approx(3.3635883)
 
     def test_oxidation_states(self):
         el = Element.Fe
@@ -360,7 +352,7 @@ class ElementTestCase(PymatgenTest):
         assert Element("Bi").is_post_transition_metal, True
 
 
-class SpecieTestCase(PymatgenTest):
+class SpeciesTestCase(PymatgenTest):
     def setUp(self):
         self.specie1 = Species.from_string("Fe2+")
         self.specie2 = Species("Fe", 3)
@@ -368,20 +360,20 @@ class SpecieTestCase(PymatgenTest):
         self.specie4 = Species("Fe", 2, {"spin": 5})
 
     def test_init(self):
-        with pytest.raises(ValueError):
+        with pytest.raises(ValueError, match="magmom is not a supported property"):
             Species("Fe", 2, {"magmom": 5})
 
     def test_ionic_radius(self):
         assert self.specie2.ionic_radius == 78.5 / 100
         assert self.specie3.ionic_radius == 92 / 100
-        assert round(abs(Species("Mn", 4).ionic_radius - 0.67), 7) == 0
+        assert Species("Mn", 4).ionic_radius == pytest.approx(0.67)
 
     def test_eq(self):
         assert self.specie1 == self.specie3, "Static and actual constructor gives unequal result!"
         assert self.specie1 != self.specie2, "Fe2+ should not be equal to Fe3+"
         assert self.specie4 != self.specie3
-        assert not self.specie1 == Element("Fe")
-        assert not Element("Fe") == self.specie1
+        assert self.specie1 != Element("Fe")
+        assert Element("Fe") != self.specie1
 
     def test_cmp(self):
         assert self.specie1 < self.specie2, "Fe2+ should be < Fe3+"
@@ -421,15 +413,13 @@ class SpecieTestCase(PymatgenTest):
         assert Species("Ni", 3).get_crystal_field_spin(spin_config="low") == 1
         assert Species("Ni", 4).get_crystal_field_spin(spin_config="low") == 0
 
-        with pytest.raises(AttributeError):
-            Species("Li", 1).get_crystal_field_spin()
-        with pytest.raises(AttributeError):
-            Species("Ge", 4).get_crystal_field_spin()
-        with pytest.raises(AttributeError):
-            Species("H", 1).get_crystal_field_spin()
-        with pytest.raises(AttributeError):
+        for elem in ("Li+", "Ge4+", "H+"):
+            symbol = Species(elem).symbol
+            with pytest.raises(AttributeError, match=f"Invalid element {symbol} for crystal field calculation"):
+                Species(elem).get_crystal_field_spin()
+        with pytest.raises(AttributeError, match="Invalid oxidation state 10 for element Fe"):
             Species("Fe", 10).get_crystal_field_spin()
-        with pytest.raises(ValueError):
+        with pytest.raises(ValueError, match="Invalid coordination or spin config"):
             Species("Fe", 2).get_crystal_field_spin("hex")
 
         s = Species("Co", 3).get_crystal_field_spin("tet", spin_config="low")
@@ -440,7 +430,7 @@ class SpecieTestCase(PymatgenTest):
         assert Species("Li").get_nmr_quadrupole_moment() == -0.808
         assert Species("Li").get_nmr_quadrupole_moment("Li-7") == -40.1
         assert Species("Si").get_nmr_quadrupole_moment() == 0.0
-        with pytest.raises(ValueError):
+        with pytest.raises(ValueError, match="No quadrupole moment for isotope='Li-109'"):
             Species("Li").get_nmr_quadrupole_moment("Li-109")
 
     def test_get_shannon_radius(self):
@@ -481,7 +471,7 @@ class SpecieTestCase(PymatgenTest):
         # Why make the thing so complicated for a use case that I have never seen???
         # fe_no_ox = Species("Fe", oxidation_state=None, properties={"spin": 5})
         # fe_no_ox_from_str = Species.from_string("Fe,spin=5")
-        # self.assertEqual(fe_no_ox, fe_no_ox_from_str)
+        # assert fe_no_ox == fe_no_ox_from_str
 
     def test_no_oxidation_state(self):
         mo0 = Species("Mo", None, {"spin": 5})
@@ -494,21 +484,41 @@ class SpecieTestCase(PymatgenTest):
         assert Species("S", -2).to_unicode_string() == "S²⁻"
 
 
-class DummySpecieTestCase(unittest.TestCase):
+@pytest.mark.parametrize(
+    ("symbol_oxi", "expected_element", "expected_oxi_state"),
+    [
+        ("Fe", "Fe", None),
+        ("Fe2+", "Fe", 2),
+        ("O2-", "O", -2),
+        ("N-", "N", -1),
+        ("Ca+", "Ca", 1),
+        ("Te3+", "Te", 3),
+        ("P5+", "P", 5),
+        ("Na0+", "Na", 0),
+        ("Na0-", "Na", 0),
+    ],
+)
+def test_symbol_oxi_state_str(symbol_oxi, expected_element, expected_oxi_state):
+    species = Species(symbol_oxi)
+    assert species._el.symbol == expected_element
+    assert species._oxi_state == expected_oxi_state
+
+
+class DummySpeciesTestCase(unittest.TestCase):
     def test_init(self):
         self.specie1 = DummySpecies("X")
-        with pytest.raises(ValueError):
+        with pytest.raises(ValueError, match="Xe contains Xe, which is a valid element symbol"):
             DummySpecies("Xe")
-        with pytest.raises(ValueError):
+        with pytest.raises(ValueError, match="Xec contains Xe, which is a valid element symbol"):
             DummySpecies("Xec")
-        with pytest.raises(ValueError):
+        with pytest.raises(ValueError, match="Vac contains V, which is a valid element symbol"):
             DummySpecies("Vac")
         self.specie2 = DummySpecies("X", 2, {"spin": 3})
         assert self.specie2.spin == 3
 
     def test_eq(self):
-        assert not DummySpecies("Xg") == DummySpecies("Xh")
-        assert not DummySpecies("Xg") == DummySpecies("Xg", 3)
+        assert DummySpecies("Xg") != DummySpecies("Xh")
+        assert DummySpecies("Xg") != DummySpecies("Xg", 3)
         assert DummySpecies("Xg", 3) == DummySpecies("Xg", 3)
 
     def test_from_string(self):
@@ -543,7 +553,3 @@ class FuncTest(unittest.TestCase):
         assert get_el_sp("U") == Element.U
         assert get_el_sp("X2+") == DummySpecies("X", 2)
         assert get_el_sp("Mn3+") == Species("Mn", 3)
-
-
-if __name__ == "__main__":
-    unittest.main()
