@@ -1,21 +1,17 @@
+from __future__ import annotations
+
 import math
 import os
-import unittest
 import warnings
 
 import numpy as np
 import pytest
 from monty.serialization import MontyDecoder, loadfn
+from numpy.testing import assert_array_equal
+from pytest import approx
 
 from pymatgen.core.operations import SymmOp
-from pymatgen.core.tensors import (
-    SquareTensor,
-    Tensor,
-    TensorCollection,
-    TensorMapping,
-    itertools,
-    symmetry_reduce,
-)
+from pymatgen.core.tensors import SquareTensor, Tensor, TensorCollection, TensorMapping, itertools, symmetry_reduce
 from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
 from pymatgen.util.testing import PymatgenTest
 
@@ -116,26 +112,24 @@ class TensorTest(PymatgenTest):
     def test_new(self):
         bad_2 = np.zeros((4, 4))
         bad_3 = np.zeros((4, 4, 4))
-        with pytest.raises(ValueError):
+        expected_msg = (
+            "Pymatgen only supports 3-dimensional tensors, and default tensor constructor uses standard notation"
+        )
+        with pytest.raises(ValueError, match=expected_msg):
             Tensor(bad_2)
-        with pytest.raises(ValueError):
+        with pytest.raises(ValueError, match=expected_msg):
             Tensor(bad_3)
         assert self.rand_rank2.rank == 2
         assert self.rand_rank3.rank == 3
         assert self.rand_rank4.rank == 4
 
     def test_zeroed(self):
-        self.assertArrayEqual(
-            self.low_val.zeroed(),
-            Tensor([[0, 1 + 1e-5, 0], [1 + 1e-6, 0, 0], [0, 0, 1 + 1e-5]]),
+        assert self.low_val.zeroed() == approx(Tensor([[0, 1 + 1e-5, 0], [1 + 1e-6, 0, 0], [0, 0, 1 + 1e-5]]))
+        assert self.low_val.zeroed(tol=1e-6) == approx(
+            Tensor([[1e-6, 1 + 1e-5, 1e-6], [1 + 1e-6, 1e-6, 1e-6], [0, 0, 1 + 1e-5]])
         )
-        self.assertArrayEqual(
-            self.low_val.zeroed(tol=1e-6),
-            Tensor([[1e-6, 1 + 1e-5, 1e-6], [1 + 1e-6, 1e-6, 1e-6], [0, 0, 1 + 1e-5]]),
-        )
-        self.assertArrayEqual(
-            Tensor([[1e-6, -30, 1], [1e-7, 1, 0], [1e-8, 0, 1]]).zeroed(),
-            Tensor([[0, -30, 1], [0, 1, 0], [0, 0, 1]]),
+        assert Tensor([[1e-6, -30, 1], [1e-7, 1, 0], [1e-8, 0, 1]]).zeroed() == approx(
+            Tensor([[0, -30, 1], [0, 1, 0], [0, 0, 1]])
         )
 
     def test_transform(self):
@@ -144,7 +138,7 @@ class TensorTest(PymatgenTest):
         symm_op = SymmOp.from_axis_angle_and_translation([0, 0, 1], 30, False, [0, 0, 1])
         new_tensor = tensor.transform(symm_op)
 
-        self.assertArrayAlmostEqual(
+        self.assert_all_close(
             new_tensor,
             [
                 [
@@ -167,21 +161,21 @@ class TensorTest(PymatgenTest):
         )
 
     def test_rotate(self):
-        self.assertArrayEqual(self.vec.rotate([[0, -1, 0], [1, 0, 0], [0, 0, 1]]), [0, 1, 0])
-        self.assertArrayAlmostEqual(
+        assert_array_equal(self.vec.rotate([[0, -1, 0], [1, 0, 0], [0, 0, 1]]), [0, 1, 0])
+        self.assert_all_close(
             self.non_symm.rotate(self.rotation),
             SquareTensor([[0.531, 0.485, 0.271], [0.700, 0.5, 0.172], [0.171, 0.233, 0.068]]),
             decimal=3,
         )
-        with pytest.raises(ValueError):
+        with pytest.raises(ValueError, match="Rotation matrix is not valid"):
             self.non_symm.rotate(self.symm_rank2)
 
     def test_einsum_sequence(self):
         x = [1, 0, 0]
         test = Tensor(np.arange(0, 3**4).reshape((3, 3, 3, 3)))
-        self.assertArrayAlmostEqual([0, 27, 54], test.einsum_sequence([x] * 3))
-        assert 360 == test.einsum_sequence([np.eye(3)] * 2)
-        with pytest.raises(ValueError):
+        self.assert_all_close([0, 27, 54], test.einsum_sequence([x] * 3))
+        assert test.einsum_sequence([np.eye(3)] * 2) == 360
+        with pytest.raises(ValueError, match="other tensors must be list of tensors or tensor input"):
             test.einsum_sequence(Tensor(np.zeros(3)))
 
     def test_symmetrized(self):
@@ -199,7 +193,7 @@ class TensorTest(PymatgenTest):
 
     def test_fit_to_structure(self):
         new_fit = self.unfit4.fit_to_structure(self.structure)
-        self.assertArrayAlmostEqual(new_fit, self.fit_r4, 1)
+        self.assert_all_close(new_fit, self.fit_r4, 1)
 
     def test_is_fit_to_structure(self):
         assert not self.unfit4.is_fit_to_structure(self.structure)
@@ -213,19 +207,17 @@ class TensorTest(PymatgenTest):
             orig = Tensor(entry["original_tensor"])
             ieee = Tensor(entry["ieee_tensor"])
             diff = np.max(abs(ieee - orig.convert_to_ieee(struct)))
-            err_msg = f"{xtal} IEEE conversion failed with max diff {diff}. Numpy version: {np.__version__}"
+            err_msg = f"{xtal} IEEE conversion failed with max {diff=}. Numpy version: {np.__version__}"
             converted = orig.convert_to_ieee(struct, refine_rotation=False)
-            self.assertArrayAlmostEqual(ieee, converted, err_msg=err_msg, decimal=3)
+            self.assert_all_close(ieee, converted, err_msg=err_msg, decimal=3)
             converted_refined = orig.convert_to_ieee(struct, refine_rotation=True)
-            err_msg = (
-                f"{xtal} IEEE conversion with refinement failed with max diff {diff}. Numpy version: {np.__version__}"
-            )
-            self.assertArrayAlmostEqual(ieee, converted_refined, err_msg=err_msg, decimal=2)
+            err_msg = f"{xtal} IEEE conversion with refinement failed with max {diff=}. Numpy version: {np.__version__}"
+            self.assert_all_close(ieee, converted_refined, err_msg=err_msg, decimal=2)
 
     def test_structure_transform(self):
         # Test trivial case
         trivial = self.fit_r4.structure_transform(self.structure, self.structure.copy())
-        self.assertArrayAlmostEqual(trivial, self.fit_r4)
+        self.assert_all_close(trivial, self.fit_r4)
 
         # Test simple rotation
         rot_symm_op = SymmOp.from_axis_angle_and_translation([1, 1, 1], 55.5)
@@ -233,13 +225,13 @@ class TensorTest(PymatgenTest):
         rot_struct.apply_operation(rot_symm_op)
         rot_tensor = self.fit_r4.rotate(rot_symm_op.rotation_matrix)
         trans_tensor = self.fit_r4.structure_transform(self.structure, rot_struct)
-        self.assertArrayAlmostEqual(rot_tensor, trans_tensor)
+        self.assert_all_close(rot_tensor, trans_tensor)
 
         # Test supercell
         bigcell = self.structure.copy()
         bigcell.make_supercell([2, 2, 3])
         trans_tensor = self.fit_r4.structure_transform(self.structure, bigcell)
-        self.assertArrayAlmostEqual(self.fit_r4, trans_tensor)
+        self.assert_all_close(self.fit_r4, trans_tensor)
 
         # Test rotated primitive to conventional for fcc structure
         sn = self.get_structure("Sn")
@@ -247,10 +239,13 @@ class TensorTest(PymatgenTest):
         sn_prim.apply_operation(rot_symm_op)
         rotated = self.fit_r4.rotate(rot_symm_op.rotation_matrix)
         transformed = self.fit_r4.structure_transform(sn, sn_prim)
-        self.assertArrayAlmostEqual(rotated, transformed)
+        self.assert_all_close(rotated, transformed)
 
     def test_from_voigt(self):
-        with pytest.raises(ValueError):
+        with pytest.raises(
+            ValueError,
+            match="The requested array has an inhomogeneous shape after 1 dimensions",
+        ):
             Tensor.from_voigt(
                 [
                     [59.33, 28.08, 28.08, 0],
@@ -282,12 +277,12 @@ class TensorTest(PymatgenTest):
         tbs = [Tensor.from_voigt(row) for row in np.eye(6) * 0.01]
         reduced = symmetry_reduce(tbs, self.get_structure("Sn"))
         assert len(reduced) == 2
-        self.assertArrayEqual([len(i) for i in reduced.values()], [2, 2])
+        assert [len(i) for i in reduced.values()] == [2, 2]
         reconstructed = []
         for k, v in reduced.items():
             reconstructed.extend([k.voigt] + [k.transform(op).voigt for op in v])
         reconstructed = sorted(reconstructed, key=lambda x: np.argmax(x))
-        self.assertArrayAlmostEqual([tb for tb in reconstructed], np.eye(6) * 0.01)
+        self.assert_all_close(list(reconstructed), np.eye(6) * 0.01)
 
     def test_tensor_mapping(self):
         # Test get
@@ -296,7 +291,7 @@ class TensorTest(PymatgenTest):
         tkey = Tensor.from_values_indices([0.01], [(0, 0)])
         tval = reduced[tkey]
         for tens_1, tens_2 in zip(tval, reduced[tbs[0]]):
-            assert pytest.approx(tens_1) == tens_2
+            assert approx(tens_1) == tens_2
         # Test set
         reduced[tkey] = "test_val"
         assert reduced[tkey] == "test_val"
@@ -318,12 +313,12 @@ class TensorTest(PymatgenTest):
         vtens[3, 3] = 73.48
         et = Tensor.from_voigt(vtens)
         populated = et.populate(sn, prec=1e-3).voigt.round(2)
-        assert round(abs(populated[1, 1] - 259.31), 7) == 0
-        assert round(abs(populated[2, 2] - 259.31), 7) == 0
-        assert round(abs(populated[0, 2] - 160.71), 7) == 0
-        assert round(abs(populated[1, 2] - 160.71), 7) == 0
-        assert round(abs(populated[4, 4] - 73.48), 7) == 0
-        assert round(abs(populated[5, 5] - 73.48), 7) == 0
+        assert populated[1, 1] == approx(259.31)
+        assert populated[2, 2] == approx(259.31)
+        assert populated[0, 2] == approx(160.71)
+        assert populated[1, 2] == approx(160.71)
+        assert populated[4, 4] == approx(73.48)
+        assert populated[5, 5] == approx(73.48)
         # test a rank 6 example
         vtens = np.zeros([6] * 3)
         indices = [(0, 0, 0), (0, 0, 1), (0, 1, 2), (0, 3, 3), (0, 5, 5), (3, 4, 5)]
@@ -332,48 +327,48 @@ class TensorTest(PymatgenTest):
             vtens[idx] = v
         toec = Tensor.from_voigt(vtens)
         toec = toec.populate(sn, prec=1e-3, verbose=True)
-        assert round(abs(toec.voigt[1, 1, 1] - -1271), 7) == 0
-        assert round(abs(toec.voigt[0, 1, 1] - -814), 7) == 0
-        assert round(abs(toec.voigt[0, 2, 2] - -814), 7) == 0
-        assert round(abs(toec.voigt[1, 4, 4] - -3), 7) == 0
-        assert round(abs(toec.voigt[2, 5, 5] - -3), 7) == 0
-        assert round(abs(toec.voigt[1, 2, 0] - -50), 7) == 0
-        assert round(abs(toec.voigt[4, 5, 3] - -95), 7) == 0
+        assert toec.voigt[1, 1, 1] == approx(-1271)
+        assert toec.voigt[0, 1, 1] == approx(-814)
+        assert toec.voigt[0, 2, 2] == approx(-814)
+        assert toec.voigt[1, 4, 4] == approx(-3)
+        assert toec.voigt[2, 5, 5] == approx(-3)
+        assert toec.voigt[1, 2, 0] == approx(-50)
+        assert toec.voigt[4, 5, 3] == approx(-95)
 
         et = Tensor.from_voigt(test_data["C3_raw"]).fit_to_structure(sn)
         new = np.zeros(et.voigt.shape)
         for idx in indices:
             new[idx] = et.voigt[idx]
         new = Tensor.from_voigt(new).populate(sn)
-        self.assertArrayAlmostEqual(new, et, decimal=2)
+        self.assert_all_close(new, et, decimal=2)
 
     def test_from_values_indices(self):
         sn = self.get_structure("Sn")
         indices = [(0, 0), (0, 1), (3, 3)]
         values = [259.31, 160.71, 73.48]
         et = Tensor.from_values_indices(values, indices, structure=sn, populate=True).voigt.round(4)
-        assert round(abs(et[1, 1] - 259.31), 7) == 0
-        assert round(abs(et[2, 2] - 259.31), 7) == 0
-        assert round(abs(et[0, 2] - 160.71), 7) == 0
-        assert round(abs(et[1, 2] - 160.71), 7) == 0
-        assert round(abs(et[4, 4] - 73.48), 7) == 0
-        assert round(abs(et[5, 5] - 73.48), 7) == 0
+        assert et[1, 1] == approx(259.31)
+        assert et[2, 2] == approx(259.31)
+        assert et[0, 2] == approx(160.71)
+        assert et[1, 2] == approx(160.71)
+        assert et[4, 4] == approx(73.48)
+        assert et[5, 5] == approx(73.48)
 
     def test_serialization(self):
         # Test base serialize-deserialize
         d = self.symm_rank2.as_dict()
         new = Tensor.from_dict(d)
-        self.assertArrayAlmostEqual(new, self.symm_rank2)
+        self.assert_all_close(new, self.symm_rank2)
 
         d = self.symm_rank3.as_dict(voigt=True)
         new = Tensor.from_dict(d)
-        self.assertArrayAlmostEqual(new, self.symm_rank3)
+        self.assert_all_close(new, self.symm_rank3)
 
     def test_projection_methods(self):
-        assert round(abs(self.rand_rank2.project([1, 0, 0]) - self.rand_rank2[0, 0]), 7) == 0
-        assert round(abs(self.rand_rank2.project([1, 1, 1]) - np.sum(self.rand_rank2) / 3), 7) == 0
+        assert self.rand_rank2.project([1, 0, 0]) == approx(self.rand_rank2[0, 0])
+        assert self.rand_rank2.project([1, 1, 1]) == approx(np.sum(self.rand_rank2) / 3)
         # Test integration
-        self.assertArrayAlmostEqual(self.ones.average_over_unit_sphere(), 1)
+        self.assert_all_close(self.ones.average_over_unit_sphere(), 1)
 
     def test_summary_methods(self):
         assert set(self.ones.get_grouped_indices()[0]) == set(itertools.product(range(3), range(3)))
@@ -384,15 +379,15 @@ class TensorTest(PymatgenTest):
     def test_round(self):
         test = self.non_symm + 0.01
         rounded = test.round(1)
-        self.assertArrayAlmostEqual(rounded, self.non_symm)
+        self.assert_all_close(rounded, self.non_symm)
         assert isinstance(rounded, Tensor)
 
 
 class TensorCollectionTest(PymatgenTest):
     def setUp(self):
-        self.seq_tc = [t for t in np.arange(4 * 3**3).reshape((4, 3, 3, 3))]
+        self.seq_tc = list(np.arange(4 * 3**3).reshape((4, 3, 3, 3)))
         self.seq_tc = TensorCollection(self.seq_tc)
-        self.rand_tc = TensorCollection([t for t in np.random.random((4, 3, 3))])
+        self.rand_tc = TensorCollection(list(np.random.random((4, 3, 3))))
         self.diff_rank = TensorCollection([np.ones([3] * i) for i in range(2, 5)])
         self.struct = self.get_structure("Si")
         ieee_file_path = os.path.join(PymatgenTest.TEST_FILES_DIR, "ieee_conversion_data.json")
@@ -414,15 +409,15 @@ class TensorCollectionTest(PymatgenTest):
             if callable(this_mod):
                 this_mod = this_mod(*args, **kwargs)
             if isinstance(this_mod, np.ndarray):
-                self.assertArrayAlmostEqual(this_mod, t_mod)
+                self.assert_all_close(this_mod, t_mod)
 
     def test_list_based_functions(self):
         # zeroed
         tc = TensorCollection([1e-4 * Tensor(np.eye(3))] * 4)
         for t in tc.zeroed():
-            self.assertArrayEqual(t, np.zeros((3, 3)))
+            assert t == approx(0)
         for t in tc.zeroed(1e-5):
-            self.assertArrayEqual(t, 1e-4 * np.eye(3))
+            assert t == approx(1e-4 * np.eye(3))
         self.list_based_function_check("zeroed", tc)
         self.list_based_function_check("zeroed", tc, tol=1e-5)
 
@@ -465,17 +460,17 @@ class TensorCollectionTest(PymatgenTest):
             self.list_based_function_check("convert_to_ieee", tc, struct)
 
         # from_voigt
-        tc_input = [t for t in np.random.random((3, 6, 6))]
+        tc_input = list(np.random.random((3, 6, 6)))
         tc = TensorCollection.from_voigt(tc_input)
         for t_input, t in zip(tc_input, tc):
-            self.assertArrayAlmostEqual(Tensor.from_voigt(t_input), t)
+            self.assert_all_close(Tensor.from_voigt(t_input), t)
 
     def test_serialization(self):
         # Test base serialize-deserialize
         d = self.seq_tc.as_dict()
         new = TensorCollection.from_dict(d)
         for t, t_new in zip(self.seq_tc, new):
-            self.assertArrayAlmostEqual(t, t_new)
+            self.assert_all_close(t, t_new)
 
         # Suppress vsym warnings and test voigt
         with warnings.catch_warnings(record=True):
@@ -483,7 +478,7 @@ class TensorCollectionTest(PymatgenTest):
             d = vsym.as_dict(voigt=True)
             new_vsym = TensorCollection.from_dict(d)
             for t, t_new in zip(vsym, new_vsym):
-                self.assertArrayAlmostEqual(t, t_new)
+                self.assert_all_close(t, t_new)
 
 
 class SquareTensorTest(PymatgenTest):
@@ -506,25 +501,28 @@ class SquareTensorTest(PymatgenTest):
         ]
         bad_matrix = [[0.1, 0.2], [0.2, 0.3, 0.4], [0.2, 0.3, 0.5]]
         too_high_rank = np.zeros((3, 3, 3))
-        with pytest.raises(ValueError):
+        with pytest.raises(
+            ValueError,
+            match="Pymatgen only supports 3-dimensional tensors, and default tensor constructor uses standard notation",
+        ):
             SquareTensor(non_sq_matrix)
-        with pytest.raises(ValueError):
+        with pytest.raises(
+            ValueError,
+            match="The requested array has an inhomogeneous shape after 1 dimensions",
+        ):
             SquareTensor(bad_matrix)
-        with pytest.raises(ValueError):
+        with pytest.raises(ValueError, match="SquareTensor input must be rank 2"):
             SquareTensor(too_high_rank)
 
     def test_properties(self):
         # transpose
-        self.assertArrayEqual(
-            self.non_symm.trans,
-            SquareTensor([[0.1, 0.4, 0.2], [0.2, 0.5, 0.5], [0.3, 0.6, 0.5]]),
-        )
-        self.assertArrayEqual(self.rand_sqtensor.trans, np.transpose(self.rand_sqtensor))
-        self.assertArrayEqual(self.symm_sqtensor, self.symm_sqtensor.trans)
+        assert self.non_symm.trans == approx(SquareTensor([[0.1, 0.4, 0.2], [0.2, 0.5, 0.5], [0.3, 0.6, 0.5]]))
+        assert self.rand_sqtensor.trans == approx(np.transpose(self.rand_sqtensor))
+        assert self.symm_sqtensor == approx(self.symm_sqtensor.trans)
         # inverse
-        self.assertArrayEqual(self.non_symm.inv, np.linalg.inv(self.non_symm))
-        with pytest.raises(ValueError):
-            self.non_invertible.inv
+        assert self.non_symm.inv == approx(np.linalg.inv(self.non_symm))
+        with pytest.raises(ValueError, match="SquareTensor is non-invertible"):
+            _ = self.non_invertible.inv
 
         # determinant
         assert self.rand_sqtensor.det == np.linalg.det(self.rand_sqtensor)
@@ -532,12 +530,9 @@ class SquareTensorTest(PymatgenTest):
         assert self.non_symm.det == 0.009
 
         # symmetrized
-        self.assertArrayEqual(
-            self.rand_sqtensor.symmetrized,
-            0.5 * (self.rand_sqtensor + self.rand_sqtensor.trans),
-        )
-        self.assertArrayEqual(self.symm_sqtensor, self.symm_sqtensor.symmetrized)
-        self.assertArrayAlmostEqual(
+        assert self.rand_sqtensor.symmetrized == approx(0.5 * (self.rand_sqtensor + self.rand_sqtensor.trans))
+        assert self.symm_sqtensor == approx(self.symm_sqtensor.symmetrized)
+        self.assert_all_close(
             self.non_symm.symmetrized,
             SquareTensor([[0.1, 0.3, 0.25], [0.3, 0.5, 0.55], [0.25, 0.55, 0.5]]),
         )
@@ -553,7 +548,7 @@ class SquareTensorTest(PymatgenTest):
             - self.rand_sqtensor[2, 1] * self.rand_sqtensor[1, 2]
         )
         i3 = np.linalg.det(self.rand_sqtensor)
-        self.assertArrayAlmostEqual([i1, i2, i3], self.rand_sqtensor.principal_invariants)
+        self.assert_all_close([i1, i2, i3], self.rand_sqtensor.principal_invariants)
 
     def test_is_rotation(self):
         assert self.rotation.is_rotation()
@@ -562,30 +557,27 @@ class SquareTensorTest(PymatgenTest):
         assert not self.low_val_2.is_rotation(tol=1e-8)
 
     def test_refine_rotation(self):
-        self.assertArrayAlmostEqual(self.rotation, self.rotation.refine_rotation())
+        self.assert_all_close(self.rotation, self.rotation.refine_rotation())
         new = self.rotation.copy()
         new[2, 2] += 0.02
         assert not new.is_rotation()
-        self.assertArrayAlmostEqual(self.rotation, new.refine_rotation())
+        self.assert_all_close(self.rotation, new.refine_rotation())
         new[1] *= 1.05
-        self.assertArrayAlmostEqual(self.rotation, new.refine_rotation())
+        self.assert_all_close(self.rotation, new.refine_rotation())
 
     def test_get_scaled(self):
-        self.assertArrayEqual(
-            self.non_symm.get_scaled(10.0),
-            SquareTensor([[1, 2, 3], [4, 5, 6], [2, 5, 5]]),
-        )
+        assert self.non_symm.get_scaled(10.0) == approx(SquareTensor([[1, 2, 3], [4, 5, 6], [2, 5, 5]]))
 
     def test_polar_decomposition(self):
         u, p = self.rand_sqtensor.polar_decomposition()
-        self.assertArrayAlmostEqual(np.dot(u, p), self.rand_sqtensor)
-        self.assertArrayAlmostEqual(np.eye(3), np.dot(u, np.conjugate(np.transpose(u))))
+        self.assert_all_close(np.dot(u, p), self.rand_sqtensor)
+        self.assert_all_close(np.eye(3), np.dot(u, np.conjugate(np.transpose(u))))
 
     def test_serialization(self):
         # Test base serialize-deserialize
         d = self.rand_sqtensor.as_dict()
         new = SquareTensor.from_dict(d)
-        self.assertArrayAlmostEqual(new, self.rand_sqtensor)
+        self.assert_all_close(new, self.rand_sqtensor)
         assert isinstance(new, SquareTensor)
 
         # Ensure proper object-independent deserialization
@@ -596,8 +588,4 @@ class SquareTensorTest(PymatgenTest):
             vsym = self.rand_sqtensor.voigt_symmetrized
             d_vsym = vsym.as_dict(voigt=True)
             new_voigt = Tensor.from_dict(d_vsym)
-            self.assertArrayAlmostEqual(vsym, new_voigt)
-
-
-if __name__ == "__main__":
-    unittest.main()
+            self.assert_all_close(vsym, new_voigt)
