@@ -1,6 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module provides classes to define a simulation trajectory, which could come from
 either relaxation or molecular dynamics.
@@ -12,34 +9,27 @@ import itertools
 import warnings
 from fnmatch import fnmatch
 from pathlib import Path
-from typing import Any, Dict, List, Tuple, Union
+from typing import Any, Dict, Iterator, List, Sequence, Tuple, Union
 
 import numpy as np
 from monty.io import zopen
 from monty.json import MSONable
 
-from pymatgen.core.structure import (
-    Composition,
-    DummySpecies,
-    Element,
-    Lattice,
-    Species,
-    Structure,
-)
+from pymatgen.core.structure import Composition, DummySpecies, Element, Lattice, Molecule, Species, Structure
 from pymatgen.io.vasp.outputs import Vasprun, Xdatcar
 
-__author__ = "Eric Sivonxay, Shyam Dwaraknath, Mingjian Wen"
+__author__ = "Eric Sivonxay, Shyam Dwaraknath, Mingjian Wen, Evan Spotte-Smith"
 __version__ = "0.1"
 __date__ = "Jun 29, 2022"
 
 Vector3D = Tuple[float, float, float]
 Matrix3D = Tuple[Vector3D, Vector3D, Vector3D]
-SitePropsType = Union[List[Dict[Any, List[Any]]], Dict[Any, List[Any]]]
+SitePropsType = Union[List[Dict[Any, Sequence[Any]]], Dict[Any, Sequence[Any]]]
 
 
 class Trajectory(MSONable):
     """
-    Trajectory of a relaxation or molecular dynamics simulation.
+    Trajectory of a geometry optimization or molecular dynamics simulation.
 
     Provides basic functions such as slicing trajectory, combining trajectories, and
     obtaining displacements.
@@ -47,13 +37,15 @@ class Trajectory(MSONable):
 
     def __init__(
         self,
-        lattice: Lattice | Matrix3D | list[Lattice] | list[Matrix3D] | np.ndarray,
         species: list[str | Element | Species | DummySpecies | Composition],
-        frac_coords: list[list[Vector3D]] | np.ndarray,
+        coords: list[list[Vector3D]] | np.ndarray | list[np.ndarray],
+        charge: int | float | None = None,
+        spin_multiplicity: int | float | None = None,
+        lattice: Lattice | Matrix3D | list[Lattice] | list[Matrix3D] | np.ndarray | None = None,
         *,
         site_properties: SitePropsType | None = None,
         frame_properties: list[dict] | None = None,
-        constant_lattice: bool = True,
+        constant_lattice: bool | None = True,
         time_step: int | float | None = None,
         coords_are_displacement: bool = False,
         base_positions: list[list[Vector3D]] | np.ndarray | None = None,
@@ -63,13 +55,6 @@ class Trajectory(MSONable):
         number of frames in the trajectory.
 
         Args:
-            lattice: shape (3, 3) or (M, 3, 3). Lattice of the structures in the
-                trajectory; should be used together with `constant_lattice`.
-                If `constant_lattice=True`, this should be a single lattice that is
-                common for all structures in the trajectory (e.g. in an NVT run).
-                If `constant_lattice=False`, this should be a list of lattices,
-                each for one structure in the trajectory (e.g. in an NPT run or a
-                relaxation that allows changing the cell size).
             species: shape (N,). List of species on each site. Can take in flexible
                 input, including:
                 i.  A sequence of element / species specified either as string
@@ -78,7 +63,19 @@ class Trajectory(MSONable):
                 ii. List of dict of elements/species and occupancies, e.g.,
                     [{"Fe" : 0.5, "Mn":0.5}, ...]. This allows the setup of
                     disordered structures.
-            frac_coords: shape (M, N, 3). fractional coordinates of the sites.
+            coords: shape (M, N, 3). fractional coordinates of the sites.
+            charge: int or float. Charge of the system. This is only used for Molecule-based
+                trajectories.
+            spin_multiplicity: int or float. Spin multiplicity of the system. This is only
+                used for Molecule-based trajectories.
+            lattice: shape (3, 3) or (M, 3, 3). Lattice of the structures in the
+                trajectory; should be used together with `constant_lattice`.
+                If `constant_lattice=True`, this should be a single lattice that is
+                common for all structures in the trajectory (e.g. in an NVT run).
+                If `constant_lattice=False`, this should be a list of lattices,
+                each for one structure in the trajectory (e.g. in an NPT run or a
+                relaxation that allows changing the cell size). This is only used for
+                Structure-based trajectories.
             site_properties: Properties associated with the sites. This should be a
                 list of `M` dicts for a single dict. If a list of dicts, each provides
                 the site properties for a frame. Each value in a dict should be a
@@ -94,35 +91,49 @@ class Trajectory(MSONable):
                 providing the properties for a frame. For example, for a trajectory with
                 `M=2`, the `frame_properties` can be [{'energy':1.0}, {'energy':2.0}].
             constant_lattice: Whether the lattice changes during the simulation.
-                Should be used together with `lattice`. See usage there.
+                Should be used together with `lattice`. See usage there. This is only
+                used for Structure-based trajectories.
             time_step: Time step of MD simulation in femto-seconds. Should be `None`
-                for relaxation trajectory.
-            coords_are_displacement: Whether `frac_coords` are given in displacements
-                (True) or positions (False). Note, if this is `True`, `frac_coords`
+                for a trajectory representing a geometry optimization.
+            coords_are_displacement: Whether `coords` are given in displacements
+                (True) or positions (False). Note, if this is `True`, `coords`
                 of a frame (say i) should be relative to the previous frame (i.e.
                 i-1), but not relative to the `base_position`.
             base_positions: shape (N, 3). The starting positions of all atoms in the
                 trajectory. Used to reconstruct positions when converting from
                 displacements to positions. Only needs to be specified if
                 `coords_are_displacement=True`. Defaults to the first index of
-                `frac_coords` when `coords_are_displacement=False`.
+                `coords` when `coords_are_displacement=False`.
         """
-        if isinstance(lattice, Lattice):
-            lattice = lattice.matrix
-        elif isinstance(lattice, list) and isinstance(lattice[0], Lattice):
-            lattice = [x.matrix for x in lattice]  # type: ignore
-        lattice = np.asarray(lattice)
+        self.charge = self.spin_multiplicity = self.lattice = self.constant_lattice = None
 
-        if not constant_lattice and lattice.shape == (3, 3):
-            self.lattice = np.tile(lattice, (len(frac_coords), 1, 1))
-            warnings.warn(
-                "Get `constant_lattice=False`, but only get a single `lattice`. "
-                "Use this single `lattice` as the lattice for all frames."
-            )
+        # First, sanity check that the necessary inputs have been provided
+        if lattice is None:
+            if charge is None:
+                raise ValueError("`charge` must be provided for a Molecule-based Trajectory!")
+
+            self.charge = int(charge)
+            if spin_multiplicity is None:
+                self.spin_multiplicity = None
+            else:
+                self.spin_multiplicity = spin_multiplicity
         else:
-            self.lattice = lattice
+            if isinstance(lattice, Lattice):
+                lattice = lattice.matrix
+            elif isinstance(lattice, list) and isinstance(lattice[0], Lattice):
+                lattice = [x.matrix for x in lattice]  # type: ignore
+            lattice = np.asarray(lattice)
 
-        self.constant_lattice = constant_lattice
+            if not constant_lattice and lattice.shape == (3, 3):
+                self.lattice = np.tile(lattice, (len(coords), 1, 1))
+                warnings.warn(
+                    "Get `constant_lattice=False`, but only get a single `lattice`. "
+                    "Use this single `lattice` as the lattice for all frames."
+                )
+            else:
+                self.lattice = lattice
+
+            self.constant_lattice = constant_lattice
 
         if coords_are_displacement:
             if base_positions is None:
@@ -132,11 +143,11 @@ class Trajectory(MSONable):
                 )
             self.base_positions = base_positions
         else:
-            self.base_positions = frac_coords[0]  # type: ignore[assignment]
+            self.base_positions = coords[0]  # type: ignore[assignment]
         self.coords_are_displacement = coords_are_displacement
 
         self.species = species
-        self.frac_coords = np.asarray(frac_coords)
+        self.coords = np.asarray(coords)
         self.time_step = time_step
 
         self._check_site_props(site_properties)
@@ -145,63 +156,83 @@ class Trajectory(MSONable):
         self._check_frame_props(frame_properties)
         self.frame_properties = frame_properties
 
-    def get_structure(self, i: int) -> Structure:
+    def get_structure(self, idx: int) -> Structure:
         """
         Get structure at specified index.
 
         Args:
-            i: Index of structure.
+            idx: Index of structure.
 
         Returns:
             A pymatgen Structure object.
         """
-        return self[i]
+        struct = self[idx]
+        if isinstance(struct, Molecule):
+            raise TypeError("Cannot return `Structure` for `Molecule`-based `Trajectory`! Use `get_molecule` instead!")
 
-    def to_positions(self):
+        return struct
+
+    def get_molecule(self, idx: int) -> Molecule:
+        """
+        Get molecule at specified index.
+
+        Args:
+            idx: Index of molecule.
+
+        Returns:
+            A pymatgen Molecule object.
+        """
+        mol = self[idx]
+        if isinstance(mol, Structure):
+            raise TypeError("Cannot return `Molecule` for `Structure`-based `Trajectory`! Use `get_structure` instead!")
+
+        return mol
+
+    def to_positions(self) -> None:
         """
         Convert displacements between consecutive frames into positions.
 
-        `base_positions` and `frac_coords` should both be in fractional coords or
+        `base_positions` and `coords` should both be in fractional coords or
         absolute coords.
 
         This is the opposite operation of `to_displacements()`.
         """
-        if self.coords_are_displacement:
-            cumulative_displacements = np.cumsum(self.frac_coords, axis=0)
-            positions = self.base_positions + cumulative_displacements
-            self.frac_coords = positions
-            self.coords_are_displacement = False
+        if not self.coords_are_displacement:
+            return
+        cumulative_displacements = np.cumsum(self.coords, axis=0)
+        positions = self.base_positions + cumulative_displacements
+        self.coords = positions
+        self.coords_are_displacement = False
 
-    def to_displacements(self):
+    def to_displacements(self) -> None:
         """
         Converts positions of trajectory into displacements between consecutive frames.
 
-        `base_positions` and `frac_coords` should both be in fractional coords. Does
+        `base_positions` and `coords` should both be in fractional coords. Does
         not work for absolute coords because the atoms are to be wrapped into the
         simulation box.
 
         This is the opposite operation of `to_positions()`.
         """
-        if not self.coords_are_displacement:
-
-            displacements = np.subtract(
-                self.frac_coords,
-                np.roll(self.frac_coords, 1, axis=0),
-            )
-            displacements[0] = np.zeros(np.shape(self.frac_coords[0]))
+        if self.coords_are_displacement:
+            return
+        displacements = np.subtract(self.coords, np.roll(self.coords, 1, axis=0))
+        displacements[0] = np.zeros(np.shape(self.coords[0]))
 
+        # check if the trajectory is periodic
+        if self.lattice is not None:
             # Deal with PBC.
             # For example - If in one frame an atom has fractional coordinates of
             # [0, 0, 0.98] and in the next its coordinates are [0, 0, 0.01], this atom
             # will have moved 0.03*c, but if we only subtract the positions, we would
             # get a displacement vector of [0, 0, -0.97]. Therefore, we can correct for
             # this by adding or subtracting 1 from the value.
-            displacements = [np.subtract(d, np.around(d)) for d in displacements]
+            displacements = np.subtract(displacements, np.around(displacements))
 
-            self.frac_coords = displacements
-            self.coords_are_displacement = True
+        self.coords = displacements
+        self.coords_are_displacement = True
 
-    def extend(self, trajectory: Trajectory):
+    def extend(self, trajectory: Trajectory) -> None:
         """
         Append a trajectory to the current one.
 
@@ -210,6 +241,15 @@ class Trajectory(MSONable):
         Args:
             trajectory: Trajectory to append.
         """
+        # Cannot combine Molecule and Structure Trajectories
+        if (
+            self.lattice is None  # is molecules
+            and trajectory.lattice is not None  # is structures
+            or self.lattice is not None  # is structures
+            and trajectory.lattice is None  # is molecules
+        ):
+            raise ValueError("Cannot combine `Molecule`- and `Structure`-based `Trajectory`. objects.")
+
         if self.time_step != trajectory.time_step:
             raise ValueError(
                 "Cannot extend trajectory. Time steps of the trajectories are "
@@ -240,36 +280,33 @@ class Trajectory(MSONable):
             len(trajectory),
         )
 
-        self.lattice, self.constant_lattice = self._combine_lattice(
-            self.lattice,
-            trajectory.lattice,
-            len(self),
-            len(trajectory),
-        )
+        if self.lattice is not None and trajectory.lattice is not None:
+            self.lattice, self.constant_lattice = self._combine_lattice(
+                self.lattice,
+                trajectory.lattice,
+                len(self),
+                len(trajectory),
+            )
 
         # Note, this should be after the other self._combine... method calls, since
         # len(self) is used there.
-        self.frac_coords = np.concatenate((self.frac_coords, trajectory.frac_coords))
+        self.coords = np.concatenate((self.coords, trajectory.coords))
 
-    def __iter__(self):
-        """
-        Iterator of the trajectory, yielding a pymatgen structure for each frame.
-        """
-        for i in range(len(self)):
-            yield self[i]
+    def __iter__(self) -> Iterator[Structure | Molecule]:
+        """Iterator of the trajectory, yielding a pymatgen Structure or Molecule for each frame."""
+        for idx in range(len(self)):
+            yield self[idx]
 
-    def __len__(self):
-        """
-        Number of frames in the trajectory.
-        """
-        return len(self.frac_coords)
+    def __len__(self) -> int:
+        """Number of frames in the trajectory."""
+        return len(self.coords)
 
-    def __getitem__(self, frames: int | slice | list[int]) -> Structure | Trajectory:
+    def __getitem__(self, frames: int | slice | list[int]) -> Molecule | Structure | Trajectory:
         """
         Get a subset of the trajectory.
 
         The output depends on the type of the input `frames`. If an int is given, return
-        a pymatgen Structure at the specified frame. If a list or a slice, return a new
+        a pymatgen Molecule or Structure at the specified frame. If a list or a slice, return a new
         trajectory with a subset of frames.
 
         Args:
@@ -278,28 +315,39 @@ class Trajectory(MSONable):
         Return:
             Subset of trajectory
         """
-        # Convert to position mode if not ready
+        # Convert to position mode if not already
         self.to_positions()
 
         # For integer input, return the structure at that frame
         if isinstance(frames, int):
-
             if frames >= len(self):
                 raise IndexError(f"Frame index {frames} out of range.")
 
-            lattice = self.lattice if self.constant_lattice else self.lattice[frames]
+            if self.lattice is None:
+                if self.charge is not None:
+                    charge = int(self.charge)
+                if self.spin_multiplicity is not None:
+                    spin = int(self.spin_multiplicity)
+                return Molecule(
+                    self.species,
+                    self.coords[frames],
+                    charge=charge,
+                    spin_multiplicity=spin,
+                    site_properties=self._get_site_props(frames),  # type: ignore
+                )
+
+            lattice = self.lattice if self.constant_lattice else self.lattice[frames]  # type: ignore
 
             return Structure(
                 Lattice(lattice),
                 self.species,
-                self.frac_coords[frames],
+                self.coords[frames],
                 site_properties=self._get_site_props(frames),  # type: ignore
                 to_unit_cell=True,
             )
 
         # For slice input, return a trajectory
         if isinstance(frames, (slice, list, np.ndarray)):
-
             if isinstance(frames, slice):
                 start, stop, step = frames.indices(len(self))
                 selected = list(range(start, stop, step))
@@ -311,18 +359,31 @@ class Trajectory(MSONable):
                     bad_frames = [i for i in frames if i > len(self)]
                     raise IndexError(f"Frame index {bad_frames} out of range.")
 
-            lattice = self.lattice if self.constant_lattice else self.lattice[selected]
-            frac_coords = self.frac_coords[selected]
-
+            coords = self.coords[selected]
             if self.frame_properties is not None:
                 frame_properties = [self.frame_properties[i] for i in selected]
             else:
                 frame_properties = None
 
+            if self.lattice is None:
+                return Trajectory(
+                    species=self.species,
+                    coords=coords,
+                    charge=self.charge,
+                    spin_multiplicity=self.spin_multiplicity,
+                    site_properties=self._get_site_props(selected),
+                    frame_properties=frame_properties,
+                    time_step=self.time_step,
+                    coords_are_displacement=False,
+                    base_positions=self.base_positions,
+                )
+
+            lattice = self.lattice if self.constant_lattice else self.lattice[selected]  # type: ignore
+
             return Trajectory(
-                lattice,
-                self.species,
-                frac_coords,
+                species=self.species,
+                coords=coords,
+                lattice=lattice,
                 site_properties=self._get_site_props(selected),
                 frame_properties=frame_properties,
                 constant_lattice=self.constant_lattice,
@@ -337,7 +398,7 @@ class Trajectory(MSONable):
     def write_Xdatcar(
         self,
         filename: str | Path = "XDATCAR",
-        system: str = None,
+        system: str | None = None,
         significant_figures: int = 6,
     ):
         """
@@ -353,6 +414,9 @@ class Trajectory(MSONable):
             system: Description of system (e.g. 2D MoS2).
             significant_figures: Significant figures in the output file.
         """
+        if self.lattice is None:
+            raise TypeError("`write_Xdatcar` can only be used with `Structure`-based `Trajectory` objects!")
+
         # Ensure trajectory is in position form
         self.to_positions()
 
@@ -364,29 +428,25 @@ class Trajectory(MSONable):
         syms = [site.specie.symbol for site in self[0]]
         site_symbols = [a[0] for a in itertools.groupby(syms)]
         syms = [site.specie.symbol for site in self[0]]
-        natoms = [len(tuple(a[1])) for a in itertools.groupby(syms)]
+        n_atoms = [len(tuple(a[1])) for a in itertools.groupby(syms)]
 
-        for si, frac_coords in enumerate(self.frac_coords):
+        for si, coords in enumerate(self.coords):
             # Only print out the info block if
             if si == 0 or not self.constant_lattice:
                 lines.extend([system, "1.0"])
 
-                if self.constant_lattice:
-                    _lattice = self.lattice
-                else:
-                    _lattice = self.lattice[si]
+                _lattice = self.lattice if self.constant_lattice else self.lattice[si]  # type: ignore
 
                 for latt_vec in _lattice:
-                    lines.append(f'{" ".join([str(el) for el in latt_vec])}')
+                    lines.append(f'{" ".join(map(str, latt_vec))}')
 
                 lines.append(" ".join(site_symbols))
-                lines.append(" ".join([str(x) for x in natoms]))
+                lines.append(" ".join(map(str, n_atoms)))
 
             lines.append(f"Direct configuration=     {si + 1}")
 
-            for (frac_coord, specie) in zip(frac_coords, self.species):
-                coords = frac_coord
-                line = f'{" ".join([format_str.format(c) for c in coords])} {specie}'
+            for coord, specie in zip(coords, self.species):
+                line = f'{" ".join(format_str.format(c) for c in coord)} {specie}'
                 lines.append(line)
 
         xdatcar_string = "\n".join(lines) + "\n"
@@ -395,15 +455,17 @@ class Trajectory(MSONable):
             f.write(xdatcar_string)
 
     def as_dict(self) -> dict:
-        """
-        Return the trajectory as a MSONAble dict.
-        """
+        """Return the trajectory as a MSONable dict."""
+        lat = self.lattice.tolist() if self.lattice is not None else None
+
         return {
             "@module": type(self).__module__,
             "@class": type(self).__name__,
-            "lattice": self.lattice.tolist(),
             "species": self.species,
-            "frac_coords": self.frac_coords.tolist(),
+            "coords": self.coords.tolist(),
+            "charge": self.charge,
+            "spin_multiplicity": self.spin_multiplicity,
+            "lattice": lat,
             "site_properties": self.site_properties,
             "frame_properties": self.frame_properties,
             "constant_lattice": self.constant_lattice,
@@ -413,12 +475,7 @@ class Trajectory(MSONable):
         }
 
     @classmethod
-    def from_structures(
-        cls,
-        structures: list[Structure],
-        constant_lattice: bool = True,
-        **kwargs,
-    ) -> Trajectory:
+    def from_structures(cls, structures: list[Structure], constant_lattice: bool = True, **kwargs) -> Trajectory:
         """
         Create trajectory from a list of structures.
 
@@ -428,6 +485,7 @@ class Trajectory(MSONable):
             structures: pymatgen Structure objects.
             constant_lattice: Whether the lattice changes during the simulation,
                 such as in an NPT MD simulation.
+            **kwargs: Additional kwargs passed to Trajectory constructor.
 
         Returns:
             A trajectory from the structures.
@@ -438,25 +496,47 @@ class Trajectory(MSONable):
             lattice = np.array([structure.lattice.matrix for structure in structures])
 
         species = structures[0].species
-        frac_coords = [structure.frac_coords for structure in structures]
+        coords = [structure.frac_coords for structure in structures]
         site_properties = [structure.site_properties for structure in structures]
 
         return cls(
-            lattice,
-            species,  # type: ignore
-            frac_coords,
-            site_properties=site_properties,
+            species=species,  # type: ignore
+            coords=coords,
+            lattice=lattice,
+            site_properties=site_properties,  # type: ignore
             constant_lattice=constant_lattice,
             **kwargs,
         )
 
     @classmethod
-    def from_file(
-        cls,
-        filename: str | Path,
-        constant_lattice: bool = True,
-        **kwargs,
-    ) -> Trajectory:
+    def from_molecules(cls, molecules: list[Molecule], **kwargs) -> Trajectory:
+        """
+        Create trajectory from a list of molecules.
+
+        Note: Assumes no atoms removed during simulation.
+
+        Args:
+            molecules: pymatgen Molecule objects.
+            **kwargs: Additional kwargs passed to Trajectory constructor.
+
+        Returns:
+            A trajectory from the structures.
+        """
+        species = molecules[0].species
+        coords = [mol.cart_coords for mol in molecules]
+        site_properties = [mol.site_properties for mol in molecules]
+
+        return cls(
+            species=species,  # type: ignore
+            coords=coords,
+            charge=int(molecules[0].charge),
+            spin_multiplicity=int(molecules[0].spin_multiplicity),
+            site_properties=site_properties,  # type: ignore
+            **kwargs,
+        )
+
+    @classmethod
+    def from_file(cls, filename: str | Path, constant_lattice: bool = True, **kwargs) -> Trajectory:
         """
         Create trajectory from XDATCAR or vasprun.xml file.
 
@@ -464,6 +544,7 @@ class Trajectory(MSONable):
             filename: Path to the file to read from.
             constant_lattice: Whether the lattice changes during the simulation,
                 such as in an NPT MD simulation.
+            **kwargs: Additional kwargs passed to Trajectory constructor.
 
         Returns:
             A trajectory from the file.
@@ -486,9 +567,7 @@ class Trajectory(MSONable):
 
     @staticmethod
     def _combine_lattice(lat1: np.ndarray, lat2: np.ndarray, len1: int, len2: int) -> tuple[np.ndarray, bool]:
-        """
-        Helper function to combine trajectory lattice.
-        """
+        """Helper function to combine trajectory lattice."""
         if lat1.ndim == lat2.ndim == 2:
             constant_lat = True
             lat = lat1
@@ -503,7 +582,9 @@ class Trajectory(MSONable):
         return lat, constant_lat
 
     @staticmethod
-    def _combine_site_props(prop1: SitePropsType | None, prop2: SitePropsType | None, len1: int, len2: int):
+    def _combine_site_props(
+        prop1: SitePropsType | None, prop2: SitePropsType | None, len1: int, len2: int
+    ) -> SitePropsType | None:
         """
         Combine site properties.
 
@@ -515,7 +596,7 @@ class Trajectory(MSONable):
         if prop1 is None and prop2 is None:
             return None
 
-        if isinstance(prop1, dict) and isinstance(prop2, dict) and prop1 == prop2:
+        if isinstance(prop1, dict) and prop1 == prop2:
             return prop1
 
         # general case
@@ -540,9 +621,7 @@ class Trajectory(MSONable):
 
     @staticmethod
     def _combine_frame_props(prop1: list[dict] | None, prop2: list[dict] | None, len1: int, len2: int) -> list | None:
-        """
-        Combine frame properties.
-        """
+        """Combine frame properties."""
         if prop1 is None and prop2 is None:
             return None
         if prop1 is None:
@@ -551,9 +630,16 @@ class Trajectory(MSONable):
             return list(prop1) + [None] * len2  # type: ignore
         return list(prop1) + list(prop2)  # type:ignore
 
-    def _check_site_props(self, site_props: SitePropsType | None):
+    def _check_site_props(self, site_props: SitePropsType | None) -> None:
         """
         Check data shape of site properties.
+
+        Args:
+            site_props (dict | list[dict] | None): Returns immediately if None.
+
+        Raises:
+            AssertionError: If the size of the site properties does not match
+                the number of sites in the structure.
         """
         if site_props is None:
             return
@@ -565,18 +651,16 @@ class Trajectory(MSONable):
                 self
             ), f"Size of the site properties {len(site_props)} does not equal to the number of frames {len(self)}."
 
-        num_sites = len(self.frac_coords[0])
-        for d in site_props:
-            for k, v in d.items():
-                assert len(v) == num_sites, (
-                    f"Size of site property {k} {len(v)}) does not equal to the "
-                    f"number of sites in the structure {num_sites}."
+        n_sites = len(self.coords[0])
+        for dct in site_props:
+            for key, val in dct.items():
+                assert len(val) == n_sites, (
+                    f"Size of site property {key} {len(val)}) does not equal to the "
+                    f"number of sites in the structure {n_sites}."
                 )
 
-    def _check_frame_props(self, frame_props: list[dict] | None):
-        """
-        Check data shape of site properties.
-        """
+    def _check_frame_props(self, frame_props: list[dict] | None) -> None:
+        """Check data shape of site properties."""
         if frame_props is None:
             return
 
@@ -585,9 +669,7 @@ class Trajectory(MSONable):
         ), f"Size of the frame properties {len(frame_props)} does not equal to the number of frames {len(self)}."
 
     def _get_site_props(self, frames: int | list[int]) -> SitePropsType | None:
-        """
-        Slice site properties.
-        """
+        """Slice site properties."""
         if self.site_properties is None:
             return None
         if isinstance(self.site_properties, dict):
