@@ -1,12 +1,11 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module defines classes to represent crystal orbital Hamilton
 populations (COHP) and integrated COHP (ICOHP), but can also be used
 for crystal orbital overlap populations (COOP).
 """
 
+from __future__ import annotations
+
 import re
 import sys
 import warnings
@@ -32,9 +31,7 @@ __date__ = "Dec 13, 2017"
 
 
 class Cohp(MSONable):
-    """
-    Basic COHP object.
-    """
+    """Basic COHP object."""
 
     def __init__(self, efermi, energies, cohp, are_coops=False, are_cobis=False, icohp=None):
         """
@@ -57,9 +54,7 @@ class Cohp(MSONable):
         return str(self)
 
     def __str__(self):
-        """
-        Returns a string that can be easily plotted (e.g. using gnuplot).
-        """
+        """Returns a string that can be easily plotted (e.g. using gnuplot)."""
         if self.are_coops:
             cohpstring = "COOP"
         elif self.are_cobis:
@@ -77,17 +72,15 @@ class Cohp(MSONable):
             if Spin.down in self.cohp:
                 header.append("I" + cohpstring + "Down")
                 data.append(self.icohp[Spin.down])
-        formatheader = "#" + " ".join(["{:15s}" for __ in header])
-        formatdata = " ".join(["{:.5f}" for __ in header])
+        formatheader = "#" + " ".join("{:15s}" for __ in header)
+        formatdata = " ".join("{:.5f}" for __ in header)
         stringarray = [formatheader.format(*header)]
         for i, __ in enumerate(self.energies):
             stringarray.append(formatdata.format(*(d[i] for d in data)))
         return "\n".join(stringarray)
 
     def as_dict(self):
-        """
-        JSON-serializable dict representation of COHP.
-        """
+        """JSON-serializable dict representation of COHP."""
         d = {
             "@module": type(self).__module__,
             "@class": type(self).__name__,
@@ -115,10 +108,7 @@ class Cohp(MSONable):
             None and both spins are present, both spins will be returned
             as a dictionary.
         """
-        if not integrated:
-            populations = self.cohp
-        else:
-            populations = self.icohp
+        populations = self.cohp if not integrated else self.icohp
 
         if populations is None:
             return None
@@ -132,9 +122,7 @@ class Cohp(MSONable):
         return {spin: populations[spin]}
 
     def get_icohp(self, spin=None):
-        """
-        Convenient alternative to get the ICOHP for a particular spin.
-        """
+        """Convenient alternative to get the ICOHP for a particular spin."""
         return self.get_cohp(spin=spin, integrated=True)
 
     def get_interpolated_value(self, energy, integrated=False):
@@ -143,6 +131,7 @@ class Cohp(MSONable):
 
         Args:
             energy: Energy to return the COHP value for.
+            integrated: Return COHP (False) or ICOHP (True)
         """
         inter = {}
         for spin in self.cohp:
@@ -189,24 +178,16 @@ class Cohp(MSONable):
         return dict_to_return
 
     @classmethod
-    def from_dict(cls, d):
-        """
-        Returns a COHP object from a dict representation of the COHP.
-        """
-        if "ICOHP" in d:
-            icohp = {Spin(int(key)): np.array(val) for key, val in d["ICOHP"].items()}
-        else:
-            icohp = None
-        if "are_cobis" not in d:
-            are_cobis = False
-        else:
-            are_cobis = d["are_cobis"]
+    def from_dict(cls, dct):
+        """Returns a COHP object from a dict representation of the COHP."""
+        icohp = {Spin(int(key)): np.array(val) for key, val in dct["ICOHP"].items()} if "ICOHP" in dct else None
+        are_cobis = False if "are_cobis" not in dct else dct["are_cobis"]
         return Cohp(
-            d["efermi"],
-            d["energies"],
-            {Spin(int(key)): np.array(val) for key, val in d["COHP"].items()},
+            dct["efermi"],
+            dct["energies"],
+            {Spin(int(key)): np.array(val) for key, val in dct["COHP"].items()},
             icohp=icohp,
-            are_coops=d["are_coops"],
+            are_coops=dct["are_coops"],
             are_cobis=are_cobis,
         )
 
@@ -264,7 +245,7 @@ class CompleteCohp(Cohp):
         Args:
             structure: Structure associated with this COHP.
             avg_cohp: The average cohp as a COHP object.
-            cohps: A dict of COHP objects for individual bonds of the form
+            cohp_dict: A dict of COHP objects for individual bonds of the form
                 {label: COHP}
             bonds: A dict containing information on the bonds of the form
                 {label: {key: val}}. The key-val pair can be any information
@@ -305,9 +286,7 @@ class CompleteCohp(Cohp):
         return "Complete COHPs for " + str(self.structure)
 
     def as_dict(self):
-        """
-        JSON-serializable dict representation of CompleteCohp.
-        """
+        """JSON-serializable dict representation of CompleteCohp."""
         d = {
             "@module": type(self).__module__,
             "@class": type(self).__name__,
@@ -367,7 +346,6 @@ class CompleteCohp(Cohp):
         Returns:
             Returns the COHP object to simplify plotting
         """
-        # TODO: possibly add option to only get one spin channel as Spin.down in the future!
         if label.lower() == "average":
             divided_cohp = self.cohp
             divided_icohp = self.icohp
@@ -396,7 +374,7 @@ class CompleteCohp(Cohp):
 
     def get_summed_cohp_by_label_list(self, label_list, divisor=1, summed_spin_channels=False):
         """
-        Returns a COHP object that includes a summed COHP divided by divisor
+        Returns a COHP object that includes a summed COHP divided by divisor.
 
         Args:
             label_list: list of labels for the COHP that should be included in the summed cohp
@@ -451,7 +429,7 @@ class CompleteCohp(Cohp):
         self, label_list, orbital_list, divisor=1, summed_spin_channels=False
     ):
         """
-        Returns a COHP object that includes a summed COHP divided by divisor
+        Returns a COHP object that includes a summed COHP divided by divisor.
 
         Args:
             label_list: list of labels for the COHP that should be included in the summed cohp
@@ -534,11 +512,11 @@ class CompleteCohp(Cohp):
             orbs = []
             for orbital in orbitals:
                 if isinstance(orbital[1], int):
-                    orbs.append(tuple((orbital[0], Orbital(orbital[1]))))
+                    orbs.append((orbital[0], Orbital(orbital[1])))
                 elif isinstance(orbital[1], Orbital):
-                    orbs.append(tuple((orbital[0], orbital[1])))
+                    orbs.append((orbital[0], orbital[1]))
                 elif isinstance(orbital[1], str):
-                    orbs.append(tuple((orbital[0], Orbital[orbital[1]])))
+                    orbs.append((orbital[0], Orbital[orbital[1]]))
                 else:
                     raise TypeError("Orbital must be str, int, or Orbital.")
             orb_index = cohp_orbs.index(orbs)
@@ -576,9 +554,7 @@ class CompleteCohp(Cohp):
 
     @classmethod
     def from_dict(cls, d):
-        """
-        Returns CompleteCohp object from dict representation.
-        """
+        """Returns CompleteCohp object from dict representation."""
         cohp_dict = {}
         efermi = d["efermi"]
         energies = d["energies"]
@@ -620,7 +596,7 @@ class CompleteCohp(Cohp):
                         }
                     except KeyError:
                         icohp = None
-                    orbitals = [tuple((int(o[0]), Orbital[o[1]])) for o in d["orb_res_cohp"][label][orb]["orbitals"]]
+                    orbitals = [(int(o[0]), Orbital[o[1]]) for o in d["orb_res_cohp"][label][orb]["orbitals"]]
                     orb_cohp[label][orb] = {
                         "COHP": cohp,
                         "ICOHP": icohp,
@@ -672,10 +648,7 @@ class CompleteCohp(Cohp):
                 icohp = None
             avg_cohp = Cohp(efermi, energies, cohp, icohp=icohp)
 
-        if "are_cobis" not in d:
-            are_cobis = False
-        else:
-            are_cobis = d["are_cobis"]
+        are_cobis = False if "are_cobis" not in d else d["are_cobis"]
 
         return CompleteCohp(
             structure,
@@ -695,22 +668,18 @@ class CompleteCohp(Cohp):
         LMTO-ASA code) or LOBSTER (for the LOBSTER code).
 
         Args:
-            cohp_file: Name of the COHP output file. Defaults to COPL
-                for LMTO and COHPCAR.lobster/COOPCAR.lobster for LOBSTER.
-
-            are_coops: Indicates whether the populations are COOPs or
-                COHPs. Defaults to False for COHPs.
-
-            are_cobis: Indicates whether the populations are COBIs or
-                COHPs. Defaults to False for COHPs.
-
             fmt: A string for the code that was used to calculate
                 the COHPs so that the output file can be handled
                 correctly. Can take the values "LMTO" or "LOBSTER".
-
+            filename: Name of the COHP output file. Defaults to COPL
+                for LMTO and COHPCAR.lobster/COOPCAR.lobster for LOBSTER.
             structure_file: Name of the file containing the structure.
                 If no file name is given, use CTRL for LMTO and POSCAR
                 for LOBSTER.
+            are_coops: Indicates whether the populations are COOPs or
+                COHPs. Defaults to False for COHPs.
+            are_cobis: Indicates whether the populations are COBIs or
+                COHPs. Defaults to False for COHPs.
 
         Returns:
             A CompleteCohp object.
@@ -733,14 +702,13 @@ class CompleteCohp(Cohp):
                 raise ValueError("You cannot have info about COOPs and COBIs in the same file.")
             if structure_file is None:
                 structure_file = "POSCAR"
-            if filename is None:
-                if filename is None:
-                    if are_coops:
-                        filename = "COOPCAR.lobster"
-                    elif are_cobis:
-                        filename = "COBICAR.lobster"
-                    else:
-                        filename = "COHPCAR.lobster"
+            if filename is None and filename is None:
+                if are_coops:
+                    filename = "COOPCAR.lobster"
+                elif are_cobis:
+                    filename = "COBICAR.lobster"
+                else:
+                    filename = "COHPCAR.lobster"
             cohp_file = Cohpcar(filename=filename, are_coops=are_coops, are_cobis=are_cobis)
             orb_res_cohp = cohp_file.orb_res_cohp
         else:
@@ -800,7 +768,7 @@ class CompleteCohp(Cohp):
                 efermi,
                 energies,
                 cohp_data["average"]["COHP"],
-                icohp=cohp_data["average"]["COHP"],
+                icohp=cohp_data["average"]["ICOHP"],
                 are_coops=are_coops,
                 are_cobis=are_cobis,
             )
@@ -814,7 +782,7 @@ class CompleteCohp(Cohp):
         bond_dict = {
             label: {
                 "length": v["length"],
-                "sites": [structure.sites[site] for site in v["sites"]],
+                "sites": [structure[site] for site in v["sites"]],
             }
             for label, v in cohp_data.items()
         }
@@ -832,7 +800,7 @@ class CompleteCohp(Cohp):
 
 class IcohpValue(MSONable):
     """
-    Class to store information on an ICOHP or ICOOP value
+    Class to store information on an ICOHP or ICOOP value.
 
     .. attribute:: num_bonds
             number of bonds used for the average cohp (relevant for Lobster versions <3.0) (int)
@@ -851,7 +819,9 @@ class IcohpValue(MSONable):
 
     """
 
-    def __init__(self, label, atom1, atom2, length, translation, num, icohp, are_coops=False, are_cobis=False):
+    def __init__(
+        self, label, atom1, atom2, length, translation, num, icohp, are_coops=False, are_cobis=False, orbitals=None
+    ):
         """
         Args:
             label: label for the icohp
@@ -863,6 +833,9 @@ class IcohpValue(MSONable):
             icohp: dict={Spin.up: icohpvalue for spin.up, Spin.down: icohpvalue for spin.down}
             are_coops: if True, this are COOPs
             are_cobis: if True, this are COBIs
+            orbitals: {[str(Orbital1)-str(Orbital2)]: {"icohp":{Spin.up: icohpvalue for spin.up, Spin.down:
+                icohpvalue for spin.down}, "orbitals":[Orbital1, Orbital2]}}.
+
         """
         if are_coops and are_cobis:
             raise ValueError("You cannot have info about COOPs and COBIs in the same file.")
@@ -875,136 +848,80 @@ class IcohpValue(MSONable):
         self._translation = translation
         self._num = num
         self._icohp = icohp
+        self._orbitals = orbitals
         if Spin.down in self._icohp:
             self._is_spin_polarized = True
         else:
             self._is_spin_polarized = False
 
-    def __str__(self):
-
+    def __str__(self) -> str:
+        """String representation of the ICOHP/ICOOP."""
         if not self._are_coops and not self._are_cobis:
             if self._is_spin_polarized:
                 return (
-                    "ICOHP "
-                    + str(self._label)
-                    + " between "
-                    + str(self._atom1)
-                    + " and "
-                    + str(self._atom2)
-                    + " ("
-                    + str(self._translation)
-                    + "): "
-                    + str(self._icohp[Spin.up])
-                    + " eV (Spin up) and "
-                    + str(self._icohp[Spin.down])
-                    + " eV (Spin down)"
+                    f"ICOHP {self._label} between {self._atom1} and {self._atom2} ({self._translation}): "
+                    f"{self._icohp[Spin.up]} eV (Spin up) and {self._icohp[Spin.down]} eV (Spin down)"
                 )
             return (
-                "ICOHP "
-                + str(self._label)
-                + " between "
-                + str(self._atom1)
-                + " and "
-                + str(self._atom2)
-                + " ("
-                + str(self._translation)
-                + "): "
-                + str(self._icohp[Spin.up])
-                + " eV (Spin up)"
+                f"ICOHP {self._label} between {self._atom1} and {self._atom2} ({self._translation}): "
+                f"{self._icohp[Spin.up]} eV (Spin up)"
             )
-        if self._are_coops:
+        if self._are_coops and not self._are_cobis:
             if self._is_spin_polarized:
                 return (
-                    "ICOOP "
-                    + str(self._label)
-                    + " between "
-                    + str(self._atom1)
-                    + " and "
-                    + str(self._atom2)
-                    + " ("
-                    + str(self._translation)
-                    + "): "
-                    + str(self._icohp[Spin.up])
-                    + " (Spin up) and "
-                    + str(self._icohp[Spin.down])
-                    + " (Spin down)"
+                    f"ICOOP {self._label} between {self._atom1} and {self._atom2} ({self._translation}): "
+                    f"{self._icohp[Spin.up]} eV (Spin up) and {self._icohp[Spin.down]} eV (Spin down)"
                 )
             return (
-                "ICOOP "
-                + str(self._label)
-                + " between "
-                + str(self._atom1)
-                + " and "
-                + str(self._atom2)
-                + " ("
-                + str(self._translation)
-                + "): "
-                + str(self._icohp[Spin.up])
-                + " (Spin up)"
+                f"ICOOP {self._label} between {self._atom1} and {self._atom2} ({self._translation}): "
+                f"{self._icohp[Spin.up]} eV (Spin up)"
             )
-        if self._is_spin_polarized:
+        if self._are_cobis and not self._are_coops:
+            if self._is_spin_polarized:
+                return (
+                    f"ICOBI {self._label} between {self._atom1} and {self._atom2} ({self._translation}): "
+                    f"{self._icohp[Spin.up]} eV (Spin up) and {self._icohp[Spin.down]} eV (Spin down)"
+                )
             return (
-                "ICOBI "
-                + str(self._label)
-                + " between "
-                + str(self._atom1)
-                + " and "
-                + str(self._atom2)
-                + " ("
-                + str(self._translation)
-                + "): "
-                + str(self._icohp[Spin.up])
-                + " (Spin up) and "
-                + str(self._icohp[Spin.down])
-                + " (Spin down)"
+                f"ICOBI {self._label} between {self._atom1} and {self._atom2} ({self._translation}): "
+                f"{self._icohp[Spin.up]} eV (Spin up)"
             )
-        return (
-            "ICOBI "
-            + str(self._label)
-            + " between "
-            + str(self._atom1)
-            + " and "
-            + str(self._atom2)
-            + " ("
-            + str(self._translation)
-            + "): "
-            + str(self._icohp[Spin.up])
-            + " (Spin up)"
-        )
+
+        return ""
 
     @property
     def num_bonds(self):
         """
         tells the number of bonds for which the ICOHP value is an average
         Returns:
-            Int
+            Int.
         """
         return self._num
 
     @property
-    def are_coops(self):
+    def are_coops(self) -> bool:
         """
         tells if ICOOPs or not
         Returns:
-            Boolean
+            Boolean.
         """
         return self._are_coops
 
     @property
-    def are_cobis(self):
+    def are_cobis(self) -> bool:
         """
         tells if ICOBIs or not
         Returns:
-            Boolean
+            Boolean.
         """
         return self._are_cobis
 
     @property
-    def is_spin_polarized(self):
+    def is_spin_polarized(self) -> bool:
         """
         tells if spin polarized calculation or not
         Returns:
-            Boolean
+            Boolean.
         """
         return self._is_spin_polarized
 
@@ -1013,45 +930,71 @@ class IcohpValue(MSONable):
         Args:
             spin: Spin.up or Spin.down
         Returns:
-            icohpvalue (float) corresponding to chosen spin
+            icohpvalue (float) corresponding to chosen spin.
         """
         if not self.is_spin_polarized and spin == Spin.down:
             raise ValueError("The calculation was not performed with spin polarization")
 
         return self._icohp[spin]
 
+    def icohpvalue_orbital(self, orbitals, spin=Spin.up):
+        """
+        Args:
+            orbitals: List of Orbitals or "str(Orbital1)-str(Orbital2)"
+            spin: Spin.up or Spin.down
+        Returns:
+            icohpvalue (float) corresponding to chosen spin.
+        """
+        if not self.is_spin_polarized and spin == Spin.down:
+            raise ValueError("The calculation was not performed with spin polarization")
+        if isinstance(orbitals, list):
+            orbitals = str(orbitals[0]) + "-" + str(orbitals[1])
+        return self._orbitals[orbitals]["icohp"][spin]
+
     @property
     def icohp(self):
         """
         dict with icohps for spinup and spindown
         Return:
-            dict={Spin.up: icohpvalue for spin.up, Spin.down: icohpvalue for spin.down}
+            dict={Spin.up: icohpvalue for spin.up, Spin.down: icohpvalue for spin.down}.
         """
         return self._icohp
 
     @property
     def summed_icohp(self):
         """
-        Adds ICOHPs of both spin channels for spin polarized compounds
+        Sums ICOHPs of both spin channels for spin polarized compounds
         Returns:
-             icohp value in eV
+             icohp value in eV.
         """
-        if self._is_spin_polarized:
-            sum_icohp = self._icohp[Spin.down] + self._icohp[Spin.up]
-        else:
-            sum_icohp = self._icohp[Spin.up]
+        sum_icohp = self._icohp[Spin.down] + self._icohp[Spin.up] if self._is_spin_polarized else self._icohp[Spin.up]
         return sum_icohp
 
+    @property
+    def summed_orbital_icohp(self):
+        """
+        Sums orbitals-resolved ICOHPs of both spin channels for spin-plarized compounds
+        Returns:
+            {"str(Orbital1)-str(Ortibal2)": icohp value in eV}.
+
+        """
+        orbital_icohp = {}
+        for orb, item in self._orbitals.items():
+            orbital_icohp[orb] = (
+                item["icohp"][Spin.up] + item["icohp"][Spin.down] if self._is_spin_polarized else item["icohp"][Spin.up]
+            )
+        return orbital_icohp
+
 
 class IcohpCollection(MSONable):
     """
-    Class to store IcohpValues
+    Class to store IcohpValues.
 
     .. attribute:: are_coops
-        Boolean to indicate if this are ICOOPs
+        Boolean to indicate if these are ICOOPs
 
     .. attribute:: are_cobis
-        Boolean to indicate if this are ICOOPs
+        Boolean to indicate if these are ICOOPs
 
     .. attribute:: is_spin_polarized
         Boolean to indicate if the Lobster calculation was done spin polarized or not
@@ -1068,15 +1011,12 @@ class IcohpCollection(MSONable):
         list_num,
         list_icohp,
         is_spin_polarized,
+        list_orb_icohp=None,
         are_coops=False,
         are_cobis=False,
     ):
         """
         Args:
-            is_spin_polarized: Boolean to indicate if the Lobster calculation was done spin polarized or not Boolean to
-                indicate if the Lobster calculation was done spin polarized or not
-            are_coops: Boolean to indicate whether ICOOPs are stored
-            are_cobis: Boolean to indicate whether ICOBIs are stored
             list_labels: list of labels for ICOHP/ICOOP values
             list_atom1: list of str of atomnames e.g. "O1"
             list_atom2: list of str of atomnames e.g. "O1"
@@ -1084,6 +1024,12 @@ class IcohpCollection(MSONable):
             list_translation: list of translation list, e.g. [0,0,0]
             list_num: list of equivalent bonds, usually 1 starting from Lobster 3.0.0
             list_icohp: list of dict={Spin.up: icohpvalue for spin.up, Spin.down: icohpvalue for spin.down}
+            is_spin_polarized: Boolean to indicate if the Lobster calculation was done spin polarized or not Boolean to
+                indicate if the Lobster calculation was done spin polarized or not
+            list_orb_icohp: list of dict={[str(Orbital1)-str(Orbital2)]: {"icohp":{Spin.up: icohpvalue for spin.up,
+                Spin.down: icohpvalue for spin.down}, "orbitals":[Orbital1, Orbital2]}}
+            are_coops: Boolean to indicate whether ICOOPs are stored
+            are_cobis: Boolean to indicate whether ICOBIs are stored.
         """
         if are_coops and are_cobis:
             raise ValueError("You cannot have info about COOPs and COBIs in the same file.")
@@ -1098,6 +1044,7 @@ class IcohpCollection(MSONable):
         self._list_translation = list_translation
         self._list_num = list_num
         self._list_icohp = list_icohp
+        self._list_orb_icohp = list_orb_icohp
 
         for ilist, listel in enumerate(list_labels):
             self._icohplist[listel] = IcohpValue(
@@ -1110,6 +1057,7 @@ class IcohpCollection(MSONable):
                 icohp=list_icohp[ilist],
                 are_coops=are_coops,
                 are_cobis=are_cobis,
+                orbitals=None if list_orb_icohp is None else list_orb_icohp[ilist],
             )
 
     def __str__(self):
@@ -1118,30 +1066,36 @@ class IcohpCollection(MSONable):
             joinstr.append(str(value))
         return "\n".join(joinstr)
 
-    def get_icohp_by_label(self, label, summed_spin_channels=True, spin=Spin.up):
+    def get_icohp_by_label(self, label, summed_spin_channels=True, spin=Spin.up, orbitals=None):
         """
         get an icohp value for a certain bond as indicated by the label (bond labels starting by "1" as in
-        ICOHPLIST/ICOOPLIST)
+        ICOHPLIST/ICOOPLIST).
 
         Args:
             label: label in str format (usually the bond number in Icohplist.lobster/Icooplist.lobster
             summed_spin_channels: Boolean to indicate whether the ICOHPs/ICOOPs of both spin channels should be summed
             spin: if summed_spin_channels is equal to False, this spin indicates which spin channel should be returned
-
+            orbitals: List of Orbital or "str(Orbital1)-str(Orbital2)"
         Returns:
             float describing ICOHP/ICOOP value
         """
         icohp_here = self._icohplist[label]
-        if icohp_here._is_spin_polarized:
+        if orbitals is None:
             if summed_spin_channels:
                 return icohp_here.summed_icohp
             return icohp_here.icohpvalue(spin)
-        return icohp_here.icohpvalue(spin)
+
+        if isinstance(orbitals, list):
+            orbitals = str(orbitals[0]) + "-" + str(orbitals[1])
+        if summed_spin_channels:
+            return icohp_here.summed_orbital_icohp[orbitals]
+
+        return icohp_here.icohpvalue_orbital(spin=spin, orbitals=orbitals)
 
     def get_summed_icohp_by_label_list(self, label_list, divisor=1.0, summed_spin_channels=True, spin=Spin.up):
         """
         get the sum of several ICOHP values that are indicated by a list of labels (labels of the bonds are the same as
-        in ICOHPLIST/ICOOPLIST)
+        in ICOHPLIST/ICOOPLIST).
 
         Args:
             label_list: list of labels of the ICOHPs/ICOOPs that should be summed
@@ -1174,7 +1128,7 @@ class IcohpCollection(MSONable):
             minbondlength: defines the minimum of the bond lengths of the bonds
             maxbondlength: defines the maximum of the bond lengths of the bonds
         Returns:
-             dict of IcohpValues, the keys correspond to the values from the initial list_labels
+             dict of IcohpValues, the keys correspond to the values from the initial list_labels.
         """
         newicohp_dict = {}
         for value in self._icohplist.values():
@@ -1192,7 +1146,8 @@ class IcohpCollection(MSONable):
         only_bonds_to=None,
     ):
         """
-        get a dict of IcohpValue for a certain site (indicated by integer)
+        get a dict of IcohpValue for a certain site (indicated by integer).
+
         Args:
             site: integer describing the site of interest, order as in Icohplist.lobster/Icooplist.lobster, starts at 0
             minsummedicohp: float, minimal icohp/icoop of the bonds that are considered. It is the summed ICOHP value
@@ -1202,6 +1157,7 @@ class IcohpCollection(MSONable):
             minbondlength: float, defines the minimum of the bond lengths of the bonds
             maxbondlength: float, defines the maximum of the bond lengths of the bonds
             only_bonds_to: list of strings describing the bonding partners that are allowed, e.g. ['O']
+
         Returns:
              dict of IcohpValues, the keys correspond to the values from the initial list_labels
         """
@@ -1216,10 +1172,7 @@ class IcohpCollection(MSONable):
                     value._atom1 = value._atom2
                     value._atom2 = save
 
-                if only_bonds_to is None:
-                    second_test = True
-                else:
-                    second_test = re.split(r"(\d+)", value._atom2)[0] in only_bonds_to
+                second_test = True if only_bonds_to is None else re.split("(\\d+)", value._atom2)[0] in only_bonds_to
                 if value._length >= minbondlength and value._length <= maxbondlength and second_test:
                     if minsummedicohp is not None:
                         if value.summed_icohp >= minsummedicohp:
@@ -1228,12 +1181,11 @@ class IcohpCollection(MSONable):
                                     newicohp_dict[key] = value
                             else:
                                 newicohp_dict[key] = value
-                    else:
-                        if maxsummedicohp is not None:
-                            if value.summed_icohp <= maxsummedicohp:
-                                newicohp_dict[key] = value
-                        else:
+                    elif maxsummedicohp is not None:
+                        if value.summed_icohp <= maxsummedicohp:
                             newicohp_dict[key] = value
+                    else:
+                        newicohp_dict[key] = value
 
         return newicohp_dict
 
@@ -1241,16 +1193,13 @@ class IcohpCollection(MSONable):
         """
         get ICOHP/ICOOP of strongest bond
         Args:
-            summed_spin_channels: Boolean to indicate whether the ICOHPs/ICOOPs of both spin channels should be summed
+            summed_spin_channels: Boolean to indicate whether the ICOHPs/ICOOPs of both spin channels should be summed.
 
             spin: if summed_spin_channels is equal to False, this spin indicates which spin channel should be returned
         Returns:
             lowest ICOHP/largest ICOOP value (i.e. ICOHP/ICOOP value of strongest bond)
         """
-        if self._are_coops or self._are_cobis:
-            extremum = -sys.float_info.max
-        else:
-            extremum = sys.float_info.max
+        extremum = -sys.float_info.max if self._are_coops or self._are_cobis else sys.float_info.max
 
         if not self._is_spin_polarized:
             if spin == Spin.down:
@@ -1262,41 +1211,28 @@ class IcohpCollection(MSONable):
                 if not self._are_coops and not self._are_cobis:
                     if value.icohpvalue(spin) < extremum:
                         extremum = value.icohpvalue(spin)
-                        # print(extremum)
-                else:
-                    if value.icohpvalue(spin) > extremum:
-                        extremum = value.icohpvalue(spin)
-                        # print(extremum)
-            else:
-                if not self._are_coops and not self._are_cobis:
-                    if value.summed_icohp < extremum:
-                        extremum = value.summed_icohp
-                        # print(extremum)
-                else:
-                    if value.summed_icohp > extremum:
-                        extremum = value.summed_icohp
-                        # print(extremum)
+                elif value.icohpvalue(spin) > extremum:
+                    extremum = value.icohpvalue(spin)
+            elif not self._are_coops and not self._are_cobis:
+                if value.summed_icohp < extremum:
+                    extremum = value.summed_icohp
+            elif value.summed_icohp > extremum:
+                extremum = value.summed_icohp
         return extremum
 
     @property
-    def is_spin_polarized(self):
-        """
-        :return: Whether it is spin polarized.
-        """
+    def is_spin_polarized(self) -> bool:
+        """:return: Whether it is spin polarized."""
         return self._is_spin_polarized
 
     @property
-    def are_coops(self):
-        """
-        :return: Whether this is a coop.
-        """
+    def are_coops(self) -> bool:
+        """:return: Whether this is a coop."""
         return self._are_coops
 
     @property
-    def are_cobis(self):
-        """
-        :return: Whether this a cobi.
-        """
+    def are_cobis(self) -> bool:
+        """:return: Whether this a cobi."""
         return self._are_cobis
 
 
@@ -1313,7 +1249,7 @@ def get_integrated_cohp_in_energy_range(
                         if float, integrates from this float up to the Fermi level;
                         if [float,float], will integrate in between
         relative_E_Fermi: if True, energy scale with E_Fermi at 0 eV is chosen
-        summed_spin_channels: if True, Spin channels will be summed
+        summed_spin_channels: if True, Spin channels will be summed.
 
     Returns:
         float indicating the integrated COHP if summed_spin_channels==True, otherwise dict of the following form {
@@ -1334,7 +1270,6 @@ def get_integrated_cohp_in_energy_range(
             summedicohp = icohps
 
     if energy_range is None:
-
         energies_corrected = cohp.energies - cohp.efermi
         spl_spinup = InterpolatedUnivariateSpline(energies_corrected, summedicohp[Spin.up], ext=0)
 
@@ -1375,10 +1310,7 @@ def get_integrated_cohp_in_energy_range(
             return spl_spinup(cohp.efermi) - spl_spinup(energy_range)
         return {Spin.up: spl_spinup(cohp.efermi) - spl_spinup(energy_range)}
 
-    if relative_E_Fermi:
-        energies_corrected = cohp.energies - cohp.efermi
-    else:
-        energies_corrected = cohp.energies
+    energies_corrected = cohp.energies - cohp.efermi if relative_E_Fermi else cohp.energies
 
     spl_spinup = InterpolatedUnivariateSpline(energies_corrected, summedicohp[Spin.up], ext=0)
 
