@@ -1,11 +1,10 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module provides core classes needed by all define electronic structure,
 such as the Spin, Orbital, etc.
 """
 
+from __future__ import annotations
+
 from enum import Enum, unique
 
 import numpy as np
@@ -79,9 +78,7 @@ class Orbital(Enum):
 
     @property
     def orbital_type(self):
-        """
-        Returns OrbitalType of an orbital.
-        """
+        """Returns OrbitalType of an orbital."""
         # pylint: disable=E1136
         return OrbitalType[self.name[0]]
 
@@ -172,7 +169,6 @@ class Magmom(MSONable):
 
     @classmethod
     def _get_transformation_matrix(cls, saxis):
-
         saxis = saxis / np.linalg.norm(saxis)
 
         alpha = np.arctan2(saxis[1], saxis[0])
@@ -193,7 +189,6 @@ class Magmom(MSONable):
 
     @classmethod
     def _get_transformation_matrix_inv(cls, saxis):
-
         saxis = saxis / np.linalg.norm(saxis)
 
         alpha = np.arctan2(saxis[1], saxis[0])
@@ -217,7 +212,7 @@ class Magmom(MSONable):
         Get magnetic moment relative to a given spin quantization axis.
         If no axis is provided, moment will be given relative to the
         Magmom's internal spin quantization axis, i.e. equivalent to
-        Magmom.moment
+        Magmom.moment.
 
         :param saxis: (list/numpy array) spin quantization axis
         :return: np.ndarray of length 3
@@ -265,16 +260,15 @@ class Magmom(MSONable):
 
     def get_00t_magmom_with_xyz_saxis(self):
         """
-        For internal implementation reasons, in non-collinear calculations
-        VASP prefers:
+        For internal implementation reasons, in non-collinear calculations VASP prefers the following.
 
-        MAGMOM = 0 0 total_magnetic_moment
-        SAXIS = x y z
+            MAGMOM = 0 0 total_magnetic_moment
+            SAXIS = x y z
 
         to an equivalent:
 
-        MAGMOM = x y z
-        SAXIS = 0 0 1
+            MAGMOM = x y z
+            SAXIS = 0 0 1
 
         This method returns a Magmom object with magnetic moment [0, 0, t],
         where t is the total magnetic moment, and saxis rotated as required.
@@ -308,7 +302,7 @@ class Magmom(MSONable):
         consistent spin quantization axis. To write MAGMOM tags to a
         VASP INCAR, a global SAXIS value for all magmoms has to be used.
         If saxis are inconsistent, can create consistent set with:
-        Magmom.get_consistent_set(magmoms)
+        Magmom.get_consistent_set(magmoms).
 
         :param magmoms: list of magmoms (Magmoms, scalars or vectors)
         :return: bool
@@ -331,10 +325,7 @@ class Magmom(MSONable):
         :return: (list of Magmoms, global spin axis) tuple
         """
         magmoms = [Magmom(magmom) for magmom in magmoms]
-        if saxis is None:
-            saxis = Magmom.get_suggested_saxis(magmoms)
-        else:
-            saxis = saxis / np.linalg.norm(saxis)
+        saxis = Magmom.get_suggested_saxis(magmoms) if saxis is None else saxis / np.linalg.norm(saxis)
         magmoms = [magmom.get_moment(saxis=saxis) for magmom in magmoms]
         return magmoms, saxis
 
@@ -364,12 +355,12 @@ class Magmom(MSONable):
         return np.array([0, 0, 1], dtype="d")
 
     @staticmethod
-    def are_collinear(magmoms):
+    def are_collinear(magmoms) -> bool:
         """
         Method checks to see if a set of magnetic moments are collinear
         with each other.
         :param magmoms: list of magmoms (Magmoms, scalars or vectors)
-        :return: bool
+        :return: bool.
         """
         magmoms = [Magmom(magmom) for magmom in magmoms]
         if not Magmom.have_consistent_saxis(magmoms):
@@ -433,9 +424,7 @@ class Magmom(MSONable):
         return np.linalg.norm(self.moment)
 
     def __eq__(self, other: object) -> bool:
-        """
-        Equal if 'global' magnetic moments are the same, saxis can differ.
-        """
+        """Equal if 'global' magnetic moments are the same, saxis can differ."""
         try:
             other_magmom = Magmom(other)
         except (TypeError, ValueError):
