@@ -1,15 +1,11 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
-"""
-This module defines classes to represent the density of states, etc.
-"""
+"""This module defines classes to represent the density of states, etc."""
 
 from __future__ import annotations
 
 import functools
 import warnings
-from typing import Mapping
+from collections import namedtuple
+from typing import TYPE_CHECKING, Mapping, NamedTuple
 
 import numpy as np
 from monty.json import MSONable
@@ -17,12 +13,16 @@ from scipy.constants import value as _cd
 from scipy.signal import hilbert
 
 from pymatgen.core.periodic_table import get_el_sp
-from pymatgen.core.sites import PeriodicSite
 from pymatgen.core.spectrum import Spectrum
 from pymatgen.core.structure import Structure
 from pymatgen.electronic_structure.core import Orbital, OrbitalType, Spin
 from pymatgen.util.coord import get_linear_interpolated_value
-from pymatgen.util.typing import ArrayLike, SpeciesLike
+
+if TYPE_CHECKING:
+    from numpy.typing import ArrayLike
+
+    from pymatgen.core.sites import PeriodicSite
+    from pymatgen.util.typing import SpeciesLike
 
 
 class DOS(Spectrum):
@@ -58,9 +58,9 @@ class DOS(Spectrum):
         super().__init__(energies, densities, efermi)
         self.efermi = efermi
 
-    def get_interpolated_gap(self, tol: float = 0.001, abs_tol: bool = False, spin: Spin = None):
+    def get_interpolated_gap(self, tol: float = 0.001, abs_tol: bool = False, spin: Spin | None = None):
         """
-        Expects a DOS object and finds the gap
+        Expects a DOS object and finds the gap.
 
         Args:
             tol: tolerance in occupations for determining the gap
@@ -141,7 +141,7 @@ class DOS(Spectrum):
         i_gap_end -= 1
         return self.x[i_gap_end], self.x[i_gap_start]
 
-    def get_gap(self, tol: float = 0.001, abs_tol: bool = False, spin: Spin = None):
+    def get_gap(self, tol: float = 0.001, abs_tol: bool = False, spin: Spin | None = None):
         """
         Expects a DOS object and finds the gap.
 
@@ -159,9 +159,7 @@ class DOS(Spectrum):
         return max(cbm - vbm, 0.0)
 
     def __str__(self):
-        """
-        Returns a string which can be easily plotted (using gnuplot).
-        """
+        """Returns a string which can be easily plotted (using gnuplot)."""
         if Spin.down in self.densities:
             stringarray = [f"#{'Energy':30s} {'DensityUp':30s} {'DensityDown':30s}"]
             for i, energy in enumerate(self.energies):
@@ -191,18 +189,25 @@ class Dos(MSONable):
         Fermi level
     """
 
-    def __init__(self, efermi: float, energies: ArrayLike, densities: Mapping[Spin, ArrayLike]):
+    def __init__(
+        self, efermi: float, energies: ArrayLike, densities: Mapping[Spin, ArrayLike], norm_vol: float | None = None
+    ) -> None:
         """
         Args:
             efermi: Fermi level energy
             energies: A sequences of energies
             densities (dict[Spin: np.array]): representing the density of states for each Spin.
+            norm_vol: The volume used to normalize the densities. Defaults to 1 if None which will not perform any
+                normalization. If not None, the resulting density will have units of states/eV/Angstrom^3, otherwise
+                the density will be in states/eV.
         """
         self.efermi = efermi
         self.energies = np.array(energies)
-        self.densities = {k: np.array(d) for k, d in densities.items()}
+        self.norm_vol = norm_vol
+        vol = norm_vol or 1
+        self.densities = {k: np.array(d) / vol for k, d in densities.items()}
 
-    def get_densities(self, spin: Spin = None):
+    def get_densities(self, spin: Spin | None = None):
         """
         Returns the density of states for a particular spin.
 
@@ -227,7 +232,7 @@ class Dos(MSONable):
     def get_smeared_densities(self, sigma: float):
         """
         Returns the Dict representation of the densities, {Spin: densities},
-        but with a Gaussian smearing of std dev sigma
+        but with a Gaussian smearing of std dev sigma.
 
         Args:
             sigma: Std dev of Gaussian smearing function.
@@ -272,9 +277,9 @@ class Dos(MSONable):
             f[spin] = get_linear_interpolated_value(self.energies, self.densities[spin], energy)
         return f
 
-    def get_interpolated_gap(self, tol: float = 0.001, abs_tol: bool = False, spin: Spin = None):
+    def get_interpolated_gap(self, tol: float = 0.001, abs_tol: bool = False, spin: Spin | None = None):
         """
-        Expects a DOS object and finds the gap
+        Expects a DOS object and finds the gap.
 
         Args:
             tol: tolerance in occupations for determining the gap
@@ -308,7 +313,7 @@ class Dos(MSONable):
         end = get_linear_interpolated_value(terminal_dens, terminal_energies, tol)
         return end - start, end, start
 
-    def get_cbm_vbm(self, tol: float = 0.001, abs_tol: bool = False, spin: Spin = None):
+    def get_cbm_vbm(self, tol: float = 0.001, abs_tol: bool = False, spin: Spin | None = None):
         """
         Expects a DOS object and finds the cbm and vbm.
 
@@ -344,7 +349,7 @@ class Dos(MSONable):
         i_gap_end -= 1
         return self.energies[i_gap_end], self.energies[i_gap_start]
 
-    def get_gap(self, tol: float = 0.001, abs_tol: bool = False, spin: Spin = None):
+    def get_gap(self, tol: float = 0.001, abs_tol: bool = False, spin: Spin | None = None):
         """
         Expects a DOS object and finds the gap.
 
@@ -362,9 +367,7 @@ class Dos(MSONable):
         return max(cbm - vbm, 0.0)
 
     def __str__(self):
-        """
-        Returns a string which can be easily plotted (using gnuplot).
-        """
+        """Returns a string which can be easily plotted (using gnuplot)."""
         if Spin.down in self.densities:
             stringarray = [f"#{'Energy':30s} {'DensityUp':30s} {'DensityDown':30s}"]
             for i, energy in enumerate(self.energies):
@@ -377,9 +380,7 @@ class Dos(MSONable):
 
     @classmethod
     def from_dict(cls, d) -> Dos:
-        """
-        Returns Dos object from dict representation of Dos.
-        """
+        """Returns Dos object from dict representation of Dos."""
         return Dos(
             d["efermi"],
             d["energies"],
@@ -387,9 +388,7 @@ class Dos(MSONable):
         )
 
     def as_dict(self) -> dict:
-        """
-        JSON-serializable dict representation of Dos.
-        """
+        """JSON-serializable dict representation of Dos."""
         return {
             "@module": type(self).__module__,
             "@class": type(self).__name__,
@@ -411,9 +410,9 @@ class FermiDos(Dos, MSONable):
     def __init__(
         self,
         dos: Dos,
-        structure: Structure = None,
-        nelecs: float = None,
-        bandgap: float = None,
+        structure: Structure | None = None,
+        nelecs: float | None = None,
+        bandgap: float | None = None,
     ):
         """
         Args:
@@ -456,10 +455,7 @@ class FermiDos(Dos, MSONable):
         self.A_to_cm = 1e-8
 
         if bandgap:
-            if evbm < self.efermi < ecbm:
-                eref = self.efermi
-            else:
-                eref = (evbm + ecbm) / 2.0
+            eref = self.efermi if evbm < self.efermi < ecbm else (evbm + ecbm) / 2.0
 
             idx_fermi = int(np.argmin(abs(self.energies - eref)))
 
@@ -596,14 +592,12 @@ class FermiDos(Dos, MSONable):
             step /= 10.0
 
         if min(relative_error) > rtol:
-            raise ValueError(f"Could not find fermi within {rtol:.1%} of concentration={concentration}")
+            raise ValueError(f"Could not find fermi within {rtol:.1%} of {concentration=}")
         return fermi
 
     @classmethod
     def from_dict(cls, d) -> FermiDos:
-        """
-        Returns Dos object from dict representation of Dos.
-        """
+        """Returns Dos object from dict representation of Dos."""
         dos = Dos(
             d["efermi"],
             d["energies"],
@@ -612,9 +606,7 @@ class FermiDos(Dos, MSONable):
         return FermiDos(dos, structure=Structure.from_dict(d["structure"]), nelecs=d["nelecs"])
 
     def as_dict(self) -> dict:
-        """
-        JSON-serializable dict representation of Dos.
-        """
+        """JSON-serializable dict representation of Dos."""
         return {
             "@module": type(self).__module__,
             "@class": type(self).__name__,
@@ -647,21 +639,38 @@ class CompleteDos(Dos):
         structure: Structure,
         total_dos: Dos,
         pdoss: Mapping[PeriodicSite, Mapping[Orbital, Mapping[Spin, ArrayLike]]],
-    ):
+        normalize: bool = False,
+    ) -> None:
         """
         Args:
             structure: Structure associated with this particular DOS.
             total_dos: total Dos for structure
             pdoss: The pdoss are supplied as an {Site: {Orbital: {Spin:Densities}}}
+            normalize: Whether to normalize the densities by the volume of the structure.
+                If True, the units of the densities are states/eV/Angstrom^3. Otherwise,
+                the units are states/eV.
         """
+        vol = structure.volume if normalize else None
         super().__init__(
             total_dos.efermi,
             energies=total_dos.energies,
             densities={k: np.array(d) for k, d in total_dos.densities.items()},
+            norm_vol=vol,
         )
         self.pdos = pdoss
         self.structure = structure
 
+    def get_normalized(self) -> CompleteDos:
+        """Returns a normalized version of the CompleteDos."""
+        if self.norm_vol is not None:
+            return self
+        return CompleteDos(
+            structure=self.structure,
+            total_dos=self,
+            pdoss=self.pdos,
+            normalize=True,
+        )
+
     def get_site_orbital_dos(self, site: PeriodicSite, orbital: Orbital) -> Dos:
         """
         Get the Dos for a particular orbital of a particular site.
@@ -690,7 +699,7 @@ class CompleteDos(Dos):
 
     def get_site_spd_dos(self, site: PeriodicSite) -> dict[OrbitalType, Dos]:
         """
-        Get orbital projected Dos of a particular site
+        Get orbital projected Dos of a particular site.
 
         Args:
             site: Site in Structure associated with CompleteDos.
@@ -767,7 +776,7 @@ class CompleteDos(Dos):
 
     def get_element_spd_dos(self, el: SpeciesLike) -> dict[OrbitalType, Dos]:
         """
-        Get element and spd projected Dos
+        Get element and spd projected Dos.
 
         Args:
             el: Element in Structure.composition associated with CompleteDos
@@ -820,13 +829,13 @@ class CompleteDos(Dos):
     def get_band_filling(
         self,
         band: OrbitalType = OrbitalType.d,
-        elements: list[SpeciesLike] = None,
-        sites: list[PeriodicSite] = None,
-        spin: Spin = None,
+        elements: list[SpeciesLike] | None = None,
+        sites: list[PeriodicSite] | None = None,
+        spin: Spin | None = None,
     ) -> float:
         """
-        Computes the orbital-projected band filling, defined as the zeroth moment
-        up to the Fermi level
+        Compute the orbital-projected band filling, defined as the zeroth moment
+        up to the Fermi level.
 
         Args:
             band: Orbital type to get the band center of (default is d-band)
@@ -841,21 +850,20 @@ class CompleteDos(Dos):
         if elements and sites:
             raise ValueError("Both element and site cannot be specified.")
 
+        densities: dict[Spin, ArrayLike] = {}
         if elements:
-            for i, el in enumerate(elements):
+            for idx, el in enumerate(elements):
                 spd_dos = self.get_element_spd_dos(el)[band]
-                if i == 0:
-                    densities = spd_dos.densities
-                else:
-                    densities = add_densities(densities, spd_dos.densities)
+                densities = (
+                    spd_dos.densities if idx == 0 else add_densities(densities, spd_dos.densities)  # type: ignore
+                )
             dos = Dos(self.efermi, self.energies, densities)
         elif sites:
-            for i, site in enumerate(sites):
+            for idx, site in enumerate(sites):
                 spd_dos = self.get_site_spd_dos(site)[band]
-                if i == 0:
-                    densities = spd_dos.densities
-                else:
-                    densities = add_densities(densities, spd_dos.densities)
+                densities = (
+                    spd_dos.densities if idx == 0 else add_densities(densities, spd_dos.densities)  # type: ignore
+                )
             dos = Dos(self.efermi, self.energies, densities)
         else:
             dos = self.get_spd_dos()[band]
@@ -874,13 +882,13 @@ class CompleteDos(Dos):
     def get_band_center(
         self,
         band: OrbitalType = OrbitalType.d,
-        elements: list[SpeciesLike] = None,
-        sites: list[PeriodicSite] = None,
-        spin: Spin = None,
-        erange: list[float] = None,
+        elements: list[SpeciesLike] | None = None,
+        sites: list[PeriodicSite] | None = None,
+        spin: Spin | None = None,
+        erange: list[float] | None = None,
     ) -> float:
         """
-        Computes the orbital-projected band center, defined as the first moment
+        Compute the orbital-projected band center, defined as the first moment
         relative to the Fermi level
             int_{-inf}^{+inf} rho(E)*E dE/int_{-inf}^{+inf} rho(E) dE
         based on the work of Hammer and Norskov, Surf. Sci., 343 (1995) where the
@@ -908,10 +916,10 @@ class CompleteDos(Dos):
     def get_band_width(
         self,
         band: OrbitalType = OrbitalType.d,
-        elements: list[SpeciesLike] = None,
-        sites: list[PeriodicSite] = None,
-        spin: Spin = None,
-        erange: list[float] = None,
+        elements: list[SpeciesLike] | None = None,
+        sites: list[PeriodicSite] | None = None,
+        spin: Spin | None = None,
+        erange: list[float] | None = None,
     ) -> float:
         """
         Get the orbital-projected band width, defined as the square root of the second moment
@@ -938,10 +946,10 @@ class CompleteDos(Dos):
     def get_band_skewness(
         self,
         band: OrbitalType = OrbitalType.d,
-        elements: list[SpeciesLike] = None,
-        sites: list[PeriodicSite] = None,
-        spin: Spin = None,
-        erange: list[float] = None,
+        elements: list[SpeciesLike] | None = None,
+        sites: list[PeriodicSite] | None = None,
+        spin: Spin | None = None,
+        erange: list[float] | None = None,
     ) -> float:
         """
         Get the orbital-projected skewness, defined as the third standardized moment
@@ -972,10 +980,10 @@ class CompleteDos(Dos):
     def get_band_kurtosis(
         self,
         band: OrbitalType = OrbitalType.d,
-        elements: list[SpeciesLike] = None,
-        sites: list[PeriodicSite] = None,
-        spin: Spin = None,
-        erange: list[float] = None,
+        elements: list[SpeciesLike] | None = None,
+        sites: list[PeriodicSite] | None = None,
+        spin: Spin | None = None,
+        erange: list[float] | None = None,
     ) -> float:
         """
         Get the orbital-projected kurtosis, defined as the fourth standardized moment
@@ -1008,10 +1016,10 @@ class CompleteDos(Dos):
         self,
         n: int,
         band: OrbitalType = OrbitalType.d,
-        elements: list[SpeciesLike] = None,
-        sites: list[PeriodicSite] = None,
-        spin: Spin = None,
-        erange: list[float] = None,
+        elements: list[SpeciesLike] | None = None,
+        sites: list[PeriodicSite] | None = None,
+        spin: Spin | None = None,
+        erange: list[float] | None = None,
         center: bool = True,
     ) -> float:
         """
@@ -1038,21 +1046,16 @@ class CompleteDos(Dos):
         if elements and sites:
             raise ValueError("Both element and site cannot be specified.")
 
+        densities: Mapping[Spin, ArrayLike] = {}
         if elements:
             for i, el in enumerate(elements):
                 spd_dos = self.get_element_spd_dos(el)[band]
-                if i == 0:
-                    densities = spd_dos.densities
-                else:
-                    densities = add_densities(densities, spd_dos.densities)
+                densities = spd_dos.densities if i == 0 else add_densities(densities, spd_dos.densities)
             dos = Dos(self.efermi, self.energies, densities)
         elif sites:
             for i, site in enumerate(sites):
                 spd_dos = self.get_site_spd_dos(site)[band]
-                if i == 0:
-                    densities = spd_dos.densities
-                else:
-                    densities = add_densities(densities, spd_dos.densities)
+                densities = spd_dos.densities if i == 0 else add_densities(densities, spd_dos.densities)
             dos = Dos(self.efermi, self.energies, densities)
         else:
             dos = self.get_spd_dos()[band]
@@ -1080,11 +1083,10 @@ class CompleteDos(Dos):
     def get_hilbert_transform(
         self,
         band: OrbitalType = OrbitalType.d,
-        elements: list[SpeciesLike] = None,
-        sites: list[PeriodicSite] = None,
+        elements: list[SpeciesLike] | None = None,
+        sites: list[PeriodicSite] | None = None,
     ) -> Dos:
-        """
-        Returns the Hilbert transform of the orbital-projected density of states,
+        """Return the Hilbert transform of the orbital-projected density of states,
         often plotted for a Newns-Anderson analysis.
 
         Args:
@@ -1099,22 +1101,16 @@ class CompleteDos(Dos):
         if elements and sites:
             raise ValueError("Both element and site cannot be specified.")
 
+        densities: Mapping[Spin, ArrayLike] = {}
         if elements:
-            densities: Mapping[Spin, ArrayLike]
             for i, el in enumerate(elements):
                 spd_dos = self.get_element_spd_dos(el)[band]
-                if i == 0:
-                    densities = spd_dos.densities
-                else:
-                    densities = add_densities(densities, spd_dos.densities)
+                densities = spd_dos.densities if i == 0 else add_densities(densities, spd_dos.densities)
             dos = Dos(self.efermi, self.energies, densities)
         elif sites:
             for i, site in enumerate(sites):
                 spd_dos = self.get_site_spd_dos(site)[band]
-                if i == 0:
-                    densities = spd_dos.densities
-                else:
-                    densities = add_densities(densities, spd_dos.densities)
+                densities = spd_dos.densities if i == 0 else add_densities(densities, spd_dos.densities)
             dos = Dos(self.efermi, self.energies, densities)
         else:
             dos = self.get_spd_dos()[band]
@@ -1129,10 +1125,10 @@ class CompleteDos(Dos):
     def get_upper_band_edge(
         self,
         band: OrbitalType = OrbitalType.d,
-        elements: list[SpeciesLike] = None,
-        sites: list[PeriodicSite] = None,
-        spin: Spin = None,
-        erange: list[float] = None,
+        elements: list[SpeciesLike] | None = None,
+        sites: list[PeriodicSite] | None = None,
+        spin: Spin | None = None,
+        erange: list[float] | None = None,
     ) -> float:
         """
         Get the orbital-projected upper band edge. The definition by Xin et al.
@@ -1165,11 +1161,164 @@ class CompleteDos(Dos):
         upper_band_edge = energies[np.argmax(densities)]
         return upper_band_edge
 
+    def get_dos_fp(
+        self,
+        type: str = "summed_pdos",
+        binning: bool = True,
+        min_e: float | None = None,
+        max_e: float | None = None,
+        n_bins: int = 256,
+        normalize: bool = True,
+    ) -> NamedTuple:
+        """
+        Generates the DOS fingerprint based on work of
+        F. Knoop, T. A. r Purcell, M. Scheffler, C. Carbogno, J. Open Source Softw. 2020, 5, 2671.
+        Source - https://gitlab.com/vibes-developers/vibes/-/tree/master/vibes/materials_fp
+        Copyright (c) 2020 Florian Knoop, Thomas A.R.Purcell, Matthias Scheffler, Christian Carbogno.
+
+
+        Args:
+            type (str): Specify fingerprint type needed can accept '{s/p/d/f/}summed_{pdos/tdos}'
+            (default is summed_pdos)
+            binning (bool): If true, the DOS fingerprint is binned using np.linspace and n_bins.
+                Default is True.
+            min_e (float): The minimum mode energy to include in the fingerprint (default is None)
+            max_e (float): The maximum mode energy to include in the fingerprint (default is None)
+            n_bins (int): Number of bins to be used in the fingerprint (default is 256)
+            normalize (bool): If true, normalizes the area under fp to equal to 1. Default is True.
+
+        Raises:
+            ValueError: If type is not one of the accepted values {s/p/d/f/}summed_{pdos/tdos}.
+
+        Returns:
+            Fingerprint(namedtuple) : The electronic density of states fingerprint
+            of format (energies, densities, type, n_bins)
+        """
+        fingerprint = namedtuple("fingerprint", "energies densities type n_bins bin_width")
+        energies = self.energies - self.efermi
+
+        if max_e is None:
+            max_e = np.max(energies)
+
+        if min_e is None:
+            min_e = np.min(energies)
+
+        pdos_obj = self.get_spd_dos()
+
+        pdos = {}
+        for key in pdos_obj:
+            dens = pdos_obj[key].get_densities()
+
+            pdos[key.name] = dens
+
+        pdos["summed_pdos"] = np.sum(list(pdos.values()), axis=0)
+        pdos["tdos"] = self.get_densities()
+
+        try:
+            densities = pdos[type]
+            if len(energies) < n_bins:
+                inds = np.where((energies >= min_e) & (energies <= max_e))
+                return fingerprint(energies[inds], densities[inds], type, len(energies), np.diff(energies)[0])
+
+            if binning:
+                ener_bounds = np.linspace(min_e, max_e, n_bins + 1)
+                ener = ener_bounds[:-1] + (ener_bounds[1] - ener_bounds[0]) / 2.0
+                bin_width = np.diff(ener)[0]
+            else:
+                ener_bounds = np.array(energies)
+                ener = np.append(energies, [energies[-1] + np.abs(energies[-1]) / 10])
+                n_bins = len(energies)
+                bin_width = np.diff(energies)[0]
+
+            dos_rebin = np.zeros(ener.shape)
+
+            for ii, e1, e2 in zip(range(len(ener)), ener_bounds[0:-1], ener_bounds[1:]):
+                inds = np.where((energies >= e1) & (energies < e2))
+                dos_rebin[ii] = np.sum(densities[inds])
+            if normalize:  # scale DOS bins to make area under histogram equal 1
+                area = np.sum(dos_rebin * bin_width)
+                dos_rebin_sc = dos_rebin / area
+            else:
+                dos_rebin_sc = dos_rebin
+
+            return fingerprint(np.array([ener]), dos_rebin_sc, type, n_bins, bin_width)
+
+        except KeyError:
+            raise ValueError(
+                "Please recheck type requested, either the orbital projections unavailable in input DOS or "
+                "there's a typo in type."
+            )
+
+    @staticmethod
+    def fp_to_dict(fp: NamedTuple) -> dict:
+        """Converts a fingerprint into a dictionary.
+
+        Args:
+            fp: The DOS fingerprint to be converted into a dictionary
+
+        Returns:
+            dict: A dict of the fingerprint Keys=type, Values=np.ndarray(energies, densities)
+        """
+        fp_dict = {}
+        fp_dict[fp[2]] = np.array([fp[0], fp[1]], dtype="object").T
+
+        return fp_dict
+
+    @staticmethod
+    def get_dos_fp_similarity(
+        fp1: NamedTuple,
+        fp2: NamedTuple,
+        col: int = 1,
+        pt: int | str = "All",
+        normalize: bool = False,
+        tanimoto: bool = False,
+    ) -> float:
+        """Calculates the similarity index (dot product) of two fingerprints.
+
+        Args:
+            fp1 (NamedTuple): The 1st dos fingerprint object
+            fp2 (NamedTuple): The 2nd dos fingerprint object
+            col (int): The item in the fingerprints (0:energies,1: densities) to take the dot product of (default is 1)
+            pt (int or str) : The index of the point that the dot product is to be taken (default is All)
+            normalize (bool): If True normalize the scalar product to 1 (default is False)
+            tanimoto (bool): If True will compute Tanimoto index (default is False)
+
+        Raises:
+            ValueError: If both tanimoto and normalize are set to True.
+
+        Returns:
+        Similarity index (float): The value of dot product
+        """
+        fp1_dict = CompleteDos.fp_to_dict(fp1) if not isinstance(fp1, dict) else fp1
+
+        fp2_dict = CompleteDos.fp_to_dict(fp2) if not isinstance(fp2, dict) else fp2
+
+        if pt == "All":
+            vec1 = np.array([pt[col] for pt in fp1_dict.values()]).flatten()
+            vec2 = np.array([pt[col] for pt in fp2_dict.values()]).flatten()
+        else:
+            vec1 = fp1_dict[fp1[2][pt]][col]
+            vec2 = fp2_dict[fp2[2][pt]][col]
+
+        if not normalize and tanimoto:
+            rescale = np.linalg.norm(vec1) ** 2 + np.linalg.norm(vec2) ** 2 - np.dot(vec1, vec2)
+            return np.dot(vec1, vec2) / rescale
+
+        if not tanimoto and normalize:
+            rescale = np.linalg.norm(vec1) * np.linalg.norm(vec2)
+            return np.dot(vec1, vec2) / rescale
+
+        if not tanimoto and not normalize:
+            rescale = 1.0
+            return np.dot(vec1, vec2) / rescale
+
+        raise ValueError(
+            "Cannot compute similarity index. Please set either normalize=True or tanimoto=True or both to False."
+        )
+
     @classmethod
     def from_dict(cls, d) -> CompleteDos:
-        """
-        Returns CompleteDos object from dict representation.
-        """
+        """Returns CompleteDos object from dict representation."""
         tdos = Dos.from_dict(d)
         struct = Structure.from_dict(d["structure"])
         pdoss = {}
@@ -1183,9 +1332,7 @@ class CompleteDos(Dos):
         return CompleteDos(struct, tdos, pdoss)
 
     def as_dict(self) -> dict:
-        """
-        JSON-serializable dict representation of CompleteDos.
-        """
+        """JSON-serializable dict representation of CompleteDos."""
         d = {
             "@module": type(self).__module__,
             "@class": type(self).__name__,
@@ -1212,9 +1359,7 @@ class CompleteDos(Dos):
 
 
 class LobsterCompleteDos(CompleteDos):
-    """
-    Extended CompleteDOS for Lobster
-    """
+    """Extended CompleteDOS for Lobster."""
 
     def get_site_orbital_dos(self, site: PeriodicSite, orbital: str) -> Dos:  # type: ignore
         """
@@ -1255,6 +1400,7 @@ class LobsterCompleteDos(CompleteDos):
     def get_site_t2g_eg_resolved_dos(self, site: PeriodicSite) -> dict[str, Dos]:
         """
         Get the t2g, eg projected DOS for a particular site.
+
         Args:
             site: Site in Structure associated with CompleteDos.
 
@@ -1267,7 +1413,6 @@ class LobsterCompleteDos(CompleteDos):
         eg_dos = []
         for s, atom_dos in self.pdos.items():
             if s == site:
-
                 for orb, pdos in atom_dos.items():
                     if _get_orb_lobster(orb) in (Orbital.dxy, Orbital.dxz, Orbital.dyz):
                         t2g_dos.append(pdos)
@@ -1282,7 +1427,7 @@ class LobsterCompleteDos(CompleteDos):
         """
         Get orbital projected Dos.
         For example, if 3s and 4s are included in the basis of some element, they will be both summed in the orbital
-        projected DOS
+        projected DOS.
 
         Returns:
             dict of {orbital: Dos}, e.g. {"s": Dos object, ...}
@@ -1296,11 +1441,11 @@ class LobsterCompleteDos(CompleteDos):
                 else:
                     spd_dos[orbital_type] = add_densities(spd_dos[orbital_type], pdos)
 
-        return {orb: Dos(self.efermi, self.energies, densities) for orb, densities in spd_dos.items()}
+        return {orb: Dos(self.efermi, self.energies, densities) for orb, densities in spd_dos.items()}  # type: ignore
 
     def get_element_spd_dos(self, el: SpeciesLike) -> dict[str, Dos]:  # type: ignore
         """
-        Get element and spd projected Dos
+        Get element and spd projected Dos.
 
 
         Args:
@@ -1320,13 +1465,11 @@ class LobsterCompleteDos(CompleteDos):
                     else:
                         el_dos[orbital_type] = add_densities(el_dos[orbital_type], pdos)
 
-        return {orb: Dos(self.efermi, self.energies, densities) for orb, densities in el_dos.items()}
+        return {orb: Dos(self.efermi, self.energies, densities) for orb, densities in el_dos.items()}  # type: ignore
 
     @classmethod
     def from_dict(cls, d) -> LobsterCompleteDos:
-        """
-        Returns: CompleteDos object from dict representation.
-        """
+        """Hydrate CompleteDos object from dict representation."""
         tdos = Dos.from_dict(d)
         struct = Structure.from_dict(d["structure"])
         pdoss = {}
@@ -1341,8 +1484,7 @@ class LobsterCompleteDos(CompleteDos):
 
 
 def add_densities(density1: Mapping[Spin, ArrayLike], density2: Mapping[Spin, ArrayLike]) -> dict[Spin, np.ndarray]:
-    """
-    Method to sum two densities.
+    """Sum two densities.
 
     Args:
         density1: First density.
@@ -1354,7 +1496,7 @@ def add_densities(density1: Mapping[Spin, ArrayLike], density2: Mapping[Spin, Ar
     return {spin: np.array(density1[spin]) + np.array(density2[spin]) for spin in density1}
 
 
-def _get_orb_type(orb):
+def _get_orb_type(orb) -> OrbitalType:
     try:
         return orb.orbital_type
     except AttributeError:
@@ -1362,7 +1504,7 @@ def _get_orb_type(orb):
 
 
 def f0(E, fermi, T) -> float:
-    """Returns the equilibrium fermi-dirac.
+    """Return the equilibrium fermi-dirac.
 
     Args:
         E (float): energy in eV
@@ -1375,31 +1517,16 @@ def f0(E, fermi, T) -> float:
     return 1.0 / (1.0 + np.exp((E - fermi) / (_cd("Boltzmann constant in eV/K") * T)))
 
 
-def _get_orb_type_lobster(orb):
+def _get_orb_type_lobster(orb) -> OrbitalType | None:
     """
     Args:
-        orb: string representation of orbital
+        orb: string representation of orbital.
+
     Returns:
         OrbitalType
     """
-    orb_labs = [
-        "s",
-        "p_y",
-        "p_z",
-        "p_x",
-        "d_xy",
-        "d_yz",
-        "d_z^2",
-        "d_xz",
-        "d_x^2-y^2",
-        "f_y(3x^2-y^2)",
-        "f_xyz",
-        "f_yz^2",
-        "f_z^3",
-        "f_xz^2",
-        "f_z(x^2-y^2)",
-        "f_x(x^2-3y^2)",
-    ]
+    orb_labs = ["s", "p_y", "p_z", "p_x", "d_xy", "d_yz", "d_z^2", "d_xz", "d_x^2-y^2"]
+    orb_labs += ["f_y(3x^2-y^2)", "f_xyz", "f_yz^2", "f_z^3", "f_xz^2", "f_z(x^2-y^2)", "f_x(x^2-3y^2)"]
 
     try:
         orbital = Orbital(orb_labs.index(orb[1:]))
@@ -1414,7 +1541,7 @@ def _get_orb_lobster(orb):
     Args:
         orb: string representation of orbital
     Returns:
-         Orbital
+         Orbital.
     """
     orb_labs = [
         "s",
