@@ -1,6 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 Entries are containers for calculated information, which is used in
 many analyses. This module contains entry related tools and implements
@@ -57,9 +54,7 @@ class Entry(MSONable, metaclass=ABCMeta):
 
     @property
     def is_element(self) -> bool:
-        """
-        :return: Whether composition of entry is an element.
-        """
+        """:return: Whether composition of entry is an element."""
         # NOTE _composition rather than composition as GrandPDEntry
         # edge case exists if we have a compound where chempots are
         # given for all bar one element type
@@ -67,32 +62,23 @@ class Entry(MSONable, metaclass=ABCMeta):
 
     @property
     def composition(self) -> Composition:
-        """
-        :return: the composition of the entry.
-        """
+        """:return: the composition of the entry."""
         return self._composition
 
     @property
     @abstractmethod
     def energy(self) -> float:
-        """
-        :return: the energy of the entry.
-        """
+        """:return: the energy of the entry."""
         raise NotImplementedError
 
     @property
     def energy_per_atom(self) -> float:
-        """
-        :return: the energy per atom of the entry.
-        """
+        """:return: the energy per atom of the entry."""
         return self.energy / self.composition.num_atoms
 
     def __repr__(self):
         return f"{type(self).__name__} : {self.composition} with energy = {self.energy:.4f}"
 
-    def __str__(self):
-        return self.__repr__()
-
     def normalize(self, mode: Literal["formula_unit", "atom"] = "formula_unit") -> Entry:
         """
         Normalize the entry's composition and energy.
@@ -125,9 +111,7 @@ class Entry(MSONable, metaclass=ABCMeta):
         return factor
 
     def as_dict(self) -> dict:
-        """
-        :return: MSONable dict.
-        """
+        """MSONable dict."""
         return {
             "@module": type(self).__module__,
             "@class": type(self).__name__,
