@@ -1,6 +1,7 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
+from __future__ import annotations
 
+import copy
+import json
 import os
 import unittest
 import warnings
@@ -10,6 +11,7 @@ from pathlib import Path
 
 import pytest
 from monty.json import MontyDecoder
+from pytest import approx
 
 from pymatgen.core.composition import Composition
 from pymatgen.core.lattice import Lattice
@@ -26,11 +28,7 @@ from pymatgen.entries.compatibility import (
     MITAqueousCompatibility,
     MITCompatibility,
 )
-from pymatgen.entries.computed_entries import (
-    ComputedEntry,
-    ComputedStructureEntry,
-    ConstantEnergyAdjustment,
-)
+from pymatgen.entries.computed_entries import ComputedEntry, ComputedStructureEntry, ConstantEnergyAdjustment
 from pymatgen.util.testing import PymatgenTest
 
 
@@ -365,7 +363,7 @@ class MaterialsProjectCompatibilityTest(unittest.TestCase):
 
     def test_correction_values(self):
         # test_corrections
-        assert self.compat.process_entry(self.entry1).correction == pytest.approx(-2.733 * 2 - 0.70229 * 3)
+        assert self.compat.process_entry(self.entry1).correction == approx(-2.733 * 2 - 0.70229 * 3)
 
         entry = ComputedEntry(
             "FeF3",
@@ -390,9 +388,9 @@ class MaterialsProjectCompatibilityTest(unittest.TestCase):
         assert self.compat.process_entry(entry) is not None
 
         # Check actual correction
-        assert self.compat.process_entry(entry).correction == pytest.approx(-2.733)
+        assert self.compat.process_entry(entry).correction == approx(-2.733)
 
-        assert self.compat.process_entry(self.entry_sulfide).correction == pytest.approx(-0.66346)
+        assert self.compat.process_entry(self.entry_sulfide).correction == approx(-0.66346)
 
     def test_U_values(self):
         # Wrong U value
@@ -529,9 +527,9 @@ class MaterialsProjectCompatibilityTest(unittest.TestCase):
             },
         )
         entry = self.compat.process_entry(entry)
-        #        self.assertEqual(entry.entry_id, -8)
-        assert entry.energy == pytest.approx(-1)
-        assert self.ggacompat.process_entry(entry).energy == pytest.approx(-1)
+        # assert entry.entry_id == -8
+        assert entry.energy == approx(-1)
+        assert self.ggacompat.process_entry(entry).energy == approx(-1)
 
     def test_get_explanation_dict(self):
         compat = MaterialsProjectCompatibility(check_potcar_hash=False)
@@ -556,7 +554,7 @@ class MaterialsProjectCompatibilityTest(unittest.TestCase):
             },
         )
         d = compat.get_explanation_dict(entry)
-        assert "MPRelaxSet Potcar Correction" == d["corrections"][0]["name"]
+        assert d["corrections"][0]["name"] == "MPRelaxSet Potcar Correction"
 
     def test_get_corrections_dict(self):
         compat = MaterialsProjectCompatibility(check_potcar_hash=False)
@@ -584,8 +582,8 @@ class MaterialsProjectCompatibilityTest(unittest.TestCase):
             },
         )
         c = compat.get_corrections_dict(entry)[0]
-        assert c["MP Anion Correction"] == pytest.approx(-2.10687)
-        assert c["MP Advanced Correction"] == pytest.approx(-5.466)
+        assert c["MP Anion Correction"] == approx(-2.10687)
+        assert c["MP Advanced Correction"] == approx(-5.466)
 
         entry.parameters["is_hubbard"] = False
         del entry.parameters["hubbards"]
@@ -794,17 +792,17 @@ class MaterialsProjectCompatibility2020Test(unittest.TestCase):
 
         with pytest.warns(UserWarning, match="Failed to guess oxidation state"):
             e1 = self.compat.process_entry(entry_blank)
-            assert e1.correction == pytest.approx(-0.422)
+            assert e1.correction == approx(-0.422)
 
         e2 = self.compat.process_entry(entry_oxi)
-        assert e2.correction == pytest.approx(-0.687 + -3.202 * 2 + -0.614 * 8)
+        assert e2.correction == approx(-0.687 + -3.202 * 2 + -0.614 * 8)
 
         e3 = self.compat.process_entry(entry_multi_anion)
-        assert e3.correction == pytest.approx(-0.361 * 4 + -0.614 * 4)
+        assert e3.correction == approx(-0.361 * 4 + -0.614 * 4)
 
     def test_correction_values(self):
         # test_corrections
-        assert self.compat.process_entry(self.entry1).correction == pytest.approx(-2.256 * 2 - 0.687 * 3)
+        assert self.compat.process_entry(self.entry1).correction == approx(-2.256 * 2 - 0.687 * 3)
 
         entry = ComputedEntry(
             "FeF3",
@@ -829,9 +827,9 @@ class MaterialsProjectCompatibility2020Test(unittest.TestCase):
         assert self.compat.process_entry(entry) is not None
 
         # Check actual correction
-        assert self.compat.process_entry(entry).correction == pytest.approx(-0.462 * 3 + -2.256)
+        assert self.compat.process_entry(entry).correction == approx(-0.462 * 3 + -2.256)
 
-        assert self.compat.process_entry(self.entry_sulfide).correction == pytest.approx(-0.503)
+        assert self.compat.process_entry(self.entry_sulfide).correction == approx(-0.503)
 
     def test_oxdiation_by_electronegativity(self):
         # make sure anion corrections are only applied when the element has
@@ -889,10 +887,10 @@ class MaterialsProjectCompatibility2020Test(unittest.TestCase):
         )
 
         # CaSi; only correction should be Si
-        assert self.compat.process_entry(entry1).correction == pytest.approx(0.071 * 2)
+        assert self.compat.process_entry(entry1).correction == approx(0.071 * 2)
 
         # SiO2; only corrections should be oxide
-        assert self.compat.process_entry(entry2).correction == pytest.approx(-0.687 * 4)
+        assert self.compat.process_entry(entry2).correction == approx(-0.687 * 4)
 
     def test_oxdiation(self):
         # make sure anion corrections are only applied when the element has
@@ -956,10 +954,10 @@ class MaterialsProjectCompatibility2020Test(unittest.TestCase):
         )
 
         # CaSi; only correction should be Si
-        assert self.compat.process_entry(entry1).correction == pytest.approx(0.071 * 2)
+        assert self.compat.process_entry(entry1).correction == approx(0.071 * 2)
 
         # SiO2; only corrections should be oxide
-        assert self.compat.process_entry(entry2).correction == pytest.approx(-0.687 * 4)
+        assert self.compat.process_entry(entry2).correction == approx(-0.687 * 4)
 
     def test_U_values(self):
         # Wrong U value
@@ -1096,8 +1094,8 @@ class MaterialsProjectCompatibility2020Test(unittest.TestCase):
             },
         )
         entry = self.compat.process_entry(entry)
-        assert entry.energy == pytest.approx(-1)
-        assert self.ggacompat.process_entry(entry).energy == pytest.approx(-1)
+        assert entry.energy == approx(-1)
+        assert self.ggacompat.process_entry(entry).energy == approx(-1)
 
     def test_get_explanation_dict(self):
         compat = MaterialsProjectCompatibility(check_potcar_hash=False)
@@ -1122,7 +1120,7 @@ class MaterialsProjectCompatibility2020Test(unittest.TestCase):
             },
         )
         d = compat.get_explanation_dict(entry)
-        assert "MPRelaxSet Potcar Correction" == d["corrections"][0]["name"]
+        assert d["corrections"][0]["name"] == "MPRelaxSet Potcar Correction"
 
     def test_energy_adjustments(self):
         compat = MaterialsProject2020Compatibility(check_potcar_hash=False)
@@ -1160,14 +1158,14 @@ class MaterialsProjectCompatibility2020Test(unittest.TestCase):
 
         for ea in c.energy_adjustments:
             if ea.name == "MP2020 GGA/GGA+U mixing correction (Fe)":
-                assert ea.value == pytest.approx(-2.256 * 4)
-                assert ea.uncertainty == pytest.approx(0.0101 * 4)
+                assert ea.value == approx(-2.256 * 4)
+                assert ea.uncertainty == approx(0.0101 * 4)
             elif ea.name == "MP2020 GGA/GGA+U mixing correction (Co)":
-                assert ea.value == pytest.approx(-1.638 * 2)
-                assert ea.uncertainty == pytest.approx(0.006 * 2)
+                assert ea.value == approx(-1.638 * 2)
+                assert ea.uncertainty == approx(0.006 * 2)
             elif ea.name == "MP2020 anion correction (oxide)":
-                assert ea.value == pytest.approx(-0.687 * 8)
-                assert ea.uncertainty == pytest.approx(0.002 * 8)
+                assert ea.value == approx(-0.687 * 8)
+                assert ea.uncertainty == approx(0.002 * 8)
 
         entry.parameters["is_hubbard"] = False
         del entry.parameters["hubbards"]
@@ -1184,7 +1182,7 @@ class MaterialsProjectCompatibility2020Test(unittest.TestCase):
         entry = compat.process_entry(self.entry1)
         for ea in entry.energy_adjustments:
             if ea.name == "MP2020 GGA/GGA+U mixing correction (Fe)":
-                assert ea.value == pytest.approx(-0.224 * 2)
+                assert ea.value == approx(-0.224 * 2)
 
     def test_msonable(self):
         compat_dict = self.compat.as_dict()
@@ -1192,6 +1190,16 @@ class MaterialsProjectCompatibility2020Test(unittest.TestCase):
         temp_compat = decoder.process_decoded(compat_dict)
         assert isinstance(temp_compat, MaterialsProject2020Compatibility)
 
+    def test_processing_entries_inplace(self):
+        # load two entries in GGA_GGA_U_R2SCAN thermo type
+        entriesJson = Path(PymatgenTest.TEST_FILES_DIR / "entries_thermo_type_GGA_GGA_U_R2SCAN.json")
+        with open(entriesJson) as file:
+            entries = json.load(file, cls=MontyDecoder)
+        # check whether the compatibility scheme can keep input entries unchanged
+        entries_copy = copy.deepcopy(entries)
+        self.compat.process_entries(entries, inplace=False)
+        assert all(e.correction == e_copy.correction for e, e_copy in zip(entries, entries_copy))
+
 
 class MITCompatibilityTest(unittest.TestCase):
     def tearDown(self):
@@ -1270,9 +1278,9 @@ class MITCompatibilityTest(unittest.TestCase):
 
     def test_correction_value(self):
         # Check actual correction
-        assert self.compat.process_entry(self.entry_O).correction == pytest.approx(-1.723 * 2 - 0.66975 * 3)
-        assert self.compat.process_entry(self.entry_F).correction == pytest.approx(-1.723)
-        assert self.compat.process_entry(self.entry_S).correction == pytest.approx(-1.113)
+        assert self.compat.process_entry(self.entry_O).correction == approx(-1.723 * 2 - 0.66975 * 3)
+        assert self.compat.process_entry(self.entry_F).correction == approx(-1.723)
+        assert self.compat.process_entry(self.entry_S).correction == approx(-1.113)
 
     def test_U_value(self):
         # MIT should have a U value for Fe containing sulfides
@@ -1417,7 +1425,7 @@ class MITCompatibilityTest(unittest.TestCase):
             },
         )
         entry = self.compat.process_entry(entry)
-        assert entry.energy == pytest.approx(-1)
+        assert entry.energy == approx(-1)
 
     def test_same_potcar_symbol(self):
         # Same symbol different hash thus a different potcar
@@ -1540,7 +1548,7 @@ class MITCompatibilityTest(unittest.TestCase):
             },
         )
         d = compat.get_explanation_dict(entry)
-        assert "MITRelaxSet Potcar Correction" == d["corrections"][0]["name"]
+        assert d["corrections"][0]["name"] == "MITRelaxSet Potcar Correction"
 
     def test_msonable(self):
         compat_dict = self.compat.as_dict()
@@ -1576,7 +1584,7 @@ class OxideTypeCorrectionTest(unittest.TestCase):
         )
 
         lio2_entry_corrected = self.compat.process_entry(lio2_entry_nostruct)
-        assert lio2_entry_corrected.energy == pytest.approx(-3 - 0.13893 * 4)
+        assert lio2_entry_corrected.energy == approx(-3 - 0.13893 * 4)
 
     def test_process_entry_superoxide(self):
         el_li = Element("Li")
@@ -1612,7 +1620,7 @@ class OxideTypeCorrectionTest(unittest.TestCase):
         )
 
         lio2_entry_corrected = self.compat.process_entry(lio2_entry)
-        assert lio2_entry_corrected.energy == pytest.approx(-3 - 0.13893 * 4)
+        assert lio2_entry_corrected.energy == approx(-3 - 0.13893 * 4)
 
     def test_process_entry_peroxide(self):
         latt = Lattice.from_parameters(3.159597, 3.159572, 7.685205, 89.999884, 89.999674, 60.000510)
@@ -1651,7 +1659,7 @@ class OxideTypeCorrectionTest(unittest.TestCase):
         )
 
         li2o2_entry_corrected = self.compat.process_entry(li2o2_entry)
-        assert li2o2_entry_corrected.energy == pytest.approx(-3 - 0.44317 * 4)
+        assert li2o2_entry_corrected.energy == approx(-3 - 0.44317 * 4)
 
     def test_process_entry_ozonide(self):
         el_li = Element("Li")
@@ -1686,7 +1694,7 @@ class OxideTypeCorrectionTest(unittest.TestCase):
         )
 
         lio3_entry_corrected = self.compat.process_entry(lio3_entry)
-        assert lio3_entry_corrected.energy == pytest.approx(-3.0)
+        assert lio3_entry_corrected.energy == approx(-3.0)
 
     def test_process_entry_oxide(self):
         el_li = Element("Li")
@@ -1716,7 +1724,7 @@ class OxideTypeCorrectionTest(unittest.TestCase):
         )
 
         li2o_entry_corrected = self.compat.process_entry(li2o_entry)
-        assert li2o_entry_corrected.energy == pytest.approx(-3.0 - 0.66975)
+        assert li2o_entry_corrected.energy == approx(-3.0 - 0.66975)
 
 
 class SulfideTypeCorrection2020Test(unittest.TestCase):
@@ -1877,7 +1885,7 @@ class SulfideTypeCorrection2020Test(unittest.TestCase):
         struct_corrected = self.compat.process_entry(na2s2_entry_struct)
         nostruct_corrected = self.compat.process_entry(na2s2_entry_nostruct)
 
-        assert struct_corrected.correction == pytest.approx(nostruct_corrected.correction)
+        assert struct_corrected.correction == approx(nostruct_corrected.correction)
 
 
 class OxideTypeCorrectionNoPeroxideCorrTest(unittest.TestCase):
@@ -1912,7 +1920,7 @@ class OxideTypeCorrectionNoPeroxideCorrTest(unittest.TestCase):
         )
 
         li2o_entry_corrected = self.compat.process_entry(li2o_entry)
-        assert li2o_entry_corrected.energy == pytest.approx(-3.0 - 0.66975)
+        assert li2o_entry_corrected.energy == approx(-3.0 - 0.66975)
 
     def test_peroxide_energy_corr(self):
         latt = Lattice.from_parameters(3.159597, 3.159572, 7.685205, 89.999884, 89.999674, 60.000510)
@@ -1930,30 +1938,19 @@ class OxideTypeCorrectionNoPeroxideCorrTest(unittest.TestCase):
             [0.666665, 0.666684, 0.149189],
         ]
         struct = Structure(latt, elts, coords)
-        li2o2_entry = ComputedStructureEntry(
-            struct,
-            -3,
-            parameters={
-                "is_hubbard": False,
-                "hubbards": None,
-                "run_type": "GGA",
-                "potcar_spec": [
-                    {
-                        "titel": "PAW_PBE Li 17Jan2003",
-                        "hash": "65e83282d1707ec078c1012afbd05be8",
-                    },
-                    {
-                        "titel": "PAW_PBE O 08Apr2002",
-                        "hash": "7a25bc5b9a5393f46600a4939d357982",
-                    },
-                ],
-            },
-        )
+        cse_params = {
+            "is_hubbard": False,
+            "hubbards": None,
+            "run_type": "GGA",
+            "potcar_spec": [
+                {"titel": "PAW_PBE Li 17Jan2003", "hash": "65e83282d1707ec078c1012afbd05be8"},
+                {"titel": "PAW_PBE O 08Apr2002", "hash": "7a25bc5b9a5393f46600a4939d357982"},
+            ],
+        }
+        li2o2_entry = ComputedStructureEntry(struct, -3, parameters=cse_params)
 
         li2o2_entry_corrected = self.compat.process_entry(li2o2_entry)
-        with pytest.raises(AssertionError):
-            self.assertAlmostEqual(*(li2o2_entry_corrected.energy, -3 - 0.44317 * 4, 4))
-        assert li2o2_entry_corrected.energy == pytest.approx(-3 - 0.66975 * 4)
+        assert li2o2_entry_corrected.energy == approx(-3 - 0.66975 * 4)
 
     def test_ozonide(self):
         el_li = Element("Li")
@@ -1988,7 +1985,7 @@ class OxideTypeCorrectionNoPeroxideCorrTest(unittest.TestCase):
         )
 
         lio3_entry_corrected = self.compat.process_entry(lio3_entry)
-        assert lio3_entry_corrected.energy == pytest.approx(-3.0 - 3 * 0.66975)
+        assert lio3_entry_corrected.energy == approx(-3.0 - 3 * 0.66975)
 
 
 class TestMaterialsProjectAqueousCompatibility:
@@ -2012,7 +2009,6 @@ class TestMaterialsProjectAqueousCompatibility:
     """
 
     def test_h_h2o_energy_with_args_single(self):
-
         compat = MaterialsProjectAqueousCompatibility(
             o2_energy=-4.9276,
             h2o_energy=-5,
@@ -2035,17 +2031,16 @@ class TestMaterialsProjectAqueousCompatibility:
         # the corrections should set the energy of any H2 polymorph the same, because
         # we have only processed one entry at time. Energy differences of H2O
         # polymorphs should be preserved.
-        assert h2o_entry_2.energy_per_atom == pytest.approx(h2o_entry_1.energy_per_atom + 4)
-        assert h2_entry_2.energy_per_atom == pytest.approx(h2_entry_1.energy_per_atom)
+        assert h2o_entry_2.energy_per_atom == approx(h2o_entry_1.energy_per_atom + 4)
+        assert h2_entry_2.energy_per_atom == approx(h2_entry_1.energy_per_atom)
 
         o2_entry_1 = ComputedEntry(Composition("O2"), -4.9276 * 2)
         o2_entry_1 = compat.process_entries(o2_entry_1)[0]
 
         h2o_form_e = 3 * h2o_entry_1.energy_per_atom - 2 * h2_entry_2.energy_per_atom - o2_entry_1.energy_per_atom
-        assert h2o_form_e == pytest.approx(MU_H2O)
+        assert h2o_form_e == approx(MU_H2O)
 
     def test_h_h2o_energy_with_args_multi(self):
-
         compat = MaterialsProjectAqueousCompatibility(
             o2_energy=-4.9276,
             h2o_energy=-5,
@@ -2061,17 +2056,16 @@ class TestMaterialsProjectAqueousCompatibility:
         compat.process_entries([h2o_entry_1, h2o_entry_2, h2_entry_1, h2_entry_2])
 
         # Energy differences of H2O and H2 polymorphs should be preserved.
-        assert h2o_entry_2.energy_per_atom == pytest.approx(h2o_entry_1.energy_per_atom + 4)
-        assert h2_entry_2.energy_per_atom == pytest.approx(h2_entry_1.energy_per_atom + 4.5)
+        assert h2o_entry_2.energy_per_atom == approx(h2o_entry_1.energy_per_atom + 4)
+        assert h2_entry_2.energy_per_atom == approx(h2_entry_1.energy_per_atom + 4.5)
 
         o2_entry_1 = ComputedEntry(Composition("O2"), -4.9276 * 2)
         o2_entry_1 = compat.process_entries(o2_entry_1)[0]
 
         h2o_form_e = 3 * h2o_entry_1.energy_per_atom - 2 * h2_entry_1.energy_per_atom - o2_entry_1.energy_per_atom
-        assert h2o_form_e == pytest.approx(MU_H2O)
+        assert h2o_form_e == approx(MU_H2O)
 
     def test_h_h2o_energy_no_args(self):
-
         with pytest.warns(UserWarning, match="You did not provide the required O2 and H2O energies."):
             compat = MaterialsProjectAqueousCompatibility(solid_compat=None)
 
@@ -2091,13 +2085,13 @@ class TestMaterialsProjectAqueousCompatibility:
         assert compat.h2o_adjustments == -0.234
 
         # the corrections should preserve the difference in energy among H2O and H2 polymorphs
-        assert h2o_entry_2.energy_per_atom == pytest.approx(h2o_entry_1.energy_per_atom + 4.195)
-        assert h2_entry_2.energy_per_atom == pytest.approx(h2_entry_1.energy_per_atom + 4.5)
+        assert h2o_entry_2.energy_per_atom == approx(h2o_entry_1.energy_per_atom + 4.195)
+        assert h2_entry_2.energy_per_atom == approx(h2_entry_1.energy_per_atom + 4.5)
 
         # the water formation energy, calculated from the lowest energy polymorphs,
         # should equal the experimental value
         h2o_form_e = 3 * h2o_entry_1.energy_per_atom - 2 * h2_entry_1.energy_per_atom - o2_entry_1.energy_per_atom
-        assert h2o_form_e == pytest.approx(MU_H2O)
+        assert h2o_form_e == approx(MU_H2O)
 
     def test_compound_entropy(self):
         compat = MaterialsProjectAqueousCompatibility(
@@ -2110,20 +2104,31 @@ class TestMaterialsProjectAqueousCompatibility:
         o2_entry_1 = compat.process_entries(o2_entry_1)[0]
         processed_energy = o2_entry_1.energy_per_atom
 
-        assert initial_energy - processed_energy == pytest.approx(compat.cpd_entropies["O2"])
+        assert initial_energy - processed_energy == approx(compat.cpd_entropies["O2"])
 
     def test_hydrate_adjustment(self):
         compat = MaterialsProjectAqueousCompatibility(
             o2_energy=-10, h2o_energy=-20, h2o_adjustments=-0.5, solid_compat=None
         )
 
-        hydrate_entry = ComputedEntry(Composition("FeH4O2"), -10)
+        hydrate_entry = ComputedEntry(Composition("FeH4O2"), -10)  # nH2O = 2
+        hydrate_entry2 = ComputedEntry(Composition("Li2O2H2"), -10)  # nH2O = 0
 
-        initial_energy = hydrate_entry.energy
-        hydrate_entry = compat.process_entries(hydrate_entry)[0]
-        processed_energy = hydrate_entry.energy
+        compat.process_entries([hydrate_entry, hydrate_entry2])
 
-        assert initial_energy - processed_energy == pytest.approx(2 * (compat.h2o_adjustments * 3 + MU_H2O))
+        assert hydrate_entry.uncorrected_energy - hydrate_entry.energy == approx(
+            2 * (compat.h2o_adjustments * 3 + MU_H2O)
+        )
+        assert hydrate_entry2.uncorrected_energy - hydrate_entry2.energy == 0
+
+    def test_processing_entries_inplace(self):
+        h2o_entry = ComputedEntry(Composition("H2O"), (-5.195 + 0.234) * 3, correction=-0.234 * 3)  # -5.195 eV/atom
+        o2_entry = ComputedEntry(Composition("O2"), -4.9276 * 2)
+        # check that compatibility scheme does not change input entries themselves
+        entries = [h2o_entry, o2_entry]
+        entries_copy = copy.deepcopy(entries)
+        MaterialsProjectAqueousCompatibility().process_entries(entries, inplace=False)
+        assert all(e.correction == e_copy.correction for e, e_copy in zip(entries, entries_copy))
 
 
 class AqueousCorrectionTest(unittest.TestCase):
@@ -2139,19 +2144,19 @@ class AqueousCorrectionTest(unittest.TestCase):
         H2_entry = self.corr.correct_entry(ComputedEntry(Composition("H2"), 3, parameters={"run_type": "GGA"}))
         H2O_entry = self.corr.correct_entry(ComputedEntry(Composition("H2O"), 3, parameters={"run_type": "GGA"}))
         H2O_formation_energy = H2O_entry.energy - (H2_entry.energy + O2_entry.energy / 2.0)
-        assert H2O_formation_energy == pytest.approx(-2.46)
+        assert H2O_formation_energy == approx(-2.46)
 
         entry = ComputedEntry(Composition("H2O"), -16, parameters={"run_type": "GGA"})
         entry = self.corr.correct_entry(entry)
-        assert entry.energy == pytest.approx(-14.916)
+        assert entry.energy == approx(-14.916)
 
         entry = ComputedEntry(Composition("H2O"), -24, parameters={"run_type": "GGA"})
         entry = self.corr.correct_entry(entry)
-        assert entry.energy == pytest.approx(-14.916)
+        assert entry.energy == approx(-14.916)
 
         entry = ComputedEntry(Composition("Cl"), -24, parameters={"run_type": "GGA"})
         entry = self.corr.correct_entry(entry)
-        assert entry.energy == pytest.approx(-24.344373)
+        assert entry.energy == approx(-24.344373)
 
 
 class MITAqueousCompatibilityTest(unittest.TestCase):
@@ -2163,7 +2168,6 @@ class MITAqueousCompatibilityTest(unittest.TestCase):
         self.aqcorr = AqueousCorrection(fp)
 
     def test_aqueous_compat(self):
-
         el_li = Element("Li")
         el_o = Element("O")
         el_h = Element("H")
@@ -2204,7 +2208,7 @@ class MITAqueousCompatibilityTest(unittest.TestCase):
         lioh_entry_compat = self.compat.process_entry(lioh_entry)
         lioh_entry_compat_aqcorr = self.aqcorr.correct_entry(lioh_entry_compat)
         lioh_entry_aqcompat = self.aqcompat.process_entry(lioh_entry)
-        assert lioh_entry_compat_aqcorr.energy == pytest.approx(lioh_entry_aqcompat.energy)
+        assert lioh_entry_compat_aqcorr.energy == approx(lioh_entry_aqcompat.energy)
 
     def test_potcar_doenst_match_structure(self):
         compat = MITCompatibility()
@@ -2376,20 +2380,16 @@ class CorrectionErrors2020CompatibilityTest(unittest.TestCase):
 
     def test_errors(self):
         entry1_corrected = self.compat.process_entry(self.entry1)
-        assert entry1_corrected.correction_uncertainty == pytest.approx(sqrt((2 * 0.0101) ** 2 + (3 * 0.002) ** 2))
+        assert entry1_corrected.correction_uncertainty == approx(sqrt((2 * 0.0101) ** 2 + (3 * 0.002) ** 2))
 
         entry2_corrected = self.compat.process_entry(self.entry2)
-        assert entry2_corrected.correction_uncertainty == pytest.approx(sqrt((3 * 0.0101) ** 2 + (4 * 0.002) ** 2))
+        assert entry2_corrected.correction_uncertainty == approx(sqrt((3 * 0.0101) ** 2 + (4 * 0.002) ** 2))
 
         entry_sulfide_corrected = self.compat.process_entry(self.entry_sulfide)
-        assert entry_sulfide_corrected.correction_uncertainty == pytest.approx(0.0093)
+        assert entry_sulfide_corrected.correction_uncertainty == approx(0.0093)
 
         entry_fluoride_corrected = self.compat.process_entry(self.entry_fluoride)
-        assert entry_fluoride_corrected.correction_uncertainty == pytest.approx(sqrt((3 * 0.0026) ** 2 + 0.0101**2))
+        assert entry_fluoride_corrected.correction_uncertainty == approx(sqrt((3 * 0.0026) ** 2 + 0.0101**2))
 
         entry_hydride_corrected = self.compat.process_entry(self.entry_hydride)
-        assert entry_hydride_corrected.correction_uncertainty == pytest.approx(0.0013)
-
-
-if __name__ == "__main__":
-    unittest.main()
+        assert entry_hydride_corrected.correction_uncertainty == approx(0.0013)
