@@ -1,6 +1,4 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
+from __future__ import annotations
 
 import copy
 import json
@@ -10,6 +8,7 @@ from collections import defaultdict
 
 import pytest
 from monty.json import MontyDecoder
+from pytest import approx
 
 from pymatgen.analysis.phase_diagram import PhaseDiagram
 from pymatgen.entries.computed_entries import (
@@ -96,10 +95,10 @@ class ComputedEntryTest(unittest.TestCase):
         self.entry7 = ComputedEntry("Fe6O9", 6.9, energy_adjustments=[ea])
 
     def test_energy(self):
-        assert self.entry.energy == pytest.approx(-269.38319884)
+        assert self.entry.energy == approx(-269.38319884)
         self.entry.correction = 1.0
-        assert self.entry.energy == pytest.approx(-268.38319884)
-        assert self.entry3.energy_per_atom == pytest.approx(2.3 / 5)
+        assert self.entry.energy == approx(-268.38319884)
+        assert self.entry3.energy_per_atom == approx(2.3 / 5)
 
     def test_composition(self):
         assert self.entry.composition.reduced_formula == "LiFe4(PO4)4"
@@ -110,29 +109,29 @@ class ComputedEntryTest(unittest.TestCase):
     def test_per_atom_props(self):
         entry = ComputedEntry("Fe6O9", 6.9)
         entry.energy_adjustments.append(CompositionEnergyAdjustment(-0.5, 9, uncertainty_per_atom=0.1, name="O"))
-        assert entry.energy == pytest.approx(2.4)
-        assert entry.energy_per_atom == pytest.approx(2.4 / 15)
-        assert entry.uncorrected_energy == pytest.approx(6.9)
-        assert entry.uncorrected_energy_per_atom == pytest.approx(6.9 / 15)
-        assert entry.correction == pytest.approx(-4.5)
-        assert entry.correction_per_atom == pytest.approx(-4.5 / 15)
-        assert entry.correction_uncertainty == pytest.approx(0.9)
-        assert entry.correction_uncertainty_per_atom == pytest.approx(0.9 / 15)
+        assert entry.energy == approx(2.4)
+        assert entry.energy_per_atom == approx(2.4 / 15)
+        assert entry.uncorrected_energy == approx(6.9)
+        assert entry.uncorrected_energy_per_atom == approx(6.9 / 15)
+        assert entry.correction == approx(-4.5)
+        assert entry.correction_per_atom == approx(-4.5 / 15)
+        assert entry.correction_uncertainty == approx(0.9)
+        assert entry.correction_uncertainty_per_atom == approx(0.9 / 15)
 
     def test_normalize(self):
         entry = ComputedEntry("Fe6O9", 6.9, correction=1)
         entry_formula = entry.normalize()
         assert entry_formula.composition.formula == "Fe2 O3"
-        assert entry_formula.uncorrected_energy == pytest.approx(6.9 / 3)
-        assert entry_formula.correction == pytest.approx(1 / 3)
-        assert entry_formula.energy * 3 == pytest.approx(6.9 + 1)
-        assert entry_formula.energy_adjustments[0].value == pytest.approx(1 / 3)
+        assert entry_formula.uncorrected_energy == approx(6.9 / 3)
+        assert entry_formula.correction == approx(1 / 3)
+        assert entry_formula.energy * 3 == approx(6.9 + 1)
+        assert entry_formula.energy_adjustments[0].value == approx(1 / 3)
         entry_atom = entry.normalize("atom")
         assert entry_atom.composition.formula == "Fe0.4 O0.6"
-        assert entry_atom.uncorrected_energy == pytest.approx(6.9 / 15)
-        assert entry_atom.correction == pytest.approx(1 / 15)
-        assert entry_atom.energy * 15 == pytest.approx(6.9 + 1)
-        assert entry_atom.energy_adjustments[0].value == pytest.approx(1 / 15)
+        assert entry_atom.uncorrected_energy == approx(6.9 / 15)
+        assert entry_atom.correction == approx(1 / 15)
+        assert entry_atom.energy * 15 == approx(6.9 + 1)
+        assert entry_atom.energy_adjustments[0].value == approx(1 / 15)
 
     def test_normalize_energy_adjustments(self):
         ealist = [
@@ -152,7 +151,7 @@ class ComputedEntryTest(unittest.TestCase):
         d = self.entry.as_dict()
         e = ComputedEntry.from_dict(d)
         assert self.entry == e
-        assert e.energy == pytest.approx(-269.38319884)
+        assert e.energy == approx(-269.38319884)
 
     def test_to_from_dict_with_adjustment(self):
         """
@@ -160,7 +159,7 @@ class ComputedEntryTest(unittest.TestCase):
         """
         d = self.entry6.as_dict()
         e = ComputedEntry.from_dict(d)
-        assert e.uncorrected_energy == pytest.approx(6.9)
+        assert e.uncorrected_energy == approx(6.9)
         assert e.energy_adjustments[0].value == self.entry6.energy_adjustments[0].value
 
     def test_to_from_dict_with_adjustment_2(self):
@@ -169,7 +168,7 @@ class ComputedEntryTest(unittest.TestCase):
         """
         d = self.entry7.as_dict()
         e = ComputedEntry.from_dict(d)
-        assert e.uncorrected_energy == pytest.approx(6.9)
+        assert e.uncorrected_energy == approx(6.9)
         assert e.energy_adjustments[0].value == self.entry7.energy_adjustments[0].value
 
     def test_to_from_dict_with_adjustment_3(self):
@@ -189,8 +188,8 @@ class ComputedEntryTest(unittest.TestCase):
             "correction": -10,
         }
         e = ComputedEntry.from_dict(d)
-        assert e.uncorrected_energy == pytest.approx(6.9)
-        assert e.correction == pytest.approx(-10)
+        assert e.uncorrected_energy == approx(6.9)
+        assert e.correction == approx(-10)
         assert len(e.energy_adjustments) == 1
 
     def test_conflicting_correction_adjustment(self):
@@ -211,10 +210,10 @@ class ComputedEntryTest(unittest.TestCase):
 
     def test_sulfide_energy(self):
         self.entry = ComputedEntry("BaS", -10.21249155)
-        assert self.entry.energy == pytest.approx(-10.21249155)
-        assert self.entry.energy_per_atom == pytest.approx(-10.21249155 / 2)
+        assert self.entry.energy == approx(-10.21249155)
+        assert self.entry.energy_per_atom == approx(-10.21249155 / 2)
         self.entry.correction = 1.0
-        assert self.entry.energy == pytest.approx(-9.21249155)
+        assert self.entry.energy == approx(-9.21249155)
 
     def test_is_element(self):
         entry = ComputedEntry("Fe3", 2.3)
@@ -232,9 +231,9 @@ class ComputedStructureEntryTest(unittest.TestCase):
         self.entry = ComputedStructureEntry(vasprun.final_structure, vasprun.final_energy, parameters=vasprun.incar)
 
     def test_energy(self):
-        assert self.entry.energy == pytest.approx(-269.38319884)
+        assert self.entry.energy == approx(-269.38319884)
         self.entry.correction = 1.0
-        assert self.entry.energy == pytest.approx(-268.38319884)
+        assert self.entry.energy == approx(-268.38319884)
 
     def test_composition(self):
         assert self.entry.composition.reduced_formula == "LiFe4(PO4)4"
@@ -243,7 +242,7 @@ class ComputedStructureEntryTest(unittest.TestCase):
         d = self.entry.as_dict()
         e = ComputedStructureEntry.from_dict(d)
         assert self.entry == e
-        assert e.energy == pytest.approx(-269.38319884)
+        assert e.energy == approx(-269.38319884)
 
     def test_str(self):
         assert str(self.entry) is not None
@@ -386,9 +385,9 @@ class ComputedStructureEntryTest(unittest.TestCase):
             },
         }
         e = ComputedEntry.from_dict(d)
-        assert e.uncorrected_energy == pytest.approx(-39.42116819)
-        assert e.energy == pytest.approx(-38.42116819)
-        assert e.correction == pytest.approx(1)
+        assert e.uncorrected_energy == approx(-39.42116819)
+        assert e.energy == approx(-38.42116819)
+        assert e.correction == approx(1)
         assert len(e.energy_adjustments) == 1
 
     def test_copy(self):
@@ -398,6 +397,27 @@ class ComputedStructureEntryTest(unittest.TestCase):
         assert copy.structure is not self.entry.structure
         assert str(copy) == str(self.entry)
 
+    def test_eq(self):
+        copy1 = self.entry.copy()
+        copy2 = self.entry.copy()
+        copy3 = self.entry.copy()
+
+        # if no entry ids but same energy/comps --> equal
+        assert copy1 == copy2
+
+        # check different entry_ids --> not equal
+        copy1.entry_id = "mp_1"
+        copy2.entry_id = "mp_2"
+        assert copy1 != copy2
+
+        # same entry_id and energy --> equal
+        copy3.entry_id = "mp_1"
+        assert copy3 == copy1
+
+        # check different energy adjustments (but same id) --> not equal
+        copy3.energy_adjustments.append(ConstantEnergyAdjustment(0.1))
+        assert copy3 != copy1
+
 
 class GibbsComputedStructureEntryTest(unittest.TestCase):
     def setUp(self):
@@ -433,17 +453,17 @@ class GibbsComputedStructureEntryTest(unittest.TestCase):
             1800: -32.32513382051749,
         }
         for t in self.temps:
-            assert self.entries_with_temps[t].energy == pytest.approx(energies[t])
+            assert self.entries_with_temps[t].energy == approx(energies[t])
 
     def test_interpolation(self):
         temp = 450
         e = GibbsComputedStructureEntry(self.struct, -2.436, temp=temp)
-        assert e.energy == pytest.approx(-53.7243542548528)
+        assert e.energy == approx(-53.7243542548528)
 
     def test_expt_gas_entry(self):
         co2_entry = GibbsComputedStructureEntry(self.co2_struct, 0, temp=900)
-        assert co2_entry.energy == pytest.approx(-16.406560223724014)
-        assert co2_entry.energy_per_atom == pytest.approx(-1.3672133519770011)
+        assert co2_entry.energy == approx(-16.406560223724014)
+        assert co2_entry.energy_per_atom == approx(-1.3672133519770011)
 
     def test_from_entries(self):
         gibbs_entries = GibbsComputedStructureEntry.from_entries(self.mp_entries)
@@ -459,7 +479,7 @@ class GibbsComputedStructureEntryTest(unittest.TestCase):
         d = test_entry.as_dict()
         e = GibbsComputedStructureEntry.from_dict(d)
         assert test_entry == e
-        assert e.energy == pytest.approx(test_entry.energy)
+        assert e.energy == approx(test_entry.energy)
 
     def test_str(self):
         assert str(self.entries_with_temps[300]) is not None
@@ -468,8 +488,4 @@ class GibbsComputedStructureEntryTest(unittest.TestCase):
         for e in self.entries_with_temps.values():
             entry = copy.deepcopy(e)
             normed_entry = entry.normalize(mode="atom")
-            assert entry.uncorrected_energy == pytest.approx(normed_entry.uncorrected_energy * self.num_atoms)
-
-
-if __name__ == "__main__":
-    unittest.main()
+            assert entry.uncorrected_energy == approx(normed_entry.uncorrected_energy * self.num_atoms)
