@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import os
 import unittest
 
@@ -9,7 +11,6 @@ from pymatgen.util.testing import PymatgenTest
 
 class CorrectionCalculatorTest(unittest.TestCase):
     def setUp(self):
-
         self.exclude_polyanions = [
             "SO4",
             "CO3",
@@ -150,7 +151,3 @@ class CorrectionCalculatorTest(unittest.TestCase):
         calculator = CorrectionCalculator(exclude_polyanions=self.exclude_polyanions)
         with pytest.raises(ValueError):
             calculator.compute_from_files(exp_path, calc_path)
-
-
-if __name__ == "__main__":
-    unittest.main()
