@@ -1,6 +1,4 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
+from __future__ import annotations
 
 import os
 import unittest
@@ -11,11 +9,7 @@ from monty.serialization import dumpfn, loadfn
 
 from pymatgen.core.periodic_table import Element
 from pymatgen.entries.computed_entries import ComputedEntry
-from pymatgen.entries.entry_tools import (
-    EntrySet,
-    group_entries_by_composition,
-    group_entries_by_structure,
-)
+from pymatgen.entries.entry_tools import EntrySet, group_entries_by_composition, group_entries_by_structure
 from pymatgen.util.testing import PymatgenTest
 
 test_dir = Path(__file__).absolute().parent / ".." / ".." / ".." / "test_files"
@@ -67,16 +61,12 @@ class EntrySetTest(unittest.TestCase):
             self.entry_set.get_subset_in_chemsys(["Fe", "F"])
 
     def test_remove_non_ground_states(self):
-        l = len(self.entry_set)
+        length = len(self.entry_set)
         self.entry_set.remove_non_ground_states()
-        assert len(self.entry_set) < l
+        assert len(self.entry_set) < length
 
     def test_as_dict(self):
         dumpfn(self.entry_set, "temp_entry_set.json")
         entry_set = loadfn("temp_entry_set.json")
         assert len(entry_set) == len(self.entry_set)
         os.remove("temp_entry_set.json")
-
-
-if __name__ == "__main__":
-    unittest.main()
