@@ -1,6 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module provides classes to interface with the Materials Project REST
 API v2 to enable the creation of data structures and pymatgen objects using
@@ -24,7 +21,7 @@ import sys
 import warnings
 from enum import Enum, unique
 from time import sleep
-from typing import Any, Literal, Sequence
+from typing import TYPE_CHECKING, Any, Literal, Sequence
 
 import requests
 from monty.json import MontyDecoder, MontyEncoder
@@ -40,10 +37,12 @@ from pymatgen.core.structure import Structure
 from pymatgen.core.surface import get_symmetrically_equivalent_miller_indices
 from pymatgen.entries.computed_entries import ComputedEntry, ComputedStructureEntry
 from pymatgen.entries.exp_entries import ExpEntry
-from pymatgen.phonon.bandstructure import PhononBandStructureSymmLine
-from pymatgen.phonon.dos import CompletePhononDos
 from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
 
+if TYPE_CHECKING:
+    from pymatgen.phonon.bandstructure import PhononBandStructureSymmLine
+    from pymatgen.phonon.dos import CompletePhononDos
+
 logger = logging.getLogger(__name__)
 
 MP_LOG_FILE = os.path.join(os.path.expanduser("~"), ".mprester.log.yaml")
@@ -64,7 +63,7 @@ def get_chunks(sequence: Sequence[Any], size=1):
 
 @unique
 class TaskType(Enum):
-    """task types available in legacy MP data"""
+    """task types available in legacy MP data."""
 
     GGA_OPT = "GGA Structure Optimization"
     GGAU_OPT = "GGA+U Structure Optimization"
@@ -84,12 +83,12 @@ class TaskType(Enum):
 
 class _MPResterLegacy:
     """
-    A class to conveniently interface with the Materials Project REST
-    interface. The recommended way to use MPRester is with the "with" context
-    manager to ensure that sessions are properly closed after usage::
+    A class to conveniently interface with the Materials Project REST interface.
+    The recommended way to use MPRester is with the "with" context manager to ensure
+    sessions are properly closed after usage.
 
-        with MPRester("API_KEY") as m:
-            do_something
+        with MPRester("API_KEY") as mpr:
+            mpr.some_method()
 
     MPRester uses the "requests" package, which provides for HTTP connection
     pooling. All connections are made via https for security.
@@ -151,7 +150,11 @@ class _MPResterLegacy:
     )
 
     def __init__(
-        self, api_key: str = None, endpoint: str = None, notify_db_version: bool = True, include_user_agent: bool = True
+        self,
+        api_key: str | None = None,
+        endpoint: str | None = None,
+        notify_db_version: bool = True,
+        include_user_agent: bool = True,
     ) -> None:
         """
         Args:
@@ -212,72 +215,69 @@ class _MPResterLegacy:
 
             try:
                 with open(MP_LOG_FILE) as f:
-                    d = dict(yaml.load(f))
+                    dct = dict(yaml.load(f)) or {}
             except (OSError, TypeError):
                 # TypeError: 'NoneType' object is not iterable occurs if MP_LOG_FILE exists but is empty
-                d = {}
+                dct = {}
 
-            d = d or {}
-
-            if "MAPI_DB_VERSION" not in d:
-                d["MAPI_DB_VERSION"] = {"LOG": {}, "LAST_ACCESSED": None}
+            if "MAPI_DB_VERSION" not in dct:
+                dct["MAPI_DB_VERSION"] = {"LOG": {}, "LAST_ACCESSED": None}
             else:
                 # ensure data is parsed as dict, rather than ordered dict,
                 # due to change in YAML parsing behavior
-                d["MAPI_DB_VERSION"] = dict(d["MAPI_DB_VERSION"])
+                dct["MAPI_DB_VERSION"] = dict(dct["MAPI_DB_VERSION"])
 
-            if "LOG" in d["MAPI_DB_VERSION"]:
-                d["MAPI_DB_VERSION"]["LOG"] = dict(d["MAPI_DB_VERSION"]["LOG"])
+            if "LOG" in dct["MAPI_DB_VERSION"]:
+                dct["MAPI_DB_VERSION"]["LOG"] = dict(dct["MAPI_DB_VERSION"]["LOG"])
 
             # store a log of what database versions are being connected to
-            if db_version not in d["MAPI_DB_VERSION"]["LOG"]:
-                d["MAPI_DB_VERSION"]["LOG"][db_version] = 1
+            if db_version not in dct["MAPI_DB_VERSION"]["LOG"]:
+                dct["MAPI_DB_VERSION"]["LOG"][db_version] = 1
             else:
-                d["MAPI_DB_VERSION"]["LOG"][db_version] += 1
+                dct["MAPI_DB_VERSION"]["LOG"][db_version] += 1
 
             # alert user if db version changed
-            last_accessed = d["MAPI_DB_VERSION"]["LAST_ACCESSED"]
+            last_accessed = dct["MAPI_DB_VERSION"]["LAST_ACCESSED"]
             if last_accessed and last_accessed != db_version:
                 print(
                     f"This database version has changed from the database last accessed ({last_accessed}).\n"
                     f"Please see release notes on materialsproject.org for information about what has changed."
                 )
-            d["MAPI_DB_VERSION"]["LAST_ACCESSED"] = db_version
+            dct["MAPI_DB_VERSION"]["LAST_ACCESSED"] = db_version
 
             # write out new database log if possible
             # base Exception is not ideal (perhaps a PermissionError, etc.) but this is not critical
             # and should be allowed to fail regardless of reason
             try:
-                with open(MP_LOG_FILE, "wt") as f:
-                    yaml.dump(d, f)
+                with open(MP_LOG_FILE, "w") as f:
+                    yaml.dump(dct, f)
             except Exception:
                 pass
 
     def __enter__(self):
-        """
-        Support for "with" context.
-        """
+        """Support for "with" context."""
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
-        """
-        Support for "with" context.
-        """
+        """Support for "with" context."""
         self.session.close()
 
-    def _make_request(self, sub_url, payload=None, method="GET", mp_decode=True):
+    def _make_request(
+        self,
+        sub_url: str,
+        payload: Any = None,
+        method: Literal["GET", "POST", "PUT", "DELETE"] = "GET",
+        mp_decode: bool = True,
+    ) -> Any:
         response = None
-        url = self.preamble + sub_url
+        url = f"{self.preamble}{sub_url}"
         try:
             if method == "POST":
                 response = self.session.post(url, data=payload, verify=True)
             else:
                 response = self.session.get(url, params=payload, verify=True)
             if response.status_code in [200, 400]:
-                if mp_decode:
-                    data = json.loads(response.text, cls=MontyDecoder)
-                else:
-                    data = json.loads(response.text)
+                data = json.loads(response.text, cls=MontyDecoder) if mp_decode else json.loads(response.text)
                 if data["valid_response"]:
                     if data.get("warning"):
                         warnings.warn(data["warning"])
@@ -287,10 +287,10 @@ class _MPResterLegacy:
             raise MPRestError(f"REST query returned with error status code {response.status_code}")
 
         except Exception as ex:
-            msg = f"{ex}. Content: {response.content}" if hasattr(response, "content") else str(ex)
+            msg = f"{ex}. Content: {getattr(response, 'content', str(ex))}"
             raise MPRestError(msg)
 
-    def get_database_version(self):
+    def get_database_version(self) -> str:
         """
         The Materials Project database is periodically updated and has a
         database version associated with it. When the database is updated,
@@ -304,13 +304,13 @@ class _MPResterLegacy:
 
         Returns: database version as a string
         """
-        d = self._make_request("/api_check")
-        return d["version"]["db"]
+        dct = self._make_request("/api_check")
+        return dct["version"]["db"]
 
     def get_materials_id_from_task_id(self, task_id):
         """
         Returns a new MP materials id from a task id (which can be
-        equivalent to an old materials id)
+        equivalent to an old materials id).
 
         Args:
             task_id (str): A task id.
@@ -494,7 +494,7 @@ class _MPResterLegacy:
         chemsys_formula_id_criteria: str | dict[str, Any],
         compatible_only: bool = True,
         inc_structure: bool | Literal["initial"] | None = None,
-        property_data: list[str] = None,
+        property_data: list[str] | None = None,
         conventional_unit_cell: bool = False,
         sort_by_e_above_hull: bool = False,
     ) -> list[ComputedEntry]:
@@ -538,7 +538,7 @@ class _MPResterLegacy:
             "potcar_symbols",
             "oxide_type",
         ]
-        props = ["energy", "unit_cell_formula", "task_id"] + params
+        props = ["energy", "unit_cell_formula", "task_id", *params]
         if sort_by_e_above_hull:
             if property_data and "e_above_hull" not in property_data:
                 property_data.append("e_above_hull")
@@ -561,7 +561,7 @@ class _MPResterLegacy:
         entries: list[ComputedEntry] = []
         for d in data:
             d["potcar_symbols"] = [
-                f"{d['pseudo_potential']['functional']} {l}" for l in d["pseudo_potential"]["labels"]
+                f"{d['pseudo_potential']['functional']} {label}" for label in d["pseudo_potential"]["labels"]
             ]
             data = {"oxide_type": d["oxide_type"]}
             if property_data:
@@ -733,7 +733,7 @@ class _MPResterLegacy:
                 return self.get_structure_by_material_id(new_material_id)
             except MPRestError:
                 raise MPRestError(
-                    f"material_id {material_id} unknown, if this seems like an error "
+                    f"{material_id=} unknown, if this seems like an error "
                     "please let us know at matsci.org/materials-project"
                 )
 
@@ -747,7 +747,7 @@ class _MPResterLegacy:
         material_id: str,
         compatible_only: bool = True,
         inc_structure: bool | Literal["initial"] | None = None,
-        property_data: list[str] = None,
+        property_data: list[str] | None = None,
         conventional_unit_cell: bool = False,
     ) -> ComputedEntry | ComputedStructureEntry:
         """
@@ -1323,9 +1323,7 @@ class _MPResterLegacy:
         )
 
     def get_stability(self, entries):
-        """
-        Returns the stability of all entries.
-        """
+        """Returns the stability of all entries."""
         try:
             payload = {"entries": json.dumps(entries, cls=MontyEncoder)}
             response = self.session.post(
@@ -1408,7 +1406,7 @@ class _MPResterLegacy:
     def get_all_substrates(self):
         """
         Gets the list of all possible substrates considered in the
-        Materials Project substrate database
+        Materials Project substrate database.
 
         Returns:
             list of material_ids corresponding to possible substrates
@@ -1493,28 +1491,25 @@ class _MPResterLegacy:
         Args:
             material_id (str): Materials Project material_id, e.g., 'mp-129'.
             pretty_formula (str): The formula of metals. e.g., 'Fe'
-            sigma(int): The sigma value of a certain type of grain boundary
-            gb_plane(list of integer): The Miller index of grain
-            boundary plane. e.g., [1, 1, 1]
-            rotation_axis(list of integer): The Miller index of rotation
-            axis. e.g., [1, 0, 0], [1, 1, 0], and [1, 1, 1]
-            Sigma value is determined by the combination of rotation axis and
-            rotation angle. The five degrees of freedom (DOF) of one grain boundary
-            include: rotation axis (2 DOFs), rotation angle (1 DOF), and grain
-            boundary plane (2 DOFs).
+            chemsys (str): The chemical system. e.g., 'Fe-O'
+            sigma (int): The sigma value of a certain type of grain boundary
+            gb_plane (list of integer): The Miller index of grain boundary plane. e.g., [1, 1, 1]
+            rotation_axis (list of integer): The Miller index of rotation axis. e.g.,
+                [1, 0, 0], [1, 1, 0], and [1, 1, 1] Sigma value is determined by the combination of
+                rotation axis and rotation angle. The five degrees of freedom (DOF) of one grain boundary
+                include: rotation axis (2 DOFs), rotation angle (1 DOF), and grain boundary plane (2 DOFs).
             include_work_of_separation (bool): whether to include the work of separation
-            (in unit of (J/m^2)). If you want to query the work of separation, please
-            specify the material_id.
-
+                (in unit of (J/m^2)). If you want to query the work of separation, please
+                specify the material_id.
 
         Returns:
             A list of grain boundaries that satisfy the query conditions (sigma, gb_plane).
             Energies are given in SI units (J/m^2).
         """
         if gb_plane:
-            gb_plane = ",".join([str(i) for i in gb_plane])
+            gb_plane = ",".join(str(plane) for plane in gb_plane)
         if rotation_axis:
-            rotation_axis = ",".join([str(i) for i in rotation_axis])
+            rotation_axis = ",".join(str(ax) for ax in rotation_axis)
 
         payload = {
             "material_id": material_id,
@@ -1533,8 +1528,8 @@ class _MPResterLegacy:
                 surface_energy = self.get_surface_data(material_id=material_id, miller_index=gb_plane_int)[
                     "surface_energy"
                 ]
-                wsep = 2 * surface_energy - gb_energy  # calculate the work of separation
-                gb_dict["work_of_separation"] = wsep
+                work_of_sep = 2 * surface_energy - gb_energy  # calculate the work of separation
+                gb_dict["work_of_separation"] = work_of_sep
             return list_of_gbs
 
         return self._make_request("/grain_boundaries", payload=payload)
@@ -1573,7 +1568,7 @@ class _MPResterLegacy:
                 `pymatgen.analysis.reaction_calculator.Reaction`.
         """
         payload = {
-            "reactants": " ".join([reactant1, reactant2]),
+            "reactants": f"{reactant1} {reactant2}",
             "open_el": open_el,
             "relative_mu": relative_mu,
             "use_hull_energy": use_hull_energy,
@@ -1582,7 +1577,7 @@ class _MPResterLegacy:
 
     def get_download_info(self, material_ids, task_types=None, file_patterns=None):
         """
-        Get a list of URLs to retrieve raw VASP output files from the NoMaD repository
+        Get a list of URLs to retrieve raw VASP output files from the NoMaD repository.
 
         Args:
             material_ids (list): list of material identifiers (mp-id's)
@@ -1619,7 +1614,7 @@ class _MPResterLegacy:
         prefix = "https://nomad-lab.eu/prod/rae/api/repo/?"
         if file_patterns is not None:
             for file_pattern in file_patterns:
-                prefix += f"file_pattern={file_pattern}&"
+                prefix += f"{file_pattern=}&"
         prefix += "external_id="
 
         task_ids = [t["task_id"] for tl in meta.values() for t in tl]
@@ -1634,7 +1629,7 @@ class _MPResterLegacy:
                 prefix += f"file_pattern={file_pattern}&"
         prefix += "external_id="
 
-        urls = [prefix + tids for tids in nomad_exist_task_ids]
+        urls = [f"{prefix}{task_ids}" for task_ids in nomad_exist_task_ids]
         return meta, urls
 
     @staticmethod
@@ -1689,7 +1684,7 @@ class _MPResterLegacy:
         Returns:
             A mongo query dict.
         """
-        toks = criteria_string.split()
+        tokens = criteria_string.split()
 
         def parse_sym(sym):
             if sym == "*":
@@ -1704,13 +1699,13 @@ class _MPResterLegacy:
                 return {"task_id": t}
             if "-" in t:
                 elements = [parse_sym(sym) for sym in t.split("-")]
-                chemsyss = []
+                chem_sys_lst = []
                 for cs in itertools.product(*elements):
                     if len(set(cs)) == len(cs):
                         # Check for valid symbols
                         cs = [Element(s).symbol for s in cs]
-                        chemsyss.append("-".join(sorted(cs)))
-                return {"chemsys": {"$in": chemsyss}}
+                        chem_sys_lst.append("-".join(sorted(cs)))
+                return {"chemsys": {"$in": chem_sys_lst}}
             all_formulas = set()
             explicit_els = []
             wild_card_els = []
@@ -1732,30 +1727,30 @@ class _MPResterLegacy:
                     all_formulas.add(c.reduced_formula)
             return {"pretty_formula": {"$in": list(all_formulas)}}
 
-        if len(toks) == 1:
-            return parse_tok(toks[0])
-        return {"$or": list(map(parse_tok, toks))}
+        if len(tokens) == 1:
+            return parse_tok(tokens[0])
+        return {"$or": list(map(parse_tok, tokens))}
 
 
 class MPRester:
     """
-    A class to conveniently interface with the new and legacy Materials Project REST
-    interface. The recommended way to use MPRester is with the "with" context
-    manager to ensure that sessions are properly closed after usage::
+    A class to conveniently interface with the new and legacy Materials Project REST interface.
 
-        with MPRester("API_KEY") as m:
-            do_something
+    The recommended way to use MPRester is as a context manager to ensure
+    that sessions are properly closed after usage:
 
-    MPRester uses the "requests" package, which provides for HTTP connection
+        with MPRester("API_KEY") as mpr:
+            docs = mpr.call_some_method()
+
+    MPRester uses the "requests" package, which provides HTTP connection
     pooling. All connections are made via https for security.
 
     For more advanced uses of the Materials API, please consult the API
     documentation at https://materialsproject.org/api and https://docs.materialsproject.org.
 
-    Note that this barebones class is to handle transition between the old and new API keys in a transparent manner,
-    providing backwards compatibility. Use it as you would with normal MPRester usage. If a new API key is detected,
-    the _MPResterNew will be initialized. Otherwise, the _MPResterLegacy. Consult the Materials Project documentation
-    at https://docs.materialsproject.org for advice on which API to use.
+    This class handles the transition between old and new MP API, making it easy to switch between them
+    by passing a new (length 32) or old (15 <= length <= 17) API key. See https://docs.materialsproject.org
+    for which API to use.
     """
 
     def __new__(cls, *args, **kwargs):
@@ -1764,20 +1759,19 @@ class MPRester:
            *args: Pass through to either legacy or new MPRester.
            **kwargs: Pass through to either legacy or new MPRester.
         """
-        if len(args) > 0:
-            api_key = args[0]
-        else:
+        api_key = args[0] if len(args) > 0 else None
+
+        if api_key is None:
             api_key = kwargs.get("api_key", SETTINGS.get("PMG_MAPI_KEY"))
             kwargs["api_key"] = api_key
 
         if not api_key:
             raise ValueError("Please supply an API key. See https://materialsproject.org/api for details.")
 
-        return (_MPResterNew if len(api_key) == 32 else _MPResterLegacy)(*args, **kwargs)
+        rester = _MPResterNew if len(api_key) == 32 else _MPResterLegacy
+
+        return rester(*args, **kwargs)
 
 
 class MPRestError(Exception):
-    """
-    Exception class for legacy MPRestAdaptor.
-    Raised when the query has problems, e.g., bad query format.
-    """
+    """Exception class for legacy MPRestAdaptor. Raised when query is malformed."""
