@@ -1,24 +1,24 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
 #
 # pylint: disable=no-member, chained-comparison
 """
 Low-level objects providing an abstraction for the objects involved in the calculation.
 """
 
+from __future__ import annotations
+
 import abc
-import collections
+from collections import namedtuple
 from enum import Enum
 from pprint import pformat
-from typing import List, cast
+from typing import Iterable, cast
 
 import numpy as np
+from frozendict import frozendict
 from monty.collections import AttrDict
 from monty.design_patterns import singleton
 from monty.json import MontyDecoder, MontyEncoder, MSONable
 
 from pymatgen.core import ArrayWithUnit, Lattice, Species, Structure, units
-from pymatgen.util.serialization import pmg_serialize
 
 
 def lattice_from_abivars(cls=None, *args, **kwargs):
@@ -31,32 +31,30 @@ def lattice_from_abivars(cls=None, *args, **kwargs):
         cls: Lattice class to be instantiated. pymatgen.core.lattice.Lattice if `cls` is None
 
     Example:
-
         lattice_from_abivars(acell=3*[10], rprim=np.eye(3))
     """
     cls = Lattice if cls is None else cls
     kwargs.update(dict(*args))
-    d = kwargs
 
-    rprim = d.get("rprim", None)
-    angdeg = d.get("angdeg", None)
-    acell = d["acell"]
+    rprim = kwargs.get("rprim")
+    ang_deg = kwargs.get("angdeg")
+    acell = kwargs["acell"]
 
     if rprim is not None:
-        if angdeg is not None:
+        if ang_deg is not None:
             raise ValueError("angdeg and rprimd are mutually exclusive")
         rprim = np.reshape(rprim, (3, 3))
         rprimd = [float(acell[i]) * rprim[i] for i in range(3)]
         # Call pymatgen constructors (note that pymatgen uses Angstrom instead of Bohr).
         return cls(ArrayWithUnit(rprimd, "bohr").to("ang"))
 
-    if angdeg is not None:
-        angdeg = np.reshape(angdeg, 3)
+    if ang_deg is not None:
+        ang_deg = np.reshape(ang_deg, 3)
 
-        if np.any(angdeg <= 0.0):
-            raise ValueError(f"Angles must be > 0 but got {str(angdeg)}")
-        if angdeg.sum() >= 360.0:
-            raise ValueError(f"The sum of angdeg must be lower that 360, angdeg {str(angdeg)}")
+        if np.any(ang_deg <= 0.0):
+            raise ValueError(f"Angles must be > 0 but got {ang_deg}")
+        if ang_deg.sum() >= 360.0:
+            raise ValueError(f"The sum of angdeg must be lower than 360, {ang_deg=}")
 
         # This code follows the implementation in ingeo.F90
         # See also http://www.abinit.org/doc/helpfiles/for-v7.8/input_variables/varbas.html#angdeg
@@ -64,14 +62,14 @@ def lattice_from_abivars(cls=None, *args, **kwargs):
         pi, sin, cos, sqrt = np.pi, np.sin, np.cos, np.sqrt
         rprim = np.zeros((3, 3))
         if (
-            abs(angdeg[0] - angdeg[1]) < tol12
-            and abs(angdeg[1] - angdeg[2]) < tol12
-            and abs(angdeg[0] - 90.0) + abs(angdeg[1] - 90.0) + abs(angdeg[2] - 90) > tol12
+            abs(ang_deg[0] - ang_deg[1]) < tol12
+            and abs(ang_deg[1] - ang_deg[2]) < tol12
+            and abs(ang_deg[0] - 90.0) + abs(ang_deg[1] - 90.0) + abs(ang_deg[2] - 90) > tol12
         ):
             # Treat the case of equal angles (except all right angles):
             # generates trigonal symmetry wrt third axis
-            cosang = cos(pi * angdeg[0] / 180.0)
-            a2 = 2.0 / 3.0 * (1.0 - cosang)
+            cos_ang = cos(pi * ang_deg[0] / 180.0)
+            a2 = 2.0 / 3.0 * (1.0 - cos_ang)
             aa = sqrt(a2)
             cc = sqrt(1.0 - a2)
             rprim[0, 0] = aa
@@ -86,17 +84,17 @@ def lattice_from_abivars(cls=None, *args, **kwargs):
         else:
             # Treat all the other cases
             rprim[0, 0] = 1.0
-            rprim[1, 0] = cos(pi * angdeg[2] / 180.0)
-            rprim[1, 1] = sin(pi * angdeg[2] / 180.0)
-            rprim[2, 0] = cos(pi * angdeg[1] / 180.0)
-            rprim[2, 1] = (cos(pi * angdeg[0] / 180.0) - rprim[1, 0] * rprim[2, 0]) / rprim[1, 1]
+            rprim[1, 0] = cos(pi * ang_deg[2] / 180.0)
+            rprim[1, 1] = sin(pi * ang_deg[2] / 180.0)
+            rprim[2, 0] = cos(pi * ang_deg[1] / 180.0)
+            rprim[2, 1] = (cos(pi * ang_deg[0] / 180.0) - rprim[1, 0] * rprim[2, 0]) / rprim[1, 1]
             rprim[2, 2] = sqrt(1.0 - rprim[2, 0] ** 2 - rprim[2, 1] ** 2)
 
         # Call pymatgen constructors (note that pymatgen uses Angstrom instead of Bohr).
         rprimd = [float(acell[i]) * rprim[i] for i in range(3)]
         return cls(ArrayWithUnit(rprimd, "bohr").to("ang"))
 
-    raise ValueError(f"Don't know how to construct a Lattice from dict:\n{pformat(d)}")
+    raise ValueError(f"Don't know how to construct a Lattice from dict:\n{pformat(kwargs)}")
 
 
 def structure_from_abivars(cls=None, *args, **kwargs):
@@ -106,8 +104,7 @@ def structure_from_abivars(cls=None, *args, **kwargs):
     Args:
         cls: Structure class to be instantiated. pymatgen.core.structure.Structure if cls is None
 
-    example:
-
+    Example:
         al_structure = structure_from_abivars(
             acell=3*[7.5],
             rprim=[0.0, 0.5, 0.5,
@@ -128,29 +125,29 @@ def structure_from_abivars(cls=None, *args, **kwargs):
 
     # lattice = Lattice.from_dict(d, fmt="abivars")
     lattice = lattice_from_abivars(**d)
-    coords, coords_are_cartesian = d.get("xred", None), False
+    coords, coords_are_cartesian = d.get("xred"), False
 
     if coords is None:
-        coords = d.get("xcart", None)
+        coords = d.get("xcart")
         if coords is not None:
             if "xangst" in d:
                 raise ValueError("xangst and xcart are mutually exclusive")
             coords = ArrayWithUnit(coords, "bohr").to("ang")
         else:
-            coords = d.get("xangst", None)
+            coords = d.get("xangst")
         coords_are_cartesian = True
 
     if coords is None:
-        raise ValueError(f"Cannot extract coordinates from:\n {str(d)}")
+        raise ValueError(f"Cannot extract coordinates from:\n {d}")
 
     coords = np.reshape(coords, (-1, 3))
 
     znucl_type, typat = d["znucl"], d["typat"]
 
-    if not isinstance(znucl_type, collections.abc.Iterable):
+    if not isinstance(znucl_type, Iterable):
         znucl_type = [znucl_type]
 
-    if not isinstance(typat, collections.abc.Iterable):
+    if not isinstance(typat, Iterable):
         typat = [typat]
 
     if len(typat) != len(coords):
@@ -170,12 +167,11 @@ def structure_from_abivars(cls=None, *args, **kwargs):
     )
 
 
-def species_by_znucl(structure: Structure) -> List[Species]:
+def species_by_znucl(structure: Structure) -> list[Species]:
     """
     Return list of unique specie found in structure **ordered according to sites**.
 
     Example:
-
         Site0: 0.5 0 0 O
         Site1: 0   0 0 Si
 
@@ -254,13 +250,13 @@ or the Virtual Crystal Approximation."""
     xred = np.where(np.abs(xred) > 1e-8, xred, 0.0)
 
     # Info on atoms.
-    d = dict(
-        natom=natom,
-        ntypat=ntypat,
-        typat=typat,
-        znucl=znucl_type,
-        xred=xred,
-    )
+    d = {
+        "natom": natom,
+        "ntypat": ntypat,
+        "typat": typat,
+        "znucl": znucl_type,
+        "xred": xred,
+    }
 
     # Add info on the lattice.
     # Should we use (rprim, acell) or (angdeg, acell) to specify the lattice?
@@ -351,11 +347,7 @@ MANDATORY = MandatoryVariable()
 DEFAULT = DefaultVariable()
 
 
-class SpinMode(
-    collections.namedtuple("SpinMode", "mode nsppol nspinor nspden"),
-    AbivarAble,
-    MSONable,
-):
+class SpinMode(namedtuple("SpinMode", "mode nsppol nspinor nspden"), AbivarAble, MSONable):
     """
     Different configurations of the electron density as implemented in abinit:
     One can use as_spinmode to construct the object via SpinMode.as_spinmode
@@ -368,6 +360,8 @@ class SpinMode(
         - spinor_nomag (non-collinear, no magnetism)
     """
 
+    __slots__ = ()
+
     @classmethod
     def as_spinmode(cls, obj):
         """Converts obj into a `SpinMode` instance"""
@@ -378,7 +372,7 @@ class SpinMode(
         try:
             return _mode2spinvars[obj]
         except KeyError:
-            raise KeyError(f"Wrong value for spin_mode: {str(obj)}")
+            raise KeyError(f"Wrong value for spin_mode: {obj}")
 
     def to_abivars(self):
         """Dictionary with Abinit input variables."""
@@ -388,10 +382,11 @@ class SpinMode(
             "nspden": self.nspden,
         }
 
-    @pmg_serialize
     def as_dict(self):
         """Convert object to dict."""
-        return {k: getattr(self, k) for k in self._fields}
+        out = {k: getattr(self, k) for k in self._fields}
+        out.update({"@module": type(self).__module__, "@class": type(self).__name__})
+        return out
 
     @classmethod
     def from_dict(cls, d):
@@ -483,7 +478,7 @@ class Smearing(AbivarAble, MSONable):
     @property
     def mode(self):
         """String with smearing technique."""
-        for (mode_str, occopt) in self._mode2occopt.items():
+        for mode_str, occopt in self._mode2occopt.items():
             if occopt == self.occopt:
                 return mode_str
         raise AttributeError(f"Unknown occopt {self.occopt}")
@@ -499,10 +494,14 @@ class Smearing(AbivarAble, MSONable):
             return {"occopt": 1, "tsmear": 0.0}
         return {"occopt": self.occopt, "tsmear": self.tsmear}
 
-    @pmg_serialize
     def as_dict(self):
-        """json friendly dict representation of Smearing"""
-        return {"occopt": self.occopt, "tsmear": self.tsmear}
+        """JSON-friendly dict representation of Smearing"""
+        return {
+            "@module": type(self).__module__,
+            "@class": type(self).__name__,
+            "occopt": self.occopt,
+            "tsmear": self.tsmear,
+        }
 
     @staticmethod
     def from_dict(d):
@@ -514,18 +513,18 @@ class ElectronsAlgorithm(dict, AbivarAble, MSONable):
     """Variables controlling the SCF/NSCF algorithm."""
 
     # None indicates that we use abinit defaults.
-    _DEFAULT = dict(
-        iprcell=None,
-        iscf=None,
-        diemac=None,
-        diemix=None,
-        diemixmag=None,
-        dielam=None,
-        diegap=None,
-        dielng=None,
-        diecut=None,
-        nstep=50,
-    )
+    _DEFAULT = {
+        "iprcell": None,
+        "iscf": None,
+        "diemac": None,
+        "diemix": None,
+        "diemixmag": None,
+        "dielam": None,
+        "diegap": None,
+        "dielng": None,
+        "diecut": None,
+        "nstep": 50,
+    }
 
     def __init__(self, *args, **kwargs):
         """Initialize object."""
@@ -539,10 +538,9 @@ class ElectronsAlgorithm(dict, AbivarAble, MSONable):
         """Dictionary with Abinit input variables."""
         return self.copy()
 
-    @pmg_serialize
     def as_dict(self):
         """Convert object to dict."""
-        return self.copy()
+        return {"@module": type(self).__module__, "@class": type(self).__name__, **self.copy()}
 
     @classmethod
     def from_dict(cls, d):
@@ -599,18 +597,18 @@ class Electrons(AbivarAble, MSONable):
         return self.spin_mode.nspden
 
     def as_dict(self):
-        """json friendly dict representation"""
-        d = {}
-        d["@module"] = type(self).__module__
-        d["@class"] = type(self).__name__
-        d["spin_mode"] = self.spin_mode.as_dict()
-        d["smearing"] = self.smearing.as_dict()
-        d["algorithm"] = self.algorithm.as_dict() if self.algorithm else None
-        d["nband"] = self.nband
-        d["fband"] = self.fband
-        d["charge"] = self.charge
-        d["comment"] = self.comment
-        return d
+        """Json friendly dict representation"""
+        dct = {}
+        dct["@module"] = type(self).__module__
+        dct["@class"] = type(self).__name__
+        dct["spin_mode"] = self.spin_mode.as_dict()
+        dct["smearing"] = self.smearing.as_dict()
+        dct["algorithm"] = self.algorithm.as_dict() if self.algorithm else None
+        dct["nband"] = self.nband
+        dct["fband"] = self.fband
+        dct["charge"] = self.charge
+        dct["comment"] = self.comment
+        return dct
 
     @classmethod
     def from_dict(cls, d):
@@ -779,13 +777,13 @@ class KSampling(AbivarAble, MSONable):
             )
 
         else:
-            raise ValueError(f"Unknown mode {mode}")
+            raise ValueError(f"Unknown {mode=}")
 
         self.abivars = abivars
         # self.abivars["#comment"] = comment
 
     @property
-    def is_homogeneous(self):
+    def is_homogeneous(self) -> bool:
         """Homogeneous sampling."""
         return self.mode not in ["path"]
 
@@ -1050,7 +1048,6 @@ class RelaxationMethod(AbivarAble, MSONable):
 
     def __init__(self, *args, **kwargs):
         """Initialize object."""
-
         # Initialize abivars with the default values.
         self.abivars = self._default_vars
 
@@ -1218,7 +1215,7 @@ class PPModel(AbivarAble, MSONable):
         return self.mode != PPModelModes.noppmodel
 
     def __repr__(self):
-        return f"<{type(self).__name__} at {id(self)}, mode = {str(self.mode)}>"
+        return f"<{type(self).__name__} at {id(self)}, mode = {self.mode}>"
 
     def to_abivars(self):
         """Return dictionary with Abinit variables."""
@@ -1326,16 +1323,10 @@ class Screening(AbivarAble):
     """
 
     # Approximations used for W
-    _WTYPES = {
-        "RPA": 0,
-    }
+    _WTYPES = frozendict(RPA=0)
 
     # Self-consistecy modes
-    _SC_MODES = {
-        "one_shot": 0,
-        "energy_only": 1,
-        "wavefunctions": 2,
-    }
+    _SC_MODES = frozendict(one_shot=0, energy_only=1, wavefunctions=2)
 
     def __init__(
         self,
@@ -1421,20 +1412,20 @@ class SelfEnergy(AbivarAble):
     This object defines the parameters used for the computation of the self-energy.
     """
 
-    _SIGMA_TYPES = {
-        "gw": 0,
-        "hartree_fock": 5,
-        "sex": 6,
-        "cohsex": 7,
-        "model_gw_ppm": 8,
-        "model_gw_cd": 9,
-    }
+    _SIGMA_TYPES = frozendict(
+        gw=0,
+        hartree_fock=5,
+        sex=6,
+        cohsex=7,
+        model_gw_ppm=8,
+        model_gw_cd=9,
+    )
 
-    _SC_MODES = {
-        "one_shot": 0,
-        "energy_only": 1,
-        "wavefunctions": 2,
-    }
+    _SC_MODES = frozendict(
+        one_shot=0,
+        energy_only=1,
+        wavefunctions=2,
+    )
 
     def __init__(
         self,
@@ -1488,8 +1479,7 @@ class SelfEnergy(AbivarAble):
         # band_mode in ["gap", "full"]
 
         # if isinstance(kptgw, str) and kptgw == "all":
-        #    self.kptgw = None
-        #    self.nkptgw = None
+        #    self.kptgw = self.nkptgw = None
         # else:
         #    self.kptgw = np.reshape(kptgw, (-1,3))
         #    self.nkptgw =  len(self.kptgw)
@@ -1527,22 +1517,22 @@ class SelfEnergy(AbivarAble):
 
     def to_abivars(self):
         """Returns a dictionary with the abinit variables."""
-        abivars = dict(
-            gwcalctyp=self.gwcalctyp,
-            ecuteps=self.ecuteps,
-            ecutsigx=self.ecutsigx,
-            symsigma=self.symsigma,
-            gw_qprange=self.gw_qprange,
-            gwpara=self.gwpara,
-            optdriver=self.optdriver,
-            nband=self.nband
-            # "ecutwfn"  : self.ecutwfn,
-            # "kptgw"    : self.kptgw,
-            # "nkptgw"   : self.nkptgw,
-            # "bdgw"     : self.bdgw,
-        )
+        abivars = {
+            "gwcalctyp": self.gwcalctyp,
+            "ecuteps": self.ecuteps,
+            "ecutsigx": self.ecutsigx,
+            "symsigma": self.symsigma,
+            "gw_qprange": self.gw_qprange,
+            "gwpara": self.gwpara,
+            "optdriver": self.optdriver,
+            "nband": self.nband,
+            # "ecutwfn": self.ecutwfn,
+            # "kptgw": self.kptgw,
+            # "nkptgw": self.nkptgw,
+            # "bdgw": self.bdgw,
+        }
 
-        # FIXME: problem with the spin
+        # TODO: problem with the spin
         # assert len(self.bdgw) == self.nkptgw
 
         # ppmodel variables
@@ -1556,21 +1546,17 @@ class ExcHamiltonian(AbivarAble):
     """This object contains the parameters for the solution of the Bethe-Salpeter equation."""
 
     # Types of excitonic Hamiltonian.
-    _EXC_TYPES = {
-        "TDA": 0,  # Tamm-Dancoff approximation.
-        "coupling": 1,  # Calculation with coupling.
-    }
+    _EXC_TYPES = frozendict(
+        TDA=0,  # Tamm-Dancoff approximation.
+        coupling=1,  # Calculation with coupling.
+    )
 
     # Algorithms used to compute the macroscopic dielectric function
     # and/or the exciton wavefunctions.
-    _ALGO2VAR = {
-        "direct_diago": 1,
-        "haydock": 2,
-        "cg": 3,
-    }
+    _ALGO2VAR = frozendict(direct_diago=1, haydock=2, cg=3)
 
     # Options specifying the treatment of the Coulomb term.
-    _COULOMB_MODES = ["diago", "full", "model_df"]
+    _COULOMB_MODES = ("diago", "full", "model_df")
 
     def __init__(
         self,
@@ -1665,36 +1651,32 @@ class ExcHamiltonian(AbivarAble):
 
     def to_abivars(self):
         """Returns a dictionary with the abinit variables."""
-        abivars = dict(
-            bs_calctype=1,
-            bs_loband=self.bs_loband,
+        abivars = {
+            "bs_calctype": 1,
+            "bs_loband": self.bs_loband,
             # nband=self.nband,
-            mbpt_sciss=self.mbpt_sciss,
-            ecuteps=self.ecuteps,
-            bs_algorithm=self._ALGO2VAR[self.algo],
-            bs_coulomb_term=21,
-            mdf_epsinf=self.mdf_epsinf,
-            bs_exchange_term=1 if self.with_lf else 0,
-            inclvkb=self.inclvkb,
-            zcut=self.zcut,
-            bs_freq_mesh=self.bs_freq_mesh,
-            bs_coupling=self._EXC_TYPES[self.exc_type],
-            optdriver=self.optdriver,
-        )
+            "mbpt_sciss": self.mbpt_sciss,
+            "ecuteps": self.ecuteps,
+            "bs_algorithm": self._ALGO2VAR[self.algo],
+            "bs_coulomb_term": 21,
+            "mdf_epsinf": self.mdf_epsinf,
+            "bs_exchange_term": 1 if self.with_lf else 0,
+            "inclvkb": self.inclvkb,
+            "zcut": self.zcut,
+            "bs_freq_mesh": self.bs_freq_mesh,
+            "bs_coupling": self._EXC_TYPES[self.exc_type],
+            "optdriver": self.optdriver,
+        }
 
         if self.use_haydock:
-            # FIXME
             abivars.update(
                 bs_haydock_niter=100,  # No. of iterations for Haydock
                 bs_hayd_term=0,  # No terminator
                 bs_haydock_tol=[0.05, 0],  # Stopping criteria
             )
 
-        elif self.use_direct_diago:
-            raise NotImplementedError("")
-
-        elif self.use_cg:
-            raise NotImplementedError("")
+        elif self.use_direct_diago or self.use_cg:
+            raise NotImplementedError
 
         else:
             raise ValueError(f"Unknown algorithm for EXC: {self.algo}")
