@@ -1,13 +1,12 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
 #
 # pylint: disable=no-member
 """Wrapper for netCDF readers."""
 
+from __future__ import annotations
+
 import logging
 import os.path
 import warnings
-from collections import OrderedDict
 
 import numpy as np
 from monty.collections import AttrDict
@@ -27,7 +26,7 @@ __version__ = "0.1"
 __maintainer__ = "Matteo Giantomassi"
 __email__ = "gmatteo at gmail.com"
 __status__ = "Development"
-__date__ = "$Feb 21, 2013M$"
+__date__ = "Feb 21, 2013M"
 
 __all__ = [
     "as_ncreader",
@@ -43,15 +42,14 @@ try:
 except ImportError as exc:
     netCDF4 = None
     warnings.warn(
-        """\
+        f"""\
 `import netCDF4` failed with the following error:
 
-%s
+{exc}
 
 Please install netcdf4 with `conda install netcdf4`
 If the conda version does not work, uninstall it with `conda uninstall hdf4 hdf5 netcdf4`
 and use `pip install netcdf4`"""
-        % str(exc)
     )
 
 
@@ -102,13 +100,13 @@ class NetcdfReader:
         try:
             self.rootgrp = netCDF4.Dataset(self.path, mode="r")
         except Exception as exc:
-            raise self.Error(f"In file {self.path}: {str(exc)}")
+            raise self.Error(f"In file {self.path}: {exc}")
 
         self.ngroups = len(list(self.walk_tree()))
 
         # Always return non-masked numpy arrays.
         # Slicing a ncvar returns a MaskedArrray and this is really annoying
-        # because it can lead to unexpected behaviour in e.g. calls to np.matmul!
+        # because it can lead to unexpected behavior in e.g. calls to np.matmul!
         # See also https://github.com/Unidata/netcdf4-python/issues/785
         self.rootgrp.set_auto_mask(False)
 
@@ -167,9 +165,9 @@ class NetcdfReader:
     def read_varnames(self, path="/"):
         """List of variable names stored in the group specified by path."""
         if path == "/":
-            return self.rootgrp.variables.keys()
+            return list(self.rootgrp.variables)
         group = self.path2group[path]
-        return group.variables.keys()
+        return list(group.variables)
 
     def read_value(self, varname, path="/", cmode=None, default=NO_DEFAULT):
         """
@@ -204,7 +202,7 @@ class NetcdfReader:
         assert var.shape[-1] == 2
         if cmode == "c":
             return var[..., 0] + 1j * var[..., 1]
-        raise ValueError("Wrong value for cmode %s" % cmode)
+        raise ValueError(f"Wrong value for {cmode=}")
 
     def read_variable(self, varname, path="/"):
         """Returns the variable with name varname in the group specified by path."""
@@ -295,26 +293,26 @@ class ETSF_Reader(NetcdfReader):
 
         Return :class:`AbinitHeader`
         """
-        d = {}
+        dct = {}
         for hvar in _HDR_VARIABLES.values():
             ncname = hvar.etsf_name if hvar.etsf_name is not None else hvar.name
             if ncname in self.rootgrp.variables:
-                d[hvar.name] = self.read_value(ncname)
+                dct[hvar.name] = self.read_value(ncname)
             elif ncname in self.rootgrp.dimensions:
-                d[hvar.name] = self.read_dimvalue(ncname)
+                dct[hvar.name] = self.read_dimvalue(ncname)
             else:
                 raise ValueError(f"Cannot find `{ncname}` in `{self.path}`")
             # Convert scalars to (well) scalars.
-            if hasattr(d[hvar.name], "shape") and not d[hvar.name].shape:
-                d[hvar.name] = np.asarray(d[hvar.name]).item()
+            if hasattr(dct[hvar.name], "shape") and not dct[hvar.name].shape:
+                dct[hvar.name] = np.asarray(dct[hvar.name]).item()
             if hvar.name in ("title", "md5_pseudos", "codvsn"):
                 # Convert array of numpy bytes to list of strings
                 if hvar.name == "codvsn":
-                    d[hvar.name] = "".join(bs.decode("utf-8").strip() for bs in d[hvar.name])
+                    dct[hvar.name] = "".join(bs.decode("utf-8").strip() for bs in dct[hvar.name])
                 else:
-                    d[hvar.name] = ["".join(bs.decode("utf-8") for bs in astr).strip() for astr in d[hvar.name]]
+                    dct[hvar.name] = ["".join(bs.decode("utf-8") for bs in astr).strip() for astr in dct[hvar.name]]
 
-        return AbinitHeader(d)
+        return AbinitHeader(dct)
 
 
 def structure_from_ncdata(ncdata, site_properties=None, cls=Structure):
@@ -325,7 +323,7 @@ def structure_from_ncdata(ncdata, site_properties=None, cls=Structure):
     Args:
         ncdata: filename or NetcdfReader instance.
         site_properties: Dictionary with site properties.
-        cls: The Structure class to instanciate.
+        cls: The Structure class to instantiate.
     """
     ncdata, closeit = as_ncreader(ncdata)
 
@@ -346,12 +344,12 @@ def structure_from_ncdata(ncdata, site_properties=None, cls=Structure):
         type_idx = type_atom[atom] - 1
         species[atom] = int(znucl_type[type_idx])
 
-    d = {}
+    dct = {}
     if site_properties is not None:
         for prop in site_properties:
-            d[prop] = ncdata.read_value(prop)
+            dct[prop] = ncdata.read_value(prop)
 
-    structure = cls(lattice, species, red_coords, site_properties=d)
+    structure = cls(lattice, species, red_coords, site_properties=dct)
 
     # Quick and dirty hack.
     # I need an abipy structure since I need to_abivars and other methods.
@@ -369,7 +367,7 @@ def structure_from_ncdata(ncdata, site_properties=None, cls=Structure):
 
 
 class _H:
-    __slots__ = ["name", "doc", "etsf_name"]
+    __slots__ = ("name", "doc", "etsf_name")
 
     def __init__(self, name, doc, etsf_name=None):
         self.name, self.doc, self.etsf_name = name, doc, etsf_name
@@ -468,7 +466,7 @@ _HDR_VARIABLES = (
     ),
     # _H(type(pawrhoij_type), allocatable :: pawrhoij(:) ! EVOLVING variable, only for paw
 )
-_HDR_VARIABLES = OrderedDict([(h.name, h) for h in _HDR_VARIABLES])  # type: ignore
+_HDR_VARIABLES = {h.name: h for h in _HDR_VARIABLES}  # type: ignore
 
 
 class AbinitHeader(AttrDict):
