@@ -1,9 +1,11 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
+from __future__ import annotations
 
 import os
 
 import numpy as np
+import pytest
+from numpy.testing import assert_array_equal
+from pytest import approx
 
 from pymatgen.core.structure import Structure
 from pymatgen.core.units import Ha_to_eV, bohr_to_ang
@@ -25,7 +27,7 @@ from pymatgen.util.testing import PymatgenTest
 class LatticeFromAbivarsTest(PymatgenTest):
     def test_rprim_acell(self):
         l1 = lattice_from_abivars(acell=3 * [10], rprim=np.eye(3))
-        self.assertAlmostEqual(l1.volume, bohr_to_ang**3 * 1000)
+        assert l1.volume == approx(bohr_to_ang**3 * 1000)
         assert l1.angles == (90, 90, 90)
         l2 = lattice_from_abivars(acell=3 * [10], angdeg=(90, 90, 90))
         assert l1 == l2
@@ -48,7 +50,7 @@ class LatticeFromAbivarsTest(PymatgenTest):
             )
             * bohr_to_ang
         )
-        self.assertArrayAlmostEqual(l2.matrix, abi_rprimd)
+        self.assert_all_close(l2.matrix, abi_rprimd)
 
         l3 = lattice_from_abivars(acell=[3, 6, 9], angdeg=(30, 40, 50))
         abi_rprimd = (
@@ -68,16 +70,15 @@ class LatticeFromAbivarsTest(PymatgenTest):
             )
             * bohr_to_ang
         )
-        self.assertArrayAlmostEqual(l3.matrix, abi_rprimd)
+        self.assert_all_close(l3.matrix, abi_rprimd)
 
-        with self.assertRaises(ValueError):
+        with pytest.raises(ValueError):
             lattice_from_abivars(acell=[1, 1, 1], angdeg=(90, 90, 90), rprim=np.eye(3))
-        with self.assertRaises(ValueError):
+        with pytest.raises(ValueError):
             lattice_from_abivars(acell=[1, 1, 1], angdeg=(-90, 90, 90))
 
     def test_znucl_typat(self):
         """Test the order of typat and znucl in the Abinit input and enforce_typat, enforce_znucl."""
-
         # Ga  Ga1  1  0.33333333333333  0.666666666666667  0.500880  1.0
         # Ga  Ga2  1  0.66666666666667  0.333333333333333  0.000880  1.0
         # N  N3  1  0.333333333333333  0.666666666666667  0.124120  1.0
@@ -87,24 +88,24 @@ class LatticeFromAbivarsTest(PymatgenTest):
         # By default, znucl is filled using the first new type found in sites.
         def_vars = structure_to_abivars(gan)
         def_znucl = def_vars["znucl"]
-        self.assertArrayEqual(def_znucl, [31, 7])
+        assert_array_equal(def_znucl, [31, 7])
         def_typat = def_vars["typat"]
-        self.assertArrayEqual(def_typat, [1, 1, 2, 2])
+        assert_array_equal(def_typat, [1, 1, 2, 2])
 
         # But it's possible to enforce a particular value of typat and znucl.
         enforce_znucl = [7, 31]
         enforce_typat = [2, 2, 1, 1]
         enf_vars = structure_to_abivars(gan, enforce_znucl=enforce_znucl, enforce_typat=enforce_typat)
-        self.assertArrayEqual(enf_vars["znucl"], enforce_znucl)
-        self.assertArrayEqual(enf_vars["typat"], enforce_typat)
-        self.assertArrayEqual(def_vars["xred"], enf_vars["xred"])
+        assert_array_equal(enf_vars["znucl"], enforce_znucl)
+        assert_array_equal(enf_vars["typat"], enforce_typat)
+        assert_array_equal(def_vars["xred"], enf_vars["xred"])
 
         assert [s.symbol for s in species_by_znucl(gan)] == ["Ga", "N"]
 
         for itype1, itype2 in zip(def_typat, enforce_typat):
             assert def_znucl[itype1 - 1] == enforce_znucl[itype2 - 1]
 
-        with self.assertRaises(ValueError):
+        with pytest.raises(ValueError):
             structure_to_abivars(gan, enforce_znucl=enforce_znucl, enforce_typat=None)
 
 
@@ -116,16 +117,16 @@ class SpinModeTest(PymatgenTest):
 
         polarized.to_abivars()
 
-        self.assertTrue(polarized is other_polarized)
-        self.assertTrue(polarized == other_polarized)
-        self.assertTrue(polarized != unpolarized)
+        assert polarized is other_polarized
+        assert polarized == other_polarized
+        assert polarized != unpolarized
 
         # Test pickle
         self.serialize_with_pickle(polarized)
 
         # Test dict methods
-        self.assertMSONable(polarized)
-        self.assertMSONable(unpolarized)
+        self.assert_msonable(polarized)
+        self.assert_msonable(unpolarized)
 
 
 class SmearingTest(PymatgenTest):
@@ -133,27 +134,27 @@ class SmearingTest(PymatgenTest):
         fd1ev = Smearing.as_smearing("fermi_dirac:1 eV")
         fd1ev.to_abivars()
 
-        self.assertTrue(fd1ev)
+        assert fd1ev
 
         same_fd = Smearing.as_smearing("fermi_dirac:" + str(1.0 / Ha_to_eV))
 
-        self.assertTrue(same_fd == fd1ev)
+        assert same_fd == fd1ev
 
         nosmear = Smearing.nosmearing()
         assert nosmear == Smearing.as_smearing("nosmearing")
 
-        self.assertFalse(nosmear)
-        self.assertTrue(nosmear != fd1ev)
-        self.assertMSONable(nosmear)
+        assert not nosmear
+        assert nosmear != fd1ev
+        self.assert_msonable(nosmear)
 
         new_fd1ev = Smearing.from_dict(fd1ev.as_dict())
-        self.assertTrue(new_fd1ev == fd1ev)
+        assert new_fd1ev == fd1ev
 
         # Test pickle
         self.serialize_with_pickle(fd1ev)
 
         # Test dict methods
-        self.assertMSONable(fd1ev)
+        self.assert_msonable(fd1ev)
 
 
 class ElectronsAlgorithmTest(PymatgenTest):
@@ -165,15 +166,15 @@ class ElectronsAlgorithmTest(PymatgenTest):
         self.serialize_with_pickle(algo)
 
         # Test dict methods
-        self.assertMSONable(algo)
+        self.assert_msonable(algo)
 
 
 class ElectronsTest(PymatgenTest):
     def test_base(self):
         default_electrons = Electrons()
-        self.assertTrue(default_electrons.nsppol == 2)
-        self.assertTrue(default_electrons.nspinor == 1)
-        self.assertTrue(default_electrons.nspden == 2)
+        assert default_electrons.nsppol == 2
+        assert default_electrons.nspinor == 1
+        assert default_electrons.nspden == 2
 
         _ = default_electrons.to_abivars()
 
@@ -192,7 +193,7 @@ class ElectronsTest(PymatgenTest):
         )
 
         # Test dict methods
-        self.assertMSONable(custom_electrons)
+        self.assert_msonable(custom_electrons)
 
 
 class KSamplingTest(PymatgenTest):
@@ -203,8 +204,8 @@ class KSamplingTest(PymatgenTest):
         monkhorst.to_abivars()
 
         # Test dict methods
-        self.assertMSONable(monkhorst)
-        self.assertMSONable(gamma_centered)
+        self.assert_msonable(monkhorst)
+        self.assert_msonable(gamma_centered)
 
 
 class RelaxationTest(PymatgenTest):
@@ -215,8 +216,8 @@ class RelaxationTest(PymatgenTest):
         atoms_and_cell.to_abivars()
 
         # Test dict methods
-        self.assertMSONable(atoms_and_cell)
-        self.assertMSONable(atoms_only)
+        self.assert_msonable(atoms_and_cell)
+        self.assert_msonable(atoms_only)
 
 
 class PPModelTest(PymatgenTest):
@@ -225,20 +226,20 @@ class PPModelTest(PymatgenTest):
         # print(godby)
         # print(repr(godby))
         godby.to_abivars()
-        self.assertTrue(godby)
+        assert godby
 
         same_godby = PPModel.as_ppmodel("godby:" + str(12.0 / Ha_to_eV))
-        self.assertTrue(same_godby == godby)
+        assert same_godby == godby
 
         noppm = PPModel.get_noppmodel()
 
-        self.assertFalse(noppm)
-        self.assertTrue(noppm != godby)
+        assert not noppm
+        assert noppm != godby
         new_godby = PPModel.from_dict(godby.as_dict())
-        self.assertTrue(new_godby == godby)
+        assert new_godby == godby
 
         # Test pickle
         self.serialize_with_pickle(godby)
 
         # Test dict methods
-        self.assertMSONable(godby)
+        self.assert_msonable(godby)
