@@ -1,10 +1,11 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
+from __future__ import annotations
 
 import os
 import tempfile
 
 import numpy as np
+import pytest
+from numpy.testing import assert_array_equal
 
 from pymatgen.core.structure import Structure
 from pymatgen.io.abinit.inputs import (
@@ -51,19 +52,25 @@ class AbinitInputTestCase(PymatgenTest):
         inp = BasicAbinitInput(structure=unit_cell, pseudos=abiref_file("14si.pspnc"))
 
         shiftk = [[0.5, 0.5, 0.5], [0.5, 0.0, 0.0], [0.0, 0.5, 0.0], [0.0, 0.0, 0.5]]
-        self.assertArrayEqual(calc_shiftk(inp.structure), shiftk)
+        assert_array_equal(calc_shiftk(inp.structure), shiftk)
         assert num_valence_electrons(inp.structure, inp.pseudos) == 8
 
         repr(inp), str(inp)
-        assert len(inp) == 0 and not inp
-        assert inp.get("foo", "bar") == "bar" and inp.pop("foo", "bar") == "bar"
+        assert len(inp) == 0
+        assert not inp
+        assert inp.get("foo", "bar") == "bar"
+        assert inp.pop("foo", "bar") == "bar"
         assert inp.comment is None
         inp.set_comment("This is a comment")
         assert inp.comment == "This is a comment"
-        assert inp.isnc and not inp.ispaw
+        assert inp.isnc
+        assert not inp.ispaw
 
         inp["ecut"] = 1
-        assert inp.get("ecut") == 1 and len(inp) == 1 and "ecut" in inp and "foo" not in inp
+        assert inp.get("ecut") == 1
+        assert len(inp) == 1
+        assert "ecut" in inp
+        assert "foo" not in inp
 
         # Test to_string
         assert inp.to_string(with_structure=True, with_pseudos=True)
@@ -78,13 +85,13 @@ class AbinitInputTestCase(PymatgenTest):
         inp.write(filepath=tmpname)
 
         # Cannot change structure variables directly.
-        with self.assertRaises(inp.Error):
+        with pytest.raises(inp.Error):
             inp.set_vars(unit_cell)
 
-        with self.assertRaises(TypeError):
+        with pytest.raises(TypeError):
             inp.add_abiobjects({})
 
-        with self.assertRaises(KeyError):
+        with pytest.raises(KeyError):
             inp.remove_vars("foo", strict=True)
         assert not inp.remove_vars("foo", strict=False)
 
@@ -93,14 +100,18 @@ class AbinitInputTestCase(PymatgenTest):
         inp_copy = inp.deepcopy()
         inp_copy["bdgw"][1] = 3
         assert inp["bdgw"] == [1, 2]
-        assert inp.remove_vars("bdgw") and "bdgw" not in inp
+        assert inp.remove_vars("bdgw")
+        assert "bdgw" not in inp
 
         removed = inp.pop_tolerances()
-        assert len(removed) == 1 and removed["toldfe"] == 1e-6
+        assert len(removed) == 1
+        assert removed["toldfe"] == 1e-6
 
         # Test set_spin_mode
         old_vars = inp.set_spin_mode("polarized")
-        assert "nsppol" in inp and inp["nspden"] == 2 and inp["nspinor"] == 1
+        assert "nsppol" in inp
+        assert inp["nspden"] == 2
+        assert inp["nspinor"] == 1
         inp.set_vars(old_vars)
 
         # Test set_structure
@@ -117,25 +128,25 @@ class AbinitInputTestCase(PymatgenTest):
         si_structure = Structure.from_file(abiref_file("si.cif"))
 
         # Ambiguous list of pseudos.
-        with self.assertRaises(BasicAbinitInput.Error):
+        with pytest.raises(BasicAbinitInput.Error):
             BasicAbinitInput(si_structure, pseudos=abiref_files("14si.pspnc", "14si.4.hgh"))
 
         # Pseudos do not match structure.
-        with self.assertRaises(BasicAbinitInput.Error):
+        with pytest.raises(BasicAbinitInput.Error):
             BasicAbinitInput(si_structure, pseudos=abiref_file("H-wdr.oncvpsp"))
 
-        si1_negative_volume = dict(
-            ntypat=1,
-            natom=1,
-            typat=[1],
-            znucl=14,
-            acell=3 * [7.60],
-            rprim=[[0.0, 0.5, 0.5], [-0.5, -0.0, -0.5], [0.5, 0.5, 0.0]],
-            xred=[[0.0, 0.0, 0.0]],
-        )
+        si1_negative_volume = {
+            "ntypat": 1,
+            "natom": 1,
+            "typat": [1],
+            "znucl": 14,
+            "acell": 3 * [7.60],
+            "rprim": [[0.0, 0.5, 0.5], [-0.5, -0.0, -0.5], [0.5, 0.5, 0.0]],
+            "xred": [[0.0, 0.0, 0.0]],
+        }
 
         # Negative triple product.
-        with self.assertRaises(BasicAbinitInput.Error):
+        with pytest.raises(BasicAbinitInput.Error):
             BasicAbinitInput(si1_negative_volume, pseudos=abiref_files("14si.pspnc"))
 
     def test_helper_functions(self):
@@ -143,14 +154,18 @@ class AbinitInputTestCase(PymatgenTest):
         inp = BasicAbinitInput(structure=abiref_file("si.cif"), pseudos="14si.pspnc", pseudo_dir=_test_dir)
 
         inp.set_kmesh(ngkpt=(1, 2, 3), shiftk=(1, 2, 3, 4, 5, 6))
-        assert inp["kptopt"] == 1 and inp["nshiftk"] == 2
+        assert inp["kptopt"] == 1
+        assert inp["nshiftk"] == 2
 
         inp.set_gamma_sampling()
-        assert inp["kptopt"] == 1 and inp["nshiftk"] == 1
+        assert inp["kptopt"] == 1
+        assert inp["nshiftk"] == 1
         assert np.all(inp["shiftk"] == 0)
 
         inp.set_kpath(ndivsm=3, kptbounds=None)
-        assert inp["ndivsm"] == 3 and inp["iscf"] == -2 and len(inp["kptbounds"]) == 12
+        assert inp["ndivsm"] == 3
+        assert inp["iscf"] == -2
+        assert len(inp["kptbounds"]) == 12
 
 
 class TestMultiDataset(PymatgenTest):
@@ -162,34 +177,37 @@ class TestMultiDataset(PymatgenTest):
         pseudo = abiref_file("14si.pspnc")
         pseudo_dir = os.path.dirname(pseudo)
         multi = BasicMultiDataset(structure=structure, pseudos=pseudo)
-        with self.assertRaises(ValueError):
+        with pytest.raises(ValueError):
             BasicMultiDataset(structure=structure, pseudos=pseudo, ndtset=-1)
 
         multi = BasicMultiDataset(structure=structure, pseudos=pseudo, pseudo_dir=pseudo_dir)
 
-        assert len(multi) == 1 and multi.ndtset == 1
+        assert len(multi) == 1
+        assert multi.ndtset == 1
         assert multi.isnc
         for i, inp in enumerate(multi):
             assert list(inp) == list(multi[i])
 
         multi.addnew_from(0)
-        assert multi.ndtset == 2 and multi[0] is not multi[1]
+        assert multi.ndtset == 2
+        assert multi[0] is not multi[1]
         assert multi[0].structure == multi[1].structure
         assert multi[0].structure is not multi[1].structure
 
         multi.set_vars(ecut=2)
         assert all(inp["ecut"] == 2 for inp in multi)
-        self.assertEqual(multi.get("ecut"), [2, 2])
+        assert multi.get("ecut") == [2, 2]
 
         multi[1].set_vars(ecut=1)
-        assert multi[0]["ecut"] == 2 and multi[1]["ecut"] == 1
-        self.assertEqual(multi.get("ecut"), [2, 1])
+        assert multi[0]["ecut"] == 2
+        assert multi[1]["ecut"] == 1
+        assert multi.get("ecut") == [2, 1]
 
-        self.assertEqual(multi.get("foo", "default"), ["default", "default"])
+        assert multi.get("foo", "default") == ["default", "default"]
 
         multi[1].set_vars(paral_kgb=1)
         assert "paral_kgb" not in multi[0]
-        self.assertEqual(multi.get("paral_kgb"), [None, 1])
+        assert multi.get("paral_kgb") == [None, 1]
 
         pert_structure = structure.copy()
         pert_structure.perturb(distance=0.1)
@@ -199,11 +217,13 @@ class TestMultiDataset(PymatgenTest):
         assert all(s == structure for s in multi.structure)
         assert multi.has_same_structures
         multi[1].set_structure(pert_structure)
-        assert multi[0].structure != multi[1].structure and multi[1].structure == pert_structure
+        assert multi[0].structure != multi[1].structure
+        assert multi[1].structure == pert_structure
         assert not multi.has_same_structures
 
         split = multi.split_datasets()
-        assert len(split) == 2 and all(split[i] == multi[i] for i in range(multi.ndtset))
+        assert len(split) == 2
+        assert all(split[i] == multi[i] for i in range(multi.ndtset))
         repr(multi)
         str(multi)
         assert multi.to_string(with_pseudos=False)
@@ -213,13 +233,13 @@ class TestMultiDataset(PymatgenTest):
         inp.write(filepath=filepath)
         multi.write(filepath=filepath)
 
-        new_multi = BasicMultiDataset.from_inputs([inp for inp in multi])
+        new_multi = BasicMultiDataset.from_inputs(list(multi))
         assert new_multi.ndtset == multi.ndtset
         assert new_multi.structure == multi.structure
 
         for old_inp, new_inp in zip(multi, new_multi):
             assert old_inp is not new_inp
-            self.assertDictEqual(old_inp.as_dict(), new_inp.as_dict())
+            assert old_inp.as_dict() == new_inp.as_dict()
 
         ref_input = multi[0]
         new_multi = BasicMultiDataset.replicate_input(input=ref_input, ndtset=4)
@@ -227,7 +247,7 @@ class TestMultiDataset(PymatgenTest):
         assert new_multi.ndtset == 4
         for inp in new_multi:
             assert ref_input is not inp
-            self.assertDictEqual(ref_input.as_dict(), inp.as_dict())
+            assert ref_input.as_dict() == inp.as_dict()
 
         # Compatible with Pickle and MSONable?
         self.serialize_with_pickle(multi, test_eq=False)
@@ -239,7 +259,7 @@ class ShiftModeTest(PymatgenTest):
         gamma = ShiftMode.GammaCentered
         assert ShiftMode.from_object("G") == gamma
         assert ShiftMode.from_object(gamma) == gamma
-        with self.assertRaises(TypeError):
+        with pytest.raises(TypeError):
             ShiftMode.from_object({})
 
 
@@ -255,7 +275,7 @@ class FactoryTest(PymatgenTest):
         str(inp)
         assert inp["nsppol"] == 2
         assert inp["nband"] == 14
-        self.assertArrayEqual(inp["ngkpt"], [2, 2, 2])
+        assert_array_equal(inp["ngkpt"], [2, 2, 2])
 
     def test_ebands_input(self):
         """Testing ebands_input factory."""
@@ -278,8 +298,8 @@ class FactoryTest(PymatgenTest):
         )
         assert len(multi_dos) == 3
         assert all(i["charge"] == 2 for i in multi_dos)
-        self.assertEqual(multi_dos.get("nsppol"), [1, 1, 1])
-        self.assertEqual(multi_dos.get("iscf"), [None, -2, -2])
+        assert multi_dos.get("nsppol") == [1, 1, 1]
+        assert multi_dos.get("iscf") == [None, -2, -2]
 
         multi_dos = ebands_input(
             self.si_structure,
@@ -293,7 +313,7 @@ class FactoryTest(PymatgenTest):
             dos_kppa=[50, 100],
         )
         assert len(multi_dos) == 4
-        self.assertEqual(multi_dos.get("iscf"), [None, -2, -2, -2])
+        assert multi_dos.get("iscf") == [None, -2, -2, -2]
         str(multi_dos)
 
     def test_ion_ioncell_relax_input(self):
@@ -303,5 +323,7 @@ class FactoryTest(PymatgenTest):
         str(multi)
         ion_inp, ioncell_inp = multi.split_datasets()
         assert ion_inp["chksymbreak"] == 0
-        assert ion_inp["ionmov"] == 3 and ion_inp["optcell"] == 0
-        assert ioncell_inp["ionmov"] == 3 and ioncell_inp["optcell"] == 2
+        assert ion_inp["ionmov"] == 3
+        assert ion_inp["optcell"] == 0
+        assert ioncell_inp["ionmov"] == 3
+        assert ioncell_inp["optcell"] == 2
