@@ -2,10 +2,13 @@
 IO for ADF files.
 """
 
+from __future__ import annotations
+
 import os
 import re
 from typing import Generator
 
+from frozendict import frozendict
 from monty.io import reverse_readline
 from monty.itertools import chunks
 from monty.json import MSONable
@@ -15,7 +18,7 @@ from pymatgen.core.structure import Molecule
 __author__ = "Xin Chen, chenxin13@mails.tsinghua.edu.cn"
 
 
-def is_numeric(s):
+def is_numeric(s) -> bool:
     """
     Return True is the string ``s`` is a numeric string.
 
@@ -24,7 +27,7 @@ def is_numeric(s):
     s : str
         A string.
 
-    Returns
+    Returns:
     -------
     res : bool
         If True, ``s`` is a numeric string and can be converted to an int or a
@@ -77,7 +80,7 @@ class AdfKey(MSONable):
     subkeys and a set of options.
     """
 
-    block_keys = {
+    block_keys = (
         "SCF",
         "GEOMETRY",
         "XC",
@@ -97,11 +100,11 @@ class AdfKey(MSONable):
         "EXACTDENSITY",
         "TOTALENERGY",
         "ANALYTICALFREQ",
-    }
-    sub_keys = {"AtomDepQuality"}
+    )
+    sub_keys = ("AtomDepQuality",)
 
     # Full blocks are blocks that must have an 'END'.
-    _full_blocks = {"GEOMETRY", "SCF", "UNITS", "BASIS", "ANALYTICALFREQ"}
+    _full_blocks = ("GEOMETRY", "SCF", "UNITS", "BASIS", "ANALYTICALFREQ")
 
     def __init__(self, name, options=None, subkeys=None):
         """
@@ -118,7 +121,7 @@ class AdfKey(MSONable):
         subkeys : Sized
             The subkeys for this key.
 
-        Raises
+        Raises:
         ------
         ValueError
             If elements in ``subkeys`` are not ``AdfKey`` objects.
@@ -148,7 +151,7 @@ class AdfKey(MSONable):
             return s.strip()
         return ""
 
-    def is_block_key(self):
+    def is_block_key(self) -> bool:
         """
         Return True if this key is a block key.
         """
@@ -168,7 +171,7 @@ class AdfKey(MSONable):
         """
         Return the string representation of this ``AdfKey``.
 
-        Notes
+        Notes:
         -----
         If this key is 'Atoms' and the coordinates are in Cartesian form, a
         different string format will be used.
@@ -209,7 +212,7 @@ class AdfKey(MSONable):
         subkey : str or AdfKey
             A key name or an AdfKey object.
 
-        Returns
+        Returns:
         -------
         has : bool
             True if this key contains the given key. Otherwise False.
@@ -220,9 +223,8 @@ class AdfKey(MSONable):
             key = subkey.key
         else:
             raise ValueError("The subkey should be an AdfKey or a string!")
-        if len(self.subkeys) > 0:
-            if key in map(lambda k: k.key, self.subkeys):
-                return True
+        if len(self.subkeys) > 0 and key in (k.key for k in self.subkeys):
+            return True
         return False
 
     def add_subkey(self, subkey):
@@ -234,7 +236,7 @@ class AdfKey(MSONable):
         subkey : AdfKey
             A new subkey.
 
-        Notes
+        Notes:
         -----
         Duplicate check will not be performed if this is an 'Atoms' block.
         """
@@ -267,7 +269,7 @@ class AdfKey(MSONable):
             A new option to add. This must have the same format with existing
             options.
 
-        Raises
+        Raises:
         ------
         TypeError
             If the format of the given ``option`` is different.
@@ -289,7 +291,7 @@ class AdfKey(MSONable):
         option : str or int
             The name (str) or index (int) of the option to remove.
 
-        Raises
+        Raises:
         ------
         TypeError
             If the option has a wrong type.
@@ -316,17 +318,14 @@ class AdfKey(MSONable):
         option : str
             The option.
 
-        Returns
+        Returns:
         -------
         has : bool
             True if the option can be found. Otherwise False will be returned.
         """
         if len(self.options) == 0:
             return False
-        for op in self.options:
-            if (self._sized_op and op[0] == option) or (op == option):
-                return True
-        return False
+        return any(self._sized_op and op[0] == option or op == option for op in self.options)
 
     def as_dict(self):
         """
@@ -355,18 +354,15 @@ class AdfKey(MSONable):
         d : dict
             A dict of saved attributes.
 
-        Returns
+        Returns:
         -------
         adfkey : AdfKey
             An AdfKey object recovered from the JSON dict ``d``.
         """
         key = d.get("name")
-        options = d.get("options", None)
+        options = d.get("options")
         subkey_list = d.get("subkeys", [])
-        if len(subkey_list) > 0:
-            subkeys = list(map(lambda k: AdfKey.from_dict(k), subkey_list))
-        else:
-            subkeys = None
+        subkeys = [AdfKey.from_dict(k) for k in subkey_list] or None
         return cls(key, options, subkeys)
 
     @staticmethod
@@ -379,32 +375,29 @@ class AdfKey(MSONable):
         string : str
             A string.
 
-        Returns
+        Returns:
         -------
         adfkey : AdfKey
             An AdfKey object recovered from the string.
 
-        Raises
+        Raises:
         ------
         ValueError
             Currently nested subkeys are not supported. If ``subend`` was found
             a ValueError would be raised.
 
-        Notes
+        Notes:
         -----
         Only the first block key will be returned.
         """
 
-        def is_float(s):
+        def is_float(s) -> bool:
             return "." in s or "E" in s or "e" in s
 
         if string.find("\n") == -1:
             el = string.split()
             if len(el) > 1:
-                if string.find("=") != -1:
-                    options = list(map(lambda s: s.split("="), el[1:]))
-                else:
-                    options = el[1:]
+                options = [s.split("=") for s in el[1:]] if string.find("=") != -1 else el[1:]
                 for i, op in enumerate(options):
                     if isinstance(op, list) and is_numeric(op[1]):
                         op[1] = float(op[1]) if is_float(op[1]) else int(op[1])
@@ -433,28 +426,27 @@ class AdfKey(MSONable):
                 return key
             elif key is not None:
                 key.add_subkey(AdfKey.from_string(line))
-        else:
-            raise Exception("IncompleteKey: 'END' is missing!")
+
+        raise Exception("IncompleteKey: 'END' is missing!")
 
 
 class AdfTask(MSONable):
     """
     Basic task for ADF. All settings in this class are independent of molecules.
 
-    Notes
+    Notes:
     -----
     Unlike other quantum chemistry packages (NWChem, Gaussian, ...), ADF does
     not support calculating force/gradient.
-
     """
 
-    operations = {
-        "energy": "Evaluate the single point energy.",
-        "optimize": "Minimize the energy by varying the molecular structure.",
-        "frequencies": "Compute second derivatives and print out an analysis of molecular vibrations.",
-        "freq": "Same as frequencies.",
-        "numerical_frequencies": "Compute molecular frequencies using numerical method.",
-    }
+    operations = frozendict(
+        energy="Evaluate the single point energy.",
+        optimize="Minimize the energy by varying the molecular structure.",
+        frequencies="Compute second derivatives and print out an analysis of molecular vibrations.",
+        freq="Same as frequencies.",
+        numerical_frequencies="Compute molecular frequencies using numerical method.",
+    )
 
     def __init__(
         self,
@@ -544,7 +536,7 @@ class AdfTask(MSONable):
         geo_subkeys : Sized
             User-defined subkeys for the block 'Geometry'.
 
-        Notes
+        Notes:
         -----
         Most of the run types of ADF are specified in the Geometry block except
         the 'AnalyticFreq'.
@@ -567,11 +559,11 @@ class AdfTask(MSONable):
 
     def __str__(self):
         s = f"""TITLE {self.title}\n
-{str(self.units)}
-{str(self.xc)}
-{str(self.basis_set)}
-{str(self.scf)}
-{str(self.geo)}"""
+{self.units}
+{self.xc}
+{self.basis_set}
+{self.scf}
+{self.geo}"""
         s += "\n"
         for block_key in self.other_directives:
             if not isinstance(block_key, AdfKey):
@@ -606,7 +598,7 @@ class AdfTask(MSONable):
         d : dict
             A dict of saved attributes.
 
-        Returns
+        Returns:
         -------
         task : AdfTask
             An AdfTask object recovered from the JSON dict ``d``.
@@ -680,7 +672,7 @@ class AdfOutput:
     """
     A basic ADF output file parser.
 
-    Attributes
+    Attributes:
     ----------
     is_failed : bool
         True is the ADF job is terminated without success. Otherwise False.
@@ -734,15 +726,11 @@ class AdfOutput:
             raise OSError("The ADF logfile can not be accessed!")
 
         self.is_failed = False
-        self.error = None
-        self.final_energy = None
-        self.final_structure = None
+        self.error = self.final_energy = self.final_structure = None
         self.energies = []
         self.structures = []
         self.frequencies = []
-        self.normal_modes = None
-        self.freq_type = None
-        self.run_type = None
+        self.normal_modes = self.freq_type = self.run_type = None
         self.is_internal_crash = False
 
         self._parse_logfile(logfile)
@@ -759,7 +747,7 @@ class AdfOutput:
         sites : list
             A list of sites.
 
-        Returns
+        Returns:
         -------
         mol : Molecule
             A ``Molecule`` object.
@@ -835,7 +823,7 @@ class AdfOutput:
                     if m:
                         cycle = int(m.group(1))
                         if cycle <= 0:
-                            raise AdfOutputError(f"Wrong cycle {cycle}")
+                            raise AdfOutputError(f"Wrong {cycle=}")
                         if cycle > last_cycle:
                             parse_cycle = True
                             last_cycle = cycle
