@@ -1,10 +1,9 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 Classes for reading/writing mcsqs files following the rndstr.in format.
 """
 
+from __future__ import annotations
+
 import numpy as np
 
 from pymatgen.core.lattice import Lattice
@@ -25,7 +24,7 @@ class Mcsqs:
     used by mcsqs and other ATAT codes.
     """
 
-    def __init__(self, structure):
+    def __init__(self, structure: Structure):
         """
         :param structure: input Structure
         """
@@ -37,8 +36,8 @@ class Mcsqs:
         :return (str):
         """
         # add lattice vectors
-        m = self.structure.lattice.matrix
-        output = [f"{l[0]:6f} {l[1]:6f} {l[2]:6f}" for l in m]
+        mat = self.structure.lattice.matrix
+        output = [f"{vec[0]:6f} {vec[1]:6f} {vec[2]:6f}" for vec in mat]
 
         # define coord system, use Cartesian
         output.append("1.0 0.0 0.0")
@@ -109,20 +108,18 @@ class Mcsqs:
 
         all_coords = []
         all_species = []
-        for l in data[first_species_line:]:
-
-            coords = np.array([l[0], l[1], l[2]], dtype=float)
+        for line in data[first_species_line:]:
+            coords = np.array([line[0], line[1], line[2]], dtype=float)
             scaled_coords = np.matmul(coords, np.linalg.inv(lattice_vecs))
             all_coords.append(scaled_coords)
 
-            species_strs = "".join(l[3:])  # join multiple strings back together
+            species_strs = "".join(line[3:])  # join multiple strings back together
             species_strs = species_strs.replace(" ", "")  # trim any white space
             species_strs = species_strs.split(",")  # comma-delimited
 
             species = {}
 
             for species_occ in species_strs:
-
                 # gets a species, occupancy pair
                 species_occ = species_occ.split("=")
 
