@@ -1,10 +1,9 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 Wrapper classes for Cif input and output from Structures.
 """
 
+from __future__ import annotations
+
 import math
 import os
 import re
@@ -42,17 +41,6 @@ space_groups = {sub_spgrp(k): k for k in SYMM_DATA["space_group_encoding"]}  # t
 
 space_groups.update({sub_spgrp(k): k for k in SYMM_DATA["space_group_encoding"]})  # type: ignore
 
-_COD_DATA = None
-
-
-def _get_cod_data():
-    global _COD_DATA
-
-    if _COD_DATA is None:
-        _COD_DATA = loadfn(os.path.join(os.path.dirname(os.path.dirname(__file__)), "symmetry", "symm_ops.json"))
-
-    return _COD_DATA
-
 
 class CifBlock:
     """
@@ -90,44 +78,44 @@ class CifBlock:
         """
         Returns the cif string for the data block
         """
-        s = [f"data_{self.header}"]
+        out = [f"data_{self.header}"]
         keys = list(self.data)
         written = []
-        for k in keys:
-            if k in written:
+        for key in keys:
+            if key in written:
                 continue
-            for l in self.loops:
+            for loop in self.loops:
                 # search for a corresponding loop
-                if k in l:
-                    s.append(self._loop_to_string(l))
-                    written.extend(l)
+                if key in loop:
+                    out.append(self._loop_to_string(loop))
+                    written.extend(loop)
                     break
-            if k not in written:
+            if key not in written:
                 # k didn't belong to a loop
-                v = self._format_field(self.data[k])
-                if len(k) + len(v) + 3 < self.maxlen:
-                    s.append(f"{k}   {v}")
+                v = self._format_field(self.data[key])
+                if len(key) + len(v) + 3 < self.maxlen:
+                    out.append(f"{key}   {v}")
                 else:
-                    s.extend([k, v])
-        return "\n".join(s)
+                    out.extend([key, v])
+        return "\n".join(out)
 
     def _loop_to_string(self, loop):
-        s = "loop_"
-        for l in loop:
-            s += "\n " + l
+        out = "loop_"
+        for line in loop:
+            out += "\n " + line
         for fields in zip(*(self.data[k] for k in loop)):
             line = "\n"
             for val in map(self._format_field, fields):
                 if val[0] == ";":
-                    s += line + "\n" + val
+                    out += line + "\n" + val
                     line = "\n"
                 elif len(line) + len(val) + 2 < self.maxlen:
                     line += "  " + val
                 else:
-                    s += line
+                    out += line
                     line = "\n  " + val
-            s += line
-        return s
+            out += line
+        return out
 
     def _format_field(self, v):
         v = str(v).strip()
@@ -137,10 +125,7 @@ class CifBlock:
         if v == "":
             return '""'
         if (" " in v or v[0] == "_") and not (v[0] == "'" and v[-1] == "'") and not (v[0] == '"' and v[-1] == '"'):
-            if "'" in v:
-                q = '"'
-            else:
-                q = "'"
+            q = '"' if "'" in v else "'"
             v = q + v + q
         return v
 
@@ -163,21 +148,21 @@ class CifBlock:
         # (these get eaten by the first expression)
         # ending quotes must not be followed by non-whitespace
         p = re.compile(r"""([^'"\s][\S]*)|'(.*?)'(?!\S)|"(.*?)"(?!\S)""")
-        for l in string.splitlines():
+        for line in string.splitlines():
             if multiline:
-                if l.startswith(";"):
+                if line.startswith(";"):
                     multiline = False
                     q.append(("", "", "", " ".join(ml)))
                     ml = []
-                    l = l[1:].strip()
+                    line = line[1:].strip()
                 else:
-                    ml.append(l)
+                    ml.append(line)
                     continue
-            if l.startswith(";"):
+            if line.startswith(";"):
                 multiline = True
-                ml.append(l[1:].strip())
+                ml.append(line[1:].strip())
             else:
-                for s in p.findall(l):
+                for s in p.findall(line):
                     # s is tuple. location of the data in the tuple
                     # depends on whether it was quoted in the input
                     q.append(s)
@@ -216,7 +201,7 @@ class CifBlock:
                     data[columns[-1]] = []
                 while q:
                     s = q[0]
-                    if s[0].startswith("loop_") or s[0].startswith("_"):
+                    if s[0].startswith(("loop_", "_")):
                         break
                     items.append("".join(q.popleft()))
                 n = len(items) // len(columns)
@@ -224,8 +209,8 @@ class CifBlock:
                 loops.append(columns)
                 for k, v in zip(columns * n, items):
                     data[k].append(v.strip())
-            elif "".join(s).strip() != "":
-                warnings.warn(f"Possible issue in cif file at line: {''.join(s).strip()}")
+            elif issue := "".join(s).strip():
+                warnings.warn(f"Possible issue in cif file at line: {issue}")
         return cls(data, loops, header)
 
 
@@ -257,9 +242,8 @@ class CifFile:
         :param string: String representation.
         :return: CifFile
         """
-        d = {}
+        dct = {}
         for x in re.split(r"^\s*data_", "x\n" + string, flags=re.MULTILINE | re.DOTALL)[1:]:
-
             # Skip over Cif block that contains powder diffraction data.
             # Some elements in this block were missing from CIF files in
             # Springer materials/Pauling file DBs.
@@ -268,8 +252,8 @@ class CifFile:
             if "powder_pattern" in re.split(r"\n", x, 1)[0]:
                 continue
             c = CifBlock.from_string("data_" + x)
-            d[c.header] = c
-        return cls(d, string)
+            dct[c.header] = c
+        return cls(dct, string)
 
     @classmethod
     def from_file(cls, filename):
@@ -290,18 +274,21 @@ class CifParser:
     CifParser's errors attribute.
     """
 
-    def __init__(self, filename, occupancy_tolerance=1.0, site_tolerance=1e-4):
+    def __init__(self, filename, occupancy_tolerance=1.0, site_tolerance=1e-4, frac_tolerance=1e-4):
         """
         Args:
             filename (str): CIF filename, bzipped or gzipped CIF files are fine too.
-            occupancy_tolerance (float): If total occupancy of a site is between 1
-                and occupancy_tolerance, the occupancies will be scaled down to 1.
-            site_tolerance (float): This tolerance is used to determine if two
-                sites are sitting in the same position, in which case they will be
-                combined to a single disordered site. Defaults to 1e-4.
+            occupancy_tolerance (float): If total occupancy of a site is between 1 and occupancy_tolerance, the
+                occupancies will be scaled down to 1.
+            site_tolerance (float): This tolerance is used to determine if two sites are sitting in the same position,
+                in which case they will be combined to a single disordered site. Defaults to 1e-4.
+            frac_tolerance (float): This tolerance is used to determine is a coordinate should be rounded to an ideal
+                value. E.g., 0.6667 is rounded to 2/3. This is desired if symmetry operations are going to be applied.
+                However, for very large CIF files, this may need to be set to 0.
         """
         self._occupancy_tolerance = occupancy_tolerance
         self._site_tolerance = site_tolerance
+        self._frac_tolerance = frac_tolerance
         if isinstance(filename, (str, Path)):
             self._cif = CifFile.from_file(filename)
         else:
@@ -312,7 +299,7 @@ class CifParser:
         self.feature_flags = {}
         self.warnings = []
 
-        def is_magcif():
+        def is_magcif() -> bool:
             """
             Checks to see if file appears to be a magCIF file (heuristic).
             """
@@ -332,7 +319,7 @@ class CifParser:
 
         self.feature_flags["magcif"] = is_magcif()
 
-        def is_magcif_incommensurate():
+        def is_magcif_incommensurate() -> bool:
             """
             Checks to see if file contains an incommensurate magnetic
             structure (heuristic).
@@ -357,21 +344,19 @@ class CifParser:
             self._cif.data[k] = self._sanitize_data(self._cif.data[k])
 
     @staticmethod
-    def from_string(cif_string, occupancy_tolerance=1.0):
+    def from_string(cif_string, **kwargs):
         """
         Creates a CifParser from a string.
 
         Args:
             cif_string (str): String representation of a CIF.
-            occupancy_tolerance (float): If total occupancy of a site is
-                between 1 and occupancy_tolerance, the occupancies will be
-                scaled down to 1.
+            **kwargs: Passthrough of all kwargs supported by CifParser.
 
         Returns:
             CifParser
         """
         stream = StringIO(cif_string)
-        return CifParser(stream, occupancy_tolerance)
+        return CifParser(stream, **kwargs)
 
     def _sanitize_data(self, data):
         """
@@ -402,7 +387,6 @@ class CifParser:
         # Check to see if "_atom_site_type_symbol" exists, as some test CIFs do
         # not contain this key.
         if "_atom_site_type_symbol" in data.data:
-
             # Keep a track of which data row needs to be removed.
             # Example of a row: Nb,Zr '0.8Nb + 0.2Zr' .2a .m-3m 0 0 0 1 14
             # 'rhombic dodecahedron, Nb<sub>14</sub>'
@@ -422,7 +406,6 @@ class CifParser:
             new_fract_z = []
 
             for idx, el_row in enumerate(data["_atom_site_label"]):
-
                 # CIF files from the Springer Materials/Pauling File have
                 # switched the label and symbol. Thus, in the
                 # above shown example row, '0.8Nb + 0.2Zr' is the symbol.
@@ -430,7 +413,6 @@ class CifParser:
                 # check if the length (or number of elements) in the label and
                 # symbol are equal.
                 if len(data["_atom_site_type_symbol"][idx].split(" + ")) > len(el_row.split(" + ")):
-
                     # Dictionary to hold extracted elements and occupancies
                     els_occu = {}
 
@@ -490,7 +472,6 @@ class CifParser:
         specification being finalized (on advice of Branton Campbell).
         """
         if self.feature_flags["magcif"]:
-
             # CIF-1 style has all underscores, interim standard
             # had period before magn instead of before the final
             # component (e.g. xyz)
@@ -540,7 +521,7 @@ class CifParser:
 
         # check for finite precision frac coordinates (e.g. 0.6667 instead of 0.6666666...7)
         # this can sometimes cause serious issues when applying symmetry operations
-        important_fracs = (1 / 3.0, 2 / 3.0)
+        important_fracs = (1 / 3, 2 / 3)
         fracs_to_change = {}
         for label in ("_atom_site_fract_x", "_atom_site_fract_y", "_atom_site_fract_z"):
             if label in data.data:
@@ -551,7 +532,7 @@ class CifParser:
                         # coordinate might not be defined e.g. '?'
                         continue
                     for comparison_frac in important_fracs:
-                        if abs(1 - frac / comparison_frac) < 1e-4:
+                        if abs(1 - frac / comparison_frac) < self._frac_tolerance:
                             fracs_to_change[(label, idx)] = str(comparison_frac)
         if fracs_to_change:
             self.warnings.append(
@@ -611,24 +592,19 @@ class CifParser:
         and necessary parameters are parsed
         """
         try:
-
             return self.get_lattice_no_exception(
                 data=data, angle_strings=angle_strings, lattice_type=lattice_type, length_strings=length_strings
             )
 
         except KeyError:
             # Missing Key search for cell setting
-            for lattice_lable in [
-                "_symmetry_cell_setting",
-                "_space_group_crystal_system",
-            ]:
+            for lattice_lable in ["_symmetry_cell_setting", "_space_group_crystal_system"]:
                 if data.data.get(lattice_lable):
                     lattice_type = data.data.get(lattice_lable).lower()
                     try:
-
                         required_args = getargspec(getattr(Lattice, lattice_type)).args
 
-                        lengths = (l for l in length_strings if l in required_args)
+                        lengths = (len for len in length_strings if len in required_args)
                         angles = (a for a in angle_strings if a in required_args)
                         return self.get_lattice(data, lengths, angles, lattice_type=lattice_type)
                     except AttributeError as exc:
@@ -644,15 +620,16 @@ class CifParser:
         data, length_strings=("a", "b", "c"), angle_strings=("alpha", "beta", "gamma"), lattice_type=None
     ):
         """
-        Generate the lattice from the provided lattice parameters.
+        Take a dictionary of CIF data and returns a pymatgen Lattice object
+
         Args:
-            data:
-            length_strings:
-            angle_strings:
-            lattice_type:
+            data: a dictionary of the CIF file
+            length_strings: The strings that are used to identify the length parameters in the CIF file.
+            angle_strings: The strings that are used to identify the angles in the CIF file.
+            lattice_type: The type of lattice.  This is a string, and can be any of the following:
 
         Returns:
-
+            Lattice object
         """
         lengths = [str2float(data["_cell_length_" + i]) for i in length_strings]
         angles = [str2float(data["_cell_angle_" + i]) for i in angle_strings]
@@ -719,7 +696,10 @@ class CifParser:
                         pass
 
                     try:
-                        for d in _get_cod_data():
+                        cod_data = loadfn(
+                            os.path.join(os.path.dirname(os.path.dirname(__file__)), "symmetry", "symm_ops.json")
+                        )
+                        for d in cod_data:
                             if sg == re.sub(r"\s+", "", d["hermann_mauguin"]):
                                 xyz = d["symops"]
                                 symops = [SymmOp.from_xyz_string(s) for s in xyz]
@@ -762,25 +742,24 @@ class CifParser:
         Separate function since additional operation for time reversal symmetry
         (which changes magnetic moments on sites) needs to be returned.
         """
-        magsymmops = []
+        mag_symm_ops = []
+        bns_name = data.data.get("_space_group_magn.name_BNS")  # get BNS label for MagneticSpaceGroup()
+        bns_num = data.data.get("_space_group_magn.number_BNS")  # get BNS number for MagneticSpaceGroup()
 
         # check to see if magCIF file explicitly contains magnetic symmetry operations
-        if data.data.get("_space_group_symop_magn_operation.xyz"):
-
-            xyzt = data.data.get("_space_group_symop_magn_operation.xyz")
+        if xyzt := data.data.get("_space_group_symop_magn_operation.xyz"):
             if isinstance(xyzt, str):
                 xyzt = [xyzt]
-            magsymmops = [MagSymmOp.from_xyzt_string(s) for s in xyzt]
+            mag_symm_ops = [MagSymmOp.from_xyzt_string(s) for s in xyzt]
 
             if data.data.get("_space_group_symop_magn_centering.xyz"):
-
                 xyzt = data.data.get("_space_group_symop_magn_centering.xyz")
                 if isinstance(xyzt, str):
                     xyzt = [xyzt]
                 centering_symops = [MagSymmOp.from_xyzt_string(s) for s in xyzt]
 
                 all_ops = []
-                for op in magsymmops:
+                for op in mag_symm_ops:
                     for centering_op in centering_symops:
                         new_translation = [
                             i - np.floor(i) for i in op.translation_vector + centering_op.translation_vector
@@ -793,39 +772,30 @@ class CifParser:
                                 time_reversal=new_time_reversal,
                             )
                         )
-                magsymmops = all_ops
+                mag_symm_ops = all_ops
 
         # else check to see if it specifies a magnetic space group
-        elif data.data.get("_space_group_magn.name_BNS") or data.data.get("_space_group_magn.number_BNS"):
+        elif bns_name or bns_num:
+            label = bns_name if bns_name else list(map(int, (bns_num.split("."))))
 
-            if data.data.get("_space_group_magn.name_BNS"):
-                # get BNS label for MagneticSpaceGroup()
-                id = data.data.get("_space_group_magn.name_BNS")
-            else:
-                # get BNS number for MagneticSpaceGroup()
-                # by converting string to list of ints
-                id = list(map(int, (data.data.get("_space_group_magn.number_BNS").split("."))))
-
-            if data.data.get("_space_group_magn.transform_BNS_Pp_abc"):
-                if data.data.get("_space_group_magn.transform_BNS_Pp_abc") != "a,b,c;0,0,0":
-
-                    jf = data.data.get("_space_group_magn.transform_BNS_Pp_abc")
-                    msg = MagneticSpaceGroup(id, jf)
+            if data.data.get("_space_group_magn.transform_BNS_Pp_abc") != "a,b,c;0,0,0":
+                jf = data.data.get("_space_group_magn.transform_BNS_Pp_abc")
+                msg = MagneticSpaceGroup(label, jf)
 
             elif data.data.get("_space_group_magn.transform_BNS_Pp"):
                 return NotImplementedError("Incomplete specification to implement.")
             else:
-                msg = MagneticSpaceGroup(id)
+                msg = MagneticSpaceGroup(label)
 
-            magsymmops = msg.symmetry_ops
+            mag_symm_ops = msg.symmetry_ops
 
-        if not magsymmops:
+        if not mag_symm_ops:
             msg = "No magnetic symmetry detected, using primitive symmetry."
             warnings.warn(msg)
             self.warnings.append(msg)
-            magsymmops = [MagSymmOp.from_xyzt_string("x, y, z, 1")]
+            mag_symm_ops = [MagSymmOp.from_xyzt_string("x, y, z, 1")]
 
-        return magsymmops
+        return mag_symm_ops
 
     @staticmethod
     def parse_oxi_states(data):
@@ -953,7 +923,6 @@ class CifParser:
             return False
 
         for i in range(len(data["_atom_site_label"])):
-
             try:
                 # If site type symbol exists, use it. Otherwise, we use the
                 # label.
@@ -1009,7 +978,7 @@ class CifParser:
                     coord_to_magmoms[match] = None
 
         sum_occu = [
-            sum(c.values()) for c in coord_to_species.values() if not set(c.elements) == {Element("O"), Element("H")}
+            sum(c.values()) for c in coord_to_species.values() if set(c.elements) != {Element("O"), Element("H")}
         ]
         if any(o > 1 for o in sum_occu):
             msg = (
@@ -1040,7 +1009,7 @@ class CifParser:
         if coord_to_species.items():
             for idx, (comp, group) in enumerate(
                 groupby(
-                    sorted(list(coord_to_species.items()), key=lambda x: x[1]),
+                    sorted(coord_to_species.items(), key=lambda x: x[1]),
                     key=lambda x: x[1],
                 )
             ):
@@ -1097,7 +1066,6 @@ class CifParser:
             struct = Structure(lattice, allspecies, allcoords, site_properties=site_properties)
 
             if symmetrized:
-
                 # Wyckoff labels not currently parsed, note that not all CIFs will contain Wyckoff labels
                 # TODO: extract Wyckoff labels (or other CIF attributes) and include as site_properties
                 wyckoffs = ["Not Parsed"] * len(struct)
@@ -1118,6 +1086,7 @@ class CifParser:
                 struct = struct.get_reduced_structure()
 
             return struct
+        return None
 
     def get_structures(self, primitive=True, symmetrized=False):
         """
@@ -1159,7 +1128,7 @@ class CifParser:
                 self.warnings.append(str(exc))
                 warnings.warn(f"No structure parsed for {i + 1} structure in CIF. Section of CIF file below.")
                 warnings.warn(str(d))
-                warnings.warn(f"Error is {str(exc)}.")
+                warnings.warn(f"Error is {exc}.")
 
         if self.warnings:
             warnings.warn("Issues encountered while parsing CIF: " + "\n".join(self.warnings))
@@ -1201,7 +1170,6 @@ class CifParser:
         # TODO: CIF specification supports multiple citations.
 
         for idx, data in enumerate(self._cif.data.values()):
-
             # convert to lower-case keys, some cif files inconsistent
             data = {k.lower(): v for k, v in data.data.items()}
 
@@ -1218,9 +1186,8 @@ class CifParser:
             # convert to bibtex author format ('and' delimited)
             if "author" in bibtex_entry:
                 # separate out semicolon authors
-                if isinstance(bibtex_entry["author"], str):
-                    if ";" in bibtex_entry["author"]:
-                        bibtex_entry["author"] = bibtex_entry["author"].split(";")
+                if isinstance(bibtex_entry["author"], str) and ";" in bibtex_entry["author"]:
+                    bibtex_entry["author"] = bibtex_entry["author"].split(";")
 
                 if isinstance(bibtex_entry["author"], list):
                     bibtex_entry["author"] = " and ".join(bibtex_entry["author"])
@@ -1240,12 +1207,12 @@ class CifParser:
         """
         :return: MSONable dict
         """
-        d = {}
+        dct = {}
         for k, v in self._cif.data.items():
-            d[k] = {}
+            dct[k] = {}
             for k2, v2 in v.data.items():
-                d[k][k2] = v2
-        return d
+                dct[k][k2] = v2
+        return dct
 
     @property
     def has_errors(self):
@@ -1436,9 +1403,9 @@ class CifWriter:
                     "_atom_site_moment_crystalaxis_z",
                 ]
             )
-        d = {}
-        d[comp.reduced_formula] = CifBlock(block, loops, comp.reduced_formula)
-        self._cf = CifFile(d)
+        dct = {}
+        dct[comp.reduced_formula] = CifBlock(block, loops, comp.reduced_formula)
+        self._cf = CifFile(dct)
 
     @property
     def ciffile(self):
@@ -1465,7 +1432,6 @@ def str2float(text):
     """
     Remove uncertainty brackets from strings and return the float.
     """
-
     try:
         # Note that the ending ) is sometimes missing. That is why the code has
         # been modified to treat it as optional. Same logic applies to lists.
