@@ -1,10 +1,9 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module provides input and output from the CSSR file format.
 """
 
+from __future__ import annotations
+
 import re
 
 from monty.io import zopen
@@ -26,7 +25,7 @@ class Cssr:
     a Structure to a Cssr file is supported.
     """
 
-    def __init__(self, structure):
+    def __init__(self, structure: Structure):
         """
         Args:
             structure (Structure/IStructure): A structure to create the Cssr object.
@@ -44,8 +43,8 @@ class Cssr:
             f"{len(self.structure)} 0",
             f"0 {self.structure.formula}",
         ]
-        for i, site in enumerate(self.structure.sites):
-            output.append(f"{i + 1} {site.specie} {site.a:.4f} {site.b:.4f} {site.c:.4f}")
+        for idx, site in enumerate(self.structure):
+            output.append(f"{idx + 1} {site.specie} {site.a:.4f} {site.b:.4f} {site.c:.4f}")
         return "\n".join(output)
 
     def write_file(self, filename):
@@ -71,14 +70,14 @@ class Cssr:
         """
         lines = string.split("\n")
         toks = lines[0].split()
-        lengths = [float(i) for i in toks]
+        lengths = [float(tok) for tok in toks]
         toks = lines[1].split()
-        angles = [float(i) for i in toks[0:3]]
+        angles = [float(tok) for tok in toks[0:3]]
         latt = Lattice.from_parameters(*lengths, *angles)
         sp = []
         coords = []
-        for l in lines[4:]:
-            m = re.match(r"\d+\s+(\w+)\s+([0-9\-\.]+)\s+([0-9\-\.]+)\s+([0-9\-\.]+)", l.strip())
+        for line in lines[4:]:
+            m = re.match(r"\d+\s+(\w+)\s+([0-9\-\.]+)\s+([0-9\-\.]+)\s+([0-9\-\.]+)", line.strip())
             if m:
                 sp.append(m.group(1))
                 coords.append([float(m.group(i)) for i in range(2, 5)])
