@@ -1,10 +1,9 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 Classes for reading/manipulating/writing exciting input files.
 """
 
+from __future__ import annotations
+
 import xml.etree.ElementTree as ET
 
 import numpy as np
@@ -108,8 +107,8 @@ class ExcitingInput(MSONable):
                 # Obtain lockxyz for each atom
                 if atom.get("lockxyz") is not None:
                     lxyz = []
-                    for l in atom.get("lockxyz").split():
-                        if l in ("True", "true"):
+                    for line in atom.get("lockxyz").split():
+                        if line in ("True", "true"):
                             lxyz.append(True)
                         else:
                             lxyz.append(False)
@@ -128,16 +127,10 @@ class ExcitingInput(MSONable):
             cartesian = False
         # get the scale attribute
         scale_in = root.find("structure").find("crystal").get("scale")
-        if scale_in:
-            scale = float(scale_in) * ExcitingInput.bohr2ang
-        else:
-            scale = ExcitingInput.bohr2ang
+        scale = float(scale_in) * ExcitingInput.bohr2ang if scale_in else ExcitingInput.bohr2ang
         # get the stretch attribute
         stretch_in = root.find("structure").find("crystal").get("stretch")
-        if stretch_in:
-            stretch = np.array([float(a) for a in stretch_in])
-        else:
-            stretch = np.array([1.0, 1.0, 1.0])
+        stretch = np.array([float(a) for a in stretch_in]) if stretch_in else np.array([1.0, 1.0, 1.0])
         # get basis vectors and scale them accordingly
         basisnode = root.find("structure").find("crystal").iter("basevect")
         for vect in basisnode:
@@ -363,9 +356,8 @@ class ExcitingInput(MSONable):
                 ExcitingInput._indent(el, level + 1)
             if not elem.tail or not elem.tail.strip():
                 elem.tail = i
-        else:
-            if level and (not elem.tail or not elem.tail.strip()):
-                elem.tail = i
+        elif level and (not elem.tail or not elem.tail.strip()):
+            elem.tail = i
 
     def _dicttoxml(self, paramdict_, element):
         for key, value in paramdict_.items():
