@@ -1,6 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module defines the FeffInputSet abstract base class and a concrete
 implementation for the Materials Project. The basic concept behind an input
@@ -250,10 +247,10 @@ class FEFFDictSet(AbstractFeffInputSet):
                 self.config_dict["TARGET"] = self.atoms.center_index + 1
                 self.config_dict["COREHOLE"] = "RPA"
                 logger.warning("Setting COREHOLE = RPA for K-space calculation")
-                if not self.config_dict.get("KMESH", None):
+                if not self.config_dict.get("KMESH"):
                     abc = self.structure.lattice.abc
                     mult = (self.nkpts * abc[0] * abc[1] * abc[2]) ** (1 / 3)
-                    self.config_dict["KMESH"] = [int(round(mult / l)) for l in abc]
+                    self.config_dict["KMESH"] = [int(round(mult / length)) for length in abc]
             else:
                 logger.warning(
                     "Large system(>=14 atoms) or EXAFS calculation, \
@@ -333,7 +330,6 @@ class FEFFDictSet(AbstractFeffInputSet):
             )
 
             for site_index, site in enumerate(sub_d["header"].struct):
-
                 if site.specie == input_atoms[0].specie:
                     site_atoms = Atoms(sub_d["header"].struct, absorbing_atom=site_index, radius=radius)
                     site_distance = np.array(site_atoms.get_lines())[:, 5].astype(np.float64)
