@@ -102,7 +102,9 @@ class FiestaRun(MSONable):
         otherwise it breaks
     """
 
-    def __init__(self, folder: str = None, grid: tuple[int, int, int] = (2, 2, 2), log_file: str = "log") -> None:
+    def __init__(
+        self, folder: str | None = None, grid: tuple[int, int, int] = (2, 2, 2), log_file: str = "log"
+    ) -> None:
         """
         Args:
             folder: Folder to look for runs.
@@ -220,7 +222,6 @@ class BasisSetReader:
 
     @staticmethod
     def _parse_file(input):
-
         lmax_nnlo_patt = re.compile(r"\s* (\d+) \s+ (\d+) \s+ \# .* ", re.VERBOSE)
 
         nl_orbital_patt = re.compile(r"\s* (\d+) \s+ (\d+) \s+ (\d+) \s+ \# .* ", re.VERBOSE)
@@ -232,26 +233,27 @@ class BasisSetReader:
         parse_preamble = False
         parse_lmax_nnlo = False
         parse_nl_orbital = False
+        nnlo = None  # fix pylint E0601: Using variable 'nnlo' before assignment
+        lmax = None
 
         for line in input.split("\n"):
-
             if parse_nl_orbital:
-                m = nl_orbital_patt.search(line)
-                n = coef_alpha_patt.search(line)
-                if m:
-                    l = m.group(1)
-                    zeta = m.group(2)
-                    ng = m.group(3)
-                    basis_set[l + "_" + zeta + "_" + ng] = []
-                elif n:
-                    alpha = n.group(1)
-                    coef = n.group(2)
-                    basis_set[l + "_" + zeta + "_" + ng].append((alpha, coef))
+                match_orb = nl_orbital_patt.search(line)
+                match_alpha = coef_alpha_patt.search(line)
+                if match_orb:
+                    l_angular = match_orb.group(1)
+                    zeta = match_orb.group(2)
+                    ng = match_orb.group(3)
+                    basis_set[l_angular + "_" + zeta + "_" + ng] = []
+                elif match_alpha:
+                    alpha = match_alpha.group(1)
+                    coef = match_alpha.group(2)
+                    basis_set[l_angular + "_" + zeta + "_" + ng].append((alpha, coef))
             elif parse_lmax_nnlo:
-                m = lmax_nnlo_patt.search(line)
-                if m:
-                    lmax = m.group(1)
-                    nnlo = m.group(2)
+                match_orb = lmax_nnlo_patt.search(line)
+                if match_orb:
+                    lmax = match_orb.group(1)
+                    nnlo = match_orb.group(2)
                     parse_lmax_nnlo = False
                     parse_nl_orbital = True
             elif parse_preamble:
@@ -278,8 +280,8 @@ class BasisSetReader:
         data_tmp.pop("preamble")
 
         for l_zeta_ng in data_tmp:
-            l = l_zeta_ng.split("_")[0]
-            nnlmo = nnlmo + (2 * int(l) + 1)
+            n_l = l_zeta_ng.split("_")[0]
+            nnlmo = nnlmo + (2 * int(n_l) + 1)
 
         return str(nnlmo)
 
@@ -308,11 +310,11 @@ class FiestaInput(MSONable):
     def __init__(
         self,
         mol,
-        correlation_grid: dict[str, str] = None,
-        Exc_DFT_option: dict[str, str] = None,
-        COHSEX_options: dict[str, str] = None,
-        GW_options: dict[str, str] = None,
-        BSE_TDDFT_options: dict[str, str] = None,
+        correlation_grid: dict[str, str] | None = None,
+        Exc_DFT_option: dict[str, str] | None = None,
+        COHSEX_options: dict[str, str] | None = None,
+        GW_options: dict[str, str] | None = None,
+        BSE_TDDFT_options: dict[str, str] | None = None,
     ):
         """
         :param mol: pymatgen mol
@@ -478,7 +480,6 @@ class FiestaInput(MSONable):
         return self._mol
 
     def __str__(self):
-
         symbols = []
         for syb in self._mol.symbol_set:
             symbols.append(syb)
@@ -590,6 +591,7 @@ $geometry
 
         Args:
             string_input: string_input to parse.
+
         Returns:
             FiestaInput object
         """
@@ -603,42 +605,42 @@ $geometry
 
         # number of atoms and species
         lines.pop(0)
-        l = lines.pop(0).strip()
-        toks = l.split()
+        line = lines.pop(0).strip()
+        toks = line.split()
         nat = toks[0]
         nsp = toks[1]
         # number of valence bands
         lines.pop(0)
-        l = lines.pop(0).strip()
-        toks = l.split()
+        line = lines.pop(0).strip()
+        toks = line.split()
 
         # correlation_grid
         # number of points and spacing in eV for correlation grid
         lines.pop(0)
-        l = lines.pop(0).strip()
-        toks = l.split()
+        line = lines.pop(0).strip()
+        toks = line.split()
         correlation_grid["n_grid"] = toks[0]
         correlation_grid["dE_grid"] = toks[1]
 
         # Exc DFT
         # relire=1 ou recalculer=0 Exc DFT
         lines.pop(0)
-        l = lines.pop(0).strip()
-        toks = l.split()
+        line = lines.pop(0).strip()
+        toks = line.split()
         Exc_DFT_option["rdVxcpsi"] = toks[0]
 
         # COHSEX
         # number of COHSEX corrected occp and unoccp bands: C=COHSEX  H=HF
         lines.pop(0)
-        l = lines.pop(0).strip()
-        toks = l.split()
+        line = lines.pop(0).strip()
+        toks = line.split()
         COHSEX_options["nv_cohsex"] = toks[0]
         COHSEX_options["nc_cohsex"] = toks[1]
         COHSEX_options["eigMethod"] = toks[2]
         # number of COHSEX iter, scf on wfns, mixing coeff; V=RI-V  I=RI-D
         lines.pop(0)
-        l = lines.pop(0).strip()
-        toks = l.split()
+        line = lines.pop(0).strip()
+        toks = line.split()
         COHSEX_options["nit_cohsex"] = toks[0]
         COHSEX_options["resMethod"] = toks[1]
         COHSEX_options["scf_cohsex_wf"] = toks[2]
@@ -647,33 +649,33 @@ $geometry
         # GW
         # number of GW corrected occp and unoccp bands
         lines.pop(0)
-        l = lines.pop(0).strip()
-        toks = l.split()
+        line = lines.pop(0).strip()
+        toks = line.split()
         GW_options["nv_corr"] = toks[0]
         GW_options["nc_corr"] = toks[1]
         # number of GW iterations
         lines.pop(0)
-        l = lines.pop(0).strip()
-        toks = l.split()
+        line = lines.pop(0).strip()
+        toks = line.split()
         GW_options["nit_gw"] = toks[0]
 
         # BSE
         # dumping for BSE and TDDFT
         lines.pop(0)
-        l = lines.pop(0).strip()
-        toks = l.split()
+        line = lines.pop(0).strip()
+        toks = line.split()
         BSE_TDDFT_options["do_bse"] = toks[0]
         BSE_TDDFT_options["do_tddft"] = toks[1]
         # number of occp. and virtual bands of BSE: nocore and up to 40 eVs
         lines.pop(0)
-        l = lines.pop(0).strip()
-        toks = l.split()
+        line = lines.pop(0).strip()
+        toks = line.split()
         BSE_TDDFT_options["nv_bse"] = toks[0]
         BSE_TDDFT_options["nc_bse"] = toks[1]
         # number of excitations needed and number of iterations
         lines.pop(0)
-        l = lines.pop(0).strip()
-        toks = l.split()
+        line = lines.pop(0).strip()
+        toks = line.split()
         BSE_TDDFT_options["npsi_bse"] = toks[0]
         BSE_TDDFT_options["nit_bse"] = toks[1]
 
@@ -683,15 +685,15 @@ $geometry
         atname = []
         i = int(nsp)
         while i != 0:
-            l = lines.pop(0).strip()
-            toks = l.split()
+            line = lines.pop(0).strip()
+            toks = line.split()
             atname.append(toks[0])
             i -= 1
 
         # scaling factor
         lines.pop(0)
-        l = lines.pop(0).strip()
-        toks = l.split()
+        line = lines.pop(0).strip()
+        toks = line.split()
         # atoms x,y,z cartesian .. will be multiplied by scale
         lines.pop(0)
         # Parse geometry
@@ -699,8 +701,8 @@ $geometry
         coords = []
         i = int(nat)
         while i != 0:
-            l = lines.pop(0).strip()
-            toks = l.split()
+            line = lines.pop(0).strip()
+            toks = line.split()
             coords.append([float(j) for j in toks[0:3]])
             species.append(atname[int(toks[3]) - 1])
             i -= 1
@@ -759,7 +761,6 @@ class FiestaOutput:
 
     @staticmethod
     def _parse_job(output):
-
         GW_BANDS_results_patt = re.compile(
             r"^<it.*  \| \s+ (\D+\d*) \s+ \| \s+ ([-\d.]+) \s+ ([-\d.]+) \s+ ([-\d.]+) \s+ \| "
             r" \s+ ([-\d.]+) \s+ ([-\d.]+) \s+ ([-\d.]+) \s+ \|"
@@ -781,27 +782,26 @@ class FiestaOutput:
         parse_gw_results = False
         parse_total_time = False
 
-        for l in output.split("\n"):
-
+        for line in output.split("\n"):
             if parse_total_time:
-                m = end_patt.search(l)
+                m = end_patt.search(line)
                 if m:
                     GW_results.update(end_normally=True)
 
-                m = total_time_patt.search(l)
+                m = total_time_patt.search(line)
                 if m:
                     GW_results.update(total_time=m.group(1))
 
             if parse_gw_results:
-                if l.find("Dumping eigen energies") != -1:
+                if line.find("Dumping eigen energies") != -1:
                     parse_total_time = True
                     parse_gw_results = False
                     continue
 
-                m = GW_BANDS_results_patt.search(l)
+                m = GW_BANDS_results_patt.search(line)
                 if m:
-                    d = {}
-                    d.update(
+                    dct = {}
+                    dct.update(
                         band=m.group(1).strip(),
                         eKS=m.group(2),
                         eXX=m.group(3),
@@ -812,19 +812,19 @@ class FiestaOutput:
                         sigma_c_SCF=m.group(8),
                         eQP_SCF=m.group(9),
                     )
-                    GW_results[m.group(1).strip()] = d
+                    GW_results[m.group(1).strip()] = dct
 
-                n = GW_GAPS_results_patt.search(l)
+                n = GW_GAPS_results_patt.search(line)
                 if n:
-                    d = {}
-                    d.update(
+                    dct = {}
+                    dct.update(
                         Egap_KS=n.group(1),
                         Egap_QP_Linear=n.group(2),
                         Egap_QP_SCF=n.group(3),
                     )
-                    GW_results["Gaps"] = d
+                    GW_results["Gaps"] = dct
 
-            if l.find("GW Results") != -1:
+            if line.find("GW Results") != -1:
                 parse_gw_results = True
 
         return GW_results
@@ -852,7 +852,6 @@ class BSEOutput:
 
     @staticmethod
     def _parse_job(output):
-
         BSE_exitons_patt = re.compile(
             r"^exiton \s+ (\d+)  : \s+  ([\d.]+) \( \s+ ([-\d.]+) \) \s+ \| .*  ",
             re.VERBOSE,
@@ -866,30 +865,29 @@ class BSEOutput:
         parse_BSE_results = False
         parse_total_time = False
 
-        for l in output.split("\n"):
-
+        for line in output.split("\n"):
             if parse_total_time:
-                m = end_patt.search(l)
+                m = end_patt.search(line)
                 if m:
                     BSE_results.update(end_normally=True)
 
-                m = total_time_patt.search(l)
+                m = total_time_patt.search(line)
                 if m:
                     BSE_results.update(total_time=m.group(1))
 
             if parse_BSE_results:
-                if l.find("FULL BSE main valence -> conduction transitions weight:") != -1:
+                if line.find("FULL BSE main valence -> conduction transitions weight:") != -1:
                     parse_total_time = True
                     parse_BSE_results = False
                     continue
 
-                m = BSE_exitons_patt.search(l)
+                m = BSE_exitons_patt.search(line)
                 if m:
-                    d = {}
-                    d.update(bse_eig=m.group(2), osc_strength=m.group(3))
-                    BSE_results[str(m.group(1).strip())] = d
+                    dct = {}
+                    dct.update(bse_eig=m.group(2), osc_strength=m.group(3))
+                    BSE_results[str(m.group(1).strip())] = dct
 
-            if l.find("FULL BSE eig.(eV), osc. strength and dipoles:") != -1:
+            if line.find("FULL BSE eig.(eV), osc. strength and dipoles:") != -1:
                 parse_BSE_results = True
 
         return BSE_results
