@@ -1,6 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module implements a core class LammpsData for generating/parsing
 LAMMPS data file, and other bridging classes to build LammpsData from
@@ -16,6 +13,8 @@ more info.
 
 """
 
+from __future__ import annotations
+
 import itertools
 import re
 import warnings
@@ -212,7 +211,6 @@ def lattice_2_lmpbox(lattice, origin=(0, 0, 0)):
 
     Returns:
         LammpsBox, SymmOp
-
     """
     a, b, c = lattice.abc
     xlo, ylo, zlo = origin
@@ -226,14 +224,13 @@ def lattice_2_lmpbox(lattice, origin=(0, 0, 0)):
     tilt = None if lattice.is_orthogonal else [xy, xz, yz]
     rot_matrix = np.linalg.solve([[xhi - xlo, 0, 0], [xy, yhi - ylo, 0], [xz, yz, zhi - zlo]], m)
     bounds = [[xlo, xhi], [ylo, yhi], [zlo, zhi]]
-    symmop = SymmOp.from_rotation_and_translation(rot_matrix, origin)
-    return LammpsBox(bounds, tilt), symmop
+    symm_op = SymmOp.from_rotation_and_translation(rot_matrix, origin)
+    return LammpsBox(bounds, tilt), symm_op
 
 
 class LammpsData(MSONable):
     """
     Object for representing the data in a LAMMPS data file.
-
     """
 
     def __init__(
@@ -306,7 +303,7 @@ class LammpsData(MSONable):
         masses = self.masses
         atoms = self.atoms.copy()
         if "nx" in atoms.columns:
-            atoms.drop(["nx", "ny", "nz"], axis=1, inplace=True)
+            atoms = atoms.drop(["nx", "ny", "nz"], axis=1)
         atoms["molecule-ID"] = 1
         ld_copy = self.__class__(self.box, masses, atoms)
         topologies = ld_copy.disassemble()[-1]
@@ -316,9 +313,9 @@ class LammpsData(MSONable):
         latt = self.box.to_lattice()
         site_properties = {}
         if "q" in atoms:
-            site_properties["charge"] = atoms["q"].values
+            site_properties["charge"] = atoms["q"].to_numpy()
         if self.velocities is not None:
-            site_properties["velocities"] = self.velocities.values
+            site_properties["velocities"] = self.velocities.to_numpy()
         return Structure(
             latt,
             species,
@@ -387,7 +384,7 @@ class LammpsData(MSONable):
         right_indent = len(str(max(all_stats)))
         count_lines = [f"{v:>{right_indent}}  {k}" for k, v in counts.items()]
         type_lines = [f"{v:>{right_indent}}  {k+ ' types'}" for k, v in types.items()]
-        stats = "\n".join(count_lines + [""] + type_lines)
+        stats = "\n".join([*count_lines, "", *type_lines])
 
         def map_coords(q):
             return f"{q:.{distance}f}"
@@ -426,26 +423,17 @@ class LammpsData(MSONable):
 
         section_template = "{kw}\n\n{df}\n"
         parts = []
-        for k, v in body_dict.items():
-            index = k != "PairIJ Coeffs"
-            if (
-                k
-                in [
-                    "Bond Coeffs",
-                    "Angle Coeffs",
-                    "Dihedral Coeffs",
-                    "Improper Coeffs",
-                ]
-                and hybrid
-            ):
-                listofdf = np.array_split(v, len(v.index))
+        for key, val in body_dict.items():
+            index = key != "PairIJ Coeffs"
+            if hybrid and key in ["Bond Coeffs", "Angle Coeffs", "Dihedral Coeffs", "Improper Coeffs"]:
+                dfs = np.array_split(val, len(val.index))
                 df_string = ""
-                for i, df in enumerate(listofdf):
+                for idx, df in enumerate(dfs):
                     if isinstance(df.iloc[0]["coeff1"], str):
                         try:
                             formatters = {
                                 **default_formatters,
-                                **coeffs[k][df.iloc[0]["coeff1"]],
+                                **coeffs[key][df.iloc[0]["coeff1"]],
                             }
                         except KeyError:
                             formatters = default_formatters
@@ -457,23 +445,19 @@ class LammpsData(MSONable):
                             na_rep="",
                         )
                     else:
-                        line_string = v.to_string(
+                        line_string = val.to_string(
                             header=False,
                             formatters=default_formatters,
                             index_names=False,
                             index=index,
                             na_rep="",
-                        ).splitlines()[i]
+                        ).splitlines()[idx]
                     df_string += line_string.replace("nan", "").rstrip() + "\n"
             else:
-                df_string = v.to_string(
-                    header=False,
-                    formatters=default_formatters,
-                    index_names=False,
-                    index=index,
-                    na_rep="",
+                df_string = val.to_string(
+                    header=False, formatters=default_formatters, index_names=False, index=index, na_rep=""
                 )
-            parts.append(section_template.format(kw=k, df=df_string))
+            parts.append(section_template.format(kw=key, df=df_string))
         body = "\n".join(parts)
 
         return file_template.format(stats=stats, box=box, body=body)
@@ -555,7 +539,7 @@ class LammpsData(MSONable):
         for um, s in zip(unique_masses, symbols):
             masses.loc[masses["mass"] == um, "element"] = s
         if atom_labels is None:  # add unique labels based on elements
-            for el, vc in masses["element"].value_counts().iteritems():
+            for el, vc in masses["element"].value_counts().items():
                 masses.loc[masses["element"] == el, "label"] = [f"{el}{c}" for c in range(1, vc + 1)]
         assert masses["label"].nunique(dropna=False) == len(masses), "Expecting unique atom label for each type"
         mass_info = [(row.label, row.mass) for row in masses.itertuples()]
@@ -621,14 +605,14 @@ class LammpsData(MSONable):
             species = masses.loc[type_ids, "element"]
             labels = masses.loc[type_ids, "label"]
             coords = atoms[["x", "y", "z"]]
-            m = Molecule(species.values, coords.values, site_properties={ff_label: labels.values})
+            m = Molecule(species.values, coords.values, site_properties={ff_label: labels.to_numpy()})
             charges = atoms.get("q")
             velocities = atoms[["vx", "vy", "vz"]] if "vx" in atoms.columns else None
             topologies = {}
             for kw in SECTION_KEYWORDS["topology"]:
                 if data.get(kw):
                     topologies[kw] = (np.array(data[kw]) - shift).tolist()
-            topologies = None if not topologies else topologies
+            topologies = topologies if topologies else None
             topo_list.append(
                 Topology(
                     sites=m,
@@ -655,7 +639,7 @@ class LammpsData(MSONable):
         with zopen(filename, "rt") as f:
             lines = f.readlines()
         kw_pattern = r"|".join(itertools.chain(*SECTION_KEYWORDS.values()))
-        section_marks = [i for i, l in enumerate(lines) if re.search(kw_pattern, l)]
+        section_marks = [idx for idx, line in enumerate(lines) if re.search(kw_pattern, line)]
         parts = np.split(lines, section_marks)
 
         float_group = r"([0-9eE.+-]+)"
@@ -667,10 +651,10 @@ class LammpsData(MSONable):
 
         header = {"counts": {}, "types": {}}
         bounds = {}
-        for l in clean_lines(parts[0][1:]):  # skip the 1st line
+        for line in clean_lines(parts[0][1:]):  # skip the 1st line
             match = None
             for k, v in header_pattern.items():  # noqa: B007
-                match = re.match(v, l)
+                match = re.match(v, line)
                 if match:
                     break
             if match and k in ["counts", "types"]:
@@ -709,15 +693,15 @@ class LammpsData(MSONable):
                     elif df.shape[1] == len(names) + 3:  # pylint: disable=E1101
                         names += ["nx", "ny", "nz"]
                     else:
-                        raise ValueError(f"Format in Atoms section inconsistent with atom_style {atom_style}")
+                        raise ValueError(f"Format in Atoms section inconsistent with {atom_style=}")
                 else:
                     raise NotImplementedError(f"Parser for {kw} section not implemented")
             df.columns = names
             if sort_id:
                 sort_by = "id" if kw != "PairIJ Coeffs" else ["id1", "id2"]
-                df.sort_values(sort_by, inplace=True)
+                df = df.sort_values(sort_by)
             if "id" in df.columns:
-                df.set_index("id", drop=True, inplace=True)
+                df = df.set_index("id", drop=True)
                 df.index.name = None
             return kw, df
 
@@ -731,7 +715,7 @@ class LammpsData(MSONable):
             if (
                 name in ["Velocities"] + SECTION_KEYWORDS["topology"] and not seen_atoms
             ):  # Atoms must appear earlier than these
-                raise RuntimeError(err_msg + f"{name} section appears before Atoms section")
+                raise RuntimeError(f"{err_msg}{name} section appears before Atoms section")
             body.update({name: section})
 
         err_msg += "Nos. of {} do not match between header and {} section"
@@ -772,7 +756,7 @@ class LammpsData(MSONable):
         atom_types = set.union(*(t.species for t in topologies))
         assert atom_types.issubset(ff.maps["Atoms"]), "Unknown atom type found in topologies"
 
-        items = dict(box=box, atom_style=atom_style, masses=ff.masses, force_field=ff.force_field)
+        items = {"box": box, "atom_style": atom_style, "masses": ff.masses, "force_field": ff.force_field}
 
         mol_ids, charges, coords, labels = [], [], [], []
         v_collector = [] if topologies[0].velocities else None
@@ -808,10 +792,10 @@ class LammpsData(MSONable):
         for k in topology:
             df = pd.DataFrame(np.concatenate(topo_collector[k]), columns=SECTION_HEADERS[k][1:])
             df["type"] = list(map(ff.maps[k].get, topo_labels[k]))
-            if any(pd.isnull(df["type"])):  # Throw away undefined topologies
+            if any(pd.isna(df["type"])):  # Throw away undefined topologies
                 warnings.warn(f"Undefined {k.lower()} detected and removed")
-                df.dropna(subset=["type"], inplace=True)
-                df.reset_index(drop=True, inplace=True)
+                df = df.dropna(subset=["type"])
+                df = df.reset_index(drop=True)
             df.index += 1
             topology[k] = df[SECTION_HEADERS[k]]
         topology = {k: v for k, v in topology.items() if not v.empty}
@@ -834,18 +818,15 @@ class LammpsData(MSONable):
                 "charge" (charged). Default to "charge".
             is_sort (bool): whether to sort sites
         """
-        if is_sort:
-            s = structure.get_sorted_structure()
-        else:
-            s = structure.copy()
-        box, symmop = lattice_2_lmpbox(s.lattice)
-        coords = symmop.operate_multi(s.cart_coords)
+        s = structure.get_sorted_structure() if is_sort else structure.copy()
+        box, symm_op = lattice_2_lmpbox(s.lattice)
+        coords = symm_op.operate_multi(s.cart_coords)
         site_properties = s.site_properties
         if "velocities" in site_properties:
             velos = np.array(s.site_properties["velocities"])
-            rot = SymmOp.from_rotation_and_translation(symmop.rotation_matrix)
+            rot = SymmOp.from_rotation_and_translation(symm_op.rotation_matrix)
             rot_velos = rot.operate_multi(velos)
-            site_properties.update({"velocities": rot_velos})
+            site_properties.update({"velocities": rot_velos})  # type: ignore
         boxed_s = Structure(
             box.to_lattice(),
             s.species,
@@ -863,6 +844,35 @@ class LammpsData(MSONable):
         topo = Topology(boxed_s)
         return cls.from_ff_and_topologies(box=box, ff=ff, topologies=[topo], atom_style=atom_style)
 
+    def set_charge_atom(self, charges: dict[int, float]):
+        """
+        Set the charges of specific atoms of the data.
+
+        Args:
+            charges: A dictionary with atom indexes as keys and
+                     charges as values, e.g., to set the charge
+                     of the atom with index 3 to -2, use `{3: -2}`.
+        """
+        for iat, q in charges.items():
+            self.atoms.loc[iat, "q"] = q
+
+    def set_charge_atom_type(self, charges: dict[str | int, float]):
+        """
+        Add or modify charges of all atoms of a given type in the data
+
+        Args:
+            charges: Dict containing the charges for the atom types to set.
+                     The dict should contain atom types as integers or labels and charges.
+                     Example: change the charge of Li atoms to +3:
+                         charges={"Li": 3}
+                         charges={1: 3} if Li atoms are of type 1
+        """
+        for iat, q in charges.items():
+            if isinstance(iat, str):
+                mass_iat = Element(iat).atomic_mass
+                iat = self.masses.loc[self.masses["mass"] == mass_iat].index[0]
+            self.atoms.loc[self.atoms["type"] == iat, "q"] = q
+
 
 class Topology(MSONable):
     """
@@ -901,10 +911,7 @@ class Topology(MSONable):
         if not isinstance(sites, (Molecule, Structure)):
             sites = Molecule.from_sites(sites)
 
-        if ff_label:
-            type_by_sites = sites.site_properties.get(ff_label)
-        else:
-            type_by_sites = [site.specie.symbol for site in sites]
+        type_by_sites = sites.site_properties.get(ff_label) if ff_label else [site.specie.symbol for site in sites]
         # search for site property if not override
         if charges is None:
             charges = sites.site_properties.get("charge")
@@ -978,10 +985,10 @@ class Topology(MSONable):
                 angle_list.extend([[i, k, j] for i, j in itertools.combinations(v, 2)])
         if dihedral:
             hub_cons = bond_arr[np.all(np.isin(bond_arr, hubs), axis=1)]
-            for i, j in hub_cons.tolist():
-                ks = [k for k in hub_spokes[i] if k != j]
-                ls = [l for l in hub_spokes[j] if l != i]
-                dihedral_list.extend([[k, i, j, l] for k, l in itertools.product(ks, ls) if k != l])
+            for ii, jj in hub_cons.tolist():
+                ks = [ki for ki in hub_spokes[ii] if ki != jj]
+                ls = [li for li in hub_spokes[jj] if li != ii]
+                dihedral_list.extend([[ki, ii, jj, li] for ki, li in itertools.product(ks, ls) if ki != li])
 
         topologies = {
             k: v for k, v in zip(SECTION_KEYWORDS["topology"][:3], [bond_list, angle_list, dihedral_list]) if len(v) > 0
@@ -998,12 +1005,11 @@ class ForceField(MSONable):
         force_field (dict): Force field section keywords (keys) and
             data (values) as DataFrames.
         maps (dict): Dict for labeling atoms and topologies.
-
     """
 
     @staticmethod
     def _is_valid(df):
-        return not pd.isnull(df).values.any()
+        return not pd.isna(df).to_numpy().any()
 
     def __init__(self, mass_info, nonbond_coeffs=None, topo_coeffs=None):
         """
@@ -1074,7 +1080,7 @@ class ForceField(MSONable):
 
         self.topo_coeffs = topo_coeffs
         if self.topo_coeffs:
-            self.topo_coeffs = {k: v for k, v in self.topo_coeffs.items() if k in SECTION_KEYWORDS["ff"][2:]}
+            self.topo_coeffs = {key: v for key, v in self.topo_coeffs.items() if key in SECTION_KEYWORDS["ff"][2:]}
             for k in self.topo_coeffs:
                 coeffs, mapper = self._process_topo(k)
                 ff_dfs.update(coeffs)
@@ -1085,20 +1091,20 @@ class ForceField(MSONable):
     def _process_nonbond(self):
         pair_df = pd.DataFrame(self.nonbond_coeffs)
         assert self._is_valid(pair_df), "Invalid nonbond coefficients with rows varying in length"
-        npair, ncoeff = pair_df.shape
-        pair_df.columns = [f"coeff{i}" for i in range(1, ncoeff + 1)]
+        n_pair, n_coeff = pair_df.shape
+        pair_df.columns = [f"coeff{i}" for i in range(1, n_coeff + 1)]
         nm = len(self.mass_info)
-        ncomb = int(nm * (nm + 1) / 2)
-        if npair == nm:
+        n_comb = int(nm * (nm + 1) / 2)
+        if n_pair == nm:
             kw = "Pair Coeffs"
             pair_df.index = range(1, nm + 1)
-        elif npair == ncomb:
+        elif n_pair == n_comb:
             kw = "PairIJ Coeffs"
             ids = list(itertools.combinations_with_replacement(range(1, nm + 1), 2))
             id_df = pd.DataFrame(ids, columns=["id1", "id2"])
             pair_df = pd.concat([id_df, pair_df], axis=1)
         else:
-            raise ValueError(f"Expecting {nm} Pair Coeffs or {ncomb} PairIJ Coeffs for {nm} atom types, got {npair}")
+            raise ValueError(f"Expecting {nm} Pair Coeffs or {n_comb} PairIJ Coeffs for {nm} atom types, got {n_pair}")
         return {kw: pair_df}
 
     def _process_topo(self, kw):
@@ -1107,7 +1113,7 @@ class ForceField(MSONable):
                 label_arr = np.array(label)
                 seqs = [[0, 1, 2, 3], [0, 2, 1, 3], [3, 1, 2, 0], [3, 2, 1, 0]]
                 return [tuple(label_arr[s]) for s in seqs]
-            return [label] + [label[::-1]]
+            return [label, label[::-1]]
 
         main_data, distinct_types = [], []
         class2_data = {k: [] for k in self.topo_coeffs[kw][0] if k in CLASS2_KEYWORDS.get(kw, [])}
