@@ -1,4 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
 # Distributed under the terms of the MIT License
 
 """
@@ -11,7 +10,7 @@ from __future__ import annotations
 import itertools
 import os
 import warnings
-from typing import Any, Sequence
+from typing import TYPE_CHECKING, Any, Sequence
 
 import numpy as np
 import spglib
@@ -19,12 +18,15 @@ from monty.io import zopen
 from monty.json import MSONable
 from monty.serialization import loadfn
 
-from pymatgen.core.composition import Composition
 from pymatgen.core.structure import Structure
 from pymatgen.io.vasp import Vasprun
 from pymatgen.io.vasp.inputs import Incar, Kpoints, Potcar
 from pymatgen.symmetry.bandstructure import HighSymmKpath
 
+if TYPE_CHECKING:
+    from pymatgen.core.composition import Composition
+
+
 __author__ = "Janine George, Marco Esters"
 __copyright__ = "Copyright 2017, The Materials Project"
 __version__ = "0.2"
@@ -46,15 +48,15 @@ class Lobsterin(dict, MSONable):
     # reminder: lobster is not case sensitive
 
     # keyword + one float can be used in file
-    FLOATKEYWORDS = [
+    FLOAT_KEYWORDS = (
         "COHPstartEnergy",
         "COHPendEnergy",
         "gaussianSmearingWidth",
         "useDecimalPlaces",
         "COHPSteps",
-    ]
+    )
     # one of these keywords +endstring can be used in file
-    STRINGKEYWORDS = [
+    STRING_KEYWORDS = (
         "basisSet",
         "cohpGenerator",
         "realspaceHamiltonian",
@@ -63,9 +65,9 @@ class Lobsterin(dict, MSONable):
         "printLCAORealSpaceWavefunction",
         "kSpaceCOHP",
         "EwaldSum",
-    ]
+    )
     # the keyword alone will turn on or off a function
-    BOOLEANKEYWORDS = [
+    BOOLEAN_KEYWORDS = (
         "saveProjectionToFile",
         "skipdos",
         "skipcohp",
@@ -96,12 +98,13 @@ class Lobsterin(dict, MSONable):
         "forceEnergyRange",
         "bandwiseSpilling",
         "kpointwiseSpilling",
-    ]
+        "LSODOS",
+    )
     # several of these keywords + ending can be used in a lobsterin file:
-    LISTKEYWORDS = ["basisfunctions", "cohpbetween", "createFatband"]
+    LISTKEYWORDS = ("basisfunctions", "cohpbetween", "createFatband")
 
     # all keywords known to this class so far
-    AVAILABLEKEYWORDS = FLOATKEYWORDS + STRINGKEYWORDS + BOOLEANKEYWORDS + LISTKEYWORDS
+    AVAILABLEKEYWORDS = FLOAT_KEYWORDS + STRING_KEYWORDS + BOOLEAN_KEYWORDS + LISTKEYWORDS
 
     def __init__(self, settingsdict: dict):
         """
@@ -175,7 +178,6 @@ class Lobsterin(dict, MSONable):
 
                 if isinstance(v1, str):
                     if v1.strip().lower() != other[new_key].strip().lower():
-
                         different_param[k1.upper()] = {
                             "lobsterin1": v1,
                             "lobsterin2": other[new_key],
@@ -190,22 +192,18 @@ class Lobsterin(dict, MSONable):
                             "lobsterin1": v1,
                             "lobsterin2": other[new_key],
                         }
+                elif v1 != other[new_key]:
+                    different_param[k1.upper()] = {
+                        "lobsterin1": v1,
+                        "lobsterin2": other[new_key],
+                    }
                 else:
-                    if v1 != other[new_key]:
-                        different_param[k1.upper()] = {
-                            "lobsterin1": v1,
-                            "lobsterin2": other[new_key],
-                        }
-                    else:
-                        similar_param[k1.upper()] = v1
+                    similar_param[k1.upper()] = v1
 
         for k2, v2 in other.items():
             if k2.upper() not in similar_param and k2.upper() not in different_param:
                 for key_here in self:
-                    if k2.lower() == key_here.lower():
-                        new_key = key_here
-                    else:
-                        new_key = k2
+                    new_key = key_here if k2.lower() == key_here.lower() else k2
                 if new_key not in self:
                     different_param[k2.upper()] = {"lobsterin1": None, "lobsterin2": v2}
         return {"Same": similar_param, "Different": different_param}
@@ -263,16 +261,16 @@ class Lobsterin(dict, MSONable):
         with open(filename, "w") as f:
             for key in Lobsterin.AVAILABLEKEYWORDS:
                 if key.lower() in [element.lower() for element in self]:
-                    if key.lower() in [element.lower() for element in Lobsterin.FLOATKEYWORDS]:
+                    if key.lower() in [element.lower() for element in Lobsterin.FLOAT_KEYWORDS]:
                         f.write(key + " " + str(self.get(key)) + "\n")
-                    elif key.lower() in [element.lower() for element in Lobsterin.BOOLEANKEYWORDS]:
+                    elif key.lower() in [element.lower() for element in Lobsterin.BOOLEAN_KEYWORDS]:
                         # checks if entry is True or False
                         for key_here in self:
                             if key.lower() == key_here.lower():
                                 new_key = key_here
                         if self.get(new_key):
                             f.write(key + "\n")
-                    elif key.lower() in [element.lower() for element in Lobsterin.STRINGKEYWORDS]:
+                    elif key.lower() in [element.lower() for element in Lobsterin.STRING_KEYWORDS]:
                         f.write(key + " " + str(self.get(key) + "\n"))
                     elif key.lower() in [element.lower() for element in Lobsterin.LISTKEYWORDS]:
                         for entry in self.get(key):
@@ -301,7 +299,7 @@ class Lobsterin(dict, MSONable):
         incar_output: str = "INCAR.lobster",
         poscar_input: str = "POSCAR",
         isym: int = -1,
-        further_settings: dict = None,
+        further_settings: dict | None = None,
     ):
         """
         Will only make the run static, insert nbands, make ISYM=-1, set LWAVE=True and write a new INCAR.
@@ -337,7 +335,7 @@ class Lobsterin(dict, MSONable):
     def get_basis(
         structure: Structure,
         potcar_symbols: list,
-        address_basis_file: str = None,
+        address_basis_file: str | None = None,
     ):
         """
         Will get the basis from given potcar_symbols (e.g., ["Fe_pv","Si"]
@@ -381,8 +379,8 @@ class Lobsterin(dict, MSONable):
     def get_all_possible_basis_functions(
         structure: Structure,
         potcar_symbols: list,
-        address_basis_file_min: str = None,
-        address_basis_file_max: str = None,
+        address_basis_file_min: str | None = None,
+        address_basis_file_max: str | None = None,
     ):
         """
         Args:
@@ -476,13 +474,13 @@ class Lobsterin(dict, MSONable):
         zs = []
         magmoms = []
 
-        for species, g in itertools.groupby(structure, key=lambda s: s.species):
+        for species, group in itertools.groupby(structure, key=lambda s: s.species):
             if species in unique_species:
                 ind = unique_species.index(species)
-                zs.extend([ind + 1] * len(tuple(g)))
+                zs.extend([ind + 1] * len(tuple(group)))
             else:
                 unique_species.append(species)
-                zs.extend([len(unique_species)] * len(tuple(g)))
+                zs.extend([len(unique_species)] * len(tuple(group)))
 
         for site in structure:
             if hasattr(site, "magmom"):
@@ -594,21 +592,19 @@ class Lobsterin(dict, MSONable):
             if len(raw_datum) > 1:
                 # check which type of keyword this is, handle accordingly
                 if raw_datum[0].lower() not in [datum2.lower() for datum2 in Lobsterin.LISTKEYWORDS]:
-                    if raw_datum[0].lower() not in [datum2.lower() for datum2 in Lobsterin.FLOATKEYWORDS]:
+                    if raw_datum[0].lower() not in [datum2.lower() for datum2 in Lobsterin.FLOAT_KEYWORDS]:
                         if raw_datum[0].lower() not in Lobsterindict:
                             Lobsterindict[raw_datum[0].lower()] = " ".join(raw_datum[1:])
                         else:
                             raise ValueError("Same keyword " + str(raw_datum[0].lower()) + "twice!")
+                    elif raw_datum[0].lower() not in Lobsterindict:
+                        Lobsterindict[raw_datum[0].lower()] = float(raw_datum[1])
                     else:
-                        if raw_datum[0].lower() not in Lobsterindict:
-                            Lobsterindict[raw_datum[0].lower()] = float(raw_datum[1])
-                        else:
-                            raise ValueError("Same keyword " + str(raw_datum[0].lower()) + "twice!")
+                        raise ValueError("Same keyword " + str(raw_datum[0].lower()) + "twice!")
+                elif raw_datum[0].lower() not in Lobsterindict:
+                    Lobsterindict[raw_datum[0].lower()] = [" ".join(raw_datum[1:])]
                 else:
-                    if raw_datum[0].lower() not in Lobsterindict:
-                        Lobsterindict[raw_datum[0].lower()] = [" ".join(raw_datum[1:])]
-                    else:
-                        Lobsterindict[raw_datum[0].lower()].append(" ".join(raw_datum[1:]))
+                    Lobsterindict[raw_datum[0].lower()].append(" ".join(raw_datum[1:]))
             elif len(raw_datum) > 0:
                 Lobsterindict[raw_datum[0].lower()] = True
 
@@ -871,7 +867,7 @@ def get_all_possible_basis_combinations(min_basis: list, max_basis: list) -> lis
                     if not isinstance(elbasis, list):
                         new_start_basis.append([elbasis, elbasis2])
                     else:
-                        new_start_basis.append(elbasis.copy() + [elbasis2])
+                        new_start_basis.append([*elbasis.copy(), elbasis2])
             start_basis = new_start_basis
         return start_basis
     return [[basis] for basis in start_basis]
