@@ -1,9 +1,14 @@
+from __future__ import annotations
+
 import os
 import unittest
 
 import numpy as np
+import pytest
+from pytest import approx
 
 from pymatgen.analysis.graphs import StructureGraph
+from pymatgen.core import Element
 from pymatgen.core.structure import Structure
 from pymatgen.electronic_structure.cohp import Cohp
 from pymatgen.electronic_structure.core import Spin
@@ -16,7 +21,7 @@ __version__ = "0.1"
 __email__ = "janine.george@uclouvain.be"
 __date__ = "Jan 14, 2021"
 
-test_dir_env = os.path.join(PymatgenTest.TEST_FILES_DIR, "cohp", "environments")
+test_dir_env = f"{PymatgenTest.TEST_FILES_DIR}/cohp/environments"
 this_dir = os.path.dirname(os.path.abspath(__file__))
 
 
@@ -214,7 +219,7 @@ class TestLobsterNeighbors(unittest.TestCase):
         )
 
     def test_use_of_coop(self):
-        with self.assertRaises(ValueError):
+        with pytest.raises(ValueError):
             _ = LobsterNeighbors(
                 are_coops=True,
                 filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353.gz"),
@@ -225,7 +230,7 @@ class TestLobsterNeighbors(unittest.TestCase):
             )
 
     def test_cation_anion_mode_without_ions(self):
-        with self.assertRaises(ValueError) as err:
+        with pytest.raises(ValueError) as exc:
             _ = LobsterNeighbors(
                 are_coops=False,
                 filename_ICOHP=os.path.join(test_dir_env, "../ICOHPLIST.lobster"),
@@ -233,11 +238,8 @@ class TestLobsterNeighbors(unittest.TestCase):
                 valences_from_charges=False,
                 additional_condition=1,
             )
-        self.assertEqual(
-            str(err.exception),
-            "Valences cannot be assigned, additional_conditions 1 and 3 and 5 and 6 will not work",
-        )
-        with self.assertRaises(ValueError) as err:
+        assert str(exc.value) == "Valences cannot be assigned, additional_conditions 1, 3, 5 and 6 will not work"
+        with pytest.raises(ValueError) as exc:
             _ = LobsterNeighbors(
                 are_coops=False,
                 filename_ICOHP=os.path.join(test_dir_env, "../ICOHPLIST.lobster"),
@@ -246,13 +248,10 @@ class TestLobsterNeighbors(unittest.TestCase):
                 additional_condition=1,
                 valences=[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
             )
-        self.assertEqual(
-            str(err.exception),
-            "All valences are equal to 0, additional_conditions 1 and 3 and 5 and 6 will not work",
-        )
+        assert str(exc.value) == "All valences are equal to 0, additional_conditions 1, 3, 5 and 6 will not work"
 
     def test_wrong_additional_correction(self):
-        with self.assertRaises(ValueError):
+        with pytest.raises(ValueError):
             _ = LobsterNeighbors(
                 are_coops=False,
                 filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.mp_353.gz"),
@@ -272,10 +271,14 @@ class TestLobsterNeighbors(unittest.TestCase):
             additional_condition=1,
             limits=[-100000, 0],
         )
-        self.assertListEqual(test.limits, [-100000, 0])
+        assert test.limits == [-100000, 0]
 
     def test_molecules_allowed(self):
-        self.chemenvlobster1.molecules_allowed
+        assert not self.chemenvlobster1.molecules_allowed
+
+    def test_get_anion_types(self):
+        assert self.chemenvlobster0_second.get_anion_types() == {Element("O")}
+        assert self.chemenvlobster0_second.anion_types == {Element("O")}
 
     def test_get_nn_info(self):
         # NO_ADDITIONAL_CONDITION = 0
@@ -288,238 +291,238 @@ class TestLobsterNeighbors(unittest.TestCase):
 
         # All bonds
         # ReO3
-        self.assertEqual(
+        assert (
             len(
                 self.chemenvlobster0.get_nn(
                     structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
                     n=0,
                 )
-            ),
-            6,
+            )
+            == 6
         )
-        self.assertEqual(
+        assert (
             len(
                 self.chemenvlobster0.get_nn(
                     structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
                     n=1,
                 )
-            ),
-            2,
+            )
+            == 2
         )
         # ONLY_ANION_CATION_BONDS = 1
-        self.assertEqual(
+        assert (
             len(
                 self.chemenvlobster1.get_nn(
                     structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
                     n=0,
                 )
-            ),
-            6,
+            )
+            == 6
         )
-        self.assertEqual(
+        assert (
             len(
                 self.chemenvlobster1.get_nn(
                     structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
                     n=1,
                 )
-            ),
-            2,
+            )
+            == 2
         )
         # NO_ELEMENT_TO_SAME_ELEMENT_BONDS = 2
-        self.assertEqual(
+        assert (
             len(
                 self.chemenvlobster2.get_nn(
                     structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
                     n=0,
                 )
-            ),
-            6,
+            )
+            == 6
         )
-        self.assertEqual(
+        assert (
             len(
                 self.chemenvlobster2.get_nn(
                     structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
                     n=1,
                 )
-            ),
-            2,
+            )
+            == 2
         )
         # ONLY_ANION_CATION_BONDS_AND_NO_ELEMENT_TO_SAME_ELEMENT_BONDS = 3
-        self.assertEqual(
+        assert (
             len(
                 self.chemenvlobster3.get_nn(
                     structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
                     n=0,
                 )
-            ),
-            6,
+            )
+            == 6
         )
-        self.assertEqual(
+        assert (
             len(
                 self.chemenvlobster3.get_nn(
                     structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
                     n=1,
                 )
-            ),
-            2,
+            )
+            == 2
         )
         # ONLY_ELEMENT_TO_OXYGEN_BONDS = 4
-        self.assertEqual(
+        assert (
             len(
                 self.chemenvlobster4.get_nn(
                     structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
                     n=0,
                 )
-            ),
-            6,
+            )
+            == 6
         )
-        self.assertEqual(
+        assert (
             len(
                 self.chemenvlobster4.get_nn(
                     structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
                     n=1,
                 )
-            ),
-            2,
+            )
+            == 2
         )
         # DO_NOT_CONSIDER_ANION_CATION_BONDS=5
-        self.assertEqual(
+        assert (
             len(
                 self.chemenvlobster5.get_nn(
                     structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
                     n=0,
                 )
-            ),
-            0,
+            )
+            == 0
         )
-        self.assertEqual(
+        assert (
             len(
                 self.chemenvlobster5.get_nn(
                     structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
                     n=1,
                 )
-            ),
-            0,
+            )
+            == 0
         )
         # ONLY_CATION_CATION_BONDS=6
-        self.assertEqual(
+        assert (
             len(
                 self.chemenvlobster6.get_nn(
                     structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
                     n=0,
                 )
-            ),
-            0,
+            )
+            == 0
         )
 
-        self.assertEqual(
+        assert (
             len(
                 self.chemenvlobster6.get_nn(
                     structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
                     n=1,
                 )
-            ),
-            0,
+            )
+            == 0
         )
 
         # All bonds
         # mp-353, Ag2O
         # all bonds
-        self.assertEqual(
+        assert (
             len(
                 self.chemenvlobster0_second.get_nn(
                     structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
                     n=0,
                 )
-            ),
-            8,
+            )
+            == 8
         )
 
         # ONLY_ANION_CATION_BONDS = 1
-        self.assertEqual(
+        assert (
             len(
                 self.chemenvlobster1_second.get_nn(
                     structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
                     n=0,
                 )
-            ),
-            2,
+            )
+            == 2
         )
 
         # NO_ELEMENT_TO_SAME_ELEMENT_BONDS = 2
-        self.assertEqual(
+        assert (
             len(
                 self.chemenvlobster2_second.get_nn(
                     structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
                     n=0,
                 )
-            ),
-            2,
+            )
+            == 2
         )
-        self.assertEqual(
+        assert (
             len(
                 self.chemenvlobster2_second.get_nn(
                     structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
                     n=4,
                 )
-            ),
-            4,
+            )
+            == 4
         )
 
         # DO_NOT_CONSIDER_ANION_CATION_BONDS=5
-        self.assertEqual(
+        assert (
             len(
                 self.chemenvlobster5_second.get_nn(
                     structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
                     n=0,
                 )
-            ),
-            6,
+            )
+            == 6
         )
-        self.assertEqual(
+        assert (
             len(
                 self.chemenvlobster5_second.get_nn(
                     structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
                     n=4,
                 )
-            ),
-            0,
+            )
+            == 0
         )
         # ONLY_CATION_CATION_BONDS=6
-        self.assertEqual(
+        assert (
             len(
                 self.chemenvlobster6_second.get_nn(
                     structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
                     n=0,
                 )
-            ),
-            6,
+            )
+            == 6
         )
-        self.assertEqual(
+        assert (
             len(
                 self.chemenvlobster6_second.get_nn(
                     structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
                     n=4,
                 )
-            ),
-            0,
+            )
+            == 0
         )
 
-        self.assertEqual(
+        assert (
             len(
                 self.chemenvlobster5_second_percentage.get_nn(
                     structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
                     n=0,
                 )
-            ),
-            0,
+            )
+            == 0
         )
 
     def test_structure_graph(self):
         sg = self.chemenvlobster1_second.get_bonded_structure(
             structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz"))
         )
-        self.assertEqual(type(sg), StructureGraph)
+        assert isinstance(sg, StructureGraph)
 
     def test_extended_structure_graph(self):
         self.chemenvlobsterNaCl = LobsterNeighbors(
@@ -541,15 +544,15 @@ class TestLobsterNeighbors(unittest.TestCase):
             edge_properties=True,
             weights=True,
         )
-        self.assertAlmostEqual(sg.graph.get_edge_data(0, 1)[0]["ICOHP"], -0.56541)
-        self.assertAlmostEqual(sg.graph.get_edge_data(0, 1)[0]["ICOBI"], 0.08484)
-        self.assertAlmostEqual(sg.graph.get_edge_data(0, 1)[0]["ICOOP"], 0.02826)
-        self.assertAlmostEqual(sg.graph.get_edge_data(0, 1)[0]["bond_label"], "21")
-        self.assertAlmostEqual(sg.graph.get_edge_data(0, 1)[5]["bond_label"], "30")
-        self.assertEqual(type(sg), StructureGraph)
+        assert sg.graph.get_edge_data(0, 1)[0]["ICOHP"] == approx(-0.56541)
+        assert sg.graph.get_edge_data(0, 1)[0]["ICOBI"] == approx(0.08484)
+        assert sg.graph.get_edge_data(0, 1)[0]["ICOOP"] == approx(0.02826)
+        assert sg.graph.get_edge_data(0, 1)[0]["bond_label"] == "21"
+        assert sg.graph.get_edge_data(0, 1)[5]["bond_label"] == "30"
+        assert isinstance(sg, StructureGraph)
 
     def test_raises_extended_structure_graph(self):
-        with self.assertRaises(ValueError):
+        with pytest.raises(ValueError):
             self.chemenvlobsterNaCl = LobsterNeighbors(
                 are_coops=False,
                 filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.NaCl.gz"),
@@ -563,7 +566,7 @@ class TestLobsterNeighbors(unittest.TestCase):
                 id_blist_sg2="icoop",
                 additional_condition=1,
             )
-        with self.assertRaises(ValueError):
+        with pytest.raises(ValueError):
             self.chemenvlobsterNaCl = LobsterNeighbors(
                 are_coops=False,
                 filename_ICOHP=os.path.join(test_dir_env, "ICOHPLIST.lobster.NaCl.gz"),
@@ -579,63 +582,54 @@ class TestLobsterNeighbors(unittest.TestCase):
             )
 
     def test_order_parameter(self):
-        self.assertAlmostEqual(
-            self.chemenvlobster1_second.get_local_order_parameters(
-                structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
-                n=0,
-            )["linear"],
-            1.0,
-        )
+        assert self.chemenvlobster1_second.get_local_order_parameters(
+            structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_353.gz")),
+            n=0,
+        )["linear"] == approx(1.0)
 
     def test_get_structure_environments(self):
         lse = self.chemenvlobster1_second.get_light_structure_environment()
-        self.assertEqual(lse.coordination_environments[0][0]["ce_symbol"], "L:2")
-        self.assertEqual(lse.coordination_environments[5][0]["ce_symbol"], "T:4")
+        assert lse.coordination_environments[0][0]["ce_symbol"] == "L:2"
+        assert lse.coordination_environments[5][0]["ce_symbol"] == "T:4"
 
         lse2 = self.chemenvlobster1.get_light_structure_environment()
-        self.assertEqual(lse2.coordination_environments[0][0]["ce_symbol"], "O:6")
+        assert lse2.coordination_environments[0][0]["ce_symbol"] == "O:6"
 
     def test_get_strucuture_environments_further_tests(self):
         lse = self.chemenvlobster1_second.get_light_structure_environment()
         lse.as_dict()
         lse.get_statistics()
-        self.assertTrue(lse.uniquely_determines_coordination_environments)
+        assert lse.uniquely_determines_coordination_environments
 
     def test_get_info_icohps_neighbors(self):
         results = self.chemenvlobster1.get_info_icohps_to_neighbors(isites=[0])
-        self.assertAlmostEqual(results[0], -33.26058)
+        assert results[0] == approx(-33.26058)
         for bond in results[1]:
-            self.assertAlmostEqual(bond, -5.54345, 3)
-        self.assertAlmostEqual(results[2], 6)
-        self.assertAlmostEqual(results[3], ["27", "30", "48", "49", "64", "73"])
+            assert bond == approx(-5.54345, abs=1e-3)
+        assert results[2] == 6
+        assert results[3] == ["27", "30", "48", "49", "64", "73"]
 
         results2 = self.chemenvlobster1.get_info_icohps_to_neighbors(isites=None)
-        self.assertAlmostEqual(results2[0], -33.26058)
+        assert results2[0] == approx(-33.26058)
         for bond in results2[1]:
-            self.assertAlmostEqual(bond, -5.54345, 3)
-        self.assertAlmostEqual(results2[2], 6)
-        self.assertAlmostEqual(results2[3], ["27", "30", "48", "49", "64", "73"])
-        self.assertAlmostEqual(
-            results2[4],
-            [
-                ["Re1", "O2"],
-                ["Re1", "O2"],
-                ["Re1", "O3"],
-                ["Re1", "O3"],
-                ["Re1", "O4"],
-                ["Re1", "O4"],
-            ],
-        )
+            assert bond == approx(-5.54345, abs=1e-3)
+        assert results2[2] == 6
+        assert results2[3] == ["27", "30", "48", "49", "64", "73"]
+        assert results2[4] == [
+            ["Re1", "O2"],
+            ["Re1", "O2"],
+            ["Re1", "O3"],
+            ["Re1", "O3"],
+            ["Re1", "O4"],
+            ["Re1", "O4"],
+        ]
 
     def test_get_sum_icohps_between_neighbors_of_atom(self):
         # will only look at icohps between cations or anions
         self.chemenvlobster1.get_info_icohps_to_neighbors(isites=[1])
-        self.assertEqual(self.chemenvlobster1.get_info_icohps_between_neighbors(isites=[1])[2], 1)
-        self.assertAlmostEqual(
-            self.chemenvlobster1.get_info_icohps_between_neighbors(isites=[1])[0],
-            -0.05507,
-        )
-        self.assertEqual(self.chemenvlobster1.get_info_icohps_between_neighbors(isites=[0])[2], 15)
+        assert self.chemenvlobster1.get_info_icohps_between_neighbors(isites=[1])[2] == 1
+        assert self.chemenvlobster1.get_info_icohps_between_neighbors(isites=[1])[0] == approx(-0.05507)
+        assert self.chemenvlobster1.get_info_icohps_between_neighbors(isites=[0])[2] == 15
         # use an example where this is easier to test (e.g., linear environment?)
 
         chemenv_here = LobsterNeighbors(
@@ -644,67 +638,32 @@ class TestLobsterNeighbors(unittest.TestCase):
             structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp-7000.gz")),
             additional_condition=1,
         )
-        self.assertEqual(len(chemenv_here.get_info_icohps_between_neighbors(isites=[0])[4]), 6)
+        assert len(chemenv_here.get_info_icohps_between_neighbors(isites=[0])[4]) == 6
 
     def test_get_plot_label(self):
-        self.assertEqual(
-            self.chemenvlobster1._get_plot_label(
-                atoms=[
-                    ["Re1", "O2"],
-                    ["Re1", "O2"],
-                    ["Re1", "O3"],
-                    ["Re1", "O3"],
-                    ["Re1", "O4"],
-                    ["Re1", "O4"],
-                ],
-                per_bond=False,
-            ),
-            "6 x O-Re",
-        )
-        self.assertEqual(
-            self.chemenvlobster1._get_plot_label(
-                atoms=[
-                    ["Re1", "O2"],
-                    ["Re1", "O2"],
-                    ["Re1", "O3"],
-                    ["Re1", "O3"],
-                    ["Re1", "O4"],
-                    ["Si1", "O4"],
-                ],
-                per_bond=False,
-            ),
-            "5 x O-Re, 1 x O-Si",
+        label = self.chemenvlobster1._get_plot_label(
+            atoms=[["Re1", "O2"], ["Re1", "O2"], ["Re1", "O3"], ["Re1", "O3"], ["Re1", "O4"], ["Re1", "O4"]],
+            per_bond=False,
         )
+        assert label == "6 x O-Re"
 
-        self.assertEqual(
-            self.chemenvlobster1._get_plot_label(
-                atoms=[
-                    ["Si1", "O2"],
-                    ["Si1", "O2"],
-                    ["Si1", "O3"],
-                    ["Re1", "O3"],
-                    ["Re1", "O4"],
-                    ["Si1", "O4"],
-                ],
-                per_bond=False,
-            ),
-            "4 x O-Si, 2 x O-Re",
+        label = self.chemenvlobster1._get_plot_label(
+            atoms=[["Re1", "O2"], ["Re1", "O2"], ["Re1", "O3"], ["Re1", "O3"], ["Re1", "O4"], ["Si1", "O4"]],
+            per_bond=False,
         )
+        assert label == "5 x O-Re, 1 x O-Si"
 
-        self.assertEqual(
-            self.chemenvlobster1._get_plot_label(
-                atoms=[
-                    ["Re1", "O2"],
-                    ["Re1", "O2"],
-                    ["Re1", "O3"],
-                    ["Re1", "O3"],
-                    ["Re1", "O4"],
-                    ["Re1", "O4"],
-                ],
-                per_bond=True,
-            ),
-            "6 x O-Re (per bond)",
+        label = self.chemenvlobster1._get_plot_label(
+            atoms=[["Si1", "O2"], ["Si1", "O2"], ["Si1", "O3"], ["Re1", "O3"], ["Re1", "O4"], ["Si1", "O4"]],
+            per_bond=False,
         )
+        assert label == "4 x O-Si, 2 x O-Re"
+
+        label = self.chemenvlobster1._get_plot_label(
+            atoms=[["Re1", "O2"], ["Re1", "O2"], ["Re1", "O3"], ["Re1", "O3"], ["Re1", "O4"], ["Re1", "O4"]],
+            per_bond=True,
+        )
+        assert label == "6 x O-Re (per bond)"
 
     def test_get_info_cohps_to_neighbors(self):
         chemenvlobster1 = LobsterNeighbors(
@@ -713,95 +672,70 @@ class TestLobsterNeighbors(unittest.TestCase):
             structure=Structure.from_file(os.path.join(test_dir_env, "POSCAR.mp_190.gz")),
             additional_condition=1,
         )
-        self.assertEqual(
-            chemenvlobster1.get_info_cohps_to_neighbors(
-                path_to_COHPCAR=os.path.join(test_dir_env, "COHPCAR.lobster.mp-190.gz"),
-                isites=[0],
-                only_bonds_to=["O"],
-            )[0],
-            "6 x O-Re (per bond)",
-        )
-        self.assertEqual(
-            type(
-                chemenvlobster1.get_info_cohps_to_neighbors(
-                    path_to_COHPCAR=os.path.join(test_dir_env, "COHPCAR.lobster.mp-190.gz"),
-                    isites=[0],
-                    only_bonds_to=["O"],
-                )[1]
-            ),
-            Cohp,
+        cohpcar_lobster_mp_190 = os.path.join(test_dir_env, "COHPCAR.lobster.mp-190.gz")
+        plot_label, summed_cohpcar_mp_190 = chemenvlobster1.get_info_cohps_to_neighbors(
+            path_to_COHPCAR=cohpcar_lobster_mp_190,
+            isites=[0],
+            only_bonds_to=["O"],
         )
+        assert plot_label == "6 x O-Re (per bond)"
+        assert isinstance(summed_cohpcar_mp_190, Cohp)
 
-        cophthing = chemenvlobster1.get_info_cohps_to_neighbors(
-            path_to_COHPCAR=os.path.join(test_dir_env, "COHPCAR.lobster.mp-190.gz"),
+        coph_thing = chemenvlobster1.get_info_cohps_to_neighbors(
+            path_to_COHPCAR=cohpcar_lobster_mp_190,
             isites=[0],
             only_bonds_to=None,
             per_bond=False,
         )[1]
-        self.assertAlmostEqual(
-            np.sum([cophthing.icohp[Spin.up], cophthing.icohp[Spin.down]], axis=0)[300],
-            chemenvlobster1.get_info_icohps_to_neighbors(isites=[0])[0],
+        assert np.sum([coph_thing.icohp[Spin.up], coph_thing.icohp[Spin.down]], axis=0)[300] == approx(
+            chemenvlobster1.get_info_icohps_to_neighbors(isites=[0])[0]
         )
 
         # summed_spin_channel
-        cophthing = chemenvlobster1.get_info_cohps_to_neighbors(
-            path_to_COHPCAR=os.path.join(test_dir_env, "COHPCAR.lobster.mp-190.gz"),
+        coph_thing = chemenvlobster1.get_info_cohps_to_neighbors(
+            path_to_COHPCAR=cohpcar_lobster_mp_190,
             isites=[0],
             only_bonds_to=None,
             per_bond=False,
             summed_spin_channels=True,
         )[1]
-        self.assertAlmostEqual(
-            cophthing.icohp[Spin.up][300],
-            chemenvlobster1.get_info_icohps_to_neighbors(isites=[0])[0],
+        assert coph_thing.icohp[Spin.up][300] == approx(chemenvlobster1.get_info_icohps_to_neighbors(isites=[0])[0])
+
+        plot_label, summed_cohpcar_mp_190_Te = chemenvlobster1.get_info_cohps_to_neighbors(
+            path_to_COHPCAR=cohpcar_lobster_mp_190,
+            isites=[0],
+            only_bonds_to=["Te"],
         )
 
-        self.assertEqual(
-            chemenvlobster1.get_info_cohps_to_neighbors(
-                path_to_COHPCAR=os.path.join(test_dir_env, "COHPCAR.lobster.mp-190.gz"),
-                isites=[0],
-                only_bonds_to=["Te"],
-            )[0],
-            None,
-        )
+        assert plot_label is None
+        assert summed_cohpcar_mp_190_Te is None
 
-        self.assertEqual(
-            chemenvlobster1.get_info_cohps_to_neighbors(
-                path_to_COHPCAR=os.path.join(test_dir_env, "COHPCAR.lobster.mp-190.gz"),
-                isites=[0],
-                only_bonds_to=["Te"],
-            )[1],
-            None,
+        plot_label, _summed_cohpcar_NaSi = self.chemenvlobster0_NaSi.get_info_cohps_to_neighbors(
+            path_to_COHPCAR=os.path.join(test_dir_env, "COHPCAR.lobster.NaSi.gz"),
+            isites=[8],
+            onlycation_isites=False,
+            only_bonds_to=["Na"],
         )
-
-        self.assertEqual(
-            self.chemenvlobster0_NaSi.get_info_cohps_to_neighbors(
-                path_to_COHPCAR=os.path.join(test_dir_env, "COHPCAR.lobster.NaSi.gz"),
-                isites=[8],
-                onlycation_isites=False,
-                only_bonds_to=["Na"],
-            )[0],
-            "1 x Na-Si (per bond)",
-        )
-        self.assertEqual(
+        assert plot_label == "1 x Na-Si (per bond)"
+        assert (
             self.chemenvlobster0_NaSi.get_info_cohps_to_neighbors(
                 path_to_COHPCAR=os.path.join(test_dir_env, "COHPCAR.lobster.NaSi.gz"),
                 isites=[8],
                 onlycation_isites=False,
                 only_bonds_to=["Si"],
-            )[0],
-            "3 x Si-Si (per bond)",
+            )[0]
+            == "3 x Si-Si (per bond)"
         )
 
         chemenvlobster1.plot_cohps_of_neighbors(
-            path_to_COHPCAR=os.path.join(test_dir_env, "COHPCAR.lobster.mp-190.gz"),
+            path_to_COHPCAR=cohpcar_lobster_mp_190,
             isites=[0],
             only_bonds_to=["O"],
             summed_spin_channels=True,
         )
 
         chemenvlobster1.plot_cohps_of_neighbors(
-            path_to_COHPCAR=os.path.join(test_dir_env, "COHPCAR.lobster.mp-190.gz"),
+            path_to_COHPCAR=cohpcar_lobster_mp_190,
             isites=[0],
             only_bonds_to=["O"],
             summed_spin_channels=True,
@@ -809,24 +743,20 @@ class TestLobsterNeighbors(unittest.TestCase):
             ylim=None,
         )
 
-        with self.assertRaises(ValueError):
+        with pytest.raises(ValueError):
             # icohplist and cohpcar do not fit together
             self.chemenvlobster1.get_info_cohps_to_neighbors(
-                path_to_COHPCAR=os.path.join(test_dir_env, "COHPCAR.lobster.mp-190.gz"),
+                path_to_COHPCAR=cohpcar_lobster_mp_190,
                 isites=[0],
                 only_bonds_to=None,
                 per_bond=False,
             )
 
-        with self.assertRaises(ValueError):
+        with pytest.raises(ValueError):
             # icohplist and cohpcar do not fit together
             self.chemenvlobster2.get_info_cohps_to_neighbors(
-                path_to_COHPCAR=os.path.join(test_dir_env, "COHPCAR.lobster.mp-190.gz"),
+                path_to_COHPCAR=cohpcar_lobster_mp_190,
                 isites=[0],
                 only_bonds_to=None,
                 per_bond=False,
             )
-
-
-if __name__ == "__main__":
-    unittest.main()
