@@ -1,6 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 Module for interfacing with phonopy, see https://atztogo.github.io/phonopy/
 """
@@ -13,15 +10,9 @@ from monty.serialization import loadfn
 from scipy.interpolate import InterpolatedUnivariateSpline
 
 from pymatgen.core import Lattice, Structure
-from pymatgen.phonon.bandstructure import (
-    PhononBandStructure,
-    PhononBandStructureSymmLine,
-)
+from pymatgen.phonon.bandstructure import PhononBandStructure, PhononBandStructureSymmLine
 from pymatgen.phonon.dos import CompletePhononDos, PhononDos
-from pymatgen.phonon.gruneisen import (
-    GruneisenParameter,
-    GruneisenPhononBandStructureSymmLine,
-)
+from pymatgen.phonon.gruneisen import GruneisenParameter, GruneisenPhononBandStructureSymmLine
 from pymatgen.phonon.thermal_displacements import ThermalDisplacementMatrices
 from pymatgen.symmetry.bandstructure import HighSymmKpath
 
@@ -30,9 +21,7 @@ try:
     from phonopy.file_IO import write_disp_yaml
     from phonopy.structure.atoms import PhonopyAtoms
 except ImportError:
-    Phonopy = None
-    write_disp_yaml = None
-    PhonopyAtoms = None
+    Phonopy = write_disp_yaml = PhonopyAtoms = None
 
 
 @requires(Phonopy, "phonopy not installed!")
@@ -81,7 +70,6 @@ def get_structure_from_dict(d):
     Adds "phonopy_masses" in the site_properties of the structures.
     Compatible with older phonopy versions.
     """
-
     species = []
     frac_coords = []
     masses = []
@@ -117,7 +105,6 @@ def eigvec_to_eigdispl(v, q, frac_coords, mass):
         frac_coords: the fractional coordinates of the atom
         mass: the mass of the atom
     """
-
     c = np.exp(2j * np.pi * np.dot(frac_coords, q)) / np.sqrt(mass)
 
     return c * v
@@ -142,7 +129,6 @@ def get_ph_bs_symm_line_from_dict(bands_dict, has_nac=False, labels_dict=None):
         labels_dict: dict that links a qpoint in frac coords to a label.
             Its value will replace the data contained in the band.yaml.
     """
-
     structure = get_structure_from_dict(bands_dict)
 
     qpts = []
@@ -159,7 +145,7 @@ def get_ph_bs_symm_line_from_dict(bands_dict, has_nac=False, labels_dict=None):
             if "eigenvector" in b:
                 eig_b = []
                 for i, eig_a in enumerate(b["eigenvector"]):
-                    v = np.zeros(3, np.complex)
+                    v = np.zeros(3, complex)
                     for x in range(3):
                         v[x] = eig_a[x][0] + eig_a[x][1] * 1j
                     eig_b.append(
@@ -264,7 +250,7 @@ def get_displaced_structures(pmg_structure, atom_disp=0.01, supercell_matrix=Non
         pmg_structure (Structure): A pymatgen structure object.
         atom_disp (float): Atomic displacement. Default is 0.01 $\\AA$.
         supercell_matrix (3x3 array): Scaling matrix for supercell.
-        yaml_fname (string): If not None, it represents the full path to
+        yaml_fname (str): If not None, it represents the full path to
             the outputting displacement yaml file, e.g. disp.yaml.
         **kwargs: Parameters used in Phonopy.generate_displacement method.
 
@@ -272,7 +258,6 @@ def get_displaced_structures(pmg_structure, atom_disp=0.01, supercell_matrix=Non
         A list of symmetrically inequivalent structures with displacements, in
         which the first element is the perfect supercell structure.
     """
-
     is_plusminus = kwargs.get("is_plusminus", "auto")
     is_diagonal = kwargs.get("is_diagonal", True)
     is_trigonal = kwargs.get("is_trigonal", False)
@@ -451,7 +436,6 @@ def get_gruneisenparameter(gruneisen_path, structure=None, structure_path=None)
     Returns: GruneisenParameter object
 
     """
-
     gruneisen_dict = loadfn(gruneisen_path)
 
     if structure_path and structure is None:
@@ -468,10 +452,7 @@ def get_gruneisenparameter(gruneisen_path, structure=None, structure_path=None)
     for p in gruneisen_dict["phonon"]:
         q = p["q-position"]
         qpts.append(q)
-        if "multiplicity" in p:
-            m = p["multiplicity"]
-        else:
-            m = 1
+        m = p["multiplicity"] if "multiplicity" in p else 1
         multiplicities.append(m)
         bands, gruneisenband = [], []
         for b in p["band"]:
@@ -526,7 +507,6 @@ def get_gs_ph_bs_symm_line_from_dict(
             These derivations occur because of very small frequencies
             (and therefore numerical inaccuracies) close to gamma.
     """
-
     if structure_path and structure is None:
         structure = Structure.from_file(structure_path)
     else:
@@ -687,7 +667,6 @@ def get_thermal_displacement_matrices(
         structure_path: path to POSCAR
 
     Returns:
-
     """
     thermal_displacements_dict = loadfn(thermal_displacements_yaml)
 
