@@ -1,13 +1,13 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module implements input and output processing from PWSCF.
 """
 
+from __future__ import annotations
+
 import re
 from collections import defaultdict
 
+from frozendict import frozendict
 from monty.io import zopen
 from monty.re import regrep
 
@@ -105,7 +105,7 @@ class PWInput:
 
         def to_str(v):
             if isinstance(v, str):
-                return f"'{v}'"
+                return f"{v!r}"
             if isinstance(v, float):
                 return f"{str(v).replace('e', 'd')}"
             if isinstance(v, bool):
@@ -139,10 +139,7 @@ class PWInput:
         out.append("ATOMIC_SPECIES")
         for k, v in sorted(site_descriptions.items(), key=lambda i: i[0]):
             e = re.match(r"[A-Z][a-z]?", k).group(0)
-            if self.pseudo is not None:
-                p = v
-            else:
-                p = v["pseudo"]
+            p = v if self.pseudo is not None else v["pseudo"]
             out.append(f"  {k}  {Element(e).atomic_mass:.4f} {p}")
 
         out.append("ATOMIC_POSITIONS crystal")
@@ -163,7 +160,7 @@ class PWInput:
             kpt_str.extend([f"{i}" for i in self.kpoints_shift])
             out.append(f"  {' '.join(kpt_str)}")
         elif self.kpoints_mode == "crystal_b":
-            out.append(f" {str(len(self.kpoints_grid))}")
+            out.append(f" {len(self.kpoints_grid)}")
             for i in range(len(self.kpoints_grid)):
                 kpt_str = [f"{entry:.4f}" for entry in self.kpoints_grid[i]]
                 out.append(f" {' '.join(kpt_str)}")
@@ -295,7 +292,7 @@ class PWInput:
                     key_ = m.group(2).strip()
                     val = m.group(3).strip()
                     if key_ != "":
-                        if sections[section].get(key, None) is None:
+                        if sections[section].get(key) is None:
                             val_ = [0.0] * 20  # MAX NTYP DEFINITION
                             val_[int(key_) - 1] = PWInput.proc_val(key, val)
                             sections[section][key] = val_
@@ -498,6 +495,7 @@ class PWInput:
         m = re.match(r"^[\"|'](.+)[\"|']$", val)
         if m:
             return m.group(1)
+        return None
 
 
 class PWInputError(BaseException):
@@ -511,18 +509,18 @@ class PWOutput:
     Parser for PWSCF output file.
     """
 
-    patterns = {
-        "energies": r"total energy\s+=\s+([\d\.\-]+)\sRy",
-        "ecut": r"kinetic\-energy cutoff\s+=\s+([\d\.\-]+)\s+Ry",
-        "lattice_type": r"bravais\-lattice index\s+=\s+(\d+)",
-        "celldm1": r"celldm\(1\)=\s+([\d\.]+)\s",
-        "celldm2": r"celldm\(2\)=\s+([\d\.]+)\s",
-        "celldm3": r"celldm\(3\)=\s+([\d\.]+)\s",
-        "celldm4": r"celldm\(4\)=\s+([\d\.]+)\s",
-        "celldm5": r"celldm\(5\)=\s+([\d\.]+)\s",
-        "celldm6": r"celldm\(6\)=\s+([\d\.]+)\s",
-        "nkpts": r"number of k points=\s+([\d]+)",
-    }
+    patterns = frozendict(
+        energies=r"total energy\s+=\s+([\d\.\-]+)\sRy",
+        ecut=r"kinetic\-energy cutoff\s+=\s+([\d\.\-]+)\s+Ry",
+        lattice_type=r"bravais\-lattice index\s+=\s+(\d+)",
+        celldm1=r"celldm\(1\)=\s+([\d\.]+)\s",
+        celldm2=r"celldm\(2\)=\s+([\d\.]+)\s",
+        celldm3=r"celldm\(3\)=\s+([\d\.]+)\s",
+        celldm4=r"celldm\(4\)=\s+([\d\.]+)\s",
+        celldm5=r"celldm\(5\)=\s+([\d\.]+)\s",
+        celldm6=r"celldm\(6\)=\s+([\d\.]+)\s",
+        nkpts=r"number of k points=\s+([\d]+)",
+    )
 
     def __init__(self, filename):
         """
