@@ -1,6 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 Classes for reading/manipulating/writing QChem input files.
 """
@@ -8,8 +5,8 @@ Classes for reading/manipulating/writing QChem input files.
 from __future__ import annotations
 
 import logging
-from pathlib import Path
-from typing import Literal
+import re
+from typing import TYPE_CHECKING, Literal
 
 from monty.io import zopen
 
@@ -18,10 +15,14 @@ from pymatgen.io.core import InputFile
 
 from .utils import lower_and_check_unique, read_pattern, read_table_pattern
 
-__author__ = "Brandon Wood, Samuel Blau, Shyam Dwaraknath, Julian Self, Evan Spotte-Smith"
-__copyright__ = "Copyright 2018, The Materials Project"
+if TYPE_CHECKING:
+    from pathlib import Path
+
+__author__ = "Brandon Wood, Samuel Blau, Shyam Dwaraknath, Julian Self, Evan Spotte-Smith, Ryan Kingsbury"
+__copyright__ = "Copyright 2018-2022, The Materials Project"
 __version__ = "0.1"
-__email__ = "b.wood@berkeley.edu"
+__maintainer__ = "Samuel Blau"
+__email__ = "samblau1@gmail.com"
 __credits__ = "Xiaohui Qu"
 
 logger = logging.getLogger(__name__)
@@ -30,7 +31,7 @@ logger = logging.getLogger(__name__)
 class QCInput(InputFile):
     """
     An object representing a QChem input file. QCInput attributes represent different sections of a QChem input file.
-    To add a new section one needs to modify __init__, __str__, from_sting and add staticmethods
+    To add a new section one needs to modify __init__, __str__, from_sting and add static methods
     to read and write the new section i.e. section_template and read_section. By design, there is very little (or no)
     checking that input parameters conform to the appropriate QChem format, this responsible lands on the user or a
     separate error handling software.
@@ -38,7 +39,7 @@ class QCInput(InputFile):
 
     def __init__(
         self,
-        molecule: Molecule | Literal["read"],
+        molecule: Molecule | list[Molecule] | Literal["read"],
         rem: dict,
         opt: dict[str, list] | None = None,
         pcm: dict | None = None,
@@ -50,13 +51,17 @@ class QCInput(InputFile):
         plots: dict | None = None,
         nbo: dict | None = None,
         geom_opt: dict | None = None,
+        cdft: list[list[dict]] | None = None,
+        almo_coupling: list[list[tuple[int, int]]] | None = None,
+        svp: dict | None = None,
+        pcm_nonels: dict | None = None,
     ):
         """
         Args:
-            molecule (pymatgen Molecule object or "read"):
-                Input molecule. molecule can be set as either a pymatgen Molecule object or as the str "read".
-                "read" can be used in multi_job QChem input files where the molecule is read in from the
-                previous calculation.
+            molecule (pymatgen Molecule object, list of Molecule objects, or "read"):
+                Input molecule(s). molecule can be set as a pymatgen Molecule object, a list of such
+                Molecule objects, or as the string "read". "read" can be used in multi_job QChem input
+                files where the molecule is read in from the previous calculation.
             rem (dict):
                 A dictionary of all the input parameters for the rem section of QChem input file.
                 Ex. rem = {'method': 'rimp2', 'basis': '6-31*G++' ... }
@@ -91,12 +96,63 @@ class QCInput(InputFile):
                 radius (e.g., 12 = carbon). In 'sequential' mode, dict keys represent the sequential
                 position of a single specific atom in the input structure.
             plots (dict):
-                    A dictionary of all the input parameters for the plots section of QChem input file.
+                    A dictionary of all the input parameters for the plots section of the QChem input file.
             nbo (dict):
-                    A dictionary of all the input parameters for the nbo section of QChem input file.
+                    A dictionary of all the input parameters for the nbo section of the QChem input file.
             geom_opt (dict):
                     A dictionary of input parameters for the geom_opt section of the QChem input file.
                     This section is required when using the new libopt3 geometry optimizer.
+            cdft (list of lists of dicts):
+                    A list of lists of dictionaries, where each dictionary represents a charge constraint in the
+                    cdft section of the QChem input file.
+
+                    Each entry in the main list represents one state (allowing for multi-configuration calculations
+                    using constrained density functional theory - configuration interaction (CDFT-CI).
+                    Each state is represented by a list, which itself contains some number of constraints
+                    (dictionaries).
+
+                    Ex:
+
+                    1. For a single-state calculation with two constraints:
+                     cdft=[[
+                        {"value": 1.0, "coefficients": [1.0], "first_atoms": [1], "last_atoms": [2], "types": [None]},
+                        {"value": 2.0, "coefficients": [1.0, -1.0], "first_atoms": [1, 17], "last_atoms": [3, 19],
+                            "types": ["s"]}
+                    ]]
+
+                    Note that a type of None will default to a charge constraint (which can also be accessed by
+                    requesting a type of "c" or "charge".
+
+                    2. For a multi-reference calculation:
+                    cdft=[
+                        [
+                            {"value": 1.0, "coefficients": [1.0], "first_atoms": [1], "last_atoms": [27],
+                                "types": ["c"]},
+                            {"value": 0.0, "coefficients": [1.0], "first_atoms": [1], "last_atoms": [27],
+                                "types": ["s"]},
+                        ],
+                        [
+                            {"value": 0.0, "coefficients": [1.0], "first_atoms": [1], "last_atoms": [27],
+                                "types": ["c"]},
+                            {"value": -1.0, "coefficients": [1.0], "first_atoms": [1], "last_atoms": [27],
+                                "types": ["s"]},
+                        ]
+                    ]
+            almo_coupling (list of lists of int 2-tuples):
+                A list of lists of int 2-tuples used for calculations of diabatization and state coupling calculations
+                    relying on the absolutely localized molecular orbitals (ALMO) methodology. Each entry in the main
+                    list represents a single state (two states are included in an ALMO calculation). Within a single
+                    state, each 2-tuple represents the charge and spin multiplicity of a single fragment.
+                ex: almo=[
+                            [
+                                (1, 2),
+                                (0, 1)
+                            ],
+                            [
+                                (0, 1),
+                                (1, 2)
+                            ]
+                        ]
         """
         self.molecule = molecule
         self.rem = lower_and_check_unique(rem)
@@ -110,6 +166,10 @@ class QCInput(InputFile):
         self.plots = lower_and_check_unique(plots)
         self.nbo = lower_and_check_unique(nbo)
         self.geom_opt = lower_and_check_unique(geom_opt)
+        self.cdft = cdft
+        self.almo_coupling = almo_coupling
+        self.svp = lower_and_check_unique(svp)
+        self.pcm_nonels = lower_and_check_unique(pcm_nonels)
 
         # Make sure rem is valid:
         #   - Has a basis
@@ -130,9 +190,8 @@ class QCInput(InputFile):
 
         if "basis" not in self.rem:
             raise ValueError("The rem dictionary must contain a 'basis' entry")
-        if "method" not in self.rem:
-            if "exchange" not in self.rem:
-                raise ValueError("The rem dictionary must contain either a 'method' entry or an 'exchange' entry")
+        if "method" not in self.rem and "exchange" not in self.rem:
+            raise ValueError("The rem dictionary must contain either a 'method' entry or an 'exchange' entry")
         if "job_type" not in self.rem:
             raise ValueError("The rem dictionary must contain a 'job_type' entry")
         if self.rem.get("job_type").lower() not in valid_job_types:
@@ -194,6 +253,21 @@ class QCInput(InputFile):
         if self.geom_opt is not None:
             combined_list.append(self.geom_opt_template(self.geom_opt))
             combined_list.append("")
+        # cdft section
+        if self.cdft is not None:
+            combined_list.append(self.cdft_template(self.cdft))
+            combined_list.append("")
+        # almo section
+        if self.almo_coupling is not None:
+            combined_list.append(self.almo_template(self.almo_coupling))
+            combined_list.append("")
+        # svp section
+        if self.svp:
+            combined_list.append(self.svp_template(self.svp))
+            combined_list.append("")
+        # pcm_nonels section
+        if self.pcm_nonels:
+            combined_list.append(self.pcm_nonels_template(self.pcm_nonels))
         return "\n".join(combined_list)
 
     @staticmethod
@@ -228,16 +302,9 @@ class QCInput(InputFile):
         molecule = cls.read_molecule(string)
         rem = cls.read_rem(string)
         # only molecule and rem are necessary everything else is checked
-        opt = None
-        pcm = None
-        solvent = None
-        smx = None
-        scan = None
-        vdw = None
+        opt = pcm = solvent = smx = scan = vdw = None
         vdw_mode = "atomic"
-        plots = None
-        nbo = None
-        geom_opt = None
+        plots = nbo = geom_opt = cdft = almo_coupling = svp = pcm_nonels = None
         if "opt" in sections:
             opt = cls.read_opt(string)
         if "pcm" in sections:
@@ -256,6 +323,14 @@ class QCInput(InputFile):
             nbo = cls.read_nbo(string)
         if "geom_opt" in sections:
             geom_opt = cls.read_geom_opt(string)
+        if "cdft" in sections:
+            cdft = cls.read_cdft(string)
+        if "almo_coupling" in sections:
+            almo_coupling = cls.read_almo(string)
+        if "svp" in sections:
+            svp = cls.read_svp(string)
+        if "pcm_nonels" in sections:
+            pcm_nonels = cls.read_pcm_nonels(string)
         return cls(
             molecule,
             rem,
@@ -269,6 +344,10 @@ class QCInput(InputFile):
             plots=plots,
             nbo=nbo,
             geom_opt=geom_opt,
+            cdft=cdft,
+            almo_coupling=almo_coupling,
+            svp=svp,
+            pcm_nonels=pcm_nonels,
         )
 
     @staticmethod
@@ -287,6 +366,7 @@ class QCInput(InputFile):
     def from_file(filename: str | Path) -> QCInput:
         """
         Create QcInput from file.
+
         Args:
             filename (str): Filename
 
@@ -300,6 +380,7 @@ class QCInput(InputFile):
     def from_multi_jobs_file(cls, filename: str) -> list[QCInput]:
         """
         Create list of QcInput from a file.
+
         Args:
             filename (str): Filename
 
@@ -314,26 +395,45 @@ class QCInput(InputFile):
             return input_list
 
     @staticmethod
-    def molecule_template(molecule: Molecule | Literal["read"]) -> str:
+    def molecule_template(molecule: Molecule | list[Molecule] | Literal["read"]) -> str:
         """
         Args:
-            molecule (Molecule): molecule
+            molecule (Molecule, list of Molecules, or "read")
 
         Returns:
             (str) Molecule template.
+
         """
-        # todo: add ghost atoms
+        # TODO: add ghost atoms
         mol_list = []
         mol_list.append("$molecule")
+
+        # Edge case; can't express molecule as fragments with only one fragment
+        if isinstance(molecule, list) and len(molecule) == 1:
+            molecule = molecule[0]
+
         if isinstance(molecule, str):
             if molecule == "read":
                 mol_list.append(" read")
             else:
                 raise ValueError('The only acceptable text value for molecule is "read"')
-        else:
+        elif isinstance(molecule, Molecule):
             mol_list.append(f" {int(molecule.charge)} {molecule.spin_multiplicity}")
             for site in molecule.sites:
                 mol_list.append(f" {site.species_string}     {site.x: .10f}     {site.y: .10f}     {site.z: .10f}")
+        else:
+            overall_charge = sum(x.charge for x in molecule)
+            unpaired_electrons = sum(x.spin_multiplicity - 1 for x in molecule)
+            overall_spin = unpaired_electrons + 1
+
+            mol_list.append(f" {int(overall_charge)} {int(overall_spin)}")
+
+            for fragment in molecule:
+                mol_list.append("--")
+                mol_list.append(f" {int(fragment.charge)} {fragment.spin_multiplicity}")
+                for site in fragment.sites:
+                    mol_list.append(f" {site.species_string}     {site.x: .10f}     {site.y: .10f}     {site.z: .10f}")
+
         mol_list.append("$end")
         return "\n".join(mol_list)
 
@@ -429,6 +529,9 @@ class QCInput(InputFile):
         for key, value in smx.items():
             if value == "tetrahydrofuran":
                 smx_list.append(f"   {key} thf")
+            # Q-Chem bug, see https://talk.q-chem.com/t/smd-unrecognized-solvent/204
+            elif value == "dimethyl sulfoxide":
+                smx_list.append(f"   {key} dmso")
             else:
                 smx_list.append(f"   {key} {value}")
         smx_list.append("$end")
@@ -519,6 +622,27 @@ class QCInput(InputFile):
         nbo_list.append("$end")
         return "\n".join(nbo_list)
 
+    @staticmethod
+    def svp_template(svp: dict) -> str:
+        """
+        Template for the $svp section.
+
+        Args:
+            svp: dict of SVP parameters, e.g.
+            {"rhoiso": "0.001", "nptleb": "1202", "itrngr": "2", "irotgr": "2"}
+
+        Returns:
+            str: the $svp section. Note that all parameters will be concatenated onto
+                 a single line formatted as a FORTRAN namelist. This is necessary
+                 because the isodensity SS(V)PE model in Q-Chem calls a secondary code.
+        """
+        svp_list = []
+        svp_list.append("$svp")
+        param_list = [f"{_key}={value}" for _key, value in svp.items()]
+        svp_list.append(", ".join(param_list))
+        svp_list.append("$end")
+        return "\n".join(svp_list)
+
     @staticmethod
     def geom_opt_template(geom_opt: dict) -> str:
         """
@@ -526,7 +650,7 @@ class QCInput(InputFile):
             geom_opt ():
 
         Returns:
-            (str)
+            (str) geom_opt parameters.
         """
         geom_opt_list = []
         geom_opt_list.append("$geom_opt")
@@ -535,6 +659,108 @@ class QCInput(InputFile):
         geom_opt_list.append("$end")
         return "\n".join(geom_opt_list)
 
+    @staticmethod
+    def cdft_template(cdft: list[list[dict]]) -> str:
+        """
+        Args:
+            cdft: list of lists of dicts
+
+        Returns:
+            (str)
+        """
+        cdft_list = []
+        cdft_list.append("$cdft")
+        for ii, state in enumerate(cdft):
+            for constraint in state:
+                types = constraint["types"]
+                cdft_list.append(f"   {constraint['value']}")
+
+                type_strings = []
+                for typ in types:
+                    if typ is None or typ.lower() in ["c", "charge"]:
+                        type_strings.append("")
+                    elif typ.lower() in ["s", "spin"]:
+                        type_strings.append("s")
+                    else:
+                        raise ValueError("Invalid CDFT constraint type!")
+
+                for coef, first, last, type_string in zip(
+                    constraint["coefficients"], constraint["first_atoms"], constraint["last_atoms"], type_strings
+                ):
+                    if type_string != "":
+                        cdft_list.append(f"   {coef} {first} {last} {type_string}")
+                    else:
+                        cdft_list.append(f"   {coef} {first} {last}")
+            if len(cdft) != 1 and ii + 1 < len(state):
+                cdft_list.append("--------------")
+
+        # Ensure that you don't have a line indicating a state that doesn't exist
+        if cdft_list[-1] == "--------------":
+            del cdft_list[-1]
+
+        cdft_list.append("$end")
+        return "\n".join(cdft_list)
+
+    @staticmethod
+    def almo_template(almo_coupling: list[list[tuple[int, int]]]) -> str:
+        """
+        Args:
+            almo: list of lists of int 2-tuples
+
+        Returns:
+            (str)
+        """
+        almo_list = []
+        almo_list.append("$almo_coupling")
+
+        # ALMO coupling calculations always involve 2 states
+        if len(almo_coupling) != 2:
+            raise ValueError("ALMO coupling calculations require exactly two states!")
+
+        state_1 = almo_coupling[0]
+        state_2 = almo_coupling[1]
+
+        for frag in state_1:
+            # Casting to int probably unnecessary, given type hint
+            # Doesn't hurt, though
+            almo_list.append(f"   {int(frag[0])} {int(frag[1])}")
+        almo_list.append("   --")
+        for frag in state_2:
+            almo_list.append(f"   {int(frag[0])} {int(frag[1])}")
+
+        almo_list.append("$end")
+        return "\n".join(almo_list)
+
+    @staticmethod
+    def pcm_nonels_template(pcm_nonels: dict) -> str:
+        """
+        Template for the $pcm_nonels section.
+
+        Arg
+            pcm_nonels: dict of CMIRS parameters, e.g.
+            {
+                "a": "-0.006736",
+                "b": "0.032698",
+                "c": "-1249.6",
+                "d": "-21.405",
+                "gamma": "3.7",
+                "solvrho": "0.05",
+                "delta": 7,
+                "gaulag_n": 40,
+            }
+
+        Returns:
+            (str)
+        """
+        pcm_nonels_list = []
+        pcm_nonels_list.append("$pcm_nonels")
+        for key, value in pcm_nonels.items():
+            # if the value is None, don't write it to output
+            if value is not None:
+                pcm_nonels_list.append(f"   {key} {value}")
+        pcm_nonels_list.append("$end")
+        return "\n".join(pcm_nonels_list)
+
     @staticmethod
     def find_sections(string: str) -> list:
         """
@@ -562,7 +788,7 @@ class QCInput(InputFile):
         return sections
 
     @staticmethod
-    def read_molecule(string: str) -> Molecule | Literal["read"]:
+    def read_molecule(string: str) -> Molecule | list[Molecule] | Literal["read"]:
         """
         Read molecule from string.
 
@@ -572,12 +798,12 @@ class QCInput(InputFile):
         Returns:
             Molecule
         """
-        charge = None
-        spin_mult = None
+        charge = spin_mult = None
         patterns = {
             "read": r"^\s*\$molecule\n\s*(read)",
-            "charge": r"^\s*\$molecule\n\s*((?:\-)*\d+)\s+\d",
-            "spin_mult": r"^\s*\$molecule\n\s(?:\-)*\d+\s*(\d)",
+            "charge": r"^\s*\$molecule\n\s*((?:\-)*\d+)\s+\d+",
+            "spin_mult": r"^\s*\$molecule\n\s(?:\-)*\d+\s*((?:\-)*\d+)",
+            "fragment": r"^\s*\$molecule\n\s*(?:\-)*\d+\s+\d+\s*\n\s*(\-\-)",
         }
         matches = read_pattern(string, patterns)
         if "read" in matches:
@@ -586,17 +812,40 @@ class QCInput(InputFile):
             charge = float(matches["charge"][0][0])
         if "spin_mult" in matches:
             spin_mult = int(matches["spin_mult"][0][0])
-        header = r"^\s*\$molecule\n\s*(?:\-)*\d+\s*\d"
-        row = r"\s*((?i)[a-z]+)\s+([\d\-\.]+)\s+([\d\-\.]+)\s+([\d\-\.]+)"
-        footer = r"^\$end"
+        multi_mol = "fragment" in matches
+
+        if not multi_mol:
+            header = r"^\s*\$molecule\n\s*(?:\-)*\d+\s+(?:\-)*\d+"
+            row = r"\s*([A-Za-z]+)\s+([\d\-\.]+)\s+([\d\-\.]+)\s+([\d\-\.]+)"
+            footer = r"^\$end"
+            mol_table = read_table_pattern(string, header_pattern=header, row_pattern=row, footer_pattern=footer)
+            species = [val[0] for val in mol_table[0]]
+            coords = [[float(val[1]), float(val[2]), float(val[3])] for val in mol_table[0]]
+            if charge is None:
+                mol = Molecule(species=species, coords=coords)
+            else:
+                mol = Molecule(species=species, coords=coords, charge=charge, spin_multiplicity=spin_mult)
+            return mol
+
+        header = r"\s*(?:\-)*\d+\s+(?:\-)*\d+"
+        row = r"\s*([A-Za-z]+)\s+([\d\-\.]+)\s+([\d\-\.]+)\s+([\d\-\.]+)"
+        footer = r"(:?(:?\-\-)|(:?\$end))"
+
+        molecules = []
+
+        patterns = {"charge_spin": r"\s*\-\-\s*([\-0-9]+)\s+([\-0-9]+)"}
+        matches = read_pattern(string, patterns)
+
         mol_table = read_table_pattern(string, header_pattern=header, row_pattern=row, footer_pattern=footer)
-        species = [val[0] for val in mol_table[0]]
-        coords = [[float(val[1]), float(val[2]), float(val[3])] for val in mol_table[0]]
-        if charge is None:
-            mol = Molecule(species=species, coords=coords)
-        else:
-            mol = Molecule(species=species, coords=coords, charge=charge, spin_multiplicity=spin_mult)
-        return mol
+        for match, table in zip(matches.get("charge_spin"), mol_table):
+            charge = int(match[0])
+            spin = int(match[1])
+            species = [val[0] for val in table]
+            coords = [[float(val[1]), float(val[2]), float(val[3])] for val in table]
+            mol = Molecule(species=species, coords=coords, charge=charge, spin_multiplicity=spin)
+            molecules.append(mol)
+
+        return molecules
 
     @staticmethod
     def read_rem(string: str) -> dict:
@@ -716,10 +965,7 @@ class QCInput(InputFile):
             print("No valid vdW inputs found. Note that there should be no '=' characters in vdW input lines.")
             return "", {}
 
-        if vdw_table[0][0][0] == 2:
-            mode = "sequential"
-        else:
-            mode = "atomic"
+        mode = "sequential" if vdw_table[0][0][0] == 2 else "atomic"
 
         return mode, dict(vdw_table[0][1:])
 
@@ -767,6 +1013,9 @@ class QCInput(InputFile):
             smx[key] = val
         if smx["solvent"] == "tetrahydrofuran":
             smx["solvent"] = "thf"
+        # Q-Chem bug, see https://talk.q-chem.com/t/smd-unrecognized-solvent/204
+        elif smx["solvent"] == "dimethyl sulfoxide":
+            smx["solvent"] = "dmso"
         return smx
 
     @staticmethod
@@ -839,7 +1088,7 @@ class QCInput(InputFile):
             (dict) nbo parameters.
         """
         header = r"^\s*\$nbo"
-        row = r"\s*([a-zA-Z\_]+)\s*=?\s*(\S+)"
+        row = r"\s*([a-zA-Z\_\d]+)\s*=?\s*(\S+)"
         footer = r"^\s*\$end"
         nbo_table = read_table_pattern(string, header_pattern=header, row_pattern=row, footer_pattern=footer)
         if nbo_table == []:
@@ -872,3 +1121,141 @@ class QCInput(InputFile):
         for key, val in geom_opt_table[0]:
             geom_opt[key] = val
         return geom_opt
+
+    @staticmethod
+    def read_cdft(string: str) -> list[list[dict]]:
+        """
+        Read cdft parameters from string.
+
+        Args:
+            string (str): String
+
+        Returns:
+             (list of lists of dicts) cdft parameters
+        """
+        pattern_sec = {
+            "full_section": r"\$cdft((:?(:?\s*[0-9\.\-]+\s+[0-9]+\s+[0-9]+(:?\s+[A-Za-z]+)?\s*\n)+|"
+            r"(:?\s*[0-9\.\-]+\s*\n)|(:?\s*\-+\s*\n))+)\$end"
+        }
+
+        pattern_const = {
+            "constraint": r"\s*([\-\.0-9]+)\s*\n((?:\s*(?:[\-\.0-9]+)\s+(?:\d+)\s+(?:\d+)(?:\s+[A-Za-z]+)?\s*)+)"
+        }
+
+        section = read_pattern(string, pattern_sec)["full_section"]
+        if len(section) == 0:
+            print("No valid cdft inputs found.")
+            return []
+
+        cdft = []
+        section = section[0][0]
+        states = re.split(r"\-{2,25}", section)
+        for state in states:
+            state_list = []
+            const_out = list(read_pattern(state, pattern_const).get("constraint"))
+            if len(const_out) == 0:
+                continue
+            for const in const_out:
+                const_dict = {
+                    "value": float(const[0]),
+                    "coefficients": [],
+                    "first_atoms": [],
+                    "last_atoms": [],
+                    "types": [],
+                }  # type: ignore
+                subconsts = const[1].strip().split("\n")
+                for subconst in subconsts:
+                    tokens = subconst.split()
+                    const_dict["coefficients"].append(float(tokens[0]))  # type: ignore
+                    const_dict["first_atoms"].append(int(tokens[1]))  # type: ignore
+                    const_dict["last_atoms"].append(int(tokens[2]))  # type: ignore
+                    if len(tokens) > 3:
+                        const_dict["types"].append(tokens[3])  # type: ignore
+                    else:
+                        const_dict["types"].append(None)  # type: ignore
+
+                state_list.append(const_dict)
+
+            cdft.append(state_list)
+
+        return cdft
+
+    @staticmethod
+    def read_almo(string: str) -> list[list[tuple[int, int]]]:
+        """
+        Read ALMO coupling parameters from string.
+
+        Args:
+            string (str): String
+
+        Returns:
+            (list of lists of int 2-tuples) almo_coupling parameters
+        """
+        pattern = {
+            "key": r"\$almo_coupling\s*\n((?:\s*[\-0-9]+\s+[\-0-9]+\s*\n)+)\s*\-\-"
+            r"((?:\s*[\-0-9]+\s+[\-0-9]+\s*\n)+)\s*\$end"
+        }
+
+        section = read_pattern(string, pattern)["key"]
+
+        if len(section) == 0:
+            print("No valid almo inputs found.")
+            return []
+
+        section = section[0]
+
+        almo_coupling = [[], []]  # type: ignore
+
+        state_1 = section[0]
+        for line in state_1.strip().split("\n"):
+            contents = line.split()
+            almo_coupling[0].append((int(contents[0]), int(contents[1])))
+
+        state_2 = section[1]
+        for line in state_2.strip().split("\n"):
+            contents = line.split()
+            almo_coupling[1].append((int(contents[0]), int(contents[1])))
+
+        return almo_coupling
+
+    @staticmethod
+    def read_svp(string: str) -> dict:
+        """
+        Read svp parameters from string.
+        """
+        header = r"^\s*\$svp"
+        row = r"(\w.*)\n"
+        footer = r"^\s*\$end"
+        svp_table = read_table_pattern(string, header_pattern=header, row_pattern=row, footer_pattern=footer)
+        if svp_table == []:
+            print("No valid svp inputs found.")
+            return {}
+        svp_list = svp_table[0][0][0].split(", ")
+        svp_dict = {}
+        for s in svp_list:
+            svp_dict[s.split("=")[0]] = s.split("=")[1]
+        return svp_dict
+
+    @staticmethod
+    def read_pcm_nonels(string: str) -> dict:
+        """
+        Read pcm_nonels parameters from string.
+
+        Args:
+            string (str): String
+
+        Returns:
+            (dict) PCM parameters
+        """
+        header = r"^\s*\$pcm_nonels"
+        row = r"\s*([a-zA-Z\_]+)\s+(.+)"
+        footer = r"^\s*\$end"
+        pcm_nonels_table = read_table_pattern(string, header_pattern=header, row_pattern=row, footer_pattern=footer)
+        if not pcm_nonels_table:
+            print(
+                "No valid $pcm_nonels inputs found. Note that there should be no '=' "
+                "characters in $pcm_nonels input lines."
+            )
+            return {}
+
+        return dict(pcm_nonels_table[0])
