@@ -1,4 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
 # Distributed under the terms of the MIT License
 
 """
@@ -36,7 +35,7 @@ class Control(MSONable, dict):
     detailed description and default values of CONTROL arguments.
     """
 
-    required_params = [
+    required_params = data_keys = (
         "nelements",
         "natoms",
         "ngrid",
@@ -45,9 +44,9 @@ class Control(MSONable, dict):
         "elements",
         "positions",
         "scell",
-    ]
-    allocations_keys = ["nelements", "natoms", "ngrid", "norientations"]
-    crystal_keys = [
+    )
+    allocations_keys = ("nelements", "natoms", "ngrid", "norientations")
+    crystal_keys = (
         "lfactor",
         "lattvec",
         "types",
@@ -59,8 +58,8 @@ class Control(MSONable, dict):
         "born",
         "scell",
         "orientations",
-    ]
-    params_keys = [
+    )
+    params_keys = (
         "t",
         "t_min",
         "t_max",
@@ -73,8 +72,8 @@ class Control(MSONable, dict):
         "maxiter",
         "nticks",
         "eps",
-    ]
-    flags_keys = [
+    )
+    flags_keys = (
         "nonanalytic",
         "convergence",
         "isotopes",
@@ -82,7 +81,7 @@ class Control(MSONable, dict):
         "nanowires",
         "onlyharmonic",
         "espresso",
-    ]
+    )
 
     def __init__(self, ngrid: list[int] | None = None, temperature: float | dict[str, float] = 300, **kwargs):
         """
@@ -181,7 +180,7 @@ class Control(MSONable, dict):
         """
         for param in self.required_params:
             if param not in self.as_dict():
-                warnings.warn(f"Required parameter '{param}' not specified!")
+                warnings.warn(f"Required parameter {param!r} not specified!")
 
         alloc_dict = _get_subdict(self, self.allocations_keys)
         alloc_nml = f90nml.Namelist({"allocations": alloc_dict})
@@ -270,7 +269,7 @@ class Control(MSONable, dict):
 
     def as_dict(self):
         """
-        Returns: MSONAble dict
+        Returns: MSONable dict
         """
         return dict(self)
 
