@@ -1,7 +1,11 @@
+from __future__ import annotations
+
 import os
 import unittest
 from os.path import join
 
+from pytest import approx
+
 from pymatgen.core.structure import Molecule
 from pymatgen.io.adf import AdfInput, AdfKey, AdfOutput, AdfTask
 from pymatgen.util.testing import PymatgenTest
@@ -75,7 +79,7 @@ def readfile(file_object):
     file_object : file or str
         The file to read. This can be either a File object or a file path.
 
-    Returns
+    Returns:
     -------
     content : str
         The content of the file.
@@ -83,24 +87,23 @@ def readfile(file_object):
     """
     if hasattr(file_object, "read"):
         return file_object.read()
-    elif isinstance(file_object, str):
+    if isinstance(file_object, str):
         with open(file_object) as f:
             content = f.read()
         return content
-    else:
-        raise ValueError("``file_object`` must be a string or a file object!")
+    raise ValueError("``file_object`` must be a string or a file object!")
 
 
 class AdfKeyTest(unittest.TestCase):
     def test_simple(self):
         unrestricted = AdfKey("unrestricted")
-        self.assertEqual(str(unrestricted).strip(), "UNRESTRICTED")
+        assert str(unrestricted).strip() == "UNRESTRICTED"
 
     def test_options(self):
         charge = AdfKey("charge", [-1, 0])
         charge_string = "CHARGE -1 0\n"
-        self.assertEqual(str(charge), "CHARGE -1 0\n")
-        self.assertEqual(str(AdfKey.from_dict(charge.as_dict())), charge_string)
+        assert str(charge) == "CHARGE -1 0\n"
+        assert str(AdfKey.from_dict(charge.as_dict())) == charge_string
 
     def test_subkeys(self):
         smooth = AdfKey("smooth", ["conservepoints"])
@@ -113,34 +116,34 @@ class AdfKeyTest(unittest.TestCase):
             [("e", 1.0e-3), ("grad", 3.0e-4), ("rad", 1.0e-2), ("angle", 0.5)],
         )
         geo = AdfKey("geometry", subkeys=[smooth, optim, iterations, step, hessupd, converge])
-        self.assertEqual(str(geo), geometry_string)
-        self.assertEqual(str(AdfKey.from_dict(geo.as_dict())), geometry_string)
-        self.assertTrue(geo.has_subkey("optim"))
+        assert str(geo) == geometry_string
+        assert str(AdfKey.from_dict(geo.as_dict())) == geometry_string
+        assert geo.has_subkey("optim")
 
     def test_end(self):
         geo = AdfKey("Geometry")
-        self.assertEqual(str(geo), "GEOMETRY\nEND\n")
+        assert str(geo) == "GEOMETRY\nEND\n"
 
     def test_subkeys_subkeys(self):
         atom_dep_quality = AdfKey("AtomDepQuality", subkeys=[AdfKey("10", ["good"]), AdfKey("12", ["normal"])])
         zlmfit = AdfKey("zlmfit", subkeys=[atom_dep_quality])
-        self.assertEqual(str(zlmfit), zlmfit_string)
-        self.assertEqual(str(AdfKey.from_dict(zlmfit.as_dict())), zlmfit_string)
+        assert str(zlmfit) == zlmfit_string
+        assert str(AdfKey.from_dict(zlmfit.as_dict())) == zlmfit_string
 
     def test_from_string(self):
         k1 = AdfKey.from_string("CHARGE -1 0")
-        self.assertEqual(k1.key, "CHARGE")
-        self.assertListEqual(k1.options, [-1, 0])
+        assert k1.key == "CHARGE"
+        assert k1.options == [-1, 0]
 
         k2 = AdfKey.from_string("step rad=0.15 angle=10.0")
-        self.assertEqual(k2.key, "step")
-        self.assertListEqual(k2.options[0], ["rad", 0.15])
-        self.assertListEqual(k2.options[1], ["angle", 10.0])
+        assert k2.key == "step"
+        assert k2.options[0] == ["rad", 0.15]
+        assert k2.options[1] == ["angle", 10.0]
 
         k3 = AdfKey.from_string("GEOMETRY\noptim all\niterations 100\nEND\n")
-        self.assertEqual(k3.key, "GEOMETRY")
-        self.assertEqual(k3.subkeys[0].options[0], "all")
-        self.assertEqual(k3.subkeys[1].options[0], 100)
+        assert k3.key == "GEOMETRY"
+        assert k3.subkeys[0].options[0] == "all"
+        assert k3.subkeys[1].options[0] == 100
 
         k4 = AdfKey.from_string(
             """SCF
@@ -150,31 +153,31 @@ class AdfKeyTest(unittest.TestCase):
             diis n=100 ok=0.0001 cyc=100 cx=5.0 cxx=10.0
             END"""
         )
-        self.assertEqual(k4.key, "SCF")
-        self.assertEqual(k4.subkeys[0].key, "iterations")
-        self.assertEqual(k4.subkeys[1].key, "converge")
-        self.assertEqual(k4.subkeys[1].options[0], 1e-7)
-        self.assertEqual(k4.subkeys[2].options[0], 0.2)
+        assert k4.key == "SCF"
+        assert k4.subkeys[0].key == "iterations"
+        assert k4.subkeys[1].key == "converge"
+        assert k4.subkeys[1].options[0] == 1e-7
+        assert k4.subkeys[2].options[0] == 0.2
 
     def test_option_operations(self):
         k1 = AdfKey("Charge", [-1, 0])
         k1.add_option(2)
-        self.assertListEqual(k1.options, [-1, 0, 2])
+        assert k1.options == [-1, 0, 2]
         k1.remove_option(0)
-        self.assertListEqual(k1.options, [0, 2])
+        assert k1.options == [0, 2]
 
         k2 = AdfKey.from_string("step rad=0.15 angle=10.0")
         k2.add_option(["length", 0.1])
-        self.assertListEqual(k2.options[2], ["length", 0.1])
+        assert k2.options[2] == ["length", 0.1]
         k2.remove_option("rad")
-        self.assertListEqual(k2.options[0], ["angle", 10.0])
+        assert k2.options[0] == ["angle", 10.0]
 
     def test_atom_block_key(self):
         block = AdfKey("atoms")
         o = Molecule.from_str(h2oxyz, "xyz")
         for site in o:
             block.add_subkey(AdfKey(str(site.specie), list(site.coords)))
-        self.assertEqual(str(block), atoms_string)
+        assert str(block) == atoms_string
 
 
 energy_task = """TITLE ADF_RUN
@@ -206,18 +209,18 @@ END
 class AdfTaskTest(unittest.TestCase):
     def test_energy(self):
         task = AdfTask()
-        self.assertEqual(str(task), energy_task)
+        assert str(task) == energy_task
 
     def test_serialization(self):
         task = AdfTask()
         o = AdfTask.from_dict(task.as_dict())
-        self.assertEqual(task.title, o.title)
-        self.assertEqual(task.basis_set, o.basis_set)
-        self.assertEqual(task.scf, o.scf)
-        self.assertEqual(task.geo, o.geo)
-        self.assertEqual(task.operation, o.operation)
-        self.assertEqual(task.units, o.units)
-        self.assertEqual(str(task), str(o))
+        assert task.title == o.title
+        assert task.basis_set == o.basis_set
+        assert task.scf == o.scf
+        assert task.geo == o.geo
+        assert task.operation == o.operation
+        assert task.units == o.units
+        assert str(task) == str(o)
 
 
 rhb18 = {
@@ -261,7 +264,7 @@ class AdfInputTest(unittest.TestCase):
         inp = AdfInput(task)
         inp.write_file(o, self.tempfile)
         s = readfile(join(test_dir, "adf", "RhB18_adf.inp"))
-        self.assertEqual(readfile(self.tempfile), s)
+        assert readfile(self.tempfile) == s
 
     def tearDown(self):
         if os.path.isfile(self.tempfile):
@@ -272,38 +275,34 @@ class AdfOutputTest(unittest.TestCase):
     def test_analytical_freq(self):
         filename = join(test_dir, "adf", "analytical_freq", "adf.out")
         o = AdfOutput(filename)
-        self.assertAlmostEqual(o.final_energy, -0.54340325)
-        self.assertEqual(len(o.energies), 4)
-        self.assertEqual(len(o.structures), 4)
-        self.assertAlmostEqual(o.frequencies[0], 1553.931)
-        self.assertAlmostEqual(o.frequencies[2], 3793.086)
-        self.assertAlmostEqual(o.normal_modes[0][2], 0.071)
-        self.assertAlmostEqual(o.normal_modes[0][6], 0.000)
-        self.assertAlmostEqual(o.normal_modes[0][7], -0.426)
-        self.assertAlmostEqual(o.normal_modes[0][8], -0.562)
+        assert o.final_energy == approx(-0.54340325)
+        assert len(o.energies) == 4
+        assert len(o.structures) == 4
+        assert o.frequencies[0] == approx(1553.931)
+        assert o.frequencies[2] == approx(3793.086)
+        assert o.normal_modes[0][2] == approx(0.071)
+        assert o.normal_modes[0][6] == approx(0.000)
+        assert o.normal_modes[0][7] == approx(-0.426)
+        assert o.normal_modes[0][8] == approx(-0.562)
 
     def test_numerical_freq(self):
         filename = join(test_dir, "adf", "numerical_freq", "adf.out")
         o = AdfOutput(filename)
-        self.assertEqual(o.freq_type, "Numerical")
-        self.assertEqual(o.final_structure.num_sites, 4)
-        self.assertEqual(len(o.frequencies), 6)
-        self.assertEqual(len(o.normal_modes), 6)
-        self.assertAlmostEqual(o.frequencies[0], 938.21)
-        self.assertAlmostEqual(o.frequencies[3], 3426.64)
-        self.assertAlmostEqual(o.frequencies[4], 3559.35)
-        self.assertAlmostEqual(o.frequencies[5], 3559.35)
-        self.assertAlmostEqual(o.normal_modes[1][0], 0.067)
-        self.assertAlmostEqual(o.normal_modes[1][3], -0.536)
-        self.assertAlmostEqual(o.normal_modes[1][7], 0.000)
-        self.assertAlmostEqual(o.normal_modes[1][9], -0.536)
+        assert o.freq_type == "Numerical"
+        assert o.final_structure.num_sites == 4
+        assert len(o.frequencies) == 6
+        assert len(o.normal_modes) == 6
+        assert o.frequencies[0] == approx(938.21)
+        assert o.frequencies[3] == approx(3426.64)
+        assert o.frequencies[4] == approx(3559.35)
+        assert o.frequencies[5] == approx(3559.35)
+        assert o.normal_modes[1][0] == approx(0.067)
+        assert o.normal_modes[1][3] == approx(-0.536)
+        assert o.normal_modes[1][7] == approx(0.000)
+        assert o.normal_modes[1][9] == approx(-0.536)
 
     def test_single_point(self):
         filename = join(test_dir, "adf", "sp", "adf.out")
         o = AdfOutput(filename)
-        self.assertAlmostEqual(o.final_energy, -0.74399276)
-        self.assertEqual(len(o.final_structure), 4)
-
-
-if __name__ == "__main__":
-    unittest.main()
+        assert o.final_energy == approx(-0.74399276)
+        assert len(o.final_structure) == 4
