@@ -1,11 +1,11 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
+from __future__ import annotations
 
 import unittest
 import warnings
 
 import numpy as np
+import pytest
+from pytest import approx
 
 from pymatgen.analysis.structure_matcher import StructureMatcher
 from pymatgen.core.composition import Composition
@@ -109,17 +109,17 @@ loop_
   C1  C0+  2  b  0  0  0.25  .  1.  0
   C2  C0+  2  c  0.3333  0.6667  0.25  .  1.  0"""
         for l1, l2, l3 in zip(str(c).split("\n"), cif_str.split("\n"), cif_str_2.split("\n")):
-            self.assertEqual(l1.strip(), l2.strip())
-            self.assertEqual(l2.strip(), l3.strip())
+            assert l1.strip() == l2.strip()
+            assert l2.strip() == l3.strip()
 
     def test_double_quotes_and_underscore_data(self):
         cif_str = """data_test
 _symmetry_space_group_name_H-M   "P -3 m 1"
 _thing   '_annoying_data'"""
         cb = CifBlock.from_string(cif_str)
-        self.assertEqual(cb["_symmetry_space_group_name_H-M"], "P -3 m 1")
-        self.assertEqual(cb["_thing"], "_annoying_data")
-        self.assertEqual(str(cb), cif_str.replace('"', "'"))
+        assert cb["_symmetry_space_group_name_H-M"] == "P -3 m 1"
+        assert cb["_thing"] == "_annoying_data"
+        assert str(cb) == cif_str.replace('"', "'")
 
     def test_double_quoted_data(self):
         cif_str = """data_test
@@ -127,9 +127,9 @@ _thing   ' '_annoying_data''
 _other   " "_more_annoying_data""
 _more   ' "even more" ' """
         cb = CifBlock.from_string(cif_str)
-        self.assertEqual(cb["_thing"], " '_annoying_data'")
-        self.assertEqual(cb["_other"], ' "_more_annoying_data"')
-        self.assertEqual(cb["_more"], ' "even more" ')
+        assert cb["_thing"] == " '_annoying_data'"
+        assert cb["_other"] == ' "_more_annoying_data"'
+        assert cb["_more"] == ' "even more" '
 
     def test_nested_fake_multiline_quotes(self):
         cif_str = """data_test
@@ -142,10 +142,7 @@ long quotes
 actually going to end now
 ;"""
         cb = CifBlock.from_string(cif_str)
-        self.assertEqual(
-            cb["_thing"],
-            " long quotes  ;  still in the quote  ; actually going to end now",
-        )
+        assert cb["_thing"] == " long quotes  ;  still in the quote  ; actually going to end now"
 
     def test_long_loop(self):
         data = {
@@ -163,18 +160,18 @@ loop_
   CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
   AAAAAAAAAAAAAAAAAAAAAAAAAAAAAA  BBBBBBBBBBBBBBBBBBBBBBBBBBBBBB
   CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC"""
-        self.assertEqual(str(CifBlock(data, loops, "test")), cif_str)
+        assert str(CifBlock(data, loops, "test")) == cif_str
 
 
 class CifIOTest(PymatgenTest):
     def test_CifParser(self):
         parser = CifParser(self.TEST_FILES_DIR / "LiFePO4.cif")
         for s in parser.get_structures(True):
-            self.assertEqual(s.formula, "Li4 Fe4 P4 O16", "Incorrectly parsed cif.")
+            assert s.formula == "Li4 Fe4 P4 O16", "Incorrectly parsed cif."
 
         parser = CifParser(self.TEST_FILES_DIR / "V2O3.cif")
         for s in parser.get_structures(True):
-            self.assertEqual(s.formula, "V4 O6")
+            assert s.formula == "V4 O6"
 
         bibtex_str = """
 @article{cifref0,
@@ -186,18 +183,18 @@ class CifIOTest(PymatgenTest):
     pages = "1599--1606"
 }
         """
-        self.assertEqual(parser.get_bibtex_string().strip(), bibtex_str.strip())
+        assert parser.get_bibtex_string().strip() == bibtex_str.strip()
 
         parser = CifParser(self.TEST_FILES_DIR / "Li2O.cif")
         prim = parser.get_structures(True)[0]
-        self.assertEqual(prim.formula, "Li2 O1")
+        assert prim.formula == "Li2 O1"
         conv = parser.get_structures(False)[0]
-        self.assertEqual(conv.formula, "Li8 O4")
+        assert conv.formula == "Li8 O4"
 
         # test for disordered structures
         parser = CifParser(self.TEST_FILES_DIR / "Li10GeP2S12.cif")
         for s in parser.get_structures(True):
-            self.assertEqual(s.formula, "Li20.2 Ge2.06 P3.94 S24", "Incorrectly parsed cif.")
+            assert s.formula == "Li20.2 Ge2.06 P3.94 S24", "Incorrectly parsed cif."
         cif_str = r"""#\#CIF1.1
 ##########################################################################
 #               Crystallographic Information Format file
@@ -272,57 +269,55 @@ loop_
 """
         parser = CifParser.from_string(cif_str)
         struct = parser.get_structures(primitive=False)[0]
-        self.assertEqual(struct.formula, "Fe4 P4 O16")
-        self.assertAlmostEqual(struct.lattice.a, 10.4117668699)
-        self.assertAlmostEqual(struct.lattice.b, 6.06717187997)
-        self.assertAlmostEqual(struct.lattice.c, 4.75948953998)
-        self.assertAlmostEqual(struct.lattice.alpha, 91)
-        self.assertAlmostEqual(struct.lattice.beta, 92)
-        self.assertAlmostEqual(struct.lattice.gamma, 93)
+        assert struct.formula == "Fe4 P4 O16"
+        assert struct.lattice.a == approx(10.4117668699)
+        assert struct.lattice.b == approx(6.06717187997)
+        assert struct.lattice.c == approx(4.75948953998)
+        assert struct.lattice.alpha == approx(91)
+        assert struct.lattice.beta == approx(92)
+        assert struct.lattice.gamma == approx(93)
 
         with warnings.catch_warnings():
             warnings.simplefilter("ignore")
             parser = CifParser(self.TEST_FILES_DIR / "srycoo.cif")
-        self.assertEqual(parser.get_structures()[0].formula, "Sr5.6 Y2.4 Co8 O21")
+        assert parser.get_structures()[0].formula == "Sr5.6 Y2.4 Co8 O21"
 
         # Test with a decimal Xyz. This should parse as two atoms in
         # conventional cell if it is correct, one if not.
         parser = CifParser(self.TEST_FILES_DIR / "Fe.cif")
-        self.assertEqual(len(parser.get_structures(primitive=False)[0]), 2)
-        self.assertFalse(parser.has_errors)
+        assert len(parser.get_structures(primitive=False)[0]) == 2
+        assert not parser.has_errors
 
     def test_get_symmetrized_structure(self):
         parser = CifParser(self.TEST_FILES_DIR / "Li2O.cif")
         sym_structure = parser.get_structures(primitive=False, symmetrized=True)[0]
         structure = parser.get_structures(primitive=False, symmetrized=False)[0]
-        self.assertIsInstance(sym_structure, SymmetrizedStructure)
-        self.assertEqual(structure, sym_structure)
-        self.assertEqual(sym_structure.equivalent_indices, [[0, 1, 2, 3], [4, 5, 6, 7, 8, 9, 10, 11]])
+        assert isinstance(sym_structure, SymmetrizedStructure)
+        assert structure == sym_structure
+        assert sym_structure.equivalent_indices == [[0, 1, 2, 3], [4, 5, 6, 7, 8, 9, 10, 11]]
 
     def test_site_symbol_preference(self):
         parser = CifParser(self.TEST_FILES_DIR / "site_type_symbol_test.cif")
-        self.assertEqual(parser.get_structures()[0].formula, "Ge0.4 Sb0.4 Te1")
+        assert parser.get_structures()[0].formula == "Ge0.4 Sb0.4 Te1"
 
     def test_implicit_hydrogen(self):
         with warnings.catch_warnings():
             warnings.simplefilter("ignore")
             parser = CifParser(self.TEST_FILES_DIR / "Senegalite_implicit_hydrogen.cif")
             for s in parser.get_structures():
-                self.assertEqual(s.formula, "Al8 P4 O32")
-                self.assertEqual(sum(s.site_properties["implicit_hydrogens"]), 20)
-            self.assertIn(
+                assert s.formula == "Al8 P4 O32"
+                assert sum(s.site_properties["implicit_hydrogens"]) == 20
+            assert (
                 "Structure has implicit hydrogens defined, "
                 "parsed structure unlikely to be suitable for use "
-                "in calculations unless hydrogens added.",
-                parser.warnings,
+                "in calculations unless hydrogens added." in parser.warnings
             )
             parser = CifParser(self.TEST_FILES_DIR / "cif_implicit_hydrogens_cod_1011130.cif")
             s = parser.get_structures()[0]
-            self.assertIn(
+            assert (
                 "Structure has implicit hydrogens defined, "
                 "parsed structure unlikely to be suitable for use "
-                "in calculations unless hydrogens added.",
-                parser.warnings,
+                "in calculations unless hydrogens added." in parser.warnings
             )
 
     def test_CifParserSpringerPauling(self):
@@ -333,38 +328,38 @@ loop_
             # Partial occupancy on sites, incorrect label, previously unparsable
             parser = CifParser(self.TEST_FILES_DIR / "PF_sd_1928405.cif")
             for s in parser.get_structures(True):
-                self.assertEqual(s.formula, "Er1 Mn3.888 Fe2.112 Sn6")
-            self.assertTrue(parser.has_errors)
+                assert s.formula == "Er1 Mn3.888 Fe2.112 Sn6"
+            assert parser.has_errors
 
             # Partial occupancy on sites, previously parsed as an ordered structure
             parser = CifParser(self.TEST_FILES_DIR / "PF_sd_1011081.cif")
             for s in parser.get_structures(True):
-                self.assertEqual(s.formula, "Zr0.2 Nb0.8")
-            self.assertTrue(parser.has_errors)
+                assert s.formula == "Zr0.2 Nb0.8"
+            assert parser.has_errors
 
             # Partial occupancy on sites, incorrect label, previously unparsable
             parser = CifParser(self.TEST_FILES_DIR / "PF_sd_1615854.cif")
             for s in parser.get_structures(True):
-                self.assertEqual(s.formula, "Na2 Al2 Si6 O16")
-            self.assertTrue(parser.has_errors)
+                assert s.formula == "Na2 Al2 Si6 O16"
+            assert parser.has_errors
 
             # Partial occupancy on sites, incorrect label, previously unparsable
             parser = CifParser(self.TEST_FILES_DIR / "PF_sd_1622133.cif")
             for s in parser.get_structures(True):
-                self.assertEqual(s.formula, "Ca0.184 Mg13.016 Fe2.8 Si16 O48")
-            self.assertTrue(parser.has_errors)
+                assert s.formula == "Ca0.184 Mg13.016 Fe2.8 Si16 O48"
+            assert parser.has_errors
 
             # Partial occupancy on sites, previously parsed as an ordered structure
             parser = CifParser(self.TEST_FILES_DIR / "PF_sd_1908491.cif")
             for s in parser.get_structures(True):
-                self.assertEqual(s.formula, "Mn0.48 Zn0.52 Ga2 Se4")
-            self.assertTrue(parser.has_errors)
+                assert s.formula == "Mn0.48 Zn0.52 Ga2 Se4"
+            assert parser.has_errors
 
             # Partial occupancy on sites, incorrect label, previously unparsable
             parser = CifParser(self.TEST_FILES_DIR / "PF_sd_1811457.cif")
             for s in parser.get_structures(True):
-                self.assertEqual(s.formula, "Ba2 Mg0.6 Zr0.2 Ta1.2 O6")
-            self.assertTrue(parser.has_errors)
+                assert s.formula == "Ba2 Mg0.6 Zr0.2 Ta1.2 O6"
+            assert parser.has_errors
 
             # Incomplete powder diffraction data, previously unparsable
             # This CIF file contains the molecular species "NH3" which is
@@ -373,26 +368,26 @@ loop_
             # in CIFs from Springer Materials/Pauling file DBs, CifParser parses the
             # element as "Nh" (Nihonium).
             parser = CifParser(self.TEST_FILES_DIR / "PF_sd_1002871.cif")
-            self.assertEqual(parser.get_structures(True)[0].formula, "Cu1 Br2 Nh6")
-            self.assertEqual(parser.get_structures(True)[1].formula, "Cu1 Br4 Nh6")
-            self.assertTrue(parser.has_errors)
+            assert parser.get_structures(True)[0].formula == "Cu1 Br2 Nh6"
+            assert parser.get_structures(True)[1].formula == "Cu1 Br4 Nh6"
+            assert parser.has_errors
 
             # Incomplete powder diffraction data, previously unparsable
             parser = CifParser(self.TEST_FILES_DIR / "PF_sd_1704003.cif")
             for s in parser.get_structures():
-                self.assertEqual(s.formula, "Rb4 Mn2 F12")
-            self.assertTrue(parser.has_errors)
+                assert s.formula == "Rb4 Mn2 F12"
+            assert parser.has_errors
 
             # Unparsable species 'OH/OH2', previously parsed as "O"
             parser = CifParser(self.TEST_FILES_DIR / "PF_sd_1500382.cif")
             for s in parser.get_structures():
-                self.assertEqual(s.formula, "Mg6 B2 O6 F1.764")
-            self.assertTrue(parser.has_errors)
+                assert s.formula == "Mg6 B2 O6 F1.764"
+            assert parser.has_errors
 
             # Unparsable species 'OH/OH2', previously parsed as "O"
             parser = CifParser(self.TEST_FILES_DIR / "PF_sd_1601634.cif")
             for s in parser.get_structures():
-                self.assertEqual(s.formula, "Zn1.29 Fe0.69 As2 Pb1.02 O8")
+                assert s.formula == "Zn1.29 Fe0.69 As2 Pb1.02 O8"
 
     def test_CifParserCod(self):
         """
@@ -404,12 +399,12 @@ loop_
             # Symbol in capital letters
             parser = CifParser(self.TEST_FILES_DIR / "Cod_2100513.cif")
             for s in parser.get_structures(True):
-                self.assertEqual(s.formula, "Ca4 Nb2.0 Al2 O12")
+                assert s.formula == "Ca4 Nb2.0 Al2 O12"
 
             # Label in capital letters
             parser = CifParser(self.TEST_FILES_DIR / "Cod_4115344.cif")
             for s in parser.get_structures(True):
-                self.assertEqual(s.formula, "Mo4 P2 H60 C60 I4 O4")
+                assert s.formula == "Mo4 P2 H60 C60 I4 O4"
 
     def test_parse_symbol(self):
         """
@@ -469,7 +464,7 @@ loop_
             warnings.simplefilter("ignore")
             parser = CifParser(self.TEST_FILES_DIR / "LiFePO4.cif")
             for sym, expected_symbol in test_cases.items():
-                self.assertEqual(parser._parse_symbol(sym), expected_symbol)
+                assert parser._parse_symbol(sym) == expected_symbol
 
     def test_CifWriter(self):
         filepath = self.TEST_FILES_DIR / "POSCAR"
@@ -493,21 +488,13 @@ loop_
  _symmetry_equiv_pos_site_id
  _symmetry_equiv_pos_as_xyz
   1  'x, y, z'
-  2  'x, y, z'
-  3  '-x, -y, -z'
-  4  '-x, -y, -z'
-  5  '-x+1/2, -y, z+1/2'
-  6  '-x+1/2, -y, z+1/2'
-  7  'x+1/2, y, -z+1/2'
-  8  'x+1/2, y, -z+1/2'
-  9  'x+1/2, -y+1/2, -z+1/2'
-  10  'x+1/2, -y+1/2, -z+1/2'
-  11  '-x+1/2, y+1/2, z+1/2'
-  12  '-x+1/2, y+1/2, z+1/2'
-  13  '-x, y+1/2, -z'
-  14  '-x, y+1/2, -z'
-  15  'x, -y+1/2, z'
-  16  'x, -y+1/2, z'
+  2  '-x, -y, -z'
+  3  '-x+1/2, -y, z+1/2'
+  4  'x+1/2, y, -z+1/2'
+  5  'x+1/2, -y+1/2, -z+1/2'
+  6  '-x+1/2, y+1/2, z+1/2'
+  7  '-x, y+1/2, -z'
+  8  'x, -y+1/2, z'
 loop_
  _atom_site_type_symbol
  _atom_site_label
@@ -522,7 +509,7 @@ loop_
   O  O3  4  0.04337231  0.75000000  0.70713767  1
   O  O4  4  0.09664244  0.25000000  0.74132035  1"""
         for l1, l2 in zip(str(writer).split("\n"), answer.split("\n")):
-            self.assertEqual(l1.strip(), l2.strip())
+            assert l1.strip() == l2.strip()
 
     def test_symmetrized(self):
         filepath = self.TEST_FILES_DIR / "POSCAR"
@@ -532,31 +519,31 @@ loop_
         cif = CifParser.from_string(str(writer))
         m = StructureMatcher()
 
-        self.assertTrue(m.fit(cif.get_structures()[0], poscar.structure))
+        assert m.fit(cif.get_structures()[0], poscar.structure)
 
         # for l1, l2 in zip(str(writer).split("\n"), answer.split("\n")):
-        #     self.assertEqual(l1.strip(), l2.strip())
+        #     assert l1.strip() == l2.strip()
 
-        s = Structure.from_file(self.TEST_FILES_DIR / "LiFePO4.cif")
-        writer = CifWriter(s, symprec=0.1)
+        struct = Structure.from_file(self.TEST_FILES_DIR / "LiFePO4.cif")
+        writer = CifWriter(struct, symprec=0.1)
         s2 = CifParser.from_string(str(writer)).get_structures()[0]
 
-        self.assertTrue(m.fit(s, s2))
+        assert m.fit(struct, s2)
 
-        s = self.get_structure("Li2O")
-        writer = CifWriter(s, symprec=0.1)
+        struct = self.get_structure("Li2O")
+        writer = CifWriter(struct, symprec=0.1)
         s2 = CifParser.from_string(str(writer)).get_structures()[0]
-        self.assertTrue(m.fit(s, s2))
+        assert m.fit(struct, s2)
 
         # test angle tolerance.
-        s = Structure.from_file(self.TEST_FILES_DIR / "LiFePO4.cif")
-        writer = CifWriter(s, symprec=0.1, angle_tolerance=0)
+        struct = Structure.from_file(self.TEST_FILES_DIR / "LiFePO4.cif")
+        writer = CifWriter(struct, symprec=0.1, angle_tolerance=0)
         d = list(writer.ciffile.data.values())[0]
-        self.assertEqual(d["_symmetry_Int_Tables_number"], 14)
-        s = Structure.from_file(self.TEST_FILES_DIR / "LiFePO4.cif")
-        writer = CifWriter(s, symprec=0.1, angle_tolerance=2)
+        assert d["_symmetry_Int_Tables_number"] == 14
+        struct = Structure.from_file(self.TEST_FILES_DIR / "LiFePO4.cif")
+        writer = CifWriter(struct, symprec=0.1, angle_tolerance=2)
         d = list(writer.ciffile.data.values())[0]
-        self.assertEqual(d["_symmetry_Int_Tables_number"], 62)
+        assert d["_symmetry_Int_Tables_number"] == 62
 
     def test_disordered(self):
         si = Element("Si")
@@ -565,13 +552,11 @@ loop_
         coords.append(np.array([0, 0, 0]))
         coords.append(np.array([0.75, 0.5, 0.75]))
         lattice = Lattice(
-            np.array(
-                [
-                    [3.8401979337, 0.00, 0.00],
-                    [1.9200989668, 3.3257101909, 0.00],
-                    [0.00, -2.2171384943, 3.1355090603],
-                ]
-            )
+            [
+                [3.8401979337, 0.00, 0.00],
+                [1.9200989668, 3.3257101909, 0.00],
+                [0.00, -2.2171384943, 3.1355090603],
+            ]
         )
         struct = Structure(lattice, [si, {si: 0.5, n: 0.5}], coords)
         writer = CifWriter(struct)
@@ -606,7 +591,7 @@ loop_
   N  N2  1  0.75000000  0.50000000  0.75000000  0.5"""
 
         for l1, l2 in zip(str(writer).split("\n"), answer.split("\n")):
-            self.assertEqual(l1.strip(), l2.strip())
+            assert l1.strip() == l2.strip()
 
     def test_cifwrite_without_refinement(self):
         si2 = Structure.from_file(self.TEST_FILES_DIR / "abinit" / "si.cif")
@@ -625,13 +610,11 @@ loop_
         coords.append(np.array([0.75, 0.5, 0.75]))
         coords.append(np.array([0, 0, 0]))
         lattice = Lattice(
-            np.array(
-                [
-                    [3.8401979337, 0.00, 0.00],
-                    [1.9200989668, 3.3257101909, 0.00],
-                    [0.00, -2.2171384943, 3.1355090603],
-                ]
-            )
+            [
+                [3.8401979337, 0.00, 0.00],
+                [1.9200989668, 3.3257101909, 0.00],
+                [0.00, -2.2171384943, 3.1355090603],
+            ]
         )
         struct = Structure(lattice, [n, {si3: 0.5, n: 0.5}, si4], coords)
         writer = CifWriter(struct)
@@ -673,18 +656,18 @@ loop_
   Si4+  Si3  1  0.00000000  0.00000000  0.00000000  1
 """
         for l1, l2 in zip(str(writer).split("\n"), answer.split("\n")):
-            self.assertEqual(l1.strip(), l2.strip())
+            assert l1.strip() == l2.strip()
 
         # test that mixed valence works properly
         s2 = Structure.from_str(answer, "cif")
-        self.assertEqual(struct.composition, s2.composition)
+        assert struct.composition == s2.composition
 
     def test_primes(self):
         with warnings.catch_warnings():
             warnings.simplefilter("ignore")
             parser = CifParser(self.TEST_FILES_DIR / "C26H16BeN2O2S2.cif")
             for s in parser.get_structures(False):
-                self.assertEqual(s.composition, 8 * Composition("C26H16BeN2O2S2"))
+                assert s.composition == 8 * Composition("C26H16BeN2O2S2")
 
     def test_missing_atom_site_type_with_oxistates(self):
         with warnings.catch_warnings():
@@ -692,7 +675,7 @@ loop_
             parser = CifParser(self.TEST_FILES_DIR / "P24Ru4H252C296S24N16.cif")
             c = Composition({"S0+": 24, "Ru0+": 4, "H0+": 252, "C0+": 296, "N0+": 16, "P0+": 24})
             for s in parser.get_structures(False):
-                self.assertEqual(s.composition, c)
+                assert s.composition == c
 
     def test_no_coords_or_species(self):
         with warnings.catch_warnings():
@@ -732,7 +715,8 @@ loop_
       ? ? ? ? ? ? ?
     """
             parser = CifParser.from_string(string)
-            self.assertRaises(ValueError, parser.get_structures)
+            with pytest.raises(ValueError):
+                parser.get_structures()
 
     def test_get_lattice_from_lattice_type(self):
         cif_structure = """#generated using pymatgen
@@ -791,29 +775,30 @@ loop_
         s_ref = poscar.structure
 
         sm = StructureMatcher(stol=0.05, ltol=0.01, angle_tol=0.1)
-        self.assertTrue(sm.fit(s_ref, s_test))
+        assert sm.fit(s_ref, s_test)
 
     def test_empty(self):
         # single line
         cb = CifBlock.from_string("data_mwe\nloop_\n_tag\n ''")
-        self.assertEqual(cb.data["_tag"][0], "")
+        assert cb.data["_tag"][0] == ""
 
         # multi line
         cb = CifBlock.from_string("data_mwe\nloop_\n_tag\n;\n;")
-        self.assertEqual(cb.data["_tag"][0], "")
+        assert cb.data["_tag"][0] == ""
 
         cb2 = CifBlock.from_string(str(cb))
-        self.assertEqual(cb, cb2)
+        assert cb == cb2
 
     def test_bad_cif(self):
         with warnings.catch_warnings():
             warnings.simplefilter("ignore")
             f = self.TEST_FILES_DIR / "bad_occu.cif"
             p = CifParser(f)
-            self.assertRaises(ValueError, p.get_structures)
+            with pytest.raises(ValueError):
+                p.get_structures()
             p = CifParser(f, occupancy_tolerance=2)
             s = p.get_structures()[0]
-            self.assertAlmostEqual(s[0].species["Al3+"], 0.5)
+            assert s[0].species["Al3+"] == approx(0.5)
 
     def test_one_line_symm(self):
         with warnings.catch_warnings():
@@ -821,7 +806,7 @@ loop_
             f = self.TEST_FILES_DIR / "OneLineSymmP1.cif"
             p = CifParser(f)
             s = p.get_structures()[0]
-            self.assertEqual(s.formula, "Ga4 Pb2 O8")
+            assert s.formula == "Ga4 Pb2 O8"
 
     def test_no_symmops(self):
         with warnings.catch_warnings():
@@ -829,23 +814,23 @@ loop_
             f = self.TEST_FILES_DIR / "nosymm.cif"
             p = CifParser(f)
             s = p.get_structures()[0]
-            self.assertEqual(s.formula, "H96 C60 O8")
+            assert s.formula == "H96 C60 O8"
 
     def test_dot_positions(self):
         f = self.TEST_FILES_DIR / "ICSD59959.cif"
         p = CifParser(f)
         s = p.get_structures()[0]
-        self.assertEqual(s.formula, "K1 Mn1 F3")
+        assert s.formula == "K1 Mn1 F3"
 
     def test_replacing_finite_precision_frac_coords(self):
         f = self.TEST_FILES_DIR / "cif_finite_precision_frac_coord_error.cif"
         with warnings.catch_warnings():
             p = CifParser(f)
             s = p.get_structures()[0]
-            self.assertEqual(str(s.composition), "N5+24")
-            self.assertIn(
-                "Some fractional coordinates rounded to ideal values to avoid issues with finite precision.",
-                p.warnings,
+            assert str(s.composition) == "N5+24"
+            assert (
+                "Some fractional coordinates rounded to ideal values to avoid issues with finite precision."
+                in p.warnings
             )
 
     def test_empty_deque(self):
@@ -883,7 +868,7 @@ loop_
   4  x-1/2,-y-1/2,z-1/2
 ;"""
         p = CifParser.from_string(s)
-        self.assertEqual(p.get_structures()[0].formula, "Si1")
+        assert p.get_structures()[0].formula == "Si1"
         cif = """
 data_1526655
 _journal_name_full
@@ -914,7 +899,8 @@ _atom_site_U_iso_or_equiv
 Si1 Si 0 0 0 1 0.0
 """
         p = CifParser.from_string(cif)
-        self.assertRaises(ValueError, p.get_structures)
+        with pytest.raises(ValueError):
+            p.get_structures()
 
 
 class MagCifTest(PymatgenTest):
@@ -930,21 +916,23 @@ class MagCifTest(PymatgenTest):
         warnings.simplefilter("default")
 
     def test_mcif_detection(self):
-        self.assertTrue(self.mcif.feature_flags["magcif"])
-        self.assertTrue(self.mcif_ncl.feature_flags["magcif"])
-        self.assertTrue(self.mcif_incom.feature_flags["magcif"])
-        self.assertTrue(self.mcif_disord.feature_flags["magcif"])
-        self.assertFalse(self.mcif.feature_flags["magcif_incommensurate"])
-        self.assertFalse(self.mcif_ncl.feature_flags["magcif_incommensurate"])
-        self.assertTrue(self.mcif_incom.feature_flags["magcif_incommensurate"])
-        self.assertFalse(self.mcif_disord.feature_flags["magcif_incommensurate"])
+        assert self.mcif.feature_flags["magcif"]
+        assert self.mcif_ncl.feature_flags["magcif"]
+        assert self.mcif_incom.feature_flags["magcif"]
+        assert self.mcif_disord.feature_flags["magcif"]
+        assert not self.mcif.feature_flags["magcif_incommensurate"]
+        assert not self.mcif_ncl.feature_flags["magcif_incommensurate"]
+        assert self.mcif_incom.feature_flags["magcif_incommensurate"]
+        assert not self.mcif_disord.feature_flags["magcif_incommensurate"]
 
     def test_get_structures(self):
         # incommensurate structures not currently supported
-        self.assertRaises(NotImplementedError, self.mcif_incom.get_structures)
+        with pytest.raises(NotImplementedError):
+            self.mcif_incom.get_structures()
 
         # disordered magnetic structures not currently supported
-        self.assertRaises(NotImplementedError, self.mcif_disord.get_structures)
+        with pytest.raises(NotImplementedError):
+            self.mcif_disord.get_structures()
 
         # taken from self.mcif_ncl, removing explicit magnetic symmops
         # so that MagneticSymmetryGroup() has to be invoked
@@ -979,16 +967,16 @@ _atom_site_moment_crystalaxis_z
 Gd1 5.05 5.05 0.0"""
 
         s = self.mcif.get_structures(primitive=False)[0]
-        self.assertEqual(s.formula, "Ni32 O32")
-        self.assertTrue(Magmom.are_collinear(s.site_properties["magmom"]))
+        assert s.formula == "Ni32 O32"
+        assert Magmom.are_collinear(s.site_properties["magmom"])
 
         # example with non-collinear spin
         s_ncl = self.mcif_ncl.get_structures(primitive=False)[0]
         s_ncl_from_msg = CifParser.from_string(magcifstr).get_structures(primitive=False)[0]
-        self.assertEqual(s_ncl.formula, "Gd4 B16")
-        self.assertFalse(Magmom.are_collinear(s_ncl.site_properties["magmom"]))
+        assert s_ncl.formula == "Gd4 B16"
+        assert not Magmom.are_collinear(s_ncl.site_properties["magmom"])
 
-        self.assertTrue(s_ncl.matches(s_ncl_from_msg))
+        assert s_ncl.matches(s_ncl_from_msg)
 
     def test_write(self):
         cw_ref_string = """# generated using pymatgen
@@ -1050,7 +1038,7 @@ loop_
         s_ncl = self.mcif_ncl.get_structures(primitive=False)[0]
 
         cw = CifWriter(s_ncl, write_magmoms=True)
-        self.assertEqual(str(cw), cw_ref_string)
+        assert str(cw) == cw_ref_string
 
         # from list-type magmoms
         list_magmoms = [list(m) for m in s_ncl.site_properties["magmom"]]
@@ -1060,7 +1048,7 @@ loop_
 
         s_ncl.add_site_property("magmom", list_magmoms)
         cw = CifWriter(s_ncl, write_magmoms=True)
-        self.assertEqual(str(cw), cw_ref_string)
+        assert str(cw) == cw_ref_string
 
         s_ncl.add_site_property("magmom", float_magmoms)
         cw = CifWriter(s_ncl, write_magmoms=True)
@@ -1121,14 +1109,14 @@ loop_
   Gd2  0.00000000  0.00000000  -7.14177849
   Gd3  0.00000000  0.00000000  -7.14177849
 """
-        self.assertEqual(str(cw).strip(), cw_ref_string_magnitudes.strip())
+        assert str(cw).strip() == cw_ref_string_magnitudes.strip()
         # test we're getting correct magmoms in ncl case
         s_ncl2 = self.mcif_ncl2.get_structures()[0]
         list_magmoms = [list(m) for m in s_ncl2.site_properties["magmom"]]
-        self.assertEqual(list_magmoms[0][0], 0.0)
-        self.assertAlmostEqual(list_magmoms[0][1], 5.9160793408726366)
-        self.assertAlmostEqual(list_magmoms[1][0], -5.1234749999999991)
-        self.assertAlmostEqual(list_magmoms[1][1], 2.9580396704363183)
+        assert list_magmoms[0][0] == 0.0
+        assert list_magmoms[0][1] == approx(5.9160793408726366)
+        assert list_magmoms[1][0] == approx(-5.1234749999999991)
+        assert list_magmoms[1][1] == approx(2.9580396704363183)
 
         # test creating an structure without oxidation state doesn't raise errors
         s_manual = Structure(Lattice.cubic(4.2), ["Cs", "Cl"], [[0, 0, 0], [0.5, 0.5, 0.5]])
@@ -1177,7 +1165,7 @@ loop_
 """
         s_manual.add_oxidation_state_by_site([1, 1])
         cw = CifWriter(s_manual, write_magmoms=True)
-        self.assertEqual(str(cw), cw_manual_oxi_string)
+        assert str(cw) == cw_manual_oxi_string
 
     @unittest.skipIf(pybtex is None, "pybtex not present")
     def test_bibtex(self):
@@ -1189,8 +1177,4 @@ loop_
     pages = "?--?"
 }
 """
-        self.assertEqual(self.mcif_ncl.get_bibtex_string(), ref_bibtex_string)
-
-
-if __name__ == "__main__":
-    unittest.main()
+        assert self.mcif_ncl.get_bibtex_string() == ref_bibtex_string
