@@ -1,11 +1,11 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
+from __future__ import annotations
 
 import os
 import unittest
 
 import numpy as np
 import pandas as pd
+from pytest import approx
 
 from pymatgen.core.structure import Molecule
 from pymatgen.io.vasp.inputs import Poscar
@@ -29,14 +29,14 @@ class XYZTest(unittest.TestCase):
         self.multi_xyz = XYZ(self.multi_mols)
 
     def test_str(self):
-        ans = """5
+        expected = """5
 H4 C1
 C 0.000000 0.000000 0.000000
 H 0.000000 0.000000 1.089000
 H 1.026719 0.000000 -0.363000
 H -0.513360 -0.889165 -0.363000
 H -0.513360 0.889165 -0.363000"""
-        self.assertEqual(str(self.xyz), ans)
+        assert str(self.xyz) == expected
 
         mxyz = XYZ(self.multi_mols, coord_precision=3)
         mxyz_text = str(mxyz)
@@ -54,24 +54,24 @@ H 10.000 10.000 11.089
 H 11.027 10.000 9.637
 H 9.487 9.111 9.637
 H 9.487 10.889 9.637"""
-        self.assertEqual(mxyz_text, ans_multi)
+        assert mxyz_text == ans_multi
 
     def test_from_string(self):
-        ans = """5
+        expected = """5
 H4 C1
 C 0.000000 0.000000 0.000000
 H 0.000000 0.000000 1.089000
 H 1.026719 0.000000 -0.363000
 H -0.513360 -0.889165 -0.363000
 H -0.513360 0.889165 -0.363000"""
-        xyz = XYZ.from_string(ans)
+        xyz = XYZ.from_string(expected)
         mol = xyz.molecule
         sp = ["C", "H", "H", "H", "H"]
         for i, site in enumerate(mol):
-            self.assertEqual(site.species_string, sp[i])
-            self.assertEqual(len(site.coords), 3)
+            assert site.species_string == sp[i]
+            assert len(site.coords) == 3
             if i == 0:
-                self.assertTrue(all([c == 0 for c in site.coords]))
+                assert all(c == 0 for c in site.coords)
 
         mol_str = """2
 Random
@@ -80,8 +80,8 @@ C 1.16730636786 -1.38166622735 -2.77112970359e-06
 """
         xyz = XYZ.from_string(mol_str)
         mol = xyz.molecule
-        self.assertTrue(abs(mol[0].z) < 1e-5)
-        self.assertTrue(abs(mol[1].z) < 1e-5)
+        assert abs(mol[0].z) < 1e-5
+        assert abs(mol[1].z) < 1e-5
 
         mol_str = """2
 Random, Alternate Scientific Notation
@@ -90,8 +90,8 @@ C 1.16730636786 -1.38166622735 -2.771*^-06
 """
         xyz = XYZ.from_string(mol_str)
         mol = xyz.molecule
-        self.assertEqual(mol[0].z, -7.222e-06)
-        self.assertEqual(mol[1].z, -2.771e-06)
+        assert mol[0].z == -7.222e-06
+        assert mol[1].z == -2.771e-06
 
         mol_str = """3
 Random
@@ -101,10 +101,10 @@ C  -4.440892098501D-01 -1.116307996198d+01  1.933502166311E+01
 """
         xyz = XYZ.from_string(mol_str)
         mol = xyz.molecule
-        self.assertAlmostEqual(mol[0].x, 0)
-        self.assertAlmostEqual(mol[1].y, 11.16307996198)
-        self.assertAlmostEqual(mol[2].x, -0.4440892098501)
-        self.assertAlmostEqual(mol[2].y, -11.16307996198)
+        assert mol[0].x == approx(0)
+        assert mol[1].y == approx(11.16307996198)
+        assert mol[2].x == approx(-0.4440892098501)
+        assert mol[2].y == approx(-11.16307996198)
         # self.assertTrue(abs(mol[1].z) < 1e-5)
 
         mol_str = """    5
@@ -117,34 +117,29 @@ C32-C2-1
  """
         xyz = XYZ.from_string(mol_str)
         mol = xyz.molecule
-        self.assertAlmostEqual(mol[0].x, 2.70450)
-        self.assertAlmostEqual(mol[1].y, 1.72490)
-        self.assertAlmostEqual(mol[2].x, 2.34210)
-        self.assertAlmostEqual(mol[3].z, -0.13790)
+        assert mol[0].x == approx(2.70450)
+        assert mol[1].y == approx(1.72490)
+        assert mol[2].x == approx(2.34210)
+        assert mol[3].z == approx(-0.13790)
 
     def test_from_file(self):
         filepath = os.path.join(PymatgenTest.TEST_FILES_DIR, "multiple_frame_xyz.xyz")
         mxyz = XYZ.from_file(filepath)
-        self.assertEqual(len(mxyz.all_molecules), 302)
-        self.assertEqual(
-            list(mxyz.all_molecules[0].cart_coords[0]),
-            [0.20303525080000001, 2.8569761204000002, 0.44737723190000001],
-        )
-        self.assertEqual(
-            list(mxyz.all_molecules[-1].cart_coords[-1]),
-            [5.5355550720000002, 0.0282305931, -0.30993102189999999],
-        )
-        self.assertEqual(
-            list(mxyz.molecule.cart_coords[-1]),
-            [5.5355550720000002, 0.0282305931, -0.30993102189999999],
-        )
+        assert len(mxyz.all_molecules) == 302
+        assert list(mxyz.all_molecules[0].cart_coords[0]) == [
+            0.20303525080000001,
+            2.8569761204000002,
+            0.44737723190000001,
+        ]
+        assert list(mxyz.all_molecules[-1].cart_coords[-1]) == [5.5355550720000002, 0.0282305931, -0.30993102189999999]
+        assert list(mxyz.molecule.cart_coords[-1]) == [5.5355550720000002, 0.0282305931, -0.30993102189999999]
 
     def test_init_from_structure(self):
         filepath = os.path.join(PymatgenTest.TEST_FILES_DIR, "POSCAR")
         poscar = Poscar.from_file(filepath)
         struct = poscar.structure
         xyz = XYZ(struct)
-        ans = """24
+        expected = """24
 Fe4 P4 O16
 Fe 2.277347 4.550379 2.260125
 Fe 2.928536 1.516793 4.639870
@@ -170,7 +165,7 @@ O 8.686436 3.313115 3.401208
 O 8.686436 5.787643 3.401208
 O 9.405548 4.550379 1.231183
 O 9.960184 1.516793 1.393875"""
-        self.assertEqual(str(xyz), ans)
+        assert str(xyz) == expected
 
     def test_as_dataframe(self):
         coords = [
@@ -201,7 +196,3 @@ O 9.960184 1.516793 1.393875"""
         # index tests
         np.testing.assert_array_equal(mol_df.columns, test_df.columns)
         np.testing.assert_array_equal(mol_df.index, test_df.index)
-
-
-if __name__ == "__main__":
-    unittest.main()
