@@ -1,6 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 Classes for reading/manipulating/writing VASP input files. All major VASP input
 files.
@@ -8,7 +5,7 @@ files.
 
 from __future__ import annotations
 
-import glob
+import hashlib
 import itertools
 import json
 import logging
@@ -19,11 +16,13 @@ import subprocess
 import warnings
 from collections import namedtuple
 from enum import Enum
-from hashlib import md5
-from typing import Any, Literal, Sequence
+from glob import glob
+from hashlib import sha256
+from typing import TYPE_CHECKING, Any, Literal, Sequence
 
 import numpy as np
 import scipy.constants as const
+from frozendict import frozendict
 from monty.io import zopen
 from monty.json import MontyDecoder, MSONable
 from monty.os import cd
@@ -38,7 +37,12 @@ from pymatgen.core.structure import Structure
 from pymatgen.electronic_structure.core import Magmom
 from pymatgen.util.io_utils import clean_lines
 from pymatgen.util.string import str_delimited
-from pymatgen.util.typing import ArrayLike, PathLike
+
+if TYPE_CHECKING:
+    from numpy.typing import ArrayLike
+
+    from pymatgen.util.typing import PathLike
+
 
 __author__ = "Shyue Ping Ong, Geoffroy Hautier, Rickard Armiento, Vincent L Chevrier, Stephen Dacek"
 __copyright__ = "Copyright 2011, The Materials Project"
@@ -96,41 +100,52 @@ class Poscar(MSONable):
     def __init__(
         self,
         structure: Structure,
-        comment: str = None,
-        selective_dynamics=None,
+        comment: str | None = None,
+        selective_dynamics: ArrayLike | None = None,
         true_names: bool = True,
-        velocities: ArrayLike = None,
-        predictor_corrector: ArrayLike = None,
-        predictor_corrector_preamble: str = None,
+        velocities: ArrayLike | None = None,
+        predictor_corrector: ArrayLike | None = None,
+        predictor_corrector_preamble: str | None = None,
         sort_structure: bool = False,
     ):
         """
-        :param structure: Structure object.
-        :param comment: Optional comment line for POSCAR. Defaults to unit
-            cell formula of structure. Defaults to None.
-        :param selective_dynamics: bool values for selective dynamics,
-            where N is number of sites. Defaults to None.
-        :param true_names: Set to False if the names in the POSCAR are not
-            well-defined and ambiguous. This situation arises commonly in
-            vasp < 5 where the POSCAR sometimes does not contain element
-            symbols. Defaults to True.
-        :param velocities: Velocities for the POSCAR. Typically parsed
-            in MD runs or can be used to initialize velocities.
-        :param predictor_corrector: Predictor corrector for the POSCAR.
-            Typically parsed in MD runs.
-        :param predictor_corrector_preamble: Preamble to the predictor
-            corrector.
-        :param sort_structure: Whether to sort structure. Useful if species
-            are not grouped properly together.
+        Args:
+            structure (Structure): Structure object.
+            comment (str | None, optional): Optional comment line for POSCAR. Defaults to unit
+                cell formula of structure. Defaults to None.
+            selective_dynamics (ArrayLike | None, optional): Bool values for selective dynamics,
+                where N is the number of sites. Defaults to None.
+            true_names (bool, optional): Set to False if the names in the POSCAR are not
+                well-defined and ambiguous. This situation arises commonly in
+                VASP < 5 where the POSCAR sometimes does not contain element
+                symbols. Defaults to True.
+            velocities (ArrayLike | None, optional): Velocities for the POSCAR. Typically parsed
+                in MD runs or can be used to initialize velocities. Defaults to None.
+            predictor_corrector (ArrayLike | None, optional): Predictor corrector for the POSCAR.
+                Typically parsed in MD runs. Defaults to None.
+            predictor_corrector_preamble (str | None, optional): Preamble to the predictor
+                corrector. Defaults to None.
+            sort_structure (bool, optional): Whether to sort the structure. Useful if species
+                are not grouped properly together. Defaults to False.
         """
         if structure.is_ordered:
             site_properties = {}
-            if selective_dynamics:
-                site_properties["selective_dynamics"] = selective_dynamics
-            if velocities:
-                site_properties["velocities"] = velocities
-            if predictor_corrector:
-                site_properties["predictor_corrector"] = predictor_corrector
+
+            if selective_dynamics is not None:
+                selective_dynamics = np.array(selective_dynamics)
+                if not selective_dynamics.all():
+                    site_properties["selective_dynamics"] = selective_dynamics
+
+            if velocities is not None:
+                velocities = np.array(velocities)
+                if velocities.any():
+                    site_properties["velocities"] = velocities
+
+            if predictor_corrector is not None:
+                predictor_corrector = np.array(predictor_corrector)
+                if predictor_corrector.any():
+                    site_properties["predictor_corrector"] = predictor_corrector
+
             structure = Structure.from_sites(structure)
             self.structure = structure.copy(site_properties=site_properties)
             if sort_structure:
@@ -192,13 +207,12 @@ class Poscar(MSONable):
         return [len(tuple(a[1])) for a in itertools.groupby(syms)]
 
     def __setattr__(self, name, value):
-        if name in ("selective_dynamics", "velocities"):
-            if value is not None and len(value) > 0:
-                value = np.array(value)
-                dim = value.shape
-                if dim[1] != 3 or dim[0] != len(self.structure):
-                    raise ValueError(name + " array must be same length as the structure.")
-                value = value.tolist()
+        if name in ("selective_dynamics", "velocities") and value is not None and len(value) > 0:
+            value = np.array(value)
+            dim = value.shape
+            if dim[1] != 3 or dim[0] != len(self.structure):
+                raise ValueError(name + " array must be same length as the structure.")
+            value = value.tolist()
         super().__setattr__(name, value)
 
     @staticmethod
@@ -237,7 +251,7 @@ class Poscar(MSONable):
         dirname = os.path.dirname(os.path.abspath(filename))
         names = None
         if check_for_POTCAR:
-            potcars = glob.glob(os.path.join(dirname, "*POTCAR*"))
+            potcars = glob(os.path.join(dirname, "*POTCAR*"))
             if potcars:
                 try:
                     potcar = Potcar.from_file(sorted(potcars)[0])
@@ -306,7 +320,7 @@ class Poscar(MSONable):
 
         vasp5_symbols = False
         try:
-            natoms = [int(i) for i in lines[5].split()]
+            n_atoms = [int(i) for i in lines[5].split()]
             ipos = 6
         except ValueError:
             vasp5_symbols = True
@@ -329,23 +343,23 @@ class Poscar(MSONable):
             Direct
               ...
             """
-            nlines_symbols = 1
-            for nlines_symbols in range(1, 11):
+            n_lines_symbols = 1
+            for n_lines_symbols in range(1, 11):
                 try:
-                    int(lines[5 + nlines_symbols].split()[0])
+                    int(lines[5 + n_lines_symbols].split()[0])
                     break
                 except ValueError:
                     pass
-            for iline_symbols in range(6, 5 + nlines_symbols):
-                symbols.extend(lines[iline_symbols].split())
-            natoms = []
-            iline_natoms_start = 5 + nlines_symbols
-            for iline_natoms in range(iline_natoms_start, iline_natoms_start + nlines_symbols):
-                natoms.extend([int(i) for i in lines[iline_natoms].split()])
+            for i_line_symbols in range(6, 5 + n_lines_symbols):
+                symbols.extend(lines[i_line_symbols].split())
+            n_atoms = []
+            iline_natoms_start = 5 + n_lines_symbols
+            for iline_natoms in range(iline_natoms_start, iline_natoms_start + n_lines_symbols):
+                n_atoms.extend([int(i) for i in lines[iline_natoms].split()])
             atomic_symbols = []
-            for i, nat in enumerate(natoms):
+            for i, nat in enumerate(n_atoms):
                 atomic_symbols.extend([symbols[i]] * nat)
-            ipos = 5 + 2 * nlines_symbols
+            ipos = 5 + 2 * n_lines_symbols
 
         pos_type = lines[ipos].split()[0]
 
@@ -357,7 +371,7 @@ class Poscar(MSONable):
             pos_type = lines[ipos].split()[0]
 
         cart = pos_type[0] in "cCkK"
-        n_sites = sum(natoms)
+        n_sites = sum(n_atoms)
 
         # If default_names is specified (usually coming from a POTCAR), use
         # them. This is in line with VASP's parsing order that the POTCAR
@@ -365,7 +379,7 @@ class Poscar(MSONable):
         if default_names:
             try:
                 atomic_symbols = []
-                for i, nat in enumerate(natoms):
+                for i, nat in enumerate(n_atoms):
                     atomic_symbols.extend([default_names[i]] * nat)
                 vasp5_symbols = True
             except IndexError:
@@ -375,7 +389,7 @@ class Poscar(MSONable):
             ind = 3 if not has_selective_dynamics else 6
             try:
                 # Check if names are appended at the end of the coordinates.
-                atomic_symbols = [l.split()[ind] for l in lines[ipos + 1 : ipos + 1 + n_sites]]
+                atomic_symbols = [line.split()[ind] for line in lines[ipos + 1 : ipos + 1 + n_sites]]
                 # Ensure symbols are valid elements
                 if not all(Element.is_valid_symbol(sym) for sym in atomic_symbols):
                     raise ValueError("Non-valid symbols detected.")
@@ -383,21 +397,19 @@ class Poscar(MSONable):
             except (ValueError, IndexError):
                 # Defaulting to false names.
                 atomic_symbols = []
-                for i, nat in enumerate(natoms):
+                for i, nat in enumerate(n_atoms):
                     sym = Element.from_Z(i + 1).symbol
                     atomic_symbols.extend([sym] * nat)
                 warnings.warn(f"Elements in POSCAR cannot be determined. Defaulting to false names {atomic_symbols}.")
-
         # read the atomic coordinates
         coords = []
         selective_dynamics = [] if has_selective_dynamics else None
         for i in range(n_sites):
-            toks = lines[ipos + 1 + i].split()
+            tokens = lines[ipos + 1 + i].split()
             crd_scale = scale if cart else 1
-            coords.append([float(j) * crd_scale for j in toks[:3]])
+            coords.append([float(j) * crd_scale for j in tokens[:3]])
             if has_selective_dynamics:
-                selective_dynamics.append([tok.upper()[0] == "T" for tok in toks[3:6]])
-
+                selective_dynamics.append([tok.upper()[0] == "T" for tok in tokens[3:6]])
         struct = Structure(
             lattice,
             atomic_symbols,
@@ -436,9 +448,7 @@ class Poscar(MSONable):
                     d3 = [float(tok) for tok in lines[st + 2 * n_sites].split()]
                     predictor_corrector.append([d1, d2, d3])
         else:
-            velocities = None
-            predictor_corrector = None
-            predictor_corrector_preamble = None
+            velocities = predictor_corrector = predictor_corrector_preamble = None
 
         return Poscar(
             struct,
@@ -462,7 +472,7 @@ class Poscar(MSONable):
                 line to maintain backward vasp 4.x compatibility. Defaults
                 to False.
             significant_figures (int): No. of significant figures to
-                output all quantities. Defaults to 6. Note that positions are
+                output all quantities. Defaults to 16. Note that positions are
                 output in fixed point, while velocities are output in
                 scientific format.
 
@@ -479,19 +489,19 @@ class Poscar(MSONable):
         format_str = f"{{:{significant_figures+5}.{significant_figures}f}}"
         lines = [self.comment, "1.0"]
         for v in latt.matrix:
-            lines.append(" ".join([format_str.format(c) for c in v]))
+            lines.append(" ".join(format_str.format(c) for c in v))
 
         if self.true_names and not vasp4_compatible:
             lines.append(" ".join(self.site_symbols))
-        lines.append(" ".join([str(x) for x in self.natoms]))
+        lines.append(" ".join(map(str, self.natoms)))
         if self.selective_dynamics:
             lines.append("Selective dynamics")
         lines.append("direct" if direct else "cartesian")
 
         selective_dynamics = self.selective_dynamics
-        for (i, site) in enumerate(self.structure):
+        for i, site in enumerate(self.structure):
             coords = site.frac_coords if direct else site.coords
-            line = " ".join([format_str.format(c) for c in coords])
+            line = " ".join(format_str.format(c) for c in coords)
             if selective_dynamics is not None:
                 sd = ["T" if j else "F" for j in selective_dynamics[i]]
                 line += f" {sd[0]} {sd[1]} {sd[2]}"
@@ -502,7 +512,7 @@ class Poscar(MSONable):
             try:
                 lines.append("")
                 for v in self.velocities:
-                    lines.append(" ".join([format_str.format(i) for i in v]))
+                    lines.append(" ".join(format_str.format(i) for i in v))
             except Exception:
                 warnings.warn("Velocities are missing or corrupted.")
 
@@ -513,7 +523,7 @@ class Poscar(MSONable):
                 pred = np.array(self.predictor_corrector)
                 for col in range(3):
                     for z in pred[:, col]:
-                        lines.append(" ".join([format_str.format(i) for i in z]))
+                        lines.append(" ".join(format_str.format(i) for i in z))
             else:
                 warnings.warn(
                     "Preamble information missing or corrupt. Writing Poscar with no predictor corrector data."
@@ -564,8 +574,8 @@ class Poscar(MSONable):
             comment=d["comment"],
             selective_dynamics=d["selective_dynamics"],
             true_names=d["true_names"],
-            velocities=d.get("velocities", None),
-            predictor_corrector=d.get("predictor_corrector", None),
+            velocities=d.get("velocities"),
+            predictor_corrector=d.get("predictor_corrector"),
         )
 
     def set_temperature(self, temperature: float):
@@ -636,7 +646,7 @@ class Incar(dict, MSONable):
     a dictionary with some helper functions
     """
 
-    def __init__(self, params: dict[str, Any] = None):
+    def __init__(self, params: dict[str, Any] | None = None):
         """
         Creates an Incar object.
 
@@ -645,7 +655,6 @@ class Incar(dict, MSONable):
         """
         super().__init__()
         if params:
-
             # if Incar contains vector-like magmoms given as a list
             # of floats, convert to a list of lists
             if (params.get("MAGMOM") and isinstance(params["MAGMOM"][0], (int, float))) and (
@@ -721,12 +730,12 @@ class Incar(dict, MSONable):
 
                 lines.append([k, " ".join(value)])
             elif isinstance(self[k], list):
-                lines.append([k, " ".join([str(i) for i in self[k]])])
+                lines.append([k, " ".join(map(str, self[k]))])
             else:
                 lines.append([k, self[k]])
 
         if pretty:
-            return str(tabulate([[l[0], "=", l[1]] for l in lines], tablefmt="plain"))
+            return str(tabulate([[line[0], "=", line[1]] for line in lines], tablefmt="plain"))
         return str_delimited(lines, None, " = ") + "\n"
 
     def __str__(self):
@@ -925,9 +934,8 @@ class Incar(dict, MSONable):
             else:
                 similar_param[k1] = v1
         for k2, v2 in other.items():
-            if k2 not in similar_param and k2 not in different_param:
-                if k2 not in self:
-                    different_param[k2] = {"INCAR1": None, "INCAR2": v2}
+            if k2 not in similar_param and k2 not in different_param and k2 not in self:
+                different_param[k2] = {"INCAR1": None, "INCAR2": v2}
         return {"Same": similar_param, "Different": different_param}
 
     def __add__(self, other):
@@ -977,13 +985,12 @@ class Incar(dict, MSONable):
 
                 # if we have a list of possible parameters, check
                 # if the user given parameter is in this list
-                elif type(incar_params[k]).__name__ == "list":
-                    if v not in incar_params[k]:
-                        warnings.warn(
-                            f"{k}: Cannot find {v} in the list of parameters",
-                            BadIncarWarning,
-                            stacklevel=2,
-                        )
+                elif type(incar_params[k]).__name__ == "list" and v not in incar_params[k]:
+                    warnings.warn(
+                        f"{k}: Cannot find {v} in the list of parameters",
+                        BadIncarWarning,
+                        stacklevel=2,
+                    )
 
 
 class Kpoints_supported_modes(Enum):
@@ -1176,7 +1183,7 @@ class Kpoints(MSONable):
         grid.
 
         Args:
-            kpts: Subdivisions N_1, N_2 and N_3 along reciprocal lattice
+            kpts: Subdivisions N_1, N_2, N_3 along reciprocal lattice
                 vectors. Defaults to (2,2,2)
             shift: Shift to be applied to the kpoints. Defaults to (0,0,0).
 
@@ -1219,7 +1226,7 @@ class Kpoints(MSONable):
         ngrid = kppa / structure.num_sites
         mult = (ngrid * lengths[0] * lengths[1] * lengths[2]) ** (1 / 3)
 
-        num_div = [int(math.floor(max(mult / l, 1))) for l in lengths]
+        num_div = [int(math.floor(max(mult / length, 1))) for length in lengths]
 
         is_hexagonal = latt.is_hexagonal()
 
@@ -1250,7 +1257,7 @@ class Kpoints(MSONable):
         ngrid = kppa / structure.num_sites
 
         mult = (ngrid * lengths[0] * lengths[1] * lengths[2]) ** (1 / 3)
-        num_div = [int(round(mult / l)) for l in lengths]
+        num_div = [int(round(mult / length)) for length in lengths]
 
         # ensure that numDiv[i] > 0
         num_div = [i if i > 0 else 1 for i in num_div]
@@ -1400,7 +1407,7 @@ class Kpoints(MSONable):
         if style == "a":
             return Kpoints.automatic(int(lines[3].split()[0].strip()))
 
-        coord_pattern = re.compile(r"^\s*([\d+.\-Ee]+)\s+([\d+.\-Ee]+)\s+" r"([\d+.\-Ee]+)")
+        coord_pattern = re.compile(r"^\s*([\d+.\-Ee]+)\s+([\d+.\-Ee]+)\s+([\d+.\-Ee]+)")
 
         # Automatic gamma and Monk KPOINTS, with optional shift
         if style in ["g", "m"]:
@@ -1436,7 +1443,7 @@ class Kpoints(MSONable):
             style = Kpoints.supported_modes.Line_mode
             kpts = []
             labels = []
-            patt = re.compile(r"([e0-9.\-]+)\s+([e0-9.\-]+)\s+([e0-9.\-]+)" r"\s*!*\s*(.*)")
+            patt = re.compile(r"([e0-9.\-]+)\s+([e0-9.\-]+)\s+([e0-9.\-]+)\s*!*\s*(.*)")
             for i in range(4, len(lines)):
                 line = lines[i]
                 m = patt.match(line)
@@ -1512,17 +1519,17 @@ class Kpoints(MSONable):
         style = self.style.name.lower()[0]
         if style == "l":
             lines.append(self.coord_type)
-        for i in range(len(self.kpts)):
-            lines.append(" ".join([str(x) for x in self.kpts[i]]))
+        for idx, kpt in enumerate(self.kpts):
+            lines.append(" ".join(map(str, kpt)))
             if style == "l":
-                lines[-1] += " ! " + self.labels[i]
-                if i % 2 == 1:
+                lines[-1] += " ! " + self.labels[idx]
+                if idx % 2 == 1:
                     lines[-1] += "\n"
             elif self.num_kpts > 0:
                 if self.labels is not None:
-                    lines[-1] += f" {int(self.kpts_weights[i])} {self.labels[i]}"
+                    lines[-1] += f" {int(self.kpts_weights[idx])} {self.labels[idx]}"
                 else:
-                    lines[-1] += f" {int(self.kpts_weights[i])}"
+                    lines[-1] += f" {int(self.kpts_weights[idx])}"
 
         # Print tetrahedron parameters if the number of tetrahedrons > 0
         if style not in "lagm" and self.tet_number > 0:
@@ -1534,7 +1541,7 @@ class Kpoints(MSONable):
 
         # Print shifts for automatic kpoints types if not zero.
         if self.num_kpts <= 0 and tuple(self.kpts_shift) != (0, 0, 0):
-            lines.append(" ".join([str(x) for x in self.kpts_shift]))
+            lines.append(" ".join(map(str, self.kpts_shift)))
         return "\n".join(lines) + "\n"
 
     def as_dict(self):
@@ -1642,66 +1649,70 @@ class PotcarSingle:
     are raised if a POTCAR hash fails validation.
     """
 
-    functional_dir = {
-        "PBE": "POT_GGA_PAW_PBE",
-        "PBE_52": "POT_GGA_PAW_PBE_52",
-        "PBE_54": "POT_GGA_PAW_PBE_54",
-        "LDA": "POT_LDA_PAW",
-        "LDA_52": "POT_LDA_PAW_52",
-        "LDA_54": "POT_LDA_PAW_54",
-        "PW91": "POT_GGA_PAW_PW91",
-        "LDA_US": "POT_LDA_US",
-        "PW91_US": "POT_GGA_US_PW91",
-        "Perdew-Zunger81": "POT_LDA_PAW",
-    }
+    functional_dir = frozendict(
+        PBE="POT_GGA_PAW_PBE",
+        PBE_52="POT_GGA_PAW_PBE_52",
+        PBE_54="POT_GGA_PAW_PBE_54",
+        LDA="POT_LDA_PAW",
+        LDA_52="POT_LDA_PAW_52",
+        LDA_54="POT_LDA_PAW_54",
+        PW91="POT_GGA_PAW_PW91",
+        LDA_US="POT_LDA_US",
+        PW91_US="POT_GGA_US_PW91",
+        Perdew_Zunger81="POT_LDA_PAW",
+    )
 
-    functional_tags = {
-        "pe": {"name": "PBE", "class": "GGA"},
-        "91": {"name": "PW91", "class": "GGA"},
-        "rp": {"name": "revPBE", "class": "GGA"},
-        "am": {"name": "AM05", "class": "GGA"},
-        "ps": {"name": "PBEsol", "class": "GGA"},
-        "pw": {"name": "PW86", "class": "GGA"},
-        "lm": {"name": "Langreth-Mehl-Hu", "class": "GGA"},
-        "pb": {"name": "Perdew-Becke", "class": "GGA"},
-        "ca": {"name": "Perdew-Zunger81", "class": "LDA"},
-        "hl": {"name": "Hedin-Lundquist", "class": "LDA"},
-        "wi": {"name": "Wigner Interpoloation", "class": "LDA"},
-    }
+    functional_tags = frozendict(
+        {
+            "pe": {"name": "PBE", "class": "GGA"},
+            "91": {"name": "PW91", "class": "GGA"},
+            "rp": {"name": "revPBE", "class": "GGA"},
+            "am": {"name": "AM05", "class": "GGA"},
+            "ps": {"name": "PBEsol", "class": "GGA"},
+            "pw": {"name": "PW86", "class": "GGA"},
+            "lm": {"name": "Langreth-Mehl-Hu", "class": "GGA"},
+            "pb": {"name": "Perdew-Becke", "class": "GGA"},
+            "ca": {"name": "Perdew-Zunger81", "class": "LDA"},
+            "hl": {"name": "Hedin-Lundquist", "class": "LDA"},
+            "wi": {"name": "Wigner Interpolation", "class": "LDA"},
+        }
+    )
 
-    parse_functions = {
-        "LULTRA": _parse_bool,
-        "LUNSCR": _parse_bool,
-        "LCOR": _parse_bool,
-        "LPAW": _parse_bool,
-        "EATOM": _parse_float,
-        "RPACOR": _parse_float,
-        "POMASS": _parse_float,
-        "ZVAL": _parse_float,
-        "RCORE": _parse_float,
-        "RWIGS": _parse_float,
-        "ENMAX": _parse_float,
-        "ENMIN": _parse_float,
-        "EMMIN": _parse_float,
-        "EAUG": _parse_float,
-        "DEXC": _parse_float,
-        "RMAX": _parse_float,
-        "RAUG": _parse_float,
-        "RDEP": _parse_float,
-        "RDEPT": _parse_float,
-        "QCUT": _parse_float,
-        "QGAM": _parse_float,
-        "RCLOC": _parse_float,
-        "IUNSCR": _parse_int,
-        "ICORE": _parse_int,
-        "NDATA": _parse_int,
-        "VRHFIN": _parse_string,
-        "LEXCH": _parse_string,
-        "TITEL": _parse_string,
-        "STEP": _parse_list,
-        "RRKJ": _parse_list,
-        "GGA": _parse_list,
-    }
+    parse_functions = frozendict(
+        LULTRA=_parse_bool,
+        LUNSCR=_parse_bool,
+        LCOR=_parse_bool,
+        LPAW=_parse_bool,
+        EATOM=_parse_float,
+        RPACOR=_parse_float,
+        POMASS=_parse_float,
+        ZVAL=_parse_float,
+        RCORE=_parse_float,
+        RWIGS=_parse_float,
+        ENMAX=_parse_float,
+        ENMIN=_parse_float,
+        EMMIN=_parse_float,
+        EAUG=_parse_float,
+        DEXC=_parse_float,
+        RMAX=_parse_float,
+        RAUG=_parse_float,
+        RDEP=_parse_float,
+        RDEPT=_parse_float,
+        QCUT=_parse_float,
+        QGAM=_parse_float,
+        RCLOC=_parse_float,
+        IUNSCR=_parse_int,
+        ICORE=_parse_int,
+        NDATA=_parse_int,
+        VRHFIN=_parse_string,
+        LEXCH=_parse_string,
+        TITEL=_parse_string,
+        STEP=_parse_list,
+        RRKJ=_parse_list,
+        GGA=_parse_list,
+        SHA256=_parse_string,
+        COPYR=_parse_string,
+    )
 
     def __init__(self, data, symbol=None):
         """
@@ -1720,7 +1731,7 @@ class PotcarSingle:
         self.header = data.split("\n")[0].strip()
 
         search_lines = re.search(
-            r"(?s)(parameters from PSCTR are:" r".*?END of PSCTR-controll parameters)",
+            r"(?s)(parameters from PSCTR are:.*?END of PSCTR-controll parameters)",
             data,
         ).group(1)
 
@@ -1760,7 +1771,7 @@ class PotcarSingle:
             PSCTR["Orbitals"] = tuple(orbitals)
 
         description_string = re.search(
-            r"(?s)Description\s*\n" r"(.*?)Error from kinetic" r" energy argument \(eV\)",
+            r"(?s)Description\s*\n(.*?)Error from kinetic energy argument \(eV\)",
             search_lines,
         )
         if description_string:
@@ -1782,7 +1793,7 @@ class PotcarSingle:
             PSCTR["OrbitalDescriptions"] = tuple(descriptions)
 
         rrkj_kinetic_energy_string = re.search(
-            r"(?s)Error from kinetic energy argument \(eV\)\s*\n" r"(.*?)END of PSCTR-controll parameters",
+            r"(?s)Error from kinetic energy argument \(eV\)\s*\n(.*?)END of PSCTR-controll parameters",
             search_lines,
         )
         rrkj_array = []
@@ -1804,25 +1815,37 @@ class PotcarSingle:
             except IndexError:
                 self._symbol = self.keywords["TITEL"].strip()
 
-        # Compute the POTCAR hashes and check them against the database of known
-        # VASP POTCARs
+        # Compute the POTCAR hashes to check them against the database of known
+        # VASP POTCARs and possibly SHA256 hashes contained in the file itself.
         self.hash = self.get_potcar_hash()
         self.file_hash = self.get_potcar_file_hash()
+        if hasattr(self, "SHA256"):
+            self.hash_sha256_from_file = self.SHA256.split()[0]
+            self.hash_sha256_computed = self.get_sha256_file_hash()
 
         if not self.identify_potcar(mode="data")[0]:
+            warnings.warn(
+                f"POTCAR with symbol {self.symbol} has metadata that does\n"
+                "not match any VASP POTCAR known to pymatgen. The data in this\n"
+                "POTCAR is known to match the following functionals:\n"
+                f"{self.identify_potcar(mode='data')[0]}",
+                UnknownPotcarWarning,
+            )
+
+        has_sh256, hash_check_passed = self.verify_potcar()
+        if not has_sh256 and not hash_check_passed:
             warnings.warn(
                 f"POTCAR data with symbol { self.symbol} does not match any VASP "
                 "POTCAR known to pymatgen. There is a possibility your "
                 "POTCAR is corrupted or that the pymatgen database is incomplete.",
                 UnknownPotcarWarning,
             )
-        elif not self.identify_potcar(mode="file")[0]:
+        elif has_sh256 and not hash_check_passed:
             warnings.warn(
-                f"POTCAR with symbol {self.symbol} has metadata that does not match\
-                          any VASP POTCAR known to pymatgen. The data in this\
-                          POTCAR is known to match the following functionals:\
-                          {self.identify_potcar(mode='data')[0]}",
-                UnknownPotcarWarning,
+                f"POTCAR with symbol {self.symbol} and functional\n"
+                f"{self.functional} has a SHA256 hash defined,\n"
+                "but the computed hash differs.\n"
+                "YOUR POTCAR FILE HAS BEEN CORRUPTED AND SHOULD NOT BE USED!"
             )
 
     def __str__(self):
@@ -1863,10 +1886,7 @@ class PotcarSingle:
         :return: PotcarSingle.
         """
         match = re.search(r"(?<=POTCAR\.)(.*)(?=.gz)", str(filename))
-        if match:
-            symbol = match.group(0)
-        else:
-            symbol = ""
+        symbol = match.group(0) if match else ""
 
         try:
             with zopen(filename, "rt") as f:
@@ -1879,7 +1899,7 @@ class PotcarSingle:
                 return PotcarSingle(f.read(), symbol=symbol or None)
 
     @staticmethod
-    def from_symbol_and_functional(symbol: str, functional: str = None):
+    def from_symbol_and_functional(symbol: str, functional: str | None = None):
         """
         Makes a PotcarSingle from a symbol and functional.
 
@@ -1893,7 +1913,7 @@ class PotcarSingle:
         d = SETTINGS.get("PMG_VASP_PSP_DIR")
         if d is None:
             raise ValueError(
-                f"No POTCAR for {symbol} with functional {functional} found. Please set the PMG_VASP_PSP_DIR "
+                f"No POTCAR for {symbol} with {functional=} found. Please set the PMG_VASP_PSP_DIR "
                 "environment in .pmgrc.yaml, or you may need to set PMG_DEFAULT_FUNCTIONAL to PBE_52 or "
                 "PBE_54 if you are using newer psps from VASP."
             )
@@ -1908,7 +1928,7 @@ class PotcarSingle:
                 psingle = PotcarSingle.from_file(p)
                 return psingle
         raise OSError(
-            f"You do not have the right POTCAR with functional {functional} and label {symbol} "
+            f"You do not have the right POTCAR with {functional=} and label {symbol} "
             f"in your VASP_PSP_DIR. Paths tried: {paths_to_try}"
         )
 
@@ -1973,17 +1993,44 @@ class PotcarSingle:
         """
         return self.functional_tags.get(self.LEXCH.lower(), {}).get("class")
 
+    def verify_potcar(self) -> tuple[bool, bool]:
+        """
+        Attempts to verify the integrity of the POTCAR data.
+
+        This method checks the whole file (removing only the SHA256
+        metadata) against the SHA256 hash in the header if this is found.
+        If no SHA256 hash is found in the file, the file hash (md5 hash of the
+        whole file) is checked against all POTCAR file hashes known to pymatgen.
+
+        Returns:
+        -------
+        (bool, bool)
+            has_sh256 and passed_hash_check are returned.
+
+        """
+        if hasattr(self, "SHA256"):
+            has_sha256 = True
+            passed_hash_check = self.hash_sha256_from_file == self.hash_sha256_computed
+        else:
+            has_sha256 = False
+            # if no sha256 hash is found in the POTCAR file, compare the whole
+            # file with known potcar file hashes.
+            md5_file_hash = self.file_hash
+            hash_db = loadfn(os.path.join(cwd, "vasp_potcar_file_hashes.json"))
+            passed_hash_check = md5_file_hash in hash_db
+        return (has_sha256, passed_hash_check)
+
     def identify_potcar(self, mode: Literal["data", "file"] = "data"):
         """
         Identify the symbol and compatible functionals associated with this PotcarSingle.
 
-        This method checks the md5 hash of either the POTCAR data (PotcarSingle.hash)
+        This method checks the md5 hash of either the POTCAR metadadata (PotcarSingle.hash)
         or the entire POTCAR file (PotcarSingle.file_hash) against a database
         of hashes for POTCARs distributed with VASP 5.4.4.
 
         Args:
-            mode ('data' | 'file'): 'data' mode checks the hash of the POTCAR data itself,
-                while 'file' mode checks the hash of the entire POTCAR file, including metadata.
+            mode ('data' | 'file'): 'data' mode checks the hash of the POTCAR metadata in self.PSCTR,
+                while 'file' mode checks the hash of the entire POTCAR file.
 
         Returns:
             symbol (List): List of symbols associated with the PotcarSingle
@@ -2106,33 +2153,54 @@ class PotcarSingle:
             return potcar_functionals, identity["potcar_symbols"]
         return [], []
 
+    def get_sha256_file_hash(self):
+        """
+        Computes a SHA256 hash of the PotcarSingle EXCLUDING lines starting with 'SHA256' and 'CPRY'
+
+        This hash corresponds to the sha256 hash printed in the header of modern POTCAR files.
+
+        :return: Hash value.
+        """
+        # we have to remove lines with the hash itself and the copyright
+        # notice to get the correct hash.
+        potcar_list = self.data.split("\n")
+        potcar_to_hash = [line for line in potcar_list if not line.strip().startswith(("SHA256", "COPYR"))]
+        potcar_to_hash_str = "\n".join(potcar_to_hash)
+        return sha256(potcar_to_hash_str.encode("utf-8")).hexdigest()
+
     def get_potcar_file_hash(self):
         """
-        Computes a hash of the entire PotcarSingle.
+        Computes a md5 hash of the entire PotcarSingle.
 
         This hash corresponds to the md5 hash of the POTCAR file itself.
 
         :return: Hash value.
         """
-        return md5(str(self).encode("utf-8")).hexdigest()
+        # usedforsecurity=False needed in FIPS mode (Federal Information Processing Standards)
+        # https://github.com/materialsproject/pymatgen/issues/2804
+        md5 = hashlib.new("md5", usedforsecurity=False)  # hashlib.md5(usedforsecurity=False) is py39+
+        md5.update(self.data.encode("utf-8"))
+        return md5.hexdigest()
 
     def get_potcar_hash(self):
         """
-        Computes a md5 hash of the data defining the PotcarSingle.
+        Computes a md5 hash of the metadata defining the PotcarSingle.
 
         :return: Hash value.
         """
         hash_str = ""
         for k, v in self.PSCTR.items():
-            if k in ("nentries", "Orbitals"):
+            # for newer POTCARS we have to exclude 'SHA256' and 'COPYR lines
+            # since they were not used in the initial hashing
+            if k in ("nentries", "Orbitals", "SHA256", "COPYR"):
                 continue
             hash_str += f"{k}"
-            if isinstance(v, int):
+            if isinstance(v, bool):
                 hash_str += f"{v}"
             elif isinstance(v, float):
                 hash_str += f"{v:.3f}"
-            elif isinstance(v, bool):
-                hash_str += f"{bool}"
+            elif isinstance(v, int):
+                hash_str += f"{v}"
             elif isinstance(v, (tuple, list)):
                 for item in v:
                     if isinstance(item, float):
@@ -2149,7 +2217,11 @@ class PotcarSingle:
                 hash_str += v.replace(" ", "")
 
         self.hash_str = hash_str
-        return md5(hash_str.lower().encode("utf-8")).hexdigest()
+        # usedforsecurity=False needed in FIPS mode (Federal Information Processing Standards)
+        # https://github.com/materialsproject/pymatgen/issues/2804
+        md5 = hashlib.new("md5", usedforsecurity=False)  # hashlib.md5(usedforsecurity=False) is py39+
+        md5.update(hash_str.lower().encode("utf-8"))
+        return md5.hexdigest()
 
     def __getattr__(self, a):
         """
@@ -2171,7 +2243,7 @@ class Potcar(list, MSONable):
     list of PotcarSingle.
     """
 
-    FUNCTIONAL_CHOICES = list(PotcarSingle.functional_dir)
+    FUNCTIONAL_CHOICES = tuple(PotcarSingle.functional_dir)
 
     def __init__(self, symbols=None, functional=None, sym_potcar_map=None):
         """
@@ -2223,32 +2295,25 @@ class Potcar(list, MSONable):
         :param filename: Filename
         :return: Potcar
         """
-        try:
-            with zopen(filename, "rt") as f:
-                fdata = f.read()
-        except UnicodeDecodeError:
-            warnings.warn("POTCAR contains invalid unicode errors. We will attempt to read it by ignoring errors.")
-            import codecs
-
-            with codecs.open(filename, "r", encoding="utf-8", errors="ignore") as f:
-                fdata = f.read()
-
+        with zopen(filename, "rt") as f:
+            fdata = f.read()
         potcar = Potcar()
-        potcar_strings = re.compile(r"\n?(\s*.*?End of Dataset)", re.S).findall(fdata)
+
         functionals = []
-        for p in potcar_strings:
-            single = PotcarSingle(p)
-            potcar.append(single)
-            functionals.append(single.functional)
+        for p in fdata.split("End of Dataset"):
+            if p_strip := p.strip():
+                single = PotcarSingle(p_strip + "\nEnd of Dataset\n")
+                potcar.append(single)
+                functionals.append(single.functional)
         if len(set(functionals)) != 1:
             raise ValueError("File contains incompatible functionals!")
         potcar.functional = functionals[0]
         return potcar
 
-    def __str__(self):
-        return "\n".join([str(potcar).strip("\n") for potcar in self]) + "\n"
+    def __str__(self) -> str:
+        return "\n".join(str(potcar).strip("\n") for potcar in self) + "\n"
 
-    def write_file(self, filename):
+    def write_file(self, filename: str) -> None:
         """
         Write Potcar to a file.
 
@@ -2406,7 +2471,7 @@ class VaspInput(dict, MSONable):
     def run_vasp(
         self,
         run_dir: PathLike = ".",
-        vasp_cmd: list = None,
+        vasp_cmd: list | None = None,
         output_file: PathLike = "vasp.out",
         err_file: PathLike = "vasp.err",
     ):
@@ -2426,6 +2491,5 @@ class VaspInput(dict, MSONable):
         vasp_cmd = [os.path.expanduser(os.path.expandvars(t)) for t in vasp_cmd]
         if not vasp_cmd:
             raise RuntimeError("You need to supply vasp_cmd or set the PMG_VASP_EXE in .pmgrc.yaml to run VASP.")
-        with cd(run_dir):
-            with open(output_file, "w") as f_std, open(err_file, "w", buffering=1) as f_err:
-                subprocess.check_call(vasp_cmd, stdout=f_std, stderr=f_err)
+        with cd(run_dir), open(output_file, "w") as f_std, open(err_file, "w", buffering=1) as f_err:
+            subprocess.check_call(vasp_cmd, stdout=f_std, stderr=f_err)
