@@ -1,22 +1,13 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
 """Classes for parsing and manipulating VASP optical properties calculations."""
 
 from __future__ import annotations
 
 import itertools
-
-__author__ = "Jimmy-Xuan Shen"
-__copyright__ = "Copyright 2022, The Materials Project"
-__maintainer__ = "Jimmy-Xuan Shen"
-__email__ = "jmmshn@gmail.com"
-
-
 from dataclasses import dataclass
 from pathlib import Path
+from typing import TYPE_CHECKING
 
 import numpy as np
-import numpy.typing as npt
 import scipy.constants
 import scipy.special
 from monty.json import MSONable
@@ -25,6 +16,14 @@ from tqdm import tqdm
 from pymatgen.electronic_structure.core import Spin
 from pymatgen.io.vasp.outputs import Vasprun, Waveder
 
+if TYPE_CHECKING:
+    from numpy.typing import ArrayLike, NDArray
+
+__author__ = "Jimmy-Xuan Shen"
+__copyright__ = "Copyright 2022, The Materials Project"
+__maintainer__ = "Jimmy-Xuan Shen"
+__email__ = "jmmshn@gmail.com"
+
 au2ang = scipy.constants.physical_constants["atomic unit of length"][0] / 1e-10
 ryd2ev = scipy.constants.physical_constants["Rydberg constant times hc in eV"][0]
 edeps = 4 * np.pi * 2 * ryd2ev * au2ang  # from constant.inc in VASP
@@ -50,16 +49,16 @@ class DielectricFunctionCalculator(MSONable):
         - Perform symmetry operations (this is not implemented here)
         - Calculate the real part
 
-    Currently, this Calculator only works for ``ISYM=0`` calculations since we cannot gauranttee that our
-    externally defined symmetry operations are the same as VASP's.  This can be fixed by printing the
-    symmetry operators into the vasprun.xml file.  If this happens in future versions of VASP,
+    Currently, this Calculator only works for ``ISYM=0`` calculations since we cannot guarantee that our
+    externally defined symmetry operations are the same as VASP's. This can be fixed by printing the
+    symmetry operators into the vasprun.xml file. If this happens in future versions of VASP,
     we can dramatically speed up the calculations here by considering only the irreducible kpoints.
     """
 
-    cder_real: npt.NDArray
-    cder_imag: npt.NDArray
-    eigs: npt.NDArray
-    kweights: npt.NDArray
+    cder_real: NDArray
+    cder_imag: NDArray
+    eigs: NDArray
+    kweights: NDArray
     nedos: int
     deltae: float
     ismear: int
@@ -142,14 +141,14 @@ class DielectricFunctionCalculator(MSONable):
         self,
         idir: int,
         jdir: int,
-        efermi: float = None,
-        nedos: int = None,
-        deltae: float = None,
-        ismear: int = None,
-        sigma: float = None,
-        cshift: float = None,
-        mask: npt.NDArray | None = None,
-    ) -> tuple[npt.NDArray, npt.NDArray]:
+        efermi: float | None = None,
+        nedos: int | None = None,
+        deltae: float | None = None,
+        ismear: int | None = None,
+        sigma: float | None = None,
+        cshift: float | None = None,
+        mask: NDArray | None = None,
+    ) -> tuple[NDArray, NDArray]:
         """Compute the frequency dependent dielectric function.
 
         Args:
@@ -194,9 +193,7 @@ class DielectricFunctionCalculator(MSONable):
             eps += 1.0 + 0.0j
         return egrid, eps
 
-    def plot_weighted_transition_data(
-        self, idir: int, jdir: int, mask: npt.NDArray | None = None, min_val: float = 0.0
-    ):
+    def plot_weighted_transition_data(self, idir: int, jdir: int, mask: NDArray | None = None, min_val: float = 0.0):
         """Data for plotting the weight matrix elements as a scatter plot.
 
         Since the computation of the final spectrum (especially the smearing part)
@@ -212,10 +209,7 @@ class DielectricFunctionCalculator(MSONable):
                 index to include in the calculation
             min_val: Minimum value below this value the matrix element will not be shown.
         """
-        if mask is not None:
-            cderm = self.cder * mask
-        else:
-            cderm = self.cder
+        cderm = self.cder * mask if mask is not None else self.cder
 
         norm_kweights = np.array(self.kweights) / np.sum(self.kweights)
         eigs_shifted = self.eigs - self.efermi
@@ -224,11 +218,10 @@ class DielectricFunctionCalculator(MSONable):
         try:
             min_band0, max_band0 = np.min(np.where(cderm)[0]), np.max(np.where(cderm)[0])
             min_band1, max_band1 = np.min(np.where(cderm)[1]), np.max(np.where(cderm)[1])
-        except ValueError as e:
-            if "zero-size array" in str(e):
-                raise ValueError("No matrix elements found.  Check the mask.")
-            else:
-                raise e
+        except ValueError as exc:
+            if "zero-size array" in str(exc):
+                raise ValueError("No matrix elements found. Check the mask.")
+            raise
 
         x_val = []
         y_val = []
@@ -283,9 +276,9 @@ def delta_func(x, ismear):
     """Replication of VASP's delta function"""
     if ismear < -1:
         raise ValueError("Delta function not implemented for ismear < -1")
-    elif ismear == -1:
+    if ismear == -1:
         return step_func(x, -1) * (1 - step_func(x, -1))
-    elif ismear < 0:
+    if ismear == 0:
         return np.exp(-(x * x)) / np.sqrt(np.pi)
     return delta_methfessel_paxton(x, ismear)
 
@@ -294,9 +287,9 @@ def step_func(x, ismear):
     """Replication of VASP's step function"""
     if ismear < -1:
         raise ValueError("Delta function not implemented for ismear < -1")
-    elif ismear == -1:
+    if ismear == -1:
         return 1 / (1.0 + np.exp(-x))
-    elif ismear < 0:
+    if ismear == 0:
         return 0.5 + 0.5 * scipy.special.erf(x)
     return step_methfessel_paxton(x, ismear)
 
@@ -349,9 +342,9 @@ def get_step(x0, sigma, nx, dx, ismear):
 
 
 def epsilon_imag(
-    cder: npt.NDArray,
-    eigs: npt.NDArray,
-    kweights: npt.ArrayLike,
+    cder: NDArray,
+    eigs: NDArray,
+    kweights: ArrayLike,
     efermi: float,
     nedos: int,
     deltae: float,
@@ -359,7 +352,7 @@ def epsilon_imag(
     sigma: float,
     idir: int,
     jdir: int,
-    mask: npt.NDArray | None = None,
+    mask: NDArray | None = None,
 ):
     """Replicate the EPSILON_IMAG function of VASP.
 
@@ -388,10 +381,7 @@ def epsilon_imag(
 
     # for the transition between two bands at one kpoint the contributions is:
     #  (fermi[band_i] - fermi[band_j]) * rspin * normalized_kpoint_weight
-    if mask is not None:
-        cderm = cder * mask
-    else:
-        cderm = cder
+    cderm = cder * mask if mask is not None else cder
 
     # min_band0, max_band0 = np.min(np.where(cderm)[0]), np.max(np.where(cderm)[0])
     # min_band1, max_band1 = np.min(np.where(cderm)[1]), np.max(np.where(cderm)[1])
@@ -413,7 +403,7 @@ def epsilon_imag(
     num_ = (max_band0 - min_band0) * (max_band1 - min_band1) * nk * nspin
     epsdd = np.zeros_like(egrid, dtype=np.complex128)
     for ib, jb, ik, ispin in tqdm(itertools.product(*iter_idx), total=num_):
-        # print(f"ib={ib}, jb={jb}, ik={ik}, ispin={ispin}")
+        # print(f"{ib=}, {jb=}, {ik=}, {ispin=}")
         fermi_w_i = step_func((eigs_shifted[ib, ik, ispin]) / sigma, ismear)
         fermi_w_j = step_func((eigs_shifted[jb, ik, ispin]) / sigma, ismear)
         weight = (fermi_w_j - fermi_w_i) * rspin * norm_kweights[ik]
@@ -433,7 +423,7 @@ def kramers_kronig(
     nedos: int,
     deltae: float,
     cshift: float = 0.1,
-) -> npt.NDArray:
+) -> NDArray:
     """Perform the Kramers-Kronig transformation.
 
     Perform the Kramers-Kronig transformation exactly as VASP does it.
