@@ -1,9 +1,6 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
+"""This module defines classes to represent the phonon density of states, etc."""
 
-"""
-This module defines classes to represent the phonon density of states, etc.
-"""
+from __future__ import annotations
 
 import numpy as np
 import scipy.constants as const
@@ -82,7 +79,7 @@ class PhononDos(MSONable):
 
     def __radd__(self, other):
         """
-        Reflected addition of two DOS objects
+        Reflected addition of two DOS objects.
 
         Args:
             other: Another DOS object.
@@ -102,9 +99,7 @@ class PhononDos(MSONable):
         return get_linear_interpolated_value(self.frequencies, self.densities, frequency)
 
     def __str__(self):
-        """
-        Returns a string which can be easily plotted (using gnuplot).
-        """
+        """Returns a string which can be easily plotted (using gnuplot)."""
         stringarray = [f"#{'Frequency':30s} {'Density':30s}"]
         for i, frequency in enumerate(self.frequencies):
             stringarray.append(f"{frequency:.5f} {self.densities[i]:.5f}")
@@ -112,15 +107,11 @@ class PhononDos(MSONable):
 
     @classmethod
     def from_dict(cls, d):
-        """
-        Returns PhononDos object from dict representation of PhononDos.
-        """
+        """Returns PhononDos object from dict representation of PhononDos."""
         return cls(d["frequencies"], d["densities"])
 
     def as_dict(self):
-        """
-        JSON-serializable dict representation of PhononDos.
-        """
+        """JSON-serializable dict representation of PhononDos."""
         return {
             "@module": type(self).__module__,
             "@class": type(self).__name__,
@@ -130,9 +121,7 @@ class PhononDos(MSONable):
 
     @lazy_property
     def ind_zero_freq(self):
-        """
-        Index of the first point for which the frequencies are equal or greater than zero.
-        """
+        """Index of the first point for which the frequencies are equal or greater than zero."""
         ind = np.searchsorted(self.frequencies, 0)
         if ind >= len(self.frequencies):
             raise ValueError("No positive frequencies found")
@@ -140,16 +129,12 @@ class PhononDos(MSONable):
 
     @lazy_property
     def _positive_frequencies(self):
-        """
-        Numpy array containing the list of positive frequencies
-        """
+        """Numpy array containing the list of positive frequencies."""
         return self.frequencies[self.ind_zero_freq :]
 
     @lazy_property
     def _positive_densities(self):
-        """
-        Numpy array containing the list of densities corresponding to positive frequencies
-        """
+        """Numpy array containing the list of densities corresponding to positive frequencies."""
         return self.densities[self.ind_zero_freq :]
 
     def cv(self, t, structure=None):
@@ -159,7 +144,7 @@ class PhononDos(MSONable):
         Result in J/(K*mol-c). A mol-c is the abbreviation of a mole-cell, that is, the number
         of Avogadro times the atoms in a unit cell. To compare with experimental data the result
         should be divided by the number of unit formulas in the cell. If the structure is provided
-        the division is performed internally and the result is in J/(K*mol)
+        the division is performed internally and the result is in J/(K*mol).
 
         Args:
             t: a temperature in K
@@ -194,7 +179,7 @@ class PhononDos(MSONable):
         Result in J/(K*mol-c). A mol-c is the abbreviation of a mole-cell, that is, the number
         of Avogadro times the atoms in a unit cell. To compare with experimental data the result
         should be divided by the number of unit formulas in the cell. If the structure is provided
-        the division is performed internally and the result is in J/(K*mol)
+        the division is performed internally and the result is in J/(K*mol).
 
         Args:
             t: a temperature in K
@@ -227,7 +212,7 @@ class PhononDos(MSONable):
         Result in J/mol-c. A mol-c is the abbreviation of a mole-cell, that is, the number
         of Avogadro times the atoms in a unit cell. To compare with experimental data the result
         should be divided by the number of unit formulas in the cell. If the structure is provided
-        the division is performed internally and the result is in J/mol
+        the division is performed internally and the result is in J/mol.
 
         Args:
             t: a temperature in K
@@ -260,7 +245,7 @@ class PhononDos(MSONable):
         Result in J/mol-c. A mol-c is the abbreviation of a mole-cell, that is, the number
         of Avogadro times the atoms in a unit cell. To compare with experimental data the result
         should be divided by the number of unit formulas in the cell. If the structure is provided
-        the division is performed internally and the result is in J/mol
+        the division is performed internally and the result is in J/mol.
 
         Args:
             t: a temperature in K
@@ -292,7 +277,7 @@ class PhononDos(MSONable):
         Result in J/mol-c. A mol-c is the abbreviation of a mole-cell, that is, the number
         of Avogadro times the atoms in a unit cell. To compare with experimental data the result
         should be divided by the number of unit formulas in the cell. If the structure is provided
-        the division is performed internally and the result is in J/mol
+        the division is performed internally and the result is in J/mol.
 
         Args:
             structure: the structure of the system. If not None it will be used to determine the number of
@@ -327,7 +312,7 @@ class CompletePhononDos(PhononDos):
         Args:
             structure: Structure associated with this particular DOS.
             total_dos: total Dos for structure
-            pdoss: The pdoss are supplied as an {Site: Densities}
+            pdoss: The pdoss are supplied as an {Site: Densities}.
         """
         super().__init__(frequencies=total_dos.frequencies, densities=total_dos.densities)
         self.pdos = {site: np.array(dens) for site, dens in pdoss.items()}
@@ -363,9 +348,7 @@ class CompletePhononDos(PhononDos):
 
     @classmethod
     def from_dict(cls, d):
-        """
-        Returns CompleteDos object from dict representation.
-        """
+        """Returns CompleteDos object from dict representation."""
         tdos = PhononDos.from_dict(d)
         struct = Structure.from_dict(d["structure"])
         pdoss = {}
@@ -375,9 +358,7 @@ class CompletePhononDos(PhononDos):
         return cls(struct, tdos, pdoss)
 
     def as_dict(self):
-        """
-        JSON-serializable dict representation of CompletePhononDos.
-        """
+        """JSON-serializable dict representation of CompletePhononDos."""
         d = {
             "@module": type(self).__module__,
             "@class": type(self).__name__,
