@@ -1,9 +1,4 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
-"""
-This module implements plotter for DOS and band structure.
-"""
+"""This module implements plotter for DOS and band structure."""
 
 from __future__ import annotations
 
@@ -29,13 +24,12 @@ def freq_units(units):
     """
 
     Args:
-        units: str, accepted values: thz, ev, mev, ha, cm-1, cm^-1
+        units: str, accepted values: thz, ev, mev, ha, cm-1, cm^-1.
 
     Returns:
         Returns conversion factor from THz to the required units and the label in the form of a namedtuple
 
     """
-
     d = {
         "thz": FreqUnits(1, "THz"),
         "ev": FreqUnits(const.value("hertz-electron volt relationship") * const.tera, "eV"),
@@ -61,20 +55,17 @@ def freq_units(units):
 
 class PhononDosPlotter:
     """
-    Class for plotting phonon DOSs. Note that the interface is extremely flexible
-    given that there are many different ways in which people want to view
-    DOS. The typical usage is::
+    Class for plotting phonon DOSs. The interface is extremely flexible given there are many
+    different ways in which people want to view DOS.
+    Typical usage is:
+        # Initializes plotter with some optional args. Defaults are usually fine
+        plotter = PhononDosPlotter().
 
-        # Initializes plotter with some optional args. Defaults are usually
-        # fine,
-        plotter = PhononDosPlotter()
-
-        # Adds a DOS with a label.
+        # Add DOS with a label
         plotter.add_dos("Total DOS", dos)
 
-        # Alternatively, you can add a dict of DOSs. This is the typical
-        # form returned by CompletePhononDos.get_element_dos().
-
+        # Alternatively, you can add a dict of DOSes. This is the typical form
+        # returned by CompletePhononDos.get_element_dos().
     """
 
     def __init__(self, stack=False, sigma=None):
@@ -82,8 +73,7 @@ class PhononDosPlotter:
         Args:
             stack: Whether to plot the DOS as a stacked area graph
             sigma: A float specifying a standard deviation for Gaussian smearing
-            the DOS for nicer looking plots. Defaults to None for no
-            smearing.
+                the DOS for nicer looking plots. Defaults to None for no smearing.
         """
         self.stack = stack
         self.sigma = sigma
@@ -111,10 +101,7 @@ class PhononDosPlotter:
             dos_dict: dict of {label: Dos}
             key_sort_func: function used to sort the dos_dict keys.
         """
-        if key_sort_func:
-            keys = sorted(dos_dict, key=key_sort_func)
-        else:
-            keys = list(dos_dict)
+        keys = sorted(dos_dict, key=key_sort_func) if key_sort_func else list(dos_dict)
         for label in keys:
             self.add_dos(label, dos_dict[label])
 
@@ -240,9 +227,7 @@ class PhononDosPlotter:
 
 
 class PhononBSPlotter:
-    """
-    Class to plot or get data to facilitate the plot of band structure objects.
-    """
+    """Class to plot or get data to facilitate the plot of band structure objects."""
 
     def __init__(self, bs):
         """
@@ -259,9 +244,7 @@ class PhononBSPlotter:
         self._nb_bands = self._bs.nb_bands
 
     def _maketicks(self, plt):
-        """
-        utility private method to add ticks to a band structure
-        """
+        """Utility private method to add ticks to a band structure."""
         ticks = self.get_ticks()
         # Sanitize only plot the uniq values
         uniq_d = []
@@ -272,13 +255,12 @@ class PhononBSPlotter:
                 uniq_d.append(tt[0])
                 uniq_l.append(tt[1])
                 logger.debug(f"Adding label {tt[0]} at {tt[1]}")
+            elif tt[1] == temp_ticks[i - 1][1]:
+                logger.debug(f"Skipping label {tt[1]}")
             else:
-                if tt[1] == temp_ticks[i - 1][1]:
-                    logger.debug(f"Skipping label {tt[1]}")
-                else:
-                    logger.debug(f"Adding label {tt[0]} at {tt[1]}")
-                    uniq_d.append(tt[0])
-                    uniq_l.append(tt[1])
+                logger.debug(f"Adding label {tt[0]} at {tt[1]}")
+                uniq_d.append(tt[0])
+                uniq_l.append(tt[1])
 
         logger.debug(f"Unique labels are {list(zip(uniq_d, uniq_l))}")
         plt.gca().set_xticks(uniq_d)
@@ -300,7 +282,7 @@ class PhononBSPlotter:
 
     def bs_plot_data(self):
         """
-        Get the data nicely formatted for a plot
+        Get the data nicely formatted for a plot.
 
         Returns:
             A dict of the following format:
@@ -317,7 +299,6 @@ class PhononBSPlotter:
         ticks = self.get_ticks()
 
         for b in self._bs.branches:
-
             frequency.append([])
             distance.append([self._bs.distance[j] for j in range(b["start_index"], b["end_index"] + 1)])
 
@@ -381,7 +362,7 @@ class PhononBSPlotter:
     def _get_weight(self, vec: np.ndarray, indices: list[list[int]]) -> np.ndarray:
         """
         compute the weight for each combination of sites according to the
-        eigenvector
+        eigenvector.
         """
         num_atom = int(self._nb_bands / 3)
         new_vec = np.zeros(num_atom)
@@ -392,10 +373,9 @@ class PhononBSPlotter:
         norm_f = 0
         for comb in indices:
             projector = np.zeros(len(new_vec))
-            l = len(projector)
-            for j in range(l):
-                if j in comb:
-                    projector[j] = 1
+            for idx in range(len(projector)):
+                if idx in comb:
+                    projector[idx] = 1
             group_weight = np.dot(projector, new_vec)
             gw.append(group_weight)
             norm_f += group_weight
@@ -403,17 +383,14 @@ class PhononBSPlotter:
 
     @staticmethod
     def _make_color(colors: list[int]) -> list[int]:
-        """
-        convert the eigendisplacements to rgb colors
-
-        """
+        """Convert the eigendisplacements to rgb colors."""
         # if there are two groups, use red and blue
         if len(colors) == 2:
             return [colors[0], 0, colors[1]]
-        elif len(colors) == 3:
+        if len(colors) == 3:
             return colors
         # if there are four groups, use cyan, magenta, yellow and black
-        elif len(colors) == 4:
+        if len(colors) == 4:
             r = (1 - colors[0]) * (1 - colors[3])
             g = (1 - colors[1]) * (1 - colors[3])
             b = (1 - colors[2]) * (1 - colors[3])
@@ -423,9 +400,9 @@ class PhononBSPlotter:
     def get_proj_plot(
         self,
         site_comb: str | list[list[int]] = "element",
-        ylim: tuple[None | float, None | float] = None,
+        ylim: tuple[None | float, None | float] | None = None,
         units: str = "thz",
-        rgb_labels: tuple[None | str] = None,
+        rgb_labels: tuple[None | str] | None = None,
     ) -> plt.Axes:
         """
         Get a matplotlib object for the bandstructure plot projected along atomic
@@ -434,11 +411,14 @@ class PhononBSPlotter:
         Args:
             site_comb: a list of list, for example, [[0],[1],[2,3,4]];
                 the numbers in each sublist represents the indices of atoms;
-                the atoms in a same sublist will be plotted in a same color；
+                the atoms in a same sublist will be plotted in a same color;
                 if not specified, unique elements are automatically grouped.
             ylim: Specify the y-axis (frequency) limits; by default None let
                 the code choose.
             units: units for the frequencies. Accepted values thz, ev, mev, ha, cm-1, cm^-1.
+                Defaults to "thz".
+            rgb_labels: a list of rgb colors for the labels; if not specified,
+                the colors will be automatically generated.
         """
         from matplotlib.collections import LineCollection
 
@@ -503,11 +483,10 @@ class PhononBSPlotter:
         labels: list[str]
         if rgb_labels is not None:
             labels = rgb_labels  # type: ignore[assignment]
+        elif site_comb == "element":
+            labels = [e.symbol for e in self._bs.structure.composition.elements]
         else:
-            if site_comb == "element":
-                labels = [e.symbol for e in self._bs.structure.composition.elements]
-            else:
-                labels = [f"{i}" for i in range(len(site_comb))]
+            labels = [f"{i}" for i in range(len(site_comb))]
         if len(indices) == 2:
             BSDOSPlotter._rb_line(ax, labels[0], labels[1], "best")
         elif len(indices) == 3:
@@ -546,17 +525,24 @@ class PhononBSPlotter:
     def show_proj(
         self,
         site_comb: str | list[list[int]] = "element",
-        ylim: tuple[None | float, None | float] = None,
+        ylim: tuple[None | float, None | float] | None = None,
         units: str = "thz",
-        rgb_labels: tuple[str] = None,
+        rgb_labels: tuple[str] | None = None,
     ):
         """
         Show the projected plot using matplotlib.
 
         Args:
+            site_comb: A list of list of indices of sites to combine. For example,
+                [[0, 1], [2, 3]] will combine the projections of sites 0 and 1,
+                and sites 2 and 3. Defaults to "element", which will combine
+                sites by element.
             ylim: Specify the y-axis (frequency) limits; by default None let
                 the code choose.
             units: units for the frequencies. Accepted values thz, ev, mev, ha, cm-1, cm^-1.
+                Defaults to "thz".
+            rgb_labels: A list of labels for the rgb triangle. Defaults to None,
+                which will use the element symbols.
         """
         self.get_proj_plot(site_comb=site_comb, ylim=ylim, units=units, rgb_labels=rgb_labels)
         plt.show()
@@ -591,11 +577,10 @@ class PhononBSPlotter:
                     tick_labels.pop()
                     tick_distance.pop()
                     tick_labels.append(label0 + "$\\mid$" + label1)
+                elif c.label.startswith("\\") or c.label.find("_") != -1:
+                    tick_labels.append("$" + c.label + "$")
                 else:
-                    if c.label.startswith("\\") or c.label.find("_") != -1:
-                        tick_labels.append("$" + c.label + "$")
-                    else:
-                        tick_labels.append(c.label)
+                    tick_labels.append(c.label)
                 previous_label = c.label
                 previous_branch = this_branch
         return {"distance": tick_distance, "label": tick_labels}
@@ -605,11 +590,13 @@ class PhononBSPlotter:
         plot two band structure for comparison. One is in red the other in blue.
         The two band structures need to be defined on the same symmetry lines!
         and the distance between symmetry lines is the one of the band structure
-        used to build the PhononBSPlotter
+        used to build the PhononBSPlotter.
 
         Args:
             other_plotter: another PhononBSPlotter object defined along the same symmetry lines
-            units:
+            units: units for the frequencies. Accepted values thz, ev, mev, ha, cm-1, cm^-1.
+                Defaults to 'thz'.
+
         Returns:
             a matplotlib object with both band structures
         """
@@ -635,9 +622,7 @@ class PhononBSPlotter:
         return plt
 
     def plot_brillouin(self):
-        """
-        plot the Brillouin zone
-        """
+        """Plot the Brillouin zone."""
         # get labels and lines
         labels = {}
         for q in self._bs.qpoints:
@@ -660,7 +645,7 @@ class ThermoPlotter:
     """
     Plotter for thermodynamic properties obtained from phonon DOS.
     If the structure corresponding to the DOS, it will be used to extract the formula unit and provide
-    the plots in units of mol instead of mole-cell
+    the plots in units of mol instead of mole-cell.
     """
 
     def __init__(self, dos, structure=None):
@@ -686,6 +671,7 @@ class ThermoPlotter:
             label: label of the plot
             ylim: tuple specifying the y-axis limits.
             kwargs: kwargs passed to the matplotlib function 'plot'.
+
         Returns:
             matplotlib figure
         """
@@ -723,15 +709,13 @@ class ThermoPlotter:
             ntemp: number of steps
             ylim: tuple specifying the y-axis limits.
             kwargs: kwargs passed to the matplotlib function 'plot'.
+
         Returns:
             matplotlib figure
         """
         temperatures = np.linspace(tmin, tmax, ntemp)
 
-        if self.structure:
-            ylabel = r"$C_v$ (J/K/mol)"
-        else:
-            ylabel = r"$C_v$ (J/K/mol-c)"
+        ylabel = "$C_v$ (J/K/mol)" if self.structure else "$C_v$ (J/K/mol-c)"
 
         fig = self._plot_thermo(self.dos.cv, temperatures, ylabel=ylabel, ylim=ylim, **kwargs)
 
@@ -748,15 +732,13 @@ class ThermoPlotter:
             ntemp: number of steps
             ylim: tuple specifying the y-axis limits.
             kwargs: kwargs passed to the matplotlib function 'plot'.
+
         Returns:
             matplotlib figure
         """
         temperatures = np.linspace(tmin, tmax, ntemp)
 
-        if self.structure:
-            ylabel = r"$S$ (J/K/mol)"
-        else:
-            ylabel = r"$S$ (J/K/mol-c)"
+        ylabel = "$S$ (J/K/mol)" if self.structure else "$S$ (J/K/mol-c)"
 
         fig = self._plot_thermo(self.dos.entropy, temperatures, ylabel=ylabel, ylim=ylim, **kwargs)
 
@@ -773,15 +755,13 @@ class ThermoPlotter:
             ntemp: number of steps
             ylim: tuple specifying the y-axis limits.
             kwargs: kwargs passed to the matplotlib function 'plot'.
+
         Returns:
             matplotlib figure
         """
         temperatures = np.linspace(tmin, tmax, ntemp)
 
-        if self.structure:
-            ylabel = r"$\Delta E$ (kJ/mol)"
-        else:
-            ylabel = r"$\Delta E$ (kJ/mol-c)"
+        ylabel = "$\\Delta E$ (kJ/mol)" if self.structure else "$\\Delta E$ (kJ/mol-c)"
 
         fig = self._plot_thermo(self.dos.internal_energy, temperatures, ylabel=ylabel, ylim=ylim, factor=1e-3, **kwargs)
 
@@ -798,15 +778,13 @@ class ThermoPlotter:
             ntemp: number of steps
             ylim: tuple specifying the y-axis limits.
             kwargs: kwargs passed to the matplotlib function 'plot'.
+
         Returns:
             matplotlib figure
         """
         temperatures = np.linspace(tmin, tmax, ntemp)
 
-        if self.structure:
-            ylabel = r"$\Delta F$ (kJ/mol)"
-        else:
-            ylabel = r"$\Delta F$ (kJ/mol-c)"
+        ylabel = "$\\Delta F$ (kJ/mol)" if self.structure else "$\\Delta F$ (kJ/mol-c)"
 
         fig = self._plot_thermo(
             self.dos.helmholtz_free_energy, temperatures, ylabel=ylabel, ylim=ylim, factor=1e-3, **kwargs
@@ -825,6 +803,7 @@ class ThermoPlotter:
             ntemp: number of steps
             ylim: tuple specifying the y-axis limits.
             kwargs: kwargs passed to the matplotlib function 'plot'.
+
         Returns:
             matplotlib figure
         """
@@ -868,15 +847,13 @@ class ThermoPlotter:
 
 
 class GruneisenPlotter:
-    """
-    Class to plot Gruneisenparameter Object
-    """
+    """Class to plot Gruneisenparameter Object."""
 
     def __init__(self, gruneisen):
         """
         Class to plot information from Gruneisenparameter Object
         Args:
-            gruneisen: GruneisenParameter Object
+            gruneisen: GruneisenParameter Object.
         """
         self._gruneisen = gruneisen
 
@@ -886,7 +863,7 @@ class GruneisenPlotter:
         Args:
             marker: marker for the depiction
             markersize: size of the marker
-            units: unit for the plots, accepted units: thz, ev, mev, ha, cm-1, cm^-1
+            units: unit for the plots, accepted units: thz, ev, mev, ha, cm-1, cm^-1.
 
         Returns: plot
         """
@@ -917,7 +894,7 @@ class GruneisenPlotter:
         """
         will show the plot
         Args:
-            units: units for the plot, accepted units: thz, ev, mev, ha, cm-1, cm^-1
+            units: units for the plot, accepted units: thz, ev, mev, ha, cm-1, cm^-1.
 
         Returns: plot
         """
@@ -930,9 +907,7 @@ class GruneisenPlotter:
         Args:
             filename: name of the filename
             img_format: format of the saved plot
-            units: accepted units: thz, ev, mev, ha, cm-1, cm^-1
-
-        Returns:
+            units: accepted units: thz, ev, mev, ha, cm-1, cm^-1.
         """
         plt = self.get_plot(units=units)
         plt.savefig(filename, format=img_format)
@@ -940,9 +915,7 @@ class GruneisenPlotter:
 
 
 class GruneisenPhononBSPlotter(PhononBSPlotter):
-    """
-    Class to plot or get data to facilitate the plot of band structure objects.
-    """
+    """Class to plot or get data to facilitate the plot of band structure objects."""
 
     def __init__(self, bs):
         """
@@ -959,7 +932,7 @@ class GruneisenPhononBSPlotter(PhononBSPlotter):
 
     def bs_plot_data(self):
         """
-        Get the data nicely formatted for a plot
+        Get the data nicely formatted for a plot.
 
         Returns:
             A dict of the following format:
@@ -976,7 +949,6 @@ class GruneisenPhononBSPlotter(PhononBSPlotter):
         ticks = self.get_ticks()
 
         for b in self._bs.branches:
-
             frequency.append([])
             gruneisen.append([])
             distance.append([self._bs.distance[j] for j in range(b["start_index"], b["end_index"] + 1)])
@@ -1062,15 +1034,16 @@ class GruneisenPhononBSPlotter(PhononBSPlotter):
         plt.savefig(filename, format=img_format)
         plt.close()
 
-    def plot_compare_gs(self, other_plotter):
+    def plot_compare_gs(self, other_plotter: GruneisenPhononBSPlotter) -> plt:
         """
         plot two band structure for comparison. One is in red the other in blue.
         The two band structures need to be defined on the same symmetry lines!
         and the distance between symmetry lines is
-        the one of the band structure used to build the PhononBSPlotter
+        the one of the band structure used to build the PhononBSPlotter.
 
         Args:
-            another GruneisenPhononBSPlotter object defined along the same symmetry lines
+            other_plotter (GruneisenPhononBSPlotter): another phonon DOS plotter defined along
+                the same symmetry lines.
 
         Returns:
             a matplotlib object with both band structures
