@@ -1,9 +1,5 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
-"""
-This module provides classes to handle thermal displacement matrices (anisotropic displacement parameters).
-"""
+"""This module provides classes to handle thermal displacement matrices (anisotropic displacement parameters)."""
+from __future__ import annotations
 
 import re
 from functools import partial
@@ -38,26 +34,26 @@ __date__ = "August 09, 2022"
 class ThermalDisplacementMatrices(MSONable):
     """
     Class to handle thermal displacement matrices
-    This class stores thermal displacement matrices in Ucart format
+    This class stores thermal displacement matrices in Ucart format.
 
     An earlier implementation based on Matlab can be found here:
     https://github.com/JaGeo/MolecularToolbox
-    ( J. George, A. Wang, V. L. Deringer, R. Wang, R. Dronskowski, U. Englert, CrystEngComm, 2015, 17, 7414–7422.)
+    ( J. George, A. Wang, V. L. Deringer, R. Wang, R. Dronskowski, U. Englert, CrystEngComm, 2015, 17, 7414-7422.)
     """
 
     def __init__(self, thermal_displacement_matrix_cart, structure, temperature, thermal_displacement_matrix_cif=None):
         """
         Args:
-            thermal_displacement_matrix: 2D numpy array including the thermal_displacement matrix Ucart
+            thermal_displacement_matrix_cart: 2D numpy array including the thermal_displacement matrix Ucart
                 1st dimension atom types, then compressed thermal displacement matrix will follow
-                 U11, U22, U33, U23, U13, U12 (xx, yy, zz, yz, xz, xy)
-                 convention similar to "thermal_displacement_matrices.yaml" in phonopy
+                U11, U22, U33, U23, U13, U12 (xx, yy, zz, yz, xz, xy)
+                convention similar to "thermal_displacement_matrices.yaml" in phonopy
             structure: A pymatgen Structure object
             temperature: temperature at which thermal displacement matrix was determined
-            thermal_displacement_matrix: 2D numpy array including the thermal_displacement matrix Ucif format
+            thermal_displacement_matrix_cif: 2D numpy array including the thermal_displacement matrix Ucif format
                 1st dimension atom types, then compressed thermal displacement matrix will follow
-                 U11, U22, U33, U23, U13, U12 (xx, yy, zz, yz, xz, xy)
-                 convention similar to "thermal_displacement_matrices.yaml" in phonopy
+                U11, U22, U33, U23, U13, U12 (xx, yy, zz, yz, xz, xy)
+                convention similar to "thermal_displacement_matrices.yaml" in phonopy.
         """
         self.thermal_displacement_matrix_cart = np.array(thermal_displacement_matrix_cart)
         self.structure = structure
@@ -80,7 +76,7 @@ class ThermalDisplacementMatrices(MSONable):
     @staticmethod
     def get_full_matrix(thermal_displacement):
         """
-        Transfers the reduced matrix to the full matrix (order of reduced matrix U11, U22, U33, U23, U13, U12)
+        Transfers the reduced matrix to the full matrix (order of reduced matrix U11, U22, U33, U23, U13, U12).
 
         Args:
             thermal_displacement: 2d numpy array, first dimension are the atoms
@@ -105,7 +101,7 @@ class ThermalDisplacementMatrices(MSONable):
     @staticmethod
     def get_reduced_matrix(thermal_displacement):
         """
-        Transfers the full matrix to reduced matrix (order of reduced matrix U11, U22, U33, U23, U13, U12)
+        Transfers the full matrix to reduced matrix (order of reduced matrix U11, U22, U33, U23, U13, U12).
 
         Args:
             thermal_displacement: 2d numpy array, first dimension are the atoms
@@ -127,8 +123,8 @@ class ThermalDisplacementMatrices(MSONable):
     @property
     def Ustar(self):
         """
-        Computation as described in R. W. Grosse-Kunstleve, P. D. Adams, J Appl Cryst 2002, 35, 477–480.
-        Returns: Ustar as a numpy array, first dimension are the atoms in the structure
+        Computation as described in R. W. Grosse-Kunstleve, P. D. Adams, J Appl Cryst 2002, 35, 477-480.
+        Returns: Ustar as a numpy array, first dimension are the atoms in the structure.
         """
         A = self.structure.lattice.matrix.T
         Ainv = np.linalg.inv(A)
@@ -141,11 +137,11 @@ class ThermalDisplacementMatrices(MSONable):
     @property
     def Ucif(self):
         """
-        Computation as described in R. W. Grosse-Kunstleve, P. D. Adams, J Appl Cryst 2002, 35, 477–480.
-        Returns: Ucif as a numpy array, first dimension are the atoms in the structure
+        Computation as described in R. W. Grosse-Kunstleve, P. D. Adams, J Appl Cryst 2002, 35, 477-480.
+        Returns: Ucif as a numpy array, first dimension are the atoms in the structure.
         """
         if self.thermal_displacement_matrix_cif is None:
-            # computation as described in R. W. Grosse-Kunstleve, P. D. Adams, J Appl Cryst 2002, 35, 477–480.
+            # computation as described in R. W. Grosse-Kunstleve, P. D. Adams, J Appl Cryst 2002, 35, 477-480.
             # will compute Ucif based on Ustar for each atom in the structure
 
             A = self.structure.lattice.matrix.T  # check this again?
@@ -157,14 +153,13 @@ class ThermalDisplacementMatrices(MSONable):
                 mat_cif = np.dot(np.dot(Ninv, mat), Ninv.T)
                 Ucif.append(mat_cif)
             return np.array(Ucif)
-        else:
-            return self.thermal_displacement_matrix_cif_matrixform
+        return self.thermal_displacement_matrix_cif_matrixform
 
     @property
     def B(self):
         """
-        Computation as described in R. W. Grosse-Kunstleve, P. D. Adams, J Appl Cryst 2002, 35, 477–480.
-        Returns: B as a numpy array, first dimension are the atoms in the structure
+        Computation as described in R. W. Grosse-Kunstleve, P. D. Adams, J Appl Cryst 2002, 35, 477-480.
+        Returns: B as a numpy array, first dimension are the atoms in the structure.
         """
         B = []
         for mat in self.Ucif:
@@ -175,8 +170,8 @@ class ThermalDisplacementMatrices(MSONable):
     @property
     def beta(self):
         """
-        Computation as described in R. W. Grosse-Kunstleve, P. D. Adams, J Appl Cryst 2002, 35, 477–480.
-        Returns: beta as a numpy array, first dimension are the atoms in the structure
+        Computation as described in R. W. Grosse-Kunstleve, P. D. Adams, J Appl Cryst 2002, 35, 477-480.
+        Returns: beta as a numpy array, first dimension are the atoms in the structure.
         """
         # will compute beta based on Ustar
         beta = []
@@ -188,8 +183,8 @@ class ThermalDisplacementMatrices(MSONable):
     @property
     def U1U2U3(self):
         """
-        Computation as described in R. W. Grosse-Kunstleve, P. D. Adams, J Appl Cryst 2002, 35, 477–480.
-        Returns: numpy array of eigenvalues of Ucart,  first dimension are the atoms in the structure
+        Computation as described in R. W. Grosse-Kunstleve, P. D. Adams, J Appl Cryst 2002, 35, 477-480.
+        Returns: numpy array of eigenvalues of Ucart,  first dimension are the atoms in the structure.
         """
         U1U2U3 = []
         for mat in self.thermal_displacement_matrix_cart_matrixform:
@@ -198,7 +193,7 @@ class ThermalDisplacementMatrices(MSONable):
 
     def write_cif(self, filename):
         """
-        Writes a cif including thermal displacements
+        Writes a cif including thermal displacements.
 
         Args:
             filename: name of the cif file
@@ -238,7 +233,8 @@ class ThermalDisplacementMatrices(MSONable):
     def compute_directionality_quality_criterion(self, other):
         """
         Will compute directionality of prolate displacement ellipsoids as described in
-        https://doi.org/10.1039/C9CE00794F with the earlier implementation: https://github.com/damMroz/Angle/
+        https://doi.org/10.1039/C9CE00794F with the earlier implementation: https://github.com/damMroz/Angle/.
+
         Args:
             other: ThermalDisplacementMatrix
             please make sure that the order of the atoms in both objects that are compared
@@ -387,10 +383,7 @@ class ThermalDisplacementMatrices(MSONable):
 
     @property
     def ratio_prolate(self):
-        """
-        This will compute ratio between largest eigenvalue of Ucart and smallest one
-        Returns:
-        """
+        """This will compute ratio between largest and smallest eigenvalue of Ucart."""
         ratios = []
         for us in self.U1U2U3:
             ratios.append(np.max(us) / np.min(us))
@@ -400,7 +393,7 @@ class ThermalDisplacementMatrices(MSONable):
     @staticmethod
     def from_Ucif(thermal_displacement_matrix_cif, structure, temperature):
         """
-        Starting from a numpy array, it will convert Ucif values into Ucart values and initialize the class
+        Starting from a numpy array, it will convert Ucif values into Ucart values and initialize the class.
 
         Args:
             thermal_displacement_matrix_cif: np.array,
@@ -446,7 +439,7 @@ class ThermalDisplacementMatrices(MSONable):
         E.g., with code like this:
         def sort_order(site):
             return [site.specie.X, site.frac_coords[0], site.frac_coords[1], site.frac_coords[2]]
-        new_structure0 = Structure.from_sites(sorted(structure0, key=sort_order))
+        new_structure0 = Structure.from_sites(sorted(structure0, key=sort_order)).
 
         Returns: Structure object.
         """
@@ -467,7 +460,7 @@ class ThermalDisplacementMatrices(MSONable):
         return self.structure.copy(site_properties=site_properties)
 
     @staticmethod
-    def from_structure_with_site_properties_Ucif(structure: Structure, temperature: float = None):
+    def from_structure_with_site_properties_Ucif(structure: Structure, temperature: float | None = None):
         """
         Will create this object with the help of a structure with site properties.
 
@@ -501,7 +494,7 @@ class ThermalDisplacementMatrices(MSONable):
         Reads a cif with P1 symmetry including positions and ADPs.
         Currently, no check of symmetry is performed as CifParser methods cannot be easily reused
         Args:
-            filename: Filename of the cif
+            filename: Filename of the cif.
 
         Returns: ThermalDisplacementMatrices Object.
 
@@ -520,7 +513,6 @@ class ThermalDisplacementMatrices(MSONable):
             allcoords = []
             allspecies = []
             for i in range(len(data["_atom_site_label"])):
-
                 try:
                     # If site type symbol exists, use it. Otherwise, we use the
                     # label.
