@@ -1,19 +1,17 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
-"""
-This module implements symmetry-related structure forms.
-"""
+"""This module implements symmetry-related structure forms."""
 
 from __future__ import annotations
 
-from typing import Sequence
+from typing import TYPE_CHECKING, Sequence
 
 import numpy as np
 from tabulate import tabulate
 
 from pymatgen.core.structure import PeriodicSite, Structure
 
+if TYPE_CHECKING:
+    from pymatgen.symmetry.analyzer import SpacegroupOperations
+
 
 class SymmetrizedStructure(Structure):
     """
@@ -30,20 +28,19 @@ class SymmetrizedStructure(Structure):
     def __init__(
         self,
         structure: Structure,
-        spacegroup,
+        spacegroup: SpacegroupOperations,
         equivalent_positions: Sequence[int],
         wyckoff_letters: Sequence[str],
-    ):
+    ) -> None:
         """
         Args:
             structure (Structure): Original structure
-            spacegroup (SpacegroupOperations): An input SpacegroupOperations from
-                SpacegroupAnalyzer.
-            equivalent_positions: Equivalent positions from SpacegroupAnalyzer.
-            wyckoff_letters: Wyckoff letters
+            spacegroup (SpacegroupOperations): An input SpacegroupOperations from SpacegroupAnalyzer.
+            equivalent_positions (list[int]): Equivalent positions from SpacegroupAnalyzer.
+            wyckoff_letters (list[str]): Wyckoff letters.
         """
         self.spacegroup = spacegroup
-        u, inv = np.unique(equivalent_positions, return_inverse=True)
+        uniq, inverse = np.unique(equivalent_positions, return_inverse=True)
         self.site_labels = equivalent_positions
 
         super().__init__(
@@ -53,22 +50,20 @@ class SymmetrizedStructure(Structure):
             site_properties=structure.site_properties,
         )
 
-        equivalent_indices = [[] for _ in range(len(u))]  # type: ignore
-        equivalent_sites = [[] for _ in range(len(u))]  # type: ignore
-        wyckoff_symbols = [[] for _ in range(len(u))]  # type: ignore
-        for i, inv_ in enumerate(inv):
-            equivalent_indices[inv_].append(i)
-            equivalent_sites[inv_].append(self.sites[i])
-            wyckoff_symbols[inv_].append(wyckoff_letters[i])
-        self.equivalent_indices: list[int] = equivalent_indices  # type: ignore
-        self.equivalent_sites: list[PeriodicSite] = equivalent_sites  # type: ignore
+        equivalent_indices: list[list[int]] = [[] for _ in range(len(uniq))]
+        equivalent_sites: list[list[PeriodicSite]] = [[] for _ in range(len(uniq))]
+        wyckoff_symbols: list[list[str]] = [[] for _ in range(len(uniq))]
+        for idx, inv_ in enumerate(inverse):
+            equivalent_indices[inv_].append(idx)
+            equivalent_sites[inv_].append(self.sites[idx])
+            wyckoff_symbols[inv_].append(wyckoff_letters[idx])
+        self.equivalent_indices = equivalent_indices
+        self.equivalent_sites = equivalent_sites
         self.wyckoff_letters = wyckoff_letters
-        self.wyckoff_symbols = [f"{len(w)}{w[0]}" for w in wyckoff_symbols]
+        self.wyckoff_symbols = [f"{len(symb)}{symb[0]}" for symb in wyckoff_symbols]
 
     def copy(self):
-        """
-        :return: Copy of structure.
-        """
+        """:return: Copy of structure."""
         return SymmetrizedStructure(
             self,
             spacegroup=self.spacegroup,
@@ -76,13 +71,16 @@ class SymmetrizedStructure(Structure):
             wyckoff_letters=self.wyckoff_letters,
         )
 
-    def find_equivalent_sites(self, site) -> list[PeriodicSite]:
+    def find_equivalent_sites(self, site: PeriodicSite) -> list[PeriodicSite]:
         """
-        Finds all symmetrically equivalent sites for a particular site
+        Finds all symmetrically equivalent sites for a particular site.
 
         Args:
             site (PeriodicSite): A site in the structure
 
+        Raises:
+            ValueError: if site is not in the structure.
+
         Returns:
             ([PeriodicSite]): List of all symmetrically equivalent sites.
         """
@@ -92,10 +90,10 @@ class SymmetrizedStructure(Structure):
 
         raise ValueError("Site not in structure")
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return str(self)
 
-    def __str__(self):
+    def __str__(self) -> str:
         outs = [
             "SymmetrizedStructure",
             f"Full Formula ({self.composition.formula})",
@@ -103,40 +101,30 @@ class SymmetrizedStructure(Structure):
             f"Spacegroup: {self.spacegroup.int_symbol} ({self.spacegroup.int_number})",
         ]
 
-        def to_s(x):
-            return f"{x:0.6f}"
+        def to_str(x):
+            return f"{x:>10.6f}"
 
-        outs.append("abc   : " + " ".join([to_s(i).rjust(10) for i in self.lattice.abc]))
-        outs.append("angles: " + " ".join([to_s(i).rjust(10) for i in self.lattice.angles]))
+        outs.append(f"abc   : {' '.join(to_str(val) for val in self.lattice.abc)}")
+        outs.append(f"angles: {' '.join(to_str(val) for val in self.lattice.angles)}")
         if self._charge:
-            if self._charge >= 0:
-                outs.append(f"Overall Charge: +{self._charge}")
-            else:
-                outs.append(f"Overall Charge: -{self._charge}")
+            outs.append(f"Overall Charge: {self._charge:+}")
         outs.append(f"Sites ({len(self)})")
         data = []
         props = self.site_properties
         keys = sorted(props)
-        for i, sites in enumerate(self.equivalent_sites):
+        for idx, sites in enumerate(self.equivalent_sites):
             site = sites[0]
-            row = [str(i), site.species_string]
-            row.extend([to_s(j) for j in site.frac_coords])
-            row.append(self.wyckoff_symbols[i])
+            row = [str(idx), site.species_string]
+            row.extend([to_str(j) for j in site.frac_coords])
+            row.append(self.wyckoff_symbols[idx])
             for k in keys:
-                row.append(props[k][i])
+                row.append(props[k][idx])
             data.append(row)
-        outs.append(
-            tabulate(
-                data,
-                headers=["#", "SP", "a", "b", "c", "Wyckoff"] + keys,
-            )
-        )
+        outs.append(tabulate(data, headers=["#", "SP", "a", "b", "c", "Wyckoff", *keys]))
         return "\n".join(outs)
 
     def as_dict(self):
-        """
-        :return: MSONAble dict
-        """
+        """:return: MSONable dict"""
         structure = Structure.from_sites(self.sites)
         return {
             "structure": structure.as_dict(),
@@ -146,14 +134,14 @@ class SymmetrizedStructure(Structure):
         }
 
     @classmethod
-    def from_dict(cls, d):
+    def from_dict(cls, dct):
         """
         :param d: Dict representation
         :return: SymmetrizedStructure
         """
         return cls(
-            Structure.from_dict(d["structure"]),
-            spacegroup=d["spacegroup"],
-            equivalent_positions=d["equivalent_positions"],
-            wyckoff_letters=d["wyckoff_letters"],
+            Structure.from_dict(dct["structure"]),
+            spacegroup=dct["spacegroup"],
+            equivalent_positions=dct["equivalent_positions"],
+            wyckoff_letters=dct["wyckoff_letters"],
         )
