@@ -1,4 +1,4 @@
-import unittest
+from __future__ import annotations
 
 import numpy as np
 
@@ -74,8 +74,7 @@ class MagneticSpaceGroupTest(PymatgenTest):
         assert msg.is_compatible(hexagonal)
 
     def test_symmetry_ops(self):
-
-        msg_1_symmops = "\n".join([str(op) for op in self.msg_1.symmetry_ops])
+        msg_1_symmops = "\n".join(map(str, self.msg_1.symmetry_ops))
         msg_1_symmops_ref = """x, y, z, +1
 -x+3/4, -y+3/4, z, +1
 -x, -y, -z, +1
@@ -108,9 +107,9 @@ x+1/2, -y+5/4, -z+3/4, -1
 -x+5/4, y+1/2, -z+3/4, -1
 -x+1/2, y+3/4, z+1/4, -1
 x+3/4, -y+1/2, z+1/4, -1"""
-        self.assertStrContentEqual(msg_1_symmops, msg_1_symmops_ref)
+        self.assert_str_content_equal(msg_1_symmops, msg_1_symmops_ref)
 
-        msg_2_symmops = "\n".join([str(op) for op in self.msg_2.symmetry_ops])
+        msg_2_symmops = "\n".join(map(str, self.msg_2.symmetry_ops))
         msg_2_symmops_ref = """x, y, z, +1
 -x, y+1/2, -z, +1
 -x, -y, -z, +1
@@ -119,9 +118,9 @@ x+1/2, -y+1/2, -z+1/2, -1
 -x+1/2, -y, z+1/2, -1
 -x+1/2, y+1/2, z+1/2, -1
 x+1/2, y, -z+1/2, -1"""
-        self.assertStrContentEqual(msg_2_symmops, msg_2_symmops_ref)
+        self.assert_str_content_equal(msg_2_symmops, msg_2_symmops_ref)
 
-        msg_3_symmops = "\n".join([str(op) for op in self.msg_3.symmetry_ops])
+        msg_3_symmops = "\n".join(map(str, self.msg_3.symmetry_ops))
         msg_3_symmops_ref = """x, y, z, +1
 x, -y, -z, +1
 -x, y, -z+1/2, +1
@@ -140,7 +139,7 @@ x, -y+1/2, -z+1/2, -1
 -x, -y+1/2, z, -1"""
         assert msg_3_symmops == msg_3_symmops_ref
 
-        msg_4_symmops = "\n".join([str(op) for op in self.msg_4.symmetry_ops])
+        msg_4_symmops = "\n".join(map(str, self.msg_4.symmetry_ops))
         msg_4_symmops_ref = """x, y, z, +1
 -x, -y, -z, +1
 x+1/2, y, z, -1
@@ -148,7 +147,6 @@ x+1/2, y, z, -1
         assert msg_4_symmops == msg_4_symmops_ref
 
     def test_equivalence_to_spacegroup(self):
-
         # first 230 magnetic space groups have same symmetry operations
         # as normal space groups, so should give same orbits
 
@@ -168,7 +166,6 @@ x+1/2, y, z, -1
                 assert np.allclose(pp_sg, pp_msg)
 
     def test_str(self):
-
         msg = MagneticSpaceGroup([4, 11])
 
         ref_string = """BNS: 4.11 P_b2_1
@@ -201,9 +198,5 @@ Wyckoff Positions (OG): (1,0,0)+ (0,2,0)+ (0,0,1)+
 2b  (0,y,1/2;mx,0,mz) (0,y+1,-1/2;-mx,0,-mz)
 2a  (0,y,0;mx,0,mz) (0,y+1,0;-mx,0,-mz)"""
 
-        self.assertStrContentEqual(str(msg), ref_string)
-        self.assertStrContentEqual(msg.data_str(), ref_string_all)
-
-
-if __name__ == "__main__":
-    unittest.main()
+        self.assert_str_content_equal(str(msg), ref_string)
+        self.assert_str_content_equal(msg.data_str(), ref_string_all)
