@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import unittest
 
 import numpy as np
@@ -74,7 +76,6 @@ class JonesFaithfulTransformationTest(unittest.TestCase):
                 assert np.allclose(coord, ref_coord)
 
     def test_transform_symmops(self):
-
         # reference data for this test taken from GENPOS
         # http://cryst.ehu.es/cryst/get_gen.html
 
@@ -187,7 +188,3 @@ y,-x,-z+1/2
 
         for transformed_op, ref_transformed_op in zip(transformed_symmops, ref_transformed_symmops):
             assert transformed_op == ref_transformed_op
-
-
-if __name__ == "__main__":
-    unittest.main()
