@@ -1,6 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module defines site transformations which transforms a structure into
 another structure. Site transformations differ from standard transformations
@@ -14,22 +11,23 @@ import itertools
 import logging
 import math
 import time
+from typing import TYPE_CHECKING
 
 import numpy as np
 from monty.json import MSONable
 
 from pymatgen.analysis.ewald import EwaldMinimizer, EwaldSummation
 from pymatgen.analysis.local_env import MinimumDistanceNN
-from pymatgen.core.sites import PeriodicSite
-from pymatgen.core.structure import Structure
 from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
 from pymatgen.transformations.transformation_abc import AbstractTransformation
 
+if TYPE_CHECKING:
+    from pymatgen.core.sites import PeriodicSite
+    from pymatgen.core.structure import Structure
+
 
 class InsertSitesTransformation(AbstractTransformation):
-    """
-    This transformation substitutes certain sites with certain species.
-    """
+    """This transformation substitutes certain sites with certain species."""
 
     def __init__(self, species, coords, coords_are_cartesian=False, validate_proximity=True):
         """
@@ -49,7 +47,7 @@ class InsertSitesTransformation(AbstractTransformation):
         self.coords_are_cartesian = coords_are_cartesian
         self.validate_proximity = validate_proximity
 
-    def apply_transformation(self, structure):
+    def apply_transformation(self, structure: Structure):
         """
         Apply the transformation.
 
@@ -79,19 +77,17 @@ class InsertSitesTransformation(AbstractTransformation):
 
     @property
     def inverse(self):
-        """Return: None"""
-        return None
+        """Return: None."""
+        return
 
     @property
-    def is_one_to_many(self):
-        """Return: False"""
+    def is_one_to_many(self) -> bool:
+        """Return: False."""
         return False
 
 
 class ReplaceSiteSpeciesTransformation(AbstractTransformation):
-    """
-    This transformation substitutes certain sites with certain species.
-    """
+    """This transformation substitutes certain sites with certain species."""
 
     def __init__(self, indices_species_map):
         """
@@ -105,7 +101,7 @@ class ReplaceSiteSpeciesTransformation(AbstractTransformation):
         """
         self.indices_species_map = indices_species_map
 
-    def apply_transformation(self, structure):
+    def apply_transformation(self, structure: Structure):
         """
         Apply the transformation.
 
@@ -131,28 +127,26 @@ class ReplaceSiteSpeciesTransformation(AbstractTransformation):
 
     @property
     def inverse(self):
-        """Return: None"""
-        return None
+        """Return: None."""
+        return
 
     @property
-    def is_one_to_many(self):
-        """Return: False"""
+    def is_one_to_many(self) -> bool:
+        """Return: False."""
         return False
 
 
 class RemoveSitesTransformation(AbstractTransformation):
-    """
-    Remove certain sites in a structure.
-    """
+    """Remove certain sites in a structure."""
 
     def __init__(self, indices_to_remove):
         """
         Args:
-            indices_to_remove: List of indices to remove. E.g., [0, 1, 2]
+            indices_to_remove: List of indices to remove. E.g., [0, 1, 2].
         """
         self.indices_to_remove = indices_to_remove
 
-    def apply_transformation(self, structure):
+    def apply_transformation(self, structure: Structure):
         """
         Apply the transformation.
 
@@ -175,19 +169,17 @@ class RemoveSitesTransformation(AbstractTransformation):
 
     @property
     def inverse(self):
-        """Return: None"""
-        return None
+        """Return: None."""
+        return
 
     @property
-    def is_one_to_many(self):
-        """Return: False"""
+    def is_one_to_many(self) -> bool:
+        """Return: False."""
         return False
 
 
 class TranslateSitesTransformation(AbstractTransformation):
-    """
-    This class translates a set of sites by a certain vector.
-    """
+    """This class translates a set of sites by a certain vector."""
 
     def __init__(self, indices_to_move, translation_vector, vector_in_frac_coords=True):
         """
@@ -205,7 +197,7 @@ class TranslateSitesTransformation(AbstractTransformation):
         self.translation_vector = np.array(translation_vector)
         self.vector_in_frac_coords = vector_in_frac_coords
 
-    def apply_transformation(self, structure):
+    def apply_transformation(self, structure: Structure):
         """
         Apply the transformation.
 
@@ -243,14 +235,12 @@ class TranslateSitesTransformation(AbstractTransformation):
         return TranslateSitesTransformation(self.indices_to_move, -self.translation_vector, self.vector_in_frac_coords)
 
     @property
-    def is_one_to_many(self):
-        """Return: False"""
+    def is_one_to_many(self) -> bool:
+        """Return: False."""
         return False
 
     def as_dict(self):
-        """
-        JSON-serializable dict representation.
-        """
+        """JSON-serializable dict representation."""
         d = MSONable.as_dict(self)
         d["translation_vector"] = self.translation_vector.tolist()
         return d
@@ -455,7 +445,7 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
 
         return all_structures
 
-    def _enumerate_ordering(self, structure):
+    def _enumerate_ordering(self, structure: Structure):
         # Generate the disordered structure first.
         s = structure.copy()
         for indices, fraction in zip(self.indices, self.fractions):
@@ -463,22 +453,19 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
                 new_sp = {sp: occu * fraction for sp, occu in structure[ind].species.items()}
                 s[ind] = new_sp
         # Perform enumeration
-        from pymatgen.transformations.advanced_transformations import (
-            EnumerateStructureTransformation,
-        )
+        from pymatgen.transformations.advanced_transformations import EnumerateStructureTransformation
 
         trans = EnumerateStructureTransformation()
         return trans.apply_transformation(s, 10000)
 
-    def apply_transformation(self, structure: Structure, return_ranked_list=False):
+    def apply_transformation(self, structure: Structure, return_ranked_list: bool | int = False):
         """
         Apply the transformation.
 
         Args:
             structure: input structure
-            return_ranked_list (bool): Whether or not multiple structures are
-                returned. If return_ranked_list is a number, that number of
-                structures is returned.
+            return_ranked_list (bool | int): Whether or not multiple structures are returned.
+                If return_ranked_list is int, that number of structures is returned.
 
         Returns:
             Depending on returned_ranked list, either a transformed structure
@@ -536,28 +523,26 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
 
     @property
     def inverse(self):
-        """Return: None"""
-        return None
+        """Return: None."""
+        return
 
     @property
-    def is_one_to_many(self):
-        """Return: True"""
+    def is_one_to_many(self) -> bool:
+        """Return: True."""
         return True
 
 
 class AddSitePropertyTransformation(AbstractTransformation):
-    """
-    Simple transformation to add site properties to a given structure
-    """
+    """Simple transformation to add site properties to a given structure."""
 
     def __init__(self, site_properties):
         """
         Args:
-            site_properties (dict): site properties to be added to a structure
+            site_properties (dict): site properties to be added to a structure.
         """
         self.site_properties = site_properties
 
-    def apply_transformation(self, structure):
+    def apply_transformation(self, structure: Structure):
         """
         Apply the transformation.
 
@@ -575,12 +560,12 @@ class AddSitePropertyTransformation(AbstractTransformation):
 
     @property
     def inverse(self):
-        """Return: None"""
-        return None
+        """Return: None."""
+        return
 
     @property
-    def is_one_to_many(self):
-        """Return: False"""
+    def is_one_to_many(self) -> bool:
+        """Return: False."""
         return False
 
 
@@ -608,7 +593,7 @@ class RadialSiteDistortionTransformation(AbstractTransformation):
         self.displacement = displacement
         self.nn_only = nn_only
 
-    def apply_transformation(self, structure):
+    def apply_transformation(self, structure: Structure):
         """
         Apply the transformation.
 
@@ -654,7 +639,7 @@ class RadialSiteDistortionTransformation(AbstractTransformation):
         return False
 
     @property
-    def is_one_to_many(self):
+    def is_one_to_many(self) -> bool:
         """
         Determines if a Transformation is a one-to-many transformation. If a
         Transformation is a one-to-many transformation, the
