@@ -1,5 +1,4 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
+from __future__ import annotations
 
 import functools
 import json
@@ -9,7 +8,9 @@ import unittest
 import warnings
 from shutil import which
 
+import pytest
 from monty.json import MontyDecoder
+from pytest import approx
 
 from pymatgen.core.lattice import Lattice
 from pymatgen.core.periodic_table import Element
@@ -59,13 +60,13 @@ class RotationTransformationsTest(unittest.TestCase):
     def test_as_from_dict(self):
         t = RotationTransformation([0, 1, 0], 30, False)
         d = t.as_dict()
-        self.assertEqual(type(RotationTransformation.from_dict(d)), RotationTransformation)
+        assert isinstance(RotationTransformation.from_dict(d), RotationTransformation)
 
     def test_rotation_transformation(self):
         t = RotationTransformation([0, 1, 0], 30, False)
         s2 = t.apply_transformation(self.struct)
         s1 = t.inverse.apply_transformation(s2)
-        self.assertTrue((abs(s1.lattice.matrix - self.struct.lattice.matrix) < 1e-8).all())
+        assert (abs(s1.lattice.matrix - self.struct.lattice.matrix) < 1e-8).all()
 
 
 class RemoveSpeciesTransformationTest(unittest.TestCase):
@@ -85,10 +86,10 @@ class RemoveSpeciesTransformationTest(unittest.TestCase):
         )
         struct = Structure(lattice, ["Li+", "Li+", "O2-", "O2-"], coords)
         s = t.apply_transformation(struct)
-        self.assertEqual(s.composition.formula, "O2")
+        assert s.composition.formula == "O2"
 
         d = t.as_dict()
-        self.assertEqual(type(RemoveSpeciesTransformation.from_dict(d)), RemoveSpeciesTransformation)
+        assert isinstance(RemoveSpeciesTransformation.from_dict(d), RemoveSpeciesTransformation)
 
 
 class SubstitutionTransformationTest(unittest.TestCase):
@@ -108,7 +109,7 @@ class SubstitutionTransformationTest(unittest.TestCase):
         )
         struct = Structure(lattice, ["Li+", "Li+", "O2-", "O2-"], coords)
         s = t.apply_transformation(struct)
-        self.assertEqual(s.composition.formula, "Na2 S2")
+        assert s.composition.formula == "Na2 S2"
 
     def test_fractional_substitution(self):
         t = SubstitutionTransformation({"Li+": "Na+", "O2-": {"S2-": 0.5, "Se2-": 0.5}})
@@ -128,7 +129,7 @@ class SubstitutionTransformationTest(unittest.TestCase):
         )
         struct = Structure(lattice, ["Li+", "Li+", "O2-", "O2-"], coords)
         s = t.apply_transformation(struct)
-        self.assertEqual(s.composition.formula, "Na2 Se1 S1")
+        assert s.composition.formula == "Na2 Se1 S1"
 
 
 class SupercellTransformationTest(unittest.TestCase):
@@ -150,13 +151,13 @@ class SupercellTransformationTest(unittest.TestCase):
     def test_apply_transformation(self):
         t = SupercellTransformation([[2, 1, 0], [0, 2, 0], [1, 0, 2]])
         s = t.apply_transformation(self.struct)
-        self.assertEqual(s.composition.formula, "Li16 O16")
+        assert s.composition.formula == "Li16 O16"
 
     def test_from_scaling_factors(self):
         scale_factors = [random.randint(1, 5) for i in range(3)]
         t = SupercellTransformation.from_scaling_factors(*scale_factors)
         s = t.apply_transformation(self.struct)
-        self.assertEqual(s.num_sites, 4 * functools.reduce(lambda a, b: a * b, scale_factors))
+        assert s.num_sites == 4 * functools.reduce(lambda a, b: a * b, scale_factors)
 
 
 class OxidationStateDecorationTransformationTest(unittest.TestCase):
@@ -176,13 +177,10 @@ class OxidationStateDecorationTransformationTest(unittest.TestCase):
         )
         struct = Structure(lattice, ["Li", "Li", "O", "O"], coords)
         s = t.apply_transformation(struct)
-        self.assertEqual(s[0].species_string, "Li+")
-        self.assertEqual(s[2].species_string, "O2-")
+        assert s[0].species_string == "Li+"
+        assert s[2].species_string == "O2-"
         d = t.as_dict()
-        self.assertEqual(
-            type(OxidationStateDecorationTransformation.from_dict(d)),
-            OxidationStateDecorationTransformation,
-        )
+        assert isinstance(OxidationStateDecorationTransformation.from_dict(d), OxidationStateDecorationTransformation)
 
 
 class AutoOxiStateDecorationTransformationTest(unittest.TestCase):
@@ -192,13 +190,13 @@ class AutoOxiStateDecorationTransformationTest(unittest.TestCase):
         s = t.apply_transformation(p.structure)
         expected_oxi = {"Li": 1, "P": 5, "O": -2, "Fe": 2}
         for site in s:
-            self.assertEqual(site.specie.oxi_state, expected_oxi[site.specie.symbol])
+            assert site.specie.oxi_state == expected_oxi[site.specie.symbol]
 
     def test_as_from_dict(self):
         t = AutoOxiStateDecorationTransformation()
         d = t.as_dict()
         t = AutoOxiStateDecorationTransformation.from_dict(d)
-        self.assertEqual(t.analyzer.dist_scale_factor, 1.015)
+        assert t.analyzer.dist_scale_factor == 1.015
 
 
 class OxidationStateRemovalTransformationTest(unittest.TestCase):
@@ -218,14 +216,11 @@ class OxidationStateRemovalTransformationTest(unittest.TestCase):
         )
         struct = Structure(lattice, ["Li+", "Li+", "O2-", "O2-"], coords)
         s = t.apply_transformation(struct)
-        self.assertEqual(s[0].species_string, "Li")
-        self.assertEqual(s[2].species_string, "O")
+        assert s[0].species_string == "Li"
+        assert s[2].species_string == "O"
 
         d = t.as_dict()
-        self.assertEqual(
-            type(OxidationStateRemovalTransformation.from_dict(d)),
-            OxidationStateRemovalTransformation,
-        )
+        assert isinstance(OxidationStateRemovalTransformation.from_dict(d), OxidationStateRemovalTransformation)
 
 
 @unittest.skipIf(not enumlib_present, "enum_lib not present.")
@@ -251,13 +246,10 @@ class PartialRemoveSpecieTransformationTest(unittest.TestCase):
             ]
         )
         struct = Structure(lattice, ["Li+", "Li+", "Li+", "O2-"], coords)
-        self.assertEqual(len(t.apply_transformation(struct, 100)), 2)
+        assert len(t.apply_transformation(struct, 100)) == 2
 
         d = t.as_dict()
-        self.assertEqual(
-            type(PartialRemoveSpecieTransformation.from_dict(d)),
-            PartialRemoveSpecieTransformation,
-        )
+        assert isinstance(PartialRemoveSpecieTransformation.from_dict(d), PartialRemoveSpecieTransformation)
 
     def test_apply_transformation_fast(self):
         t = PartialRemoveSpecieTransformation("Li+", 0.5)
@@ -273,26 +265,22 @@ class PartialRemoveSpecieTransformationTest(unittest.TestCase):
         fast_opt_s = t.apply_transformation(struct)
         t = PartialRemoveSpecieTransformation("Li+", 0.5, PartialRemoveSpecieTransformation.ALGO_COMPLETE)
         slow_opt_s = t.apply_transformation(struct)
-        self.assertAlmostEqual(
-            EwaldSummation(fast_opt_s).total_energy,
-            EwaldSummation(slow_opt_s).total_energy,
-            4,
-        )
-        self.assertEqual(fast_opt_s, slow_opt_s)
+        assert EwaldSummation(fast_opt_s).total_energy == approx(EwaldSummation(slow_opt_s).total_energy, abs=1e-4)
+        assert fast_opt_s == slow_opt_s
 
     def test_apply_transformations_complete_ranking(self):
         p = Poscar.from_file(os.path.join(PymatgenTest.TEST_FILES_DIR, "POSCAR.LiFePO4"), check_for_POTCAR=False)
         t1 = OxidationStateDecorationTransformation({"Li": 1, "Fe": 2, "P": 5, "O": -2})
         s = t1.apply_transformation(p.structure)
         t = PartialRemoveSpecieTransformation("Li+", 0.5, PartialRemoveSpecieTransformation.ALGO_COMPLETE)
-        self.assertEqual(len(t.apply_transformation(s, 10)), 6)
+        assert len(t.apply_transformation(s, 10)) == 6
 
     def test_apply_transformations_best_first(self):
         p = Poscar.from_file(os.path.join(PymatgenTest.TEST_FILES_DIR, "POSCAR.LiFePO4"), check_for_POTCAR=False)
         t1 = OxidationStateDecorationTransformation({"Li": 1, "Fe": 2, "P": 5, "O": -2})
         s = t1.apply_transformation(p.structure)
         t = PartialRemoveSpecieTransformation("Li+", 0.5, PartialRemoveSpecieTransformation.ALGO_BEST_FIRST)
-        self.assertEqual(len(t.apply_transformation(s)), 26)
+        assert len(t.apply_transformation(s)) == 26
 
 
 class OrderDisorderedStructureTransformationTest(unittest.TestCase):
@@ -322,8 +310,8 @@ class OrderDisorderedStructureTransformationTest(unittest.TestCase):
             coords,
         )
         output = t.apply_transformation(struct, return_ranked_list=50)
-        self.assertEqual(len(output), 12)
-        self.assertIsInstance(output[0]["structure"], Structure)
+        assert len(output) == 12
+        assert isinstance(output[0]["structure"], Structure)
 
         struct = Structure(
             lattice,
@@ -336,34 +324,31 @@ class OrderDisorderedStructureTransformationTest(unittest.TestCase):
             coords,
         )
         output = t.apply_transformation(struct, return_ranked_list=50)
-        self.assertIsInstance(output, list)
-        self.assertEqual(len(output), 4)
-        self.assertEqual(t.lowest_energy_structure, output[0]["structure"])
+        assert isinstance(output, list)
+        assert len(output) == 4
+        assert t.lowest_energy_structure == output[0]["structure"]
 
         struct = Structure(lattice, [{"Si4+": 0.5}, {"Si4+": 0.5}, {"O2-": 0.5}, {"O2-": 0.5}], coords)
         allstructs = t.apply_transformation(struct, 50)
-        self.assertEqual(len(allstructs), 4)
+        assert len(allstructs) == 4
 
         struct = Structure(lattice, [{"Si4+": 0.333}, {"Si4+": 0.333}, {"Si4+": 0.333}, "O2-"], coords)
         allstructs = t.apply_transformation(struct, 50)
-        self.assertEqual(len(allstructs), 3)
+        assert len(allstructs) == 3
 
         d = t.as_dict()
-        self.assertEqual(
-            type(OrderDisorderedStructureTransformation.from_dict(d)),
-            OrderDisorderedStructureTransformation,
-        )
+        assert isinstance(OrderDisorderedStructureTransformation.from_dict(d), OrderDisorderedStructureTransformation)
 
     def test_no_oxidation(self):
         specie = {"Cu1+": 0.5, "Au2+": 0.5}
         cuau = Structure.from_spacegroup("Fm-3m", Lattice.cubic(3.677), [specie], [[0, 0, 0]])
         trans = OrderDisorderedStructureTransformation()
         ss = trans.apply_transformation(cuau, return_ranked_list=100)
-        self.assertEqual(ss[0]["structure"].composition["Cu+"], 2)
+        assert ss[0]["structure"].composition["Cu+"] == 2
         trans = OrderDisorderedStructureTransformation(no_oxi_states=True)
         ss = trans.apply_transformation(cuau, return_ranked_list=100)
-        self.assertEqual(ss[0]["structure"].composition["Cu+"], 0)
-        self.assertEqual(ss[0]["structure"].composition["Cu"], 2)
+        assert ss[0]["structure"].composition["Cu+"] == 0
+        assert ss[0]["structure"].composition["Cu"] == 2
 
     def test_symmetrized_structure(self):
         t = OrderDisorderedStructureTransformation(symmetrized_structures=True)
@@ -379,12 +364,12 @@ class OrderDisorderedStructureTransformationTest(unittest.TestCase):
         sp.append({"Si4+": 0.5})
         c.append([0.75, 0.25, 0.25])
         sp.append({"Si4+": 0.5})
-        l = Lattice.cubic(5)
-        s = Structure(l, sp, c)
-        test_site = PeriodicSite("Si4+", c[2], l)
-        s = SymmetrizedStructure(s, "not_real", [0, 1, 1, 2, 2], ["a", "b", "b", "c", "c"])
-        output = t.apply_transformation(s)
-        self.assertTrue(test_site in output.sites)
+        latt = Lattice.cubic(5)
+        struct = Structure(latt, sp, c)
+        test_site = PeriodicSite("Si4+", c[2], latt)
+        struct = SymmetrizedStructure(struct, "not_real", [0, 1, 1, 2, 2], ["a", "b", "b", "c", "c"])
+        output = t.apply_transformation(struct)
+        assert test_site in output.sites
 
     def test_too_small_cell(self):
         t = OrderDisorderedStructureTransformation()
@@ -398,7 +383,8 @@ class OrderDisorderedStructureTransformationTest(unittest.TestCase):
             ]
         )
         struct = Structure(lattice, [{"X4+": 0.33, "O2-": 0.33, "P5+": 0.33}], coords)
-        self.assertRaises(ValueError, t.apply_transformation, struct)
+        with pytest.raises(ValueError, match="Occupancy fractions not consistent with size of unit cell"):
+            t.apply_transformation(struct)
 
     def test_best_first(self):
         t = OrderDisorderedStructureTransformation(algo=2)
@@ -426,7 +412,7 @@ class OrderDisorderedStructureTransformationTest(unittest.TestCase):
             coords,
         )
         output = t.apply_transformation(struct, return_ranked_list=3)
-        self.assertAlmostEqual(output[0]["energy"], -234.57813667648315, 4)
+        assert output[0]["energy"] == approx(-234.57813667648315, abs=1e-4)
 
 
 class PrimitiveCellTransformationTest(unittest.TestCase):
@@ -451,15 +437,15 @@ class PrimitiveCellTransformationTest(unittest.TestCase):
         )
         struct = Structure(lattice, ["Li+", "Li+", "Li+", "Li+", "O2-", "O2-", "O2-", "O2-"], coords)
         s = t.apply_transformation(struct)
-        self.assertEqual(len(s), 4)
+        assert len(s) == 4
 
         with open(os.path.join(PymatgenTest.TEST_FILES_DIR, "TiO2_super.json")) as f:
             s = json.load(f, cls=MontyDecoder)
             prim = t.apply_transformation(s)
-            self.assertEqual(prim.formula, "Ti4 O8")
+            assert prim.formula == "Ti4 O8"
 
         d = t.as_dict()
-        self.assertEqual(type(PrimitiveCellTransformation.from_dict(d)), PrimitiveCellTransformation)
+        assert isinstance(PrimitiveCellTransformation.from_dict(d), PrimitiveCellTransformation)
 
 
 class ConventionalCellTransformationTest(unittest.TestCase):
@@ -479,7 +465,7 @@ class ConventionalCellTransformationTest(unittest.TestCase):
         )
         struct = Structure(lattice, ["Li+", "Li+", "O2-", "O2-"], coords)
         conventional_struct = t.apply_transformation(struct)
-        self.assertEqual(conventional_struct.lattice.alpha, 90)
+        assert conventional_struct.lattice.alpha == 90
 
 
 class PerturbStructureTransformationTest(unittest.TestCase):
@@ -503,25 +489,19 @@ class PerturbStructureTransformationTest(unittest.TestCase):
         struct = Structure(lattice, ["Li+", "Li+", "Li+", "Li+", "O2-", "O2-", "O2-", "O2-"], coords)
         transformed_s = t.apply_transformation(struct)
         for i, site in enumerate(transformed_s):
-            self.assertAlmostEqual(site.distance(struct[i]), 0.05)
+            assert site.distance(struct[i]) == approx(0.05)
 
         d = t.as_dict()
-        self.assertEqual(
-            type(PerturbStructureTransformation.from_dict(d)),
-            PerturbStructureTransformation,
-        )
+        assert isinstance(PerturbStructureTransformation.from_dict(d), PerturbStructureTransformation)
 
         t2 = PerturbStructureTransformation(0.05, 0)
         transformed_s2 = t2.apply_transformation(struct)
         for i, site in enumerate(transformed_s2):
-            self.assertLessEqual(site.distance(struct[i]), 0.05)
-            self.assertGreaterEqual(site.distance(struct[i]), 0)
+            assert site.distance(struct[i]) <= 0.05
+            assert site.distance(struct[i]) >= 0
 
         d = t2.as_dict()
-        self.assertEqual(
-            type(PerturbStructureTransformation.from_dict(d)),
-            PerturbStructureTransformation,
-        )
+        assert isinstance(PerturbStructureTransformation.from_dict(d), PerturbStructureTransformation)
 
 
 class DeformStructureTransformationTest(unittest.TestCase):
@@ -544,37 +524,32 @@ class DeformStructureTransformationTest(unittest.TestCase):
         ]
         struct = Structure(lattice, ["Li+", "Li+", "Li+", "Li+", "O2-", "O2-", "O2-", "O2-"], coords)
         transformed_s = t.apply_transformation(struct)
-        self.assertAlmostEqual(transformed_s.lattice.a, 3.84019793)
-        self.assertAlmostEqual(transformed_s.lattice.b, 3.84379750)
-        self.assertAlmostEqual(transformed_s.lattice.c, 3.75022981)
+        assert transformed_s.lattice.a == approx(3.84019793)
+        assert transformed_s.lattice.b == approx(3.84379750)
+        assert transformed_s.lattice.c == approx(3.75022981)
 
         d = json.loads(json.dumps(t.as_dict()))
-        self.assertEqual(
-            type(DeformStructureTransformation.from_dict(d)),
-            DeformStructureTransformation,
-        )
+        assert isinstance(DeformStructureTransformation.from_dict(d), DeformStructureTransformation)
 
 
 class DiscretizeOccupanciesTransformationTest(unittest.TestCase):
     def test_apply_transformation(self):
-        l = Lattice.cubic(4)
+        latt = Lattice.cubic(4)
         s_orig = Structure(
-            l,
+            latt,
             [{"Li": 0.19, "Na": 0.19, "K": 0.62}, {"O": 1}],
             [[0, 0, 0], [0.5, 0.5, 0.5]],
         )
         dot = DiscretizeOccupanciesTransformation(max_denominator=5, tol=0.5)
         s = dot.apply_transformation(s_orig)
-        self.assertEqual(
-            dict(s[0].species),
-            {Element("Li"): 0.2, Element("Na"): 0.2, Element("K"): 0.6},
-        )
+        assert dict(s[0].species) == {Element("Li"): 0.2, Element("Na"): 0.2, Element("K"): 0.6}
 
         dot = DiscretizeOccupanciesTransformation(max_denominator=5, tol=0.01)
-        self.assertRaises(RuntimeError, dot.apply_transformation, s_orig)
+        with pytest.raises(RuntimeError):
+            dot.apply_transformation(s_orig)
 
         s_orig_2 = Structure(
-            l,
+            latt,
             [{"Li": 0.5, "Na": 0.25, "K": 0.25}, {"O": 1}],
             [[0, 0, 0], [0.5, 0.5, 0.5]],
         )
@@ -582,30 +557,28 @@ class DiscretizeOccupanciesTransformationTest(unittest.TestCase):
         dot = DiscretizeOccupanciesTransformation(max_denominator=9, tol=0.25, fix_denominator=False)
 
         s = dot.apply_transformation(s_orig_2)
-        self.assertEqual(
-            dict(s[0].species),
-            {
-                Element("Li"): Fraction(1 / 2),
-                Element("Na"): Fraction(1 / 4),
-                Element("K"): Fraction(1 / 4),
-            },
-        )
+        assert dict(s[0].species) == {
+            Element("Li"): Fraction(1 / 2),
+            Element("Na"): Fraction(1 / 4),
+            Element("K"): Fraction(1 / 4),
+        }
 
         dot = DiscretizeOccupanciesTransformation(max_denominator=9, tol=0.05, fix_denominator=True)
-        self.assertRaises(RuntimeError, dot.apply_transformation, s_orig_2)
+        with pytest.raises(RuntimeError, match="Cannot discretize structure within tolerance"):
+            dot.apply_transformation(s_orig_2)
 
 
 class ChargedCellTransformationTest(unittest.TestCase):
     def test_apply_transformation(self):
-        l = Lattice.cubic(4)
+        lattice = Lattice.cubic(4)
         s_orig = Structure(
-            l,
+            lattice,
             [{"Li": 0.19, "Na": 0.19, "K": 0.62}, {"O": 1}],
             [[0, 0, 0], [0.5, 0.5, 0.5]],
         )
         cct = ChargedCellTransformation(charge=3)
         s = cct.apply_transformation(s_orig)
-        self.assertEqual(s.charge, 3)
+        assert s.charge == 3
 
 
 class ScaleToRelaxedTransformationTest(unittest.TestCase):
@@ -617,7 +590,7 @@ class ScaleToRelaxedTransformationTest(unittest.TestCase):
         slab_scaling = ScaleToRelaxedTransformation(Cu_init, Cu_fin)
         Au_init = Structure.from_file(os.path.join(f, "Au_slab_init.cif"))
         Au_fin = slab_scaling.apply_transformation(Au_init)
-        self.assertAlmostEqual(Au_fin.lattice.volume, Au_init.lattice.volume)
+        assert Au_fin.lattice.volume == approx(Au_init.lattice.volume)
 
         # Test on gb relaxation
         f = os.path.join(PymatgenTest.TEST_FILES_DIR, "grain_boundary")
@@ -626,20 +599,16 @@ class ScaleToRelaxedTransformationTest(unittest.TestCase):
         Zn_init = Structure.from_file(os.path.join(f, "Zn_gb_init.cif"))
         gb_scaling = ScaleToRelaxedTransformation(Be_init, Be_fin)
         Zn_fin = gb_scaling.apply_transformation(Zn_init)
-        self.assertTrue(all([site.species_string == "Zn" for site in Zn_fin]))
-        self.assertEqual(Be_init.lattice.a < Be_fin.lattice.a, Zn_init.lattice.a < Zn_fin.lattice.a)
-        self.assertEqual(Be_init.lattice.b < Be_fin.lattice.b, Zn_init.lattice.b < Zn_fin.lattice.b)
-        self.assertEqual(Be_init.lattice.c < Be_fin.lattice.c, Zn_init.lattice.c < Zn_fin.lattice.c)
+        assert all(site.species_string == "Zn" for site in Zn_fin)
+        assert (Be_init.lattice.a < Be_fin.lattice.a) == (Zn_init.lattice.a < Zn_fin.lattice.a)
+        assert (Be_init.lattice.b < Be_fin.lattice.b) == (Zn_init.lattice.b < Zn_fin.lattice.b)
+        assert (Be_init.lattice.c < Be_fin.lattice.c) == (Zn_init.lattice.c < Zn_fin.lattice.c)
         Fe_fin = Structure.from_file(os.path.join(f, "Fe_gb_fin.cif"))
         Fe_init = Structure.from_file(os.path.join(f, "Fe_gb_init.cif"))
         Mo_init = Structure.from_file(os.path.join(f, "Mo_gb_init.cif"))
         gb_scaling = ScaleToRelaxedTransformation(Fe_init, Fe_fin)
         Mo_fin = gb_scaling.apply_transformation(Mo_init)
-        self.assertTrue(all([site.species_string == "Mo" for site in Mo_fin]))
-        self.assertEqual(Fe_init.lattice.a < Fe_fin.lattice.a, Mo_init.lattice.a < Mo_fin.lattice.a)
-        self.assertEqual(Fe_init.lattice.b < Fe_fin.lattice.b, Mo_init.lattice.b < Mo_fin.lattice.b)
-        self.assertEqual(Fe_init.lattice.c < Fe_fin.lattice.c, Mo_init.lattice.c < Mo_fin.lattice.c)
-
-
-if __name__ == "__main__":
-    unittest.main()
+        assert all(site.species_string == "Mo" for site in Mo_fin)
+        assert (Fe_init.lattice.a < Fe_fin.lattice.a) == (Mo_init.lattice.a < Mo_fin.lattice.a)
+        assert (Fe_init.lattice.b < Fe_fin.lattice.b) == (Mo_init.lattice.b < Mo_fin.lattice.b)
+        assert (Fe_init.lattice.c < Fe_fin.lattice.c) == (Mo_init.lattice.c < Mo_fin.lattice.c)
