@@ -1,4 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
 # Distributed under the terms of the MIT License.import string
 
 """
@@ -11,19 +10,20 @@ tries to fit multiple functions to the x, y data
 
 calculates which function fits best
 for tol < 0
-returns the x value for which y is converged within tol of the assymtotic value
+returns the x value for which y is converged within tol of the asymptotic value
 for tol > 0
 returns the x_value for which dy(x)/dx < tol for all x >= x_value, conv is true is such a x_value exists
-for the best fit a gnuplot line is printed plotting the data, the function and the assymthotic value
+for the best fit a gnuplot line is printed plotting the data, the function and the asymptotic value
 """
 
+from __future__ import annotations
+
 import random
 import string
 
 import numpy as np
 
 __author__ = "Michiel van Setten"
-__copyright__ = " "
 __version__ = "0.9"
 __maintainer__ = "Michiel van Setten"
 __email__ = "mjvansetten@gmail.com"
@@ -37,7 +37,6 @@ def id_generator(size=8, chars=string.ascii_uppercase + string.digits):
         chars ():
 
     Returns:
-
     """
     return "".join(random.choice(chars) for _ in range(size))
 
@@ -103,7 +102,6 @@ def print_and_raise_error(xs, ys, name):
         name ():
 
     Returns:
-
     """
     print("Index error in", name)
     print("ys: ", ys)
@@ -168,7 +166,6 @@ def p0_exponential(xs, ys):
         ys ():
 
     Returns:
-
     """
     n0 = 1.005
     b0 = (n0 ** -xs[-1] - n0 ** -xs[1]) / (ys[-1] - ys[1])
@@ -200,7 +197,6 @@ def p0_single_reciprocal(xs, ys):
         ys ():
 
     Returns:
-
     """
     c = 1
     b = (1 / (xs[-1] - c) - 1 / (xs[1] - c)) / (ys[-1] - ys[1])
@@ -230,7 +226,6 @@ def p0_simple_reciprocal(xs, ys):
         ys ():
 
     Returns:
-
     """
     b = (ys[-1] - ys[-2]) / (1 / (xs[-1]) - 1 / (xs[-2]))
     a = ys[-2] - b / (xs[-2])
@@ -260,7 +255,6 @@ def p0_simple_2reciprocal(xs, ys):
         ys ():
 
     Returns:
-
     """
     c = 2
     b = (ys[-1] - ys[1]) / (1 / xs[-1] ** c - 1 / xs[1] ** c)
@@ -291,7 +285,6 @@ def p0_simple_4reciprocal(xs, ys):
         ys ():
 
     Returns:
-
     """
     c = 4
     b = (ys[-1] - ys[1]) / (1 / xs[-1] ** c - 1 / xs[1] ** c)
@@ -321,7 +314,6 @@ def p0_simple_5reciprocal(xs, ys):
         ys ():
 
     Returns:
-
     """
     c = 0.5
     b = (ys[-1] - ys[1]) / (1 / xs[-1] ** c - 1 / xs[1] ** c)
@@ -337,7 +329,6 @@ def extrapolate_simple_reciprocal(xs, ys):
         ys ():
 
     Returns:
-
     """
     b = (ys[-2] - ys[-1]) / (1 / (xs[-2]) - 1 / (xs[-1]))
     a = ys[-1] - b / (xs[-1])
@@ -383,7 +374,7 @@ def measure(function, xs, ys, popt, weights):
                 raise NotImplementedError
             n += 1
         except IndexError:
-            raise RuntimeError("y does not exist for x = ", x, " this should not happen")
+            raise RuntimeError(f"y does not exist for {x = }, this should not happen")
 
     return m
 
@@ -396,7 +387,6 @@ def get_weights(xs, ys, mode=2):
         mode ():
 
     Returns:
-
     """
     ds = get_derivatives(xs, ys, fd=True)
     if mode == 1:
@@ -407,10 +397,10 @@ def get_weights(xs, ys, mode=2):
         for d in ds:
             weights.append(abs(mind / d))
     if mode == 2:
-        maxxs = max(xs) ** 2
+        x_max = max(xs) ** 2
         weights = []
         for x in xs:
-            weights.append(x**2 / maxxs)
+            weights.append(x**2 / x_max)
     else:
         weights = [1] * len(xs)
     return weights
@@ -524,8 +514,7 @@ def determine_convergence(xs, ys, name, tol: float = 0.0001, extra="", verbose=F
         raise RuntimeError("the range of x and y are not equal")
     conv = False
     x_value = float("inf")
-    y_value = None
-    n_value = None
+    y_value = n_value = None
     popt = [None, None, None]
     if len(xs) > 2:
         ds = get_derivatives(xs[0 : len(ys)], ys)
@@ -539,44 +528,33 @@ def determine_convergence(xs, ys, name, tol: float = 0.0001, extra="", verbose=F
                         popt, pcov, func = multi_reciprocal_extra(xs, ys)
                     else:
                         print(xs, ys)
-                        popt, pcov = None, None  # type: ignore
+                        popt, pcov = None, None  # type: ignore[assignment]
                 elif mode == "extra_noise":
                     popt, pcov, func = multi_reciprocal_extra(xs, ys, noise=True)
                 else:
                     raise NotImplementedError("unknown mode for test conv")
                 if func[1] > abs(tol):
-                    print(
-                        "warning function ",
-                        func[0],
-                        " as the best fit but not a good fit: ",
-                        func[1],
-                    )
-                # todo print this to file via a method in helper, as dict
+                    print(f"warning function {func[0]} as the best fit but not a good fit: {func[1]}")
+                # TODO print this to file via a method in helper, as dict
                 if plots:
-                    with open(name + ".fitdat", mode="a") as f:
+                    with open(f"{name}.fitdat", mode="a") as f:
                         f.write("{")
-                        f.write('"popt": ' + str(popt) + ", ")
-                        f.write('"pcov": ' + str(pcov) + ", ")
+                        f.write(f'"popt": {popt}, ')
+                        f.write(f'"pcov": {pcov}, ')
                         f.write('"data": [')
                         for n in range(0, len(ys), 1):
-                            f.write("[" + str(xs[n]) + " " + str(ys[n]) + "]")
+                            f.write(f"[{xs[n]} {ys[n]}]")
                         f.write("]}\n")
 
                     print_plot_line(func[0], popt, xs, ys, name, tol=tol, extra=extra)
 
         except ImportError:
-            popt, pcov = None, None  # type: ignore
+            popt, pcov = None, None  # type: ignore[assignment]
         for n in range(0, len(ds), 1):
             if verbose:
                 print(n, ys[n])
                 print(ys)
-            if tol < 0:
-                if popt[0] is not None:
-                    test = abs(popt[0] - ys[n])
-                else:
-                    test = float("inf")
-            else:
-                test = abs(ds[n])
+            test = (abs(popt[0] - ys[n]) if popt[0] is not None else float("inf")) if tol < 0 else abs(ds[n])
             if verbose:
                 print(test)
             if test < abs(tol):
