@@ -1,11 +1,9 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 Utilities for manipulating coordinates or list of coordinates, under periodic
 boundary conditions or otherwise. Many of these are heavily vectorized in
 numpy for performance.
 """
+
 from __future__ import annotations
 
 import itertools
@@ -15,10 +13,10 @@ import typing
 import numpy as np
 from monty.json import MSONable
 
-from pymatgen.util import coord_cython as cuc
+from pymatgen.util import coord_cython
 
 if typing.TYPE_CHECKING:
-    from pymatgen.util.typing import ArrayLike
+    from numpy.typing import ArrayLike
 
 
 # array size threshold for looping instead of broadcasting
@@ -60,13 +58,14 @@ def in_coord_list(coord_list, coord, atol=1e-8):
     return len(find_in_coord_list(coord_list, coord, atol=atol)) > 0
 
 
-def is_coord_subset(subset, superset, atol=1e-8):
+def is_coord_subset(subset: ArrayLike, superset: ArrayLike, atol: float = 1e-8) -> bool:
     """
     Tests if all coords in subset are contained in superset.
-    Doesn't use periodic boundary conditions
+    Doesn't use periodic boundary conditions.
 
     Args:
-        subset, superset: List of coords
+        subset: List of coords
+        superset: List of coords
 
     Returns:
         True if all of subset is in superset.
@@ -75,16 +74,18 @@ def is_coord_subset(subset, superset, atol=1e-8):
     c2 = np.array(superset)
     is_close = np.all(np.abs(c1[:, None, :] - c2[None, :, :]) < atol, axis=-1)
     any_close = np.any(is_close, axis=-1)
-    return np.all(any_close)
+    return all(any_close)
 
 
-def coord_list_mapping(subset, superset, atol=1e-8):
+def coord_list_mapping(subset: ArrayLike, superset: ArrayLike, atol: float = 1e-8):
     """
     Gives the index mapping from a subset to a superset.
     Subset and superset cannot contain duplicate rows
 
     Args:
-        subset, superset: List of coords
+        subset (ArrayLike): List of coords
+        superset (ArrayLike): List of coords
+        atol (float): Absolute tolerance. Defaults to 1e-8.
 
     Returns:
         list of indices such that superset[indices] = subset
@@ -93,9 +94,8 @@ def coord_list_mapping(subset, superset, atol=1e-8):
     c2 = np.array(superset)
     inds = np.where(np.all(np.isclose(c1[:, None, :], c2[None, :, :], atol=atol), axis=2))[1]
     result = c2[inds]
-    if not np.allclose(c1, result, atol=atol):
-        if not is_coord_subset(subset, superset):
-            raise ValueError("subset is not a subset of superset")
+    if not np.allclose(c1, result, atol=atol) and not is_coord_subset(subset, superset):
+        raise ValueError("not a subset of superset")
     if not result.shape == c1.shape:
         raise ValueError("Something wrong with the inputs, likely duplicates in superset")
     return inds
@@ -115,8 +115,8 @@ def coord_list_mapping_pbc(subset, superset, atol=1e-8, pbc=(True, True, True)):
         list of indices such that superset[indices] = subset
     """
     # pylint: disable=I1101
-    atol = np.array([1.0, 1.0, 1.0]) * atol
-    return cuc.coord_list_mapping_pbc(subset, superset, atol, pbc)
+    atol = np.ones(3) * atol
+    return coord_cython.coord_list_mapping_pbc(subset, superset, atol, pbc)
 
 
 def get_linear_interpolated_value(x_values, y_values, x):
@@ -202,14 +202,14 @@ def pbc_shortest_vectors(lattice, fcoords1, fcoords2, mask=None, return_d2=False
         mask (boolean array): Mask of matches that are not allowed.
             i.e. if mask[1,2] is True, then subset[1] cannot be matched
             to superset[2]
-        return_d2 (boolean): whether to also return the squared distances
+        return_d2 (bool): whether to also return the squared distances
 
     Returns:
         array of displacement vectors from fcoords1 to fcoords2
         first index is fcoords1 index, second is fcoords2 index
     """
     # pylint: disable=I1101
-    return cuc.pbc_shortest_vectors(lattice, fcoords1, fcoords2, mask, return_d2)
+    return coord_cython.pbc_shortest_vectors(lattice, fcoords1, fcoords2, mask, return_d2)
 
 
 def find_in_coord_list_pbc(fcoord_list, fcoord, atol=1e-8, pbc=(True, True, True)):
@@ -272,12 +272,9 @@ def is_coord_subset_pbc(subset, superset, atol=1e-8, mask=None, pbc=(True, True,
     # pylint: disable=I1101
     c1 = np.array(subset, dtype=np.float64)
     c2 = np.array(superset, dtype=np.float64)
-    if mask is not None:
-        m = np.array(mask, dtype=int)
-    else:
-        m = np.zeros((len(subset), len(superset)), dtype=int)
+    m = np.array(mask, dtype=int) if mask is not None else np.zeros((len(subset), len(superset)), dtype=int)
     atol = np.zeros(3, dtype=np.float64) + atol
-    return cuc.is_coord_subset_pbc(c1, c2, atol, m, pbc)
+    return coord_cython.is_coord_subset_pbc(c1, c2, atol, m, pbc)
 
 
 def lattice_points_in_supercell(supercell_matrix):
@@ -292,18 +289,7 @@ def lattice_points_in_supercell(supercell_matrix):
     Returns:
         numpy array of the fractional coordinates
     """
-    diagonals = np.array(
-        [
-            [0, 0, 0],
-            [0, 0, 1],
-            [0, 1, 0],
-            [0, 1, 1],
-            [1, 0, 0],
-            [1, 0, 1],
-            [1, 1, 0],
-            [1, 1, 1],
-        ]
-    )
+    diagonals = np.array([[0, 0, 0], [0, 0, 1], [0, 1, 0], [0, 1, 1], [1, 0, 0], [1, 0, 1], [1, 1, 0], [1, 1, 1]])
     d_points = np.dot(diagonals, supercell_matrix)
 
     mins = np.min(d_points, axis=0)
@@ -318,9 +304,9 @@ def lattice_points_in_supercell(supercell_matrix):
 
     frac_points = np.dot(all_points, np.linalg.inv(supercell_matrix))
 
-    tvects = frac_points[np.all(frac_points < 1 - 1e-10, axis=1) & np.all(frac_points >= -1e-10, axis=1)]
-    assert len(tvects) == round(abs(np.linalg.det(supercell_matrix)))
-    return tvects
+    t_vecs = frac_points[np.all(frac_points < 1 - 1e-10, axis=1) & np.all(frac_points >= -1e-10, axis=1)]
+    assert len(t_vecs) == round(abs(np.linalg.det(supercell_matrix)))
+    return t_vecs
 
 
 def barycentric_coords(coords, simplex):
@@ -364,7 +350,7 @@ def get_angle(v1, v2, units="degrees"):
         return math.degrees(angle)
     if units == "radians":
         return angle
-    raise ValueError(f"Invalid units {units}")
+    raise ValueError(f"Invalid {units=}")
 
 
 class Simplex(MSONable):
@@ -413,8 +399,8 @@ class Simplex(MSONable):
         """
         try:
             return np.dot(np.concatenate([point, [1]]), self._aug_inv)
-        except AttributeError:
-            raise ValueError("Simplex is not full-dimensional")
+        except AttributeError as exc:
+            raise ValueError("Simplex is not full-dimensional") from exc
 
     def point_from_bary_coords(self, bary_coords):
         """
@@ -426,8 +412,8 @@ class Simplex(MSONable):
         """
         try:
             return np.dot(bary_coords, self._aug[:, :-1])
-        except AttributeError:
-            raise ValueError("Simplex is not full-dimensional")
+        except AttributeError as exc:
+            raise ValueError("Simplex is not full-dimensional") from exc
 
     def in_simplex(self, point, tolerance=1e-8):
         """
@@ -457,12 +443,12 @@ class Simplex(MSONable):
         """
         b1 = self.bary_coords(point1)
         b2 = self.bary_coords(point2)
-        l = b1 - b2
+        line = b1 - b2
         # don't use barycentric dimension where line is parallel to face
-        valid = np.abs(l) > 1e-10
+        valid = np.abs(line) > 1e-10
         # array of all the barycentric coordinates on the line where
         # one of the values is 0
-        possible = b1 - (b1[valid] / l[valid])[:, None] * l
+        possible = b1 - (b1[valid] / line[valid])[:, None] * line
         barys = []
         for p in possible:
             # it's only an intersection if its in the simplex
@@ -475,32 +461,23 @@ class Simplex(MSONable):
                         break
                 if not found:
                     barys.append(p)
-        assert len(barys) < 3
+        assert len(barys) < 3, "More than 2 intersections found"
         return [self.point_from_bary_coords(b) for b in barys]
 
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, Simplex):
             return NotImplemented
-        for p in itertools.permutations(self._coords):
-            if np.allclose(p, other.coords):
-                return True
-        return False
+        return any(np.allclose(p, other.coords) for p in itertools.permutations(self._coords))
 
     def __hash__(self):
         return len(self._coords)
 
     def __repr__(self):
-        output = [
-            f"{self.simplex_dim}-simplex in {self.space_dim}D space",
-            "Vertices:",
-        ]
+        output = [f"{self.simplex_dim}-simplex in {self.space_dim}D space\nVertices:"]
         for coord in self._coords:
             output.append(f"\t({', '.join(map(str, coord))})")
         return "\n".join(output)
 
-    def __str__(self):
-        return self.__repr__()
-
     @property
     def coords(self):
         """
