@@ -1,10 +1,9 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module provides utilities for basic math operations.
 """
 
+from __future__ import annotations
+
 import numpy as np
 
 
@@ -47,8 +46,8 @@ def min_max_indexes(seq):
     Uses enumerate, max, and min to return the indices of the values
     in a list with the maximum and minimum value:
     """
-    l = sorted(enumerate(seq), key=lambda s: s[1])
-    return l[0][0], l[-1][0]
+    lst = sorted(enumerate(seq), key=lambda s: s[1])
+    return lst[0][0], lst[-1][0]
 
 
 def strictly_increasing(values):
@@ -100,24 +99,24 @@ def monotonic(values, mode="<", atol=1.0e-8):
             if abs(vp - v) > atol and vp >= v:
                 return False
 
-    raise ValueError(f"Wrong mode {str(mode)}")
+    raise ValueError(f"Wrong {mode=}")
 
 
-def round_to_sigfigs(num, sigfigs):
+def round_to_sigfigs(num, sig_figs):
     """
     Rounds a number rounded to a specific number of significant
     figures instead of to a specific precision.
     """
-    if not isinstance(sigfigs, int):
-        raise TypeError("Number of significant figures must be integer.")
+    if not isinstance(sig_figs, int):
+        raise TypeError("Number of significant figures must be integer")
 
-    if sigfigs < 1:
-        raise ValueError("Number of significant figures must be larger than zero.")
+    if sig_figs < 1:
+        raise ValueError("Number of significant figures must be positive")
 
     if num == 0:
         return num
 
-    prec = int(sigfigs - np.ceil(np.log10(np.absolute(num))))
+    prec = int(sig_figs - np.ceil(np.log10(np.absolute(num))))
     return round(num, prec)
 
 
