@@ -1,6 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 Classes and methods related to the Structure Notation Language (SNL)
 """
@@ -22,8 +19,7 @@ try:
     from pybtex import errors
     from pybtex.database.input import bibtex
 except ImportError:
-    pybtex = None
-    bibtex = None
+    pybtex = bibtex = None
 
 from pymatgen.core.structure import Molecule, Structure
 
@@ -83,6 +79,8 @@ class HistoryNode(namedtuple("HistoryNode", ["name", "url", "description"])):
         Structure (dict).
     """
 
+    __slots__ = ()
+
     def as_dict(self) -> dict[str, str]:
         """
         Returns: Dict
@@ -133,6 +131,8 @@ class Author(namedtuple("Author", ["name", "email"])):
         Email of author (String)
     """
 
+    __slots__ = ()
+
     def __str__(self):
         """
         String representation of an Author
@@ -244,7 +244,7 @@ class StructureNL:
             raise ValueError("Invalid format for SNL reference! Should be BibTeX string.")
         if len(references) > MAX_BIBTEX_CHARS:
             raise ValueError(
-                f"The BibTeX string must be fewer than {MAX_BIBTEX_CHARS} chars " f", you have {len(references)}"
+                f"The BibTeX string must be fewer than {MAX_BIBTEX_CHARS} chars, you have {len(references)}"
             )
 
         self.references = references
@@ -254,9 +254,9 @@ class StructureNL:
         self.remarks = [remarks] if isinstance(remarks, str) else remarks
 
         # check remarks limit
-        for r in self.remarks:
-            if len(r) > 140:
-                raise ValueError(f"The remark exceeds the maximum size of140 characters: {r}")
+        for remark in self.remarks:
+            if len(remark) > 140:
+                raise ValueError(f"The remark exceeds the maximum size of 140 characters: {remark}")
 
         # check data limit
         self.data = data or {}
@@ -266,11 +266,11 @@ class StructureNL:
                 f"bytes (you have {sys.getsizeof(data)})"
             )
 
-        for k in self.data:
-            if not k.startswith("_"):
+        for key in self.data:
+            if not key.startswith("_"):
                 raise ValueError(
                     "data must contain properly namespaced data with keys starting with an underscore. "
-                    f"The key {k} does not start with an underscore."
+                    f"The key {key} does not start with an underscore."
                 )
 
         # check for valid history nodes
@@ -321,11 +321,11 @@ class StructureNL:
         return cls(
             structure,
             a["authors"],
-            projects=a.get("projects", None),
+            projects=a.get("projects"),
             references=a.get("references", ""),
-            remarks=a.get("remarks", None),
+            remarks=a.get("remarks"),
             data=data,
-            history=a.get("history", None),
+            history=a.get("history"),
             created_at=created_at,
         )
 
