@@ -1,6 +1,3 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 Common test support for pymatgen test scripts.
 
@@ -9,18 +6,21 @@ tests in a single location, so that test scripts can just import it and work
 right away.
 """
 
+from __future__ import annotations
+
 import json
+import string
 import tempfile
 import unittest
 from pathlib import Path
+from typing import ClassVar
 
-import numpy.testing as nptu
-from monty.dev import requires
+import pytest
 from monty.json import MontyDecoder, MSONable
 from monty.serialization import loadfn
+from numpy.testing import assert_allclose
 
-from pymatgen.core import SETTINGS
-from pymatgen.ext.matproj import _MPResterLegacy as MPRester
+from pymatgen.core import SETTINGS, Structure
 
 
 class PymatgenTest(unittest.TestCase):
@@ -43,88 +43,44 @@ class PymatgenTest(unittest.TestCase):
         )
         TEST_FILES_DIR = MODULE_DIR / ".." / ".." / "test_files"
 
-    TEST_STRUCTURES = {}  # Dict for test structures to aid testing.
+    TEST_STRUCTURES: ClassVar[dict[str, Structure]] = {}  # Dict for test structures to aid testing.
     for fn in STRUCTURES_DIR.iterdir():
         TEST_STRUCTURES[fn.name.rsplit(".", 1)[0]] = loadfn(str(fn))
 
+    @pytest.fixture(autouse=True)  # make all tests run a in a temporary directory accessible via self.tmp_path
+    def _tmp_dir(self, tmp_path: Path, monkeypatch: pytest.MonkeyPatch) -> None:
+        # https://pytest.org/en/latest/how-to/unittest.html#using-autouse-fixtures-and-accessing-other-fixtures
+        monkeypatch.chdir(tmp_path)  # change to pytest-provided temporary directory
+        self.tmp_path = tmp_path
+
     @classmethod
-    def get_structure(cls, name):
+    def get_structure(cls, name: str) -> Structure:
         """
         Get a structure from the template directories.
 
-        :param name: Name of a structure.
-        :return: Structure
+        Args:
+            name (str): Name of structure file.
+
+        Returns:
+            Structure
         """
         return cls.TEST_STRUCTURES[name].copy()
 
-    @classmethod
-    @requires(SETTINGS.get("PMG_MAPI_KEY"), "PMG_MAPI_KEY needs to be set.")
-    def get_mp_structure(cls, mpid):
+    @staticmethod
+    def assert_all_close(actual, desired, decimal=7, err_msg="", verbose=True):
         """
-        Get a structure from MP.
-
-        :param mpid: Materials Project id.
-        :return: Structure
+        Tests if two arrays are almost equal up to some relative or absolute tolerance.
         """
-        m = MPRester()
-        return m.get_structure_by_material_id(mpid)
+        # TODO (janosh): replace the decimal kwarg with assert_allclose() atol and rtol kwargs
+        return assert_allclose(actual, desired, atol=10**-decimal, err_msg=err_msg, verbose=verbose)
 
     @staticmethod
-    def assertArrayAlmostEqual(actual, desired, decimal=7, err_msg="", verbose=True):
-        """
-        Tests if two arrays are almost equal to a tolerance. The CamelCase
-        naming is so that it is consistent with standard unittest methods.
-        """
-        return nptu.assert_almost_equal(actual, desired, decimal, err_msg, verbose)
-
-    @staticmethod
-    def assertDictsAlmostEqual(actual, desired, decimal=7, err_msg="", verbose=True):
-        """
-        Tests if two arrays are almost equal to a tolerance. The CamelCase
-        naming is so that it is consistent with standard unittest methods.
-        """
-        for k, v in actual.items():
-            if k not in desired:
-                return False
-            v2 = desired[k]
-            if isinstance(v, dict):
-                pass_test = PymatgenTest.assertDictsAlmostEqual(
-                    v, v2, decimal=decimal, err_msg=err_msg, verbose=verbose
-                )
-                if not pass_test:
-                    return False
-            elif isinstance(v, (list, tuple)):
-                pass_test = nptu.assert_almost_equal(v, v2, decimal, err_msg, verbose)
-                if not pass_test:
-                    return False
-            elif isinstance(v, (int, float)):
-                PymatgenTest().assertAlmostEqual(v, v2)  # pylint: disable=E1120
-            else:
-                assert v == v2
-        return True
-
-    @staticmethod
-    def assertArrayEqual(actual, desired, err_msg="", verbose=True):
-        """
-        Tests if two arrays are equal. The CamelCase naming is so that it is
-         consistent with standard unittest methods.
-        """
-        return nptu.assert_equal(actual, desired, err_msg=err_msg, verbose=verbose)
-
-    @staticmethod
-    def assertStrContentEqual(actual, desired, err_msg="", verbose=True):
+    def assert_str_content_equal(actual, expected):
         """
         Tests if two strings are equal, ignoring things like trailing spaces, etc.
         """
-        lines1 = actual.split("\n")
-        lines2 = desired.split("\n")
-        if len(lines1) != len(lines2):
-            return False
-        failed = []
-        for l1, l2 in zip(lines1, lines2):
-            if l1.strip() != l2.strip():
-                failed.append(f"{l1} != {l2}")
-        return len(failed) == 0
+        strip_whitespace = {ord(c): None for c in string.whitespace}
+        return actual.translate(strip_whitespace) == expected.translate(strip_whitespace)
 
     def serialize_with_pickle(self, objects, protocols=None, test_eq=True):
         """
@@ -138,6 +94,8 @@ class PymatgenTest(unittest.TestCase):
             objects: Object or list of objects.
             protocols: List of pickle protocols to test. If protocols is None,
                 HIGHEST_PROTOCOL is tested.
+            test_eq: If True, the deserialized object is compared with the
+                original object using the __eq__ method.
 
         Returns:
             Nested list with the objects deserialized with the specified
@@ -146,8 +104,6 @@ class PymatgenTest(unittest.TestCase):
         # Use the python version so that we get the traceback in case of errors
         import pickle
 
-        from pymatgen.util.serialization import pmg_pickle_dump, pmg_pickle_load
-
         # Build a list even when we receive a single object.
         got_single_object = False
         if not isinstance(objects, (list, tuple)):
@@ -168,22 +124,22 @@ class PymatgenTest(unittest.TestCase):
 
             try:
                 with open(tmpfile, mode) as fh:
-                    pmg_pickle_dump(objects, fh, protocol=protocol)
+                    pickle.dump(objects, fh, protocol=protocol)
             except Exception as exc:
-                errors.append(f"pickle.dump with protocol {protocol} raised:\n{exc}")
+                errors.append(f"pickle.dump with {protocol=} raised:\n{exc}")
                 continue
 
             try:
                 with open(tmpfile, "rb") as fh:
-                    new_objects = pmg_pickle_load(fh)
+                    new_objects = pickle.load(fh)
             except Exception as exc:
-                errors.append(f"pickle.load with protocol {protocol} raised:\n{exc}")
+                errors.append(f"pickle.load with {protocol=} raised:\n{exc}")
                 continue
 
             # Test for equality
             if test_eq:
                 for old_obj, new_obj in zip(objects, new_objects):
-                    self.assertEqual(old_obj, new_obj)
+                    assert old_obj == new_obj
 
             # Save the deserialized objects and test for equality.
             objects_by_protocol.append(new_objects)
@@ -196,15 +152,14 @@ class PymatgenTest(unittest.TestCase):
             return [o[0] for o in objects_by_protocol]
         return objects_by_protocol
 
-    def assertMSONable(self, obj, test_if_subclass=True):
+    def assert_msonable(self, obj, test_if_subclass=True):
         """
-        Tests if obj is MSONable and tries to verify whether the contract is
-        fulfilled.
+        Test if obj is MSONable and verify the contract is fulfilled.
 
         By default, the method tests whether obj is an instance of MSONable.
-        This check can be deactivated by setting test_if_subclass to False.
+        This check can be deactivated by setting test_if_subclass=False.
         """
         if test_if_subclass:
-            self.assertIsInstance(obj, MSONable)
-        self.assertDictEqual(obj.as_dict(), obj.__class__.from_dict(obj.as_dict()).as_dict())
+            assert isinstance(obj, MSONable)
+        assert obj.as_dict() == obj.__class__.from_dict(obj.as_dict()).as_dict()
         json.loads(obj.to_json(), cls=MontyDecoder)
