@@ -1,9 +1,6 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
+from __future__ import annotations
 
 import os
-import unittest
 
 from pymatgen.util.io_utils import micro_pyawk
 from pymatgen.util.testing import PymatgenTest
@@ -21,8 +18,4 @@ class FuncTest(PymatgenTest):
             return y
 
         micro_pyawk(filename, [["POTCAR:(.*)", f2, f]])
-        self.assertEqual(len(data), 6)
-
-
-if __name__ == "__main__":
-    unittest.main()
+        assert len(data) == 6
