@@ -1,4 +1,4 @@
-import unittest
+from __future__ import annotations
 
 from pymatgen.util.plotting import periodic_table_heatmap, van_arkel_triangle
 from pymatgen.util.testing import PymatgenTest
@@ -12,8 +12,8 @@ class FuncTestCase(PymatgenTest):
             "Th": 1.2475885304040335,
             "Ni": -2.0354391922547705,
         }
-        _ = periodic_table_heatmap(random_data, cmap="plasma")
         _ = periodic_table_heatmap(random_data)
+        _ = periodic_table_heatmap(random_data, cmap="plasma")
         _ = periodic_table_heatmap(random_data, max_row=7)
         _ = periodic_table_heatmap(random_data, max_row=10)
         _ = periodic_table_heatmap(random_data, cbar_label_size=18)
@@ -30,7 +30,3 @@ class FuncTestCase(PymatgenTest):
         random_list = [("Fe", "C"), ("Ni", "F")]
         _ = van_arkel_triangle(random_list)
         _ = van_arkel_triangle(random_list, annotate=True)
-
-
-if __name__ == "__main__":
-    unittest.main()
