@@ -1,10 +1,10 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
+from __future__ import annotations
 
 import datetime
 import unittest
 
 import numpy as np
+import pytest
 
 from pymatgen.core.structure import Molecule, Structure
 from pymatgen.util.provenance import Author, HistoryNode, StructureNL
@@ -74,22 +74,22 @@ class StructureNLCase(unittest.TestCase):
 
     def test_authors(self):
         a = StructureNL(self.s, self.hulk, references=self.pmg)
-        self.assertEqual(a.authors[0].name, "Hulk")
-        self.assertEqual(a.authors[0].email, "hulk@avengers.com")
+        assert a.authors[0].name == "Hulk"
+        assert a.authors[0].email == "hulk@avengers.com"
 
         a = StructureNL(self.s, self.america, references=self.pmg)
-        self.assertEqual(a.authors[0].name, "Captain America")
-        self.assertEqual(a.authors[0].email, "captainamerica@avengers.com")
+        assert a.authors[0].name == "Captain America"
+        assert a.authors[0].email == "captainamerica@avengers.com"
 
         a = StructureNL(self.s, self.thor, references=self.pmg)
-        self.assertEqual(a.authors[0].name, "Thor")
-        self.assertEqual(a.authors[0].email, "thor@avengers.com")
+        assert a.authors[0].name == "Thor"
+        assert a.authors[0].email == "thor@avengers.com"
 
         a = StructureNL(self.s, self.duo, references=self.pmg)
-        self.assertEqual(a.authors[0].name, "Iron Man")
-        self.assertEqual(a.authors[0].email, "ironman@avengers.com")
-        self.assertEqual(a.authors[1].name, "Black Widow")
-        self.assertEqual(a.authors[1].email, "blackwidow@avengers.com")
+        assert a.authors[0].name == "Iron Man"
+        assert a.authors[0].email == "ironman@avengers.com"
+        assert a.authors[1].name == "Black Widow"
+        assert a.authors[1].email == "blackwidow@avengers.com"
         StructureNL(self.s, self.hulk, references=self.pmg)
 
     def test_references(self):
@@ -97,10 +97,17 @@ class StructureNLCase(unittest.TestCase):
         StructureNL(self.s, self.hulk, references="")
 
         # An empty list should not work
-        self.assertRaises(ValueError, StructureNL, self.s, self.hulk, references=[])
+        with pytest.raises(
+            ValueError,
+            match="Invalid format for SNL reference! Should be empty string or BibTeX string.",
+        ):
+            StructureNL(self.s, self.hulk, references=[])
 
         # junk reference should not work
-        self.assertRaises(ValueError, StructureNL, self.s, self.hulk, references=self.junk)
+        with pytest.raises(ValueError) as exc:
+            StructureNL(self.s, self.hulk, references=self.junk)
+
+        assert "Invalid format for SNL reference! Should be BibTeX string." in str(exc.value)
 
         # good references should be ok
         StructureNL(self.s, self.hulk, references=self.pmg)
@@ -109,38 +116,50 @@ class StructureNLCase(unittest.TestCase):
         StructureNL(self.s, self.hulk, references=self.unicode_title)
 
         # multi-line references should be OK
-        StructureNL(self.s, self.hulk, references="\n".join([self.matproj, self.pmg]))
+        StructureNL(self.s, self.hulk, references=f"{self.matproj}\n{self.pmg}")
 
         # super long references are bad
-        self.assertRaises(ValueError, StructureNL, self.s, self.hulk, references=self.superlong)
+        with pytest.raises(ValueError) as exc:
+            StructureNL(self.s, self.hulk, references=self.superlong)
 
-    def test_historynodes(self):
+        assert "The BibTeX string must be fewer than 20000 chars, you have 60030" in str(exc.value)
+
+    def test_history_nodes(self):
         a = StructureNL(self.s, self.hulk, history=[self.valid_node])
-        self.assertEqual(a.history[0].name, "DB 1")
-        self.assertEqual(a.history[0].url, "www.db1URLgoeshere.com")
-        self.assertEqual(a.history[0].description, {"db1_id": 12424})
+        assert a.history[0].name == "DB 1"
+        assert a.history[0].url == "www.db1URLgoeshere.com"
+        assert a.history[0].description == {"db1_id": 12424}
 
         a = StructureNL(self.s, self.hulk, history=[self.valid_node, self.valid_node2])
-        self.assertEqual(a.history[1].name, "DB 2")
-        self.assertEqual(a.history[1].url, "www.db2URLgoeshere.com")
-        self.assertEqual(a.history[1].description, {"db2_id": 12424})
+        assert a.history[1].name == "DB 2"
+        assert a.history[1].url == "www.db2URLgoeshere.com"
+        assert a.history[1].description == {"db2_id": 12424}
 
         # invalid nodes should not work
-        self.assertRaises(Exception, StructureNL, self.s, self.hulk, history=[self.invalid_node])
+        with pytest.raises(KeyError, match="description"):
+            StructureNL(self.s, self.hulk, history=[self.invalid_node])
 
         # too many nodes should not work
-        self.assertRaises(ValueError, StructureNL, self.s, self.hulk, history=[self.valid_node] * 1000)
+        n_nodes = 1000
+        with pytest.raises(ValueError) as exc:
+            StructureNL(self.s, self.hulk, history=[self.valid_node] * n_nodes)
+
+        assert f"A maximum of 100 History nodes are supported, you have {n_nodes}!" in str(exc.value)
 
     def test_data(self):
         # Structure data is OK due to PMGEncoder/Decoder
         a = StructureNL(self.s, self.hulk, data={"_structure": self.s2})
-        self.assertEqual(a.data["_structure"], self.s2, "Data storage is broken")
-        self.assertRaises(ValueError, StructureNL, self.s, self.hulk, data={"bad_key": 1})
+        assert a.data["_structure"] == self.s2, "Data storage is broken"
+        with pytest.raises(ValueError, match="data must contain properly namespaced data with keys starting "):
+            StructureNL(self.s, self.hulk, data={"bad_key": 1})
 
     def test_remarks(self):
         a = StructureNL(self.s, self.hulk, remarks="string format")
-        self.assertEqual(a.remarks[0], "string format")
-        self.assertRaises(ValueError, StructureNL, self.s, self.hulk, remarks=self.remark_fail)
+        assert a.remarks[0] == "string format"
+        with pytest.raises(ValueError) as exc:
+            StructureNL(self.s, self.hulk, remarks=self.remark_fail)
+
+        assert "The remark exceeds the maximum size of 140 characters: " in str(exc.value)
 
     def test_eq(self):
         # test basic Equal()
@@ -165,7 +184,7 @@ class StructureNLCase(unittest.TestCase):
             [self.valid_node, self.valid_node2],
             created_at,
         )
-        self.assertEqual(a, b, "__eq__() method is broken! false negative")
+        assert a == b, "__eq__() method is broken! false negative"
 
         # change the created at date, now they are no longer equal
         created_at = datetime.datetime.now() + datetime.timedelta(days=-1)
@@ -179,7 +198,7 @@ class StructureNLCase(unittest.TestCase):
             [self.valid_node, self.valid_node2],
             created_at,
         )
-        self.assertNotEqual(a, c, "__eq__() method is broken! false positive")
+        assert a != c, "__eq__() method is broken! false positive"
 
         # or try a different structure, those should not be equal
         d = StructureNL(
@@ -192,7 +211,7 @@ class StructureNLCase(unittest.TestCase):
             [self.valid_node, self.valid_node2],
             created_at,
         )
-        self.assertNotEqual(a, d, "__eq__() method is broken! false positive")
+        assert a != d, "__eq__() method is broken! false positive"
 
     def test_to_from_dict(self):
         # no complicated objects in the 'data' or 'nodes' field
@@ -206,7 +225,7 @@ class StructureNLCase(unittest.TestCase):
             [self.valid_node, self.valid_node2],
         )
         b = StructureNL.from_dict(a.as_dict())
-        self.assertEqual(a, b)
+        assert a == b
         # complicated objects in the 'data' and 'nodes' field
         complicated_node = {
             "name": "complicated node",
@@ -223,16 +242,12 @@ class StructureNLCase(unittest.TestCase):
             [complicated_node, self.valid_node],
         )
         b = StructureNL.from_dict(a.as_dict())
-        self.assertEqual(
-            a,
-            b,
-            "to/from dict is broken when object embedding is used! Apparently MontyEncoding is broken...",
-        )
+        assert a == b, "to/from dict is broken when object embedding is used! Apparently MontyEncoding is broken..."
 
         # Test molecule
         molnl = StructureNL(self.mol, self.hulk, references=self.pmg)
         b = StructureNL.from_dict(molnl.as_dict())
-        self.assertEqual(molnl, b)
+        assert molnl == b
 
     def test_from_structures(self):
         s1 = Structure([[5, 0, 0], [0, 5, 0], [0, 0, 5]], ["Fe"], [[0, 0, 0]])
@@ -241,14 +256,10 @@ class StructureNLCase(unittest.TestCase):
         authors = "Test User <test@materialsproject.com>"
         snl_list = StructureNL.from_structures([s1, s2], authors, remarks=remarks)
 
-        self.assertEqual(len(snl_list), 2)
+        assert len(snl_list) == 2
         snl1 = snl_list[0]
         snl2 = snl_list[1]
-        self.assertEqual(snl1.remarks, remarks)
-        self.assertEqual(snl2.remarks, remarks)
-        self.assertEqual(snl1.authors, [Author.parse_author(authors)])
-        self.assertEqual(snl2.authors, [Author.parse_author(authors)])
-
-
-if __name__ == "__main__":
-    unittest.main()
+        assert snl1.remarks == remarks
+        assert snl2.remarks == remarks
+        assert snl1.authors == [Author.parse_author(authors)]
+        assert snl2.authors == [Author.parse_author(authors)]
