@@ -1,10 +1,9 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module defines generic plotters.
 """
 
+from __future__ import annotations
+
 import importlib
 
 from pymatgen.util.plotting import pretty_plot
@@ -76,10 +75,7 @@ class SpectrumPlotter:
             dos_dict: dict of {label: Dos}
             key_sort_func: function used to sort the dos_dict keys.
         """
-        if key_sort_func:
-            keys = sorted(spectra_dict, key=key_sort_func)
-        else:
-            keys = list(spectra_dict)
+        keys = sorted(spectra_dict, key=key_sort_func) if key_sort_func else list(spectra_dict)
         for label in keys:
             self.add_spectra(label, spectra_dict[label])
 
