@@ -1,10 +1,9 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
-
 """
 This module contains classes to wrap Python VTK to make nice molecular plots.
 """
 
+from __future__ import annotations
+
 import itertools
 import math
 import os
@@ -13,6 +12,7 @@ import time
 from typing import Sequence
 
 import numpy as np
+from frozendict import frozendict
 
 try:
     import vtk
@@ -93,7 +93,6 @@ class StructureVis:
         self.ren_win.AddRenderer(self.ren)
         self.ren.SetBackground(1, 1, 1)
         self.title = "Structure Visualizer"
-        # create a renderwindowinteractor
         self.iren = vtk.vtkRenderWindowInteractor()
         self.iren.SetRenderWindow(self.ren_win)
         self.mapper_map = {}
@@ -192,19 +191,19 @@ class StructureVis:
         """
         Display the help for various keyboard shortcuts.
         """
-        helptxt = [
+        help_text = [
             "h : Toggle help",
             "A/a, B/b or C/c : Increase/decrease cell by one a, b or c unit vector",
             "# : Toggle showing of polyhedrons",
             "-: Toggle showing of bonds",
             "r : Reset camera direction",
-            "[/]: Decrease or increase poly_radii_tol_factor by 0.05. Value = " + str(self.poly_radii_tol_factor),
+            f"[/]: Decrease or increase poly_radii_tol_factor by 0.05. Value = {self.poly_radii_tol_factor}",
             "Up/Down: Rotate view along Up direction by 90 clockwise/anticlockwise",
             "Left/right: Rotate view along camera direction by 90 clockwise/anticlockwise",
             "s: Save view to image.png",
             "o: Orthogonalize structure",
         ]
-        self.helptxt_mapper.SetInput("\n".join(helptxt))
+        self.helptxt_mapper.SetInput("\n".join(help_text))
         self.helptxt_actor.SetPosition(10, 10)
         self.helptxt_actor.VisibilityOn()
 
@@ -247,9 +246,9 @@ class StructureVis:
                 self.add_line((0, 0, 0), vec, colors[count])
                 self.add_text(vec, labels[count], colors[count])
                 count += 1
-            for (vec1, vec2) in itertools.permutations(matrix, 2):
+            for vec1, vec2 in itertools.permutations(matrix, 2):
                 self.add_line(vec1, vec1 + vec2)
-            for (vec1, vec2, vec3) in itertools.permutations(matrix, 3):
+            for vec1, vec2, vec3 in itertools.permutations(matrix, 3):
                 self.add_line(vec1 + vec2, vec1 + vec2 + vec3)
 
         if self.show_bonds or self.show_polyhedron:
@@ -257,10 +256,7 @@ class StructureVis:
             anion = elements[-1]
 
             def contains_anion(site):
-                for sp in site.species:
-                    if sp.symbol == anion.symbol:
-                        return True
-                return False
+                return any(sp.symbol == anion.symbol for sp in site.species)
 
             anion_radius = anion.average_ionic_radius
             for site in s:
@@ -439,13 +435,13 @@ class StructureVis:
         source.SetPoint1(start)
         source.SetPoint2(end)
 
-        vertexIDs = vtk.vtkStringArray()
-        vertexIDs.SetNumberOfComponents(1)
-        vertexIDs.SetName("VertexIDs")
+        vertex_ids = vtk.vtkStringArray()
+        vertex_ids.SetNumberOfComponents(1)
+        vertex_ids.SetName("VertexIDs")
         # Set the vertex labels
-        vertexIDs.InsertNextValue("a")
-        vertexIDs.InsertNextValue("b")
-        source.GetOutput().GetPointData().AddArray(vertexIDs)
+        vertex_ids.InsertNextValue("a")
+        vertex_ids.InsertNextValue("b")
+        source.GetOutput().GetPointData().AddArray(vertex_ids)
 
         mapper = vtk.vtkPolyDataMapper()
         mapper.SetInputConnection(source.GetOutputPort())
@@ -626,8 +622,8 @@ class StructureVis:
                     ii2 = np.mod(ii + 1, len(face))
                     points.InsertNextPoint(face[ii2][0], face[ii2][1], face[ii2][2])
                     points.InsertNextPoint(center[0], center[1], center[2])
-                    for ii in range(3):
-                        triangle.GetPointIds().SetId(ii, ii)
+                    for jj in range(3):
+                        triangle.GetPointIds().SetId(jj, jj)
                     triangles = vtk.vtkCellArray()
                     triangles.InsertNextCell(triangle)
                     trianglePolyData = vtk.vtkPolyData()
@@ -739,8 +735,8 @@ class StructureVis:
                     for site in self.mapper_map[mapper]:
                         row = [
                             f"{site.species_string} - ",
-                            ", ".join([f"{c:.3f}" for c in site.frac_coords]),
-                            "[" + ", ".join([f"{c:.3f}" for c in site.coords]) + "]",
+                            ", ".join(f"{c:.3f}" for c in site.frac_coords),
+                            "[" + ", ".join(f"{c:.3f}" for c in site.coords) + "]",
                         ]
                         output.append("".join(row))
                     self.helptxt_mapper.SetInput("\n".join(output))
@@ -780,7 +776,7 @@ class StructureVis:
                     site = self.mapper_map[mapper]
                     output = [
                         site.species_string,
-                        "Frac. coords: " + " ".join([f"{c:.4f}" for c in site.frac_coords]),
+                        "Frac. coords: " + " ".join(f"{c:.4f}" for c in site.frac_coords),
                     ]
                     source.SetText("\n".join(output))
                     follower.SetPosition(pick_pos)
@@ -916,11 +912,11 @@ def make_movie(structures, output_filename="movie.mp4", zoom=1.0, fps=20, bitrat
     vis.redraw()
     vis.zoom(zoom)
     sigfig = int(math.floor(math.log10(len(structures))) + 1)
-    filename = "image{0:0" + str(sigfig) + "d}.png"
+    filename = f"image{{0:0{sigfig}d}}.png"
     for i, s in enumerate(structures):
         vis.set_structure(s)
         vis.write_image(filename.format(i), 3)
-    filename = "image%0" + str(sigfig) + "d.png"
+    filename = f"image%0{sigfig}d.png"
     args = [
         "ffmpeg",
         "-y",
@@ -943,12 +939,12 @@ class MultiStructuresVis(StructureVis):
     Visualization for multiple structures.
     """
 
-    DEFAULT_ANIMATED_MOVIE_OPTIONS = {
-        "time_between_frames": 0.1,
-        "looping_type": "restart",
-        "number_of_loops": 1,
-        "time_between_loops": 1.0,
-    }
+    DEFAULT_ANIMATED_MOVIE_OPTIONS = frozendict(
+        time_between_frames=0.1,
+        looping_type="restart",
+        number_of_loops=1,
+        time_between_loops=1.0,
+    )
 
     def __init__(
         self,
@@ -1051,9 +1047,8 @@ class MultiStructuresVis(StructureVis):
         tags = {}
         for tag in self.tags:
             istruct = tag.get("istruct", "all")
-            if istruct != "all":
-                if istruct != self.istruct:
-                    continue
+            if istruct != "all" and istruct != self.istruct:
+                continue
             site_index = tag["site_index"]
             color = tag.get("color", [0.5, 0.5, 0.5])
             opacity = tag.get("opacity", 0.5)
@@ -1132,7 +1127,7 @@ class MultiStructuresVis(StructureVis):
             "# : Toggle showing of polyhedrons",
             "-: Toggle showing of bonds",
             "r : Reset camera direction",
-            "[/]: Decrease or increase poly_radii_tol_factor by 0.05. Value = " + str(self.poly_radii_tol_factor),
+            f"[/]: Decrease or increase poly_radii_tol_factor by 0.05. Value = {self.poly_radii_tol_factor}",
             "Up/Down: Rotate view along Up direction by 90 clockwise/anticlockwise",
             "Left/right: Rotate view along camera direction by 90 clockwise/anticlockwise",
             "s: Save view to image.png",
@@ -1207,7 +1202,7 @@ class MultiStructuresInteractorStyle(StructureInteractorStyle):
     Interactor for MultiStructureVis.
     """
 
-    def __init__(self, parent):
+    def __init__(self, parent) -> None:
         """
         Args:
             parent ():
@@ -1238,7 +1233,6 @@ class MultiStructuresInteractorStyle(StructureInteractorStyle):
                 parent.display_warning("FIRST STRUCTURE")
                 parent.ren_win.Render()
             else:
-
                 parent.istruct -= 1
                 parent.current_structure = parent.structures[parent.istruct]
                 parent.set_structure(parent.current_structure, reset_camera=False, to_unit_cell=False)
