@@ -1,9 +1,7 @@
-# Copyright (c) Pymatgen Development Team.
-# Distributed under the terms of the MIT License.
+from __future__ import annotations
 
 import json
 import os
-import unittest
 
 import numpy as np
 from monty.json import MontyDecoder
@@ -42,7 +40,3 @@ class SpectrumPlotterTest(PymatgenTest):
         self.plotter.add_spectrum("LiCoO2 + noise", xanes, "r")
         plt = self.plotter.get_plot()
         plt.close("all")
-
-
-if __name__ == "__main__":
-    unittest.main()
